'All variables will be of type LONG unless explicitly defined
DefLng A-Z

'All arrays will be dynamically allocated so they can be REDIM-ed
'$DYNAMIC

'We need console access to support command-line compilation via the -x command line compile option
$Console

'Initially the "SCREEN" will be hidden, if the -x option is used it will never be created
$ScreenHide

Dim Shared Version As String
Dim Shared DevChannel As String

Version = "2.2.1"
DevChannel = "Lite Edition"

'String SPacer/delimiter constants
'sp is used as the primary string spacer
'sp2 & sp3 are used when further delimiation is required
'for instance, sp2 is used for embedding spacing info for auto-layout by an IDE
Dim Shared sp As String * 1, sp2 As String * 1, sp3 As String * 1
sp = Chr$(13): sp2 = Chr$(10): sp3 = Chr$(26)
Dim Shared sp_asc As Long, sp2_asc As Long, sp3_asc As Long
sp_asc = Asc(sp): sp2_asc = Asc(sp2): sp3_asc = Asc(sp3)

'ASCII codes
Const ASC_BACKSLASH = 92
Const ASC_FORWARDSLASH = 47
Const ASC_LEFTBRACKET = 40
Const ASC_RIGHTBRACKET = 41
Const ASC_FULLSTOP = 46
Const ASC_COLON = 58
Const ASC_SEMICOLON = 59
Const ASC_UNDERSCORE = 95
Const ASC_QUOTE = 34
Const ASC_LEFTSQUAREBRACKET = 91
Const ASC_RIGHTSQUAREBRACKET = 93
Const ASC_QUESTIONMARK = 63

'_KEYDOWN/_KEYHIT codes
Const KEY_LSHIFT = 100304
Const KEY_RSHIFT = 100303
Const KEY_LCTRL = 100306
Const KEY_RCTRL = 100305
Const KEY_LALT = 100308
Const KEY_RALT = 100307
Const KEY_LAPPLE = 100310
Const KEY_RAPPLE = 100309
Const KEY_F1 = 15104
Const KEY_F2 = 15360
Const KEY_F3 = 15616
Const KEY_F4 = 15872
Const KEY_F5 = 16128
Const KEY_F6 = 16384
Const KEY_F7 = 16640
Const KEY_F8 = 16896
Const KEY_F9 = 17152
Const KEY_F10 = 17408
Const KEY_F11 = 34048
Const KEY_F12 = 34304
Const KEY_INSERT = 20992
Const KEY_DELETE = 21248
Const KEY_HOME = 18176
Const KEY_END = 20224
Const KEY_PAGEUP = 18688
Const KEY_PAGEDOWN = 20736
Const KEY_LEFT = 19200
Const KEY_RIGHT = 19712
Const KEY_UP = 18432
Const KEY_DOWN = 20480
Const KEY_ESC = 27
Const KEY_ENTER = 13

Dim Shared CHR_QUOTE As String: CHR_QUOTE = Chr$(34)
Dim Shared CHR_TAB As String: CHR_TAB = Chr$(9)
Dim Shared CRLF As String: CRLF = Chr$(13) + Chr$(10) 'carriage return+line feed

Type GL_idstruct
    cn As String * 64 'case sensitive version of n
    subfunc As Integer 'if function=1, sub=2
    callname As String * 64
    args As Integer
    arg As String * 80 'similar to t
    ret As Long 'the value it returns if it is a function (again like t)
End Type

ReDim Shared GL_COMMANDS(2000) As GL_idstruct
Dim Shared GL_HELPER_CODE As String
Dim Shared GL_COMMANDS_LAST
ReDim Shared GL_DEFINES(2000) As String 'average ~600 entries
ReDim Shared GL_DEFINES_VALUE(2000) As _Integer64
Dim Shared GL_DEFINES_LAST
Dim Shared GL_KIT: GL_KIT = 0

'INI Manager
'Fellippe Heitor, 2017-2021 - fellippe@qb64.org - @fellippeheitor

'This file isn't required to be at the top of your programs,
'unless you intend to use OPTION _EXPLICIT

'Global variables declaration

Dim currentIniFileName$
Dim currentIniFileLOF As _Unsigned Long
Dim IniWholeFile$
Dim IniSectionData$
Dim IniPosition As _Unsigned Long
Dim IniNewFile$
Dim IniLastSection$
Dim IniLastKey$
Dim IniLF$
Dim IniDisableAutoCommit
Dim IniCODE
Dim IniAllowBasicComments
Dim IniForceReload
Dim IniDisableAddQuotes

DefLng A-Z

'-------- Optional IDE Component (1/2) --------
'Allow the window to be resized
$Resize:On

_ControlChr Off

If _DirExists("internal") = 0 Then GoTo NoInternalFolder

Dim Shared AltSpecial As _Byte

Dim Shared IDEBuildModeChanged
Dim Shared IdeInfo As String

Dim Shared startPausedPending As _Byte

Dim Shared IdeSystem As Long
'1=Entering text into the main IDE window
'2=Entering text into the quick search bar
'3=Scrolling within the help window
IdeSystem = 1

Dim Shared IdeRecentLink(1 To 6, 1 To 2) As String
Dim Shared IdeOpenFile As String 'makes IdeOpen directly open the file passed
Dim Shared fileDlgSearchTerm$

Type IdeBmkType
    y As Long 'the vertical line
    x As Long 'the horizontal position to move cursor to
    reserved As Long
    reserved2 As Long
End Type
ReDim Shared IdeBmk(1) As IdeBmkType
Dim Shared IdeBmkN

Type QuickNavType
    As Long idesx, idesy, idecx, idecy
End Type

Dim Shared QuickNavTotal As Long
Dim Shared QuickNavHistory(0) As QuickNavType

ReDim Shared IdeBreakpoints(1) As _Byte
ReDim Shared IdeSkipLines(1) As _Byte

'GetInput global variables
Dim Shared iCHECKLATER 'the values will be checked later
Dim Shared iCHANGED
Dim Shared mX, mY
Dim Shared mB, mB2
Dim Shared mOB, mOB2
Dim Shared mCLICK, mCLICK2
Dim Shared mRELEASE, mRELEASE2
Dim Shared mWHEEL
Dim Shared KB '_KEYHIT value (or 0)
Dim Shared K$ 'INKEY$ equivalent of _KEYHIT's return (or "")
Dim Shared KSTATECHANGED
Dim Shared KSHIFT
Dim Shared KCTRL 'the control key
Dim Shared KCONTROL 'PC-CTRL
Dim Shared KALT, KOALT, KALTPRESS, KALTRELEASE

Dim Shared block_chr(255) As Integer
block_chr(10) = 1
block_chr(13) = 1

Dim Shared idecurrentlinelayout As String
Dim Shared idecurrentlinelayouti As Long
Dim Shared idelayoutallow As Long

Dim Shared listOfKeywords$, listOfCustomKeywords$, customKeywordsLength As Long
listOfKeywords$ = "@?@$CHECKING@$ERROR@$CONSOLE@ONLY@$DYNAMIC@$ELSE@$ELSEIF@$END@$ENDIF@$EXEICON@$IF@$INCLUDE@$LET@$RESIZE@$SCREENHIDE@$SCREENSHOW@$STATIC@$VERSIONINFO@$VIRTUALKEYBOARD@ABS@ABSOLUTE@ACCESS@ALIAS@AND@APPEND@AS@ASC@ATN@BASE@BEEP@BINARY@BLOAD@BSAVE@BYVAL@CALL@CALLS@CASE@IS@CDBL@CDECL@CHAIN@CHDIR@CHR$@CINT@CIRCLE@CLEAR@CLNG@CLOSE@CLS@COLOR@COM@COMMAND$@COMMON@CONST@COS@CSNG@CSRLIN@CUSTOMTYPE@CVD@CVDMBF@CVI@CVL@CVS@CVSMBF@DATA@DATE$@DECLARE@DEF@DEFDBL@DEFINT@DEFLNG@DEFSNG@DEFSTR@DIM@DO@DOUBLE@DRAW@DYNAMIC@ELSE@ELSEIF@END@ENDIF@ENVIRON@ENVIRON$@EOF@EQV@ERASE@ERDEV@ERDEV$@ERL@ERR@ERROR@EVERYCASE@EXIT@EXP@FIELD@FILEATTR@FILES@FIX@FN@FOR@FRE@FREE@FREEFILE@FUNCTION@GET@GOSUB@GOTO@HEX$@IF@IMP@INKEY$@INP@INPUT@INPUT$@INSTR@INT@INTEGER@INTERRUPT@INTERRUPTX@IOCTL@IOCTL$@KEY@KILL@LBOUND@LCASE$@LEFT$@LEN@LET@LIBRARY@LINE@LIST@LOC@LOCATE@LOCK@LOF@LOG@LONG@LOOP@LPOS@LPRINT@LSET@LTRIM$@MID$@MKD$@MKDIR@MKDMBF$@MKI$@MKL$@MKS$@MKSMBF$@MOD@NAME@NEXT@NOT@OCT$@OFF@ON@OPEN@OPTION@OR@OUT@OUTPUT@PAINT@PALETTE@PCOPY@PEEK@PEN@PLAY@PMAP@POINT@POKE@POS@PRESET@PRINT@PSET@PUT@RANDOM@RANDOMIZE@READ@REDIM@REM@RESET@RESTORE@RESUME@RETURN@RIGHT$@RMDIR@RND@RSET@RTRIM$@RUN@SADD@SCREEN@SEEK@SEG@SELECT@SETMEM@SGN@SHARED@SHELL@SIGNAL@SIN@SINGLE@SLEEP@SOUND@SPACE$@SPC@SQR@STATIC@STEP@STICK@STOP@STR$@STRIG@STRING@STRING$@SUB@SWAP@SYSTEM@TAB@TAN@THEN@TIME$@TIMER@TO@TROFF@TRON@TYPE@UBOUND@UCASE$@UEVENT@UNLOCK@UNTIL@USING@VAL@VARPTR@VARPTR$@VARSEG@VIEW@WAIT@WEND@WHILE@WIDTH@WINDOW@WRITE@XOR@_ACOS@_ACOSH@_ALPHA@_ALPHA32@_ARCCOT@_ARCCSC@_ARCSEC@_ASIN@_ASINH@_ATAN2@_ATANH@_AUTODISPLAY@_AXIS@_BACKGROUNDCOLOR@_BIN$@_BIT@_BLEND@_BLINK@_BLUE@_BLUE32@_BUTTON@_BUTTONCHANGE@_BYTE@_CEIL@_CLEARCOLOR@_CLIP@_CLIPBOARD$@_CLIPBOARDIMAGE@_COMMANDCOUNT@_CONNECTED@_CONNECTIONADDRESS$@_CONNECTIONADDRESS@_CONSOLE@_CONSOLETITLE@_CONTINUE@_CONTROLCHR@_COPYIMAGE@_COPYPALETTE@_COSH@_COT@_COTH@_CSC@_CSCH@_CV@_CWD$@_D2G@_D2R@_DEFAULTCOLOR@_DEFINE@_DELAY@_DEPTHBUFFER@_DESKTOPHEIGHT@_DESKTOPWIDTH@_DEST@_DEVICE$@_DEVICEINPUT@_DEVICES@_DIR$@_DIREXISTS@_DISPLAY@_DISPLAYORDER@_DONTBLEND@_DONTWAIT@"
listOfKeywords$ = listOfKeywords$ + "_ERRORLINE@_ERRORMESSAGE$@_EXIT@_EXPLICIT@_EXPLICITARRAY@_FILEEXISTS@_FLOAT@_FONT@_FONTHEIGHT@_FONTWIDTH@_FREEFONT@_FREEIMAGE@_FREETIMER@_FULLSCREEN@_G2D@_G2R@_GLRENDER@_GREEN@_GREEN32@_HEIGHT@_HIDE@_HYPOT@_ICON@_INCLERRORFILE$@_INCLERRORLINE@_INTEGER64@_KEYCLEAR@_KEYDOWN@_KEYHIT@_LASTAXIS@_LASTBUTTON@_LASTWHEEL@_LIMIT@_LOADFONT@_LOADIMAGE@_MAPTRIANGLE@_MAPUNICODE@_MEM@_MEMCOPY@_MEMELEMENT@_MEMEXISTS@_MEMFILL@_MEMFREE@_MEMGET@_MEMIMAGE@_MEMSOUND@_MEMNEW@_MEMPUT@_MIDDLE@_MK$@_MOUSEBUTTON@_MOUSEHIDE@_MOUSEINPUT@_MOUSEMOVE@_MOUSEMOVEMENTX@_MOUSEMOVEMENTY@_MOUSEPIPEOPEN@_MOUSESHOW@_MOUSEWHEEL@_MOUSEX@_MOUSEY@_NEWIMAGE@_OFFSET@_OPENCLIENT@_OPENCONNECTION@_OPENHOST@_OS$@_PALETTECOLOR@_PI@_PIXELSIZE@_PRESERVE@_PRINTIMAGE@_PRINTMODE@_PRINTSTRING@_PRINTWIDTH@_PUTIMAGE@_R2D@_R2G@_RED@_RED32@_RESIZE@_RESIZEHEIGHT@_RESIZEWIDTH@_RGB@_RGB32@_RGBA@_RGBA32@_ROUND@_SCREENCLICK@_SCREENEXISTS@_SCREENHIDE@_SCREENICON@_SCREENIMAGE@_SCREENMOVE@_SCREENPRINT@_SCREENSHOW@_SCREENX@_SCREENY@_SEC@_SECH@_SETALPHA@_SHELLHIDE@_SINH@_SNDBAL@_SNDCLOSE@_SNDCOPY@_SNDGETPOS@_SNDLEN@_SNDLIMIT@_SNDLOOP@_SNDOPEN@_SNDOPENRAW@_SNDPAUSE@_SNDPAUSED@_SNDPLAY@_SNDPLAYCOPY@_SNDPLAYFILE@_SNDPLAYING@_SNDRATE@_SNDRAW@_SNDRAWDONE@_SNDRAWLEN@_SNDSETPOS@_SNDSTOP@_SNDVOL@_SOURCE@_STARTDIR$@_STRCMP@_STRICMP@_TANH@_TITLE@_TITLE$@_UNSIGNED@_WHEEL@_WIDTH@_WINDOWHANDLE@_WINDOWHASFOCUS@_GLACCUM@_GLALPHAFUNC@_GLARETEXTURESRESIDENT@_GLARRAYELEMENT@_GLBEGIN@_GLBINDTEXTURE@_GLBITMAP@_GLBLENDFUNC@_GLCALLLIST@_GLCALLLISTS@_GLCLEAR@_GLCLEARACCUM@_GLCLEARCOLOR@_GLCLEARDEPTH@_GLCLEARINDEX@_GLCLEARSTENCIL@_GLCLIPPLANE@_GLCOLOR3B@_GLCOLOR3BV@_GLCOLOR3D@_GLCOLOR3DV@_GLCOLOR3F@_GLCOLOR3FV@_GLCOLOR3I@_GLCOLOR3IV@_GLCOLOR3S@_GLCOLOR3SV@_GLCOLOR3UB@_GLCOLOR3UBV@_GLCOLOR3UI@_GLCOLOR3UIV@_GLCOLOR3US@_GLCOLOR3USV@_GLCOLOR4B@_GLCOLOR4BV@_GLCOLOR4D@_GLCOLOR4DV@_GLCOLOR4F@_GLCOLOR4FV@_GLCOLOR4I@_GLCOLOR4IV@_GLCOLOR4S@_GLCOLOR4SV@_GLCOLOR4UB@_GLCOLOR4UBV@_GLCOLOR4UI@_GLCOLOR4UIV@_GLCOLOR4US@_GLCOLOR4USV@_GLCOLORMASK@_GLCOLORMATERIAL@_GLCOLORPOINTER@_GLCOPYPIXELS@_GLCOPYTEXIMAGE1D@_GLCOPYTEXIMAGE2D@_GLCOPYTEXSUBIMAGE1D@"
listOfKeywords$ = listOfKeywords$ + "_GLCOPYTEXSUBIMAGE2D@_GLCULLFACE@_GLDELETELISTS@_GLDELETETEXTURES@_GLDEPTHFUNC@_GLDEPTHMASK@_GLDEPTHRANGE@_GLDISABLE@_GLDISABLECLIENTSTATE@_GLDRAWARRAYS@_GLDRAWBUFFER@_GLDRAWELEMENTS@_GLDRAWPIXELS@_GLEDGEFLAG@_GLEDGEFLAGPOINTER@_GLEDGEFLAGV@_GLENABLE@_GLENABLECLIENTSTATE@_GLEND@_GLENDLIST@_GLEVALCOORD1D@_GLEVALCOORD1DV@_GLEVALCOORD1F@_GLEVALCOORD1FV@_GLEVALCOORD2D@_GLEVALCOORD2DV@_GLEVALCOORD2F@_GLEVALCOORD2FV@_GLEVALMESH1@_GLEVALMESH2@_GLEVALPOINT1@_GLEVALPOINT2@_GLFEEDBACKBUFFER@_GLFINISH@_GLFLUSH@_GLFOGF@_GLFOGFV@_GLFOGI@_GLFOGIV@_GLFRONTFACE@_GLFRUSTUM@_GLGENLISTS@_GLGENTEXTURES@_GLGETBOOLEANV@_GLGETCLIPPLANE@_GLGETDOUBLEV@_GLGETERROR@_GLGETFLOATV@_GLGETINTEGERV@_GLGETLIGHTFV@_GLGETLIGHTIV@_GLGETMAPDV@_GLGETMAPFV@_GLGETMAPIV@_GLGETMATERIALFV@_GLGETMATERIALIV@_GLGETPIXELMAPFV@_GLGETPIXELMAPUIV@_GLGETPIXELMAPUSV@_GLGETPOINTERV@_GLGETPOLYGONSTIPPLE@_GLGETSTRING@_GLGETTEXENVFV@_GLGETTEXENVIV@_GLGETTEXGENDV@_GLGETTEXGENFV@_GLGETTEXGENIV@_GLGETTEXIMAGE@_GLGETTEXLEVELPARAMETERFV@_GLGETTEXLEVELPARAMETERIV@_GLGETTEXPARAMETERFV@_GLGETTEXPARAMETERIV@_GLHINT@_GLINDEXMASK@_GLINDEXPOINTER@_GLINDEXD@_GLINDEXDV@_GLINDEXF@_GLINDEXFV@_GLINDEXI@_GLINDEXIV@_GLINDEXS@_GLINDEXSV@_GLINDEXUB@_GLINDEXUBV@_GLINITNAMES@_GLINTERLEAVEDARRAYS@_GLISENABLED@_GLISLIST@_GLISTEXTURE@_GLLIGHTMODELF@_GLLIGHTMODELFV@_GLLIGHTMODELI@_GLLIGHTMODELIV@_GLLIGHTF@_GLLIGHTFV@_GLLIGHTI@_GLLIGHTIV@_GLLINESTIPPLE@_GLLINEWIDTH@_GLLISTBASE@_GLLOADIDENTITY@_GLLOADMATRIXD@_GLLOADMATRIXF@_GLLOADNAME@_GLLOGICOP@_GLMAP1D@_GLMAP1F@_GLMAP2D@_GLMAP2F@_GLMAPGRID1D@_GLMAPGRID1F@_GLMAPGRID2D@_GLMAPGRID2F@_GLMATERIALF@_GLMATERIALFV@_GLMATERIALI@_GLMATERIALIV@_GLMATRIXMODE@_GLMULTMATRIXD@_GLMULTMATRIXF@_GLNEWLIST@_GLNORMAL3B@_GLNORMAL3BV@_GLNORMAL3D@_GLNORMAL3DV@_GLNORMAL3F@_GLNORMAL3FV@_GLNORMAL3I@_GLNORMAL3IV@_GLNORMAL3S@_GLNORMAL3SV@_GLNORMALPOINTER@_GLORTHO@_GLPASSTHROUGH@_GLPIXELMAPFV@_GLPIXELMAPUIV@_GLPIXELMAPUSV@_GLPIXELSTOREF@_GLPIXELSTOREI@_GLPIXELTRANSFERF@_GLPIXELTRANSFERI@_GLPIXELZOOM@_GLPOINTSIZE@_GLPOLYGONMODE@_GLPOLYGONOFFSET@_GLPOLYGONSTIPPLE@"
listOfKeywords$ = listOfKeywords$ + "_GLPOPATTRIB@_GLPOPCLIENTATTRIB@_GLPOPMATRIX@_GLPOPNAME@_GLPRIORITIZETEXTURES@_GLPUSHATTRIB@_GLPUSHCLIENTATTRIB@_GLPUSHMATRIX@_GLPUSHNAME@_GLRASTERPOS2D@_GLRASTERPOS2DV@_GLRASTERPOS2F@_GLRASTERPOS2FV@_GLRASTERPOS2I@_GLRASTERPOS2IV@_GLRASTERPOS2S@_GLRASTERPOS2SV@_GLRASTERPOS3D@_GLRASTERPOS3DV@_GLRASTERPOS3F@_GLRASTERPOS3FV@_GLRASTERPOS3I@_GLRASTERPOS3IV@_GLRASTERPOS3S@_GLRASTERPOS3SV@_GLRASTERPOS4D@_GLRASTERPOS4DV@_GLRASTERPOS4F@_GLRASTERPOS4FV@_GLRASTERPOS4I@_GLRASTERPOS4IV@_GLRASTERPOS4S@_GLRASTERPOS4SV@_GLREADBUFFER@_GLREADPIXELS@_GLRECTD@_GLRECTDV@_GLRECTF@_GLRECTFV@_GLRECTI@_GLRECTIV@_GLRECTS@_GLRECTSV@_GLRENDERMODE@_GLROTATED@_GLROTATEF@_GLSCALED@_GLSCALEF@_GLSCISSOR@_GLSELECTBUFFER@_GLSHADEMODEL@_GLSTENCILFUNC@_GLSTENCILMASK@_GLSTENCILOP@_GLTEXCOORD1D@_GLTEXCOORD1DV@_GLTEXCOORD1F@_GLTEXCOORD1FV@_GLTEXCOORD1I@_GLTEXCOORD1IV@_GLTEXCOORD1S@_GLTEXCOORD1SV@_GLTEXCOORD2D@_GLTEXCOORD2DV@_GLTEXCOORD2F@_GLTEXCOORD2FV@_GLTEXCOORD2I@_GLTEXCOORD2IV@_GLTEXCOORD2S@_GLTEXCOORD2SV@_GLTEXCOORD3D@_GLTEXCOORD3DV@_GLTEXCOORD3F@_GLTEXCOORD3FV@_GLTEXCOORD3I@_GLTEXCOORD3IV@_GLTEXCOORD3S@_GLTEXCOORD3SV@_GLTEXCOORD4D@_GLTEXCOORD4DV@_GLTEXCOORD4F@_GLTEXCOORD4FV@_GLTEXCOORD4I@_GLTEXCOORD4IV@_GLTEXCOORD4S@_GLTEXCOORD4SV@_GLTEXCOORDPOINTER@_GLTEXENVF@_GLTEXENVFV@_GLTEXENVI@_GLTEXENVIV@_GLTEXGEND@_GLTEXGENDV@_GLTEXGENF@_GLTEXGENFV@_GLTEXGENI@_GLTEXGENIV@_GLTEXIMAGE1D@_GLTEXIMAGE2D@_GLTEXPARAMETERF@_GLTEXPARAMETERFV@_GLTEXPARAMETERI@_GLTEXPARAMETERIV@_GLTEXSUBIMAGE1D@_GLTEXSUBIMAGE2D@_GLTRANSLATED@_GLTRANSLATEF@_GLVERTEX2D@_GLVERTEX2DV@_GLVERTEX2F@_GLVERTEX2FV@_GLVERTEX2I@_GLVERTEX2IV@_GLVERTEX2S@_GLVERTEX2SV@_GLVERTEX3D@_GLVERTEX3DV@_GLVERTEX3F@_GLVERTEX3FV@_GLVERTEX3I@_GLVERTEX3IV@_GLVERTEX3S@_GLVERTEX3SV@_GLVERTEX4D@_GLVERTEX4DV@_GLVERTEX4F@_GLVERTEX4FV@_GLVERTEX4I@_GLVERTEX4IV@_GLVERTEX4S@_GLVERTEX4SV@_GLVERTEXPOINTER@_GLVIEWPORT@SMOOTH@STRETCH@_ANTICLOCKWISE@_BEHIND@_CLEAR@_FILLBACKGROUND@_GLUPERSPECTIVE@_HARDWARE@_HARDWARE1@_KEEPBACKGROUND@_NONE@_OFF@_ONLY@_ONLYBACKGROUND@_ONTOP@_SEAMLESS@_SMOOTH@_SMOOTHSHRUNK@_SMOOTHSTRETCHED@"
listOfKeywords$ = listOfKeywords$ + "_SOFTWARE@_SQUAREPIXELS@_STRETCH@_ALLOWFULLSCREEN@_ALL@_ECHO@_INSTRREV@_TRIM$@_ACCEPTFILEDROP@_FINISHDROP@_TOTALDROPPEDFILES@_DROPPEDFILE@_DROPPEDFILE$@_SHR@_SHL@"
listOfKeywords$ = listOfKeywords$ + "_DEFLATE$@_INFLATE$@_READBIT@_RESETBIT@_SETBIT@_TOGGLEBIT@$ASSERTS@_ASSERT@_CAPSLOCK@_NUMLOCK@_SCROLLLOCK@_TOGGLE@_CONSOLEFONT@_CONSOLECURSOR@_CONSOLEINPUT@_CINP@$NOPREFIX@$COLOR@$DEBUG@_ENVIRONCOUNT@"

'IDE MODULE: shared data & definitions
'---------------------------------------------------
Const idesystem2.w = 20 '"Find" field width (Status bar)

Dim Shared idesubwindow, statusarealink As Integer
Dim Shared ideexit
Dim Shared idet As String, idel, ideli, iden
Dim Shared ideundopos, ideundobase, ideundoflag
Dim Shared idelaunched, idecompiling
Dim Shared idecompiledline 'stores the number of the last line sent to the compiler, used only to know which line to send next
Dim Shared idecompiledline$ 'stores the last line sent to the compiler
Dim Shared idesx, idesy, idecx, idecy
Dim Shared ideselect, ideselectx1, ideselecty1, idemouseselect, idembmonitor
Dim Shared ideCurrentSingleLineSelection As String
Dim Shared ideunsaved
Dim Shared ideroot As String
Dim Shared idetxt(1000) As String
Dim Shared idetxtlast As Integer
Dim Shared idehl
Dim Shared ideprogname As String
Dim Shared idepath As String
Dim Shared idefindtext As String
Dim Shared idefindcasesens As Integer
Dim Shared idefindwholeword As Integer
Dim Shared idefindbackwards As Integer
Dim Shared idefindnocomments As Integer, idefindnostrings As Integer
Dim Shared idefindonlycomments As Integer, idefindonlystrings As Integer
Dim Shared idefindinvert As Integer
Dim Shared idechangeto As String
Dim Shared idechangemade As Integer
Dim Shared ideinsert As Integer
Dim Shared idepathsep As String * 1
Dim Shared SubFuncLIST(0) As String
Dim Shared ModifyCOMMAND$
Dim Shared EnteringRGB As _Byte
Dim Shared ActiveINCLUDELink As Long
Dim Shared ActiveINCLUDELinkFile As String
Dim Shared HideCurrentLineHighlight As _Byte, ShowLineNumbers As _Byte
Dim Shared SearchMenuEnableQuickNav As Integer, searchStringFoundOn As Long
Dim Shared idegotobox_LastLineNum As Long, maxLineNumberLength As Long
Dim Shared versionStringStatus$, lineNumberStatus$, ideshowtextBypassColorRestore As _Byte

'--------------------------------------------------------------------------------
Type idedbptype
    x As Long
    y As Long
    w As Long
    h As Long
    nam As Long
End Type
'--------------------------------------------------------------------------------
Type idedbotype
    par As idedbptype
    x As Long
    y As Long
    w As Long
    h As Long
    typ As Long
    nam As Long
    txt As Long
    dft As Long
    cx As Long
    cy As Long
    foc As Long
    sel As Long 'selected item no.
    selY As Long
    stx As Long 'selected item in string form
    issel As _Byte 'selection indicator (for text boxes only)
    sx1 As Long 'selection start (for text boxes only)
    v1 As Long
    num As Long
End Type
'--------------------------------------------------------------------------------
Dim Shared idefocusline 'simply stores the location of the line to highlight in red
Dim Shared ideautorun, startPaused
Dim Shared menu$(1 To 11, 0 To 20)
Dim Shared menuDesc$(1 To 11, 0 To 20)
Dim Shared menusize(1 To 11)
Dim Shared menus As Integer, idecontextualmenuID As Integer
Dim Shared ideeditmenuID As Integer, SearchMenuID As Integer
Dim Shared OptionsMenuID As Integer, OptionsMenuSwapMouse As Integer, OptionsMenuPasteCursor As Integer
Dim Shared OptionsMenuShowErrorsImmediately As Integer, OptionsMenuIgnoreWarnings As Integer
Dim Shared OptionsMenuDisableSyntax As Integer
Dim Shared ViewMenuID As Integer, ViewMenuShowLineNumbersSubMenuID As Integer
Dim Shared ViewMenuShowSeparatorID As Integer, ViewMenuShowBGID As Integer
Dim Shared ViewMenuCompilerWarnings As Integer
Dim Shared RunMenuID As Integer, RunMenuSaveExeWithSource As Integer, brackethighlight As Integer
Dim Shared multihighlight As Integer, keywordHighlight As Integer
Dim Shared PresetColorSchemes As Integer, TotalColorSchemes As Integer, ColorSchemes$(0)
Dim Shared LastValidColorScheme As Integer
Dim Shared menubar$, idecontextualSearch$
Dim Shared ideundocombo, ideundocombochr, idenoundo, idemergeundo
Dim Shared idealthighlight, ideentermenu
Dim Shared ideautolayout, ideautoindent, ideautoindentsize, ideindentsubs, idebackupsize
Dim Shared idewx, idewy, idecustomfont, idecustomfontfile$, idecustomfontheight, idecustomfonthandle
Dim Shared iderunmode, IDE_UseFont8 As _Byte
'IDE MODULE SECTION END: shared data & definitions

ReDim Shared OName(1000) As String 'Operation Name
ReDim Shared PL(1000) As Integer 'Priority Level
ReDim Shared PP_TypeMod(0) As String, PP_ConvertedMod(0) As String 'Prepass Name Conversion variables.
Set_OrderOfOperations

Dim Shared nativeDataTypes$
nativeDataTypes$ = "@_OFFSET@OFFSET@_UNSIGNED _OFFSET@UNSIGNED OFFSET@_BIT@BIT@_UNSIGNED _BIT@UNSIGNED BIT@_BYTE@_UNSIGNED _BYTE@BYTE@UNSIGNED BYTE@INTEGER@_UNSIGNED INTEGER@UNSIGNED INTEGER@LONG@_UNSIGNED LONG@UNSIGNED LONG@_INTEGER64@INTEGER64@_UNSIGNED _INTEGER64@UNSIGNED INTEGER64@SINGLE@DOUBLE@_FLOAT@FLOAT@STRING@"

Dim Shared opex_recompileAttempts, opex_desiredState
Dim Shared opexarray_recompileAttempts, opexarray_desiredState

ReDim EveryCaseSet(100), SelectCaseCounter As _Unsigned Long
ReDim SelectCaseHasCaseBlock(100)
Dim ExecLevel(255), ExecCounter As Integer
ReDim Shared UserDefine(1, 100) As String '0 element is the name, 1 element is the string value
ReDim Shared InValidLine(10000) As _Byte
Dim DefineElse(255) As _Byte

Dim Shared UserDefineCount As Integer, UserDefineList As String

UserDefineList = "@DEFINED@UNDEFINED@WINDOWS@WIN@LINUX@MAC@MACOSX@32BIT@64BIT@VERSION@"
UserDefine(0, 2) = "LINUX"
UserDefine(0, 6) = "64BIT"
UserDefine(0, 7) = "VERSION"
UserDefine(1, 2) = "-1"
UserDefine(1, 3) = "0": UserDefine(1, 4) = "0"
UserDefine(1, 5) = "0": UserDefine(1, 6) = "-1"
UserDefine(1, 7) = Version$

Dim Shared QB64_uptime!
QB64_uptime! = Timer

NoInternalFolder:
If _DirExists("internal") = 0 Then
    _ScreenShow
    Print "QB64 cannot locate the 'internal' folder"
    Print
    Print "Check that QB64 has been extracted properly."
    Print "In the console, enter: './qb64' to start."
    Do
        _Limit 1
    Loop Until InKey$ <> ""
    System 1
End If

Dim Shared Include_GDB_Debugging_Info 'set using "options.bin"

Dim Shared DEPENDENCY_LAST
Const DEPENDENCY_LOADFONT = 1: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_AUDIO_CONVERSION = 2: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_AUDIO_DECODE = 3: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_AUDIO_OUT = 4: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_GL = 5: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_IMAGE_CODEC = 6: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_CONSOLE_ONLY = 7: DEPENDENCY_LAST = DEPENDENCY_LAST + 1 '=2 if via -g switch, =1 if via metacommand $CONSOLE:ONLY
Const DEPENDENCY_SOCKETS = 8: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_PRINTER = 9: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_ICON = 10: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_SCREENIMAGE = 11: DEPENDENCY_LAST = DEPENDENCY_LAST + 1
Const DEPENDENCY_DEVICEINPUT = 12: DEPENDENCY_LAST = DEPENDENCY_LAST + 1 'removes support for gamepad input if not present
Const DEPENDENCY_ZLIB = 13: DEPENDENCY_LAST = DEPENDENCY_LAST + 1 'ZLIB library linkage, if desired, for compression/decompression.

Dim Shared DEPENDENCY(1 To DEPENDENCY_LAST)

Dim Shared UseGL 'declared SUB _GL (no params)

Dim Shared OS_BITS As Long, WindowTitle As String
OS_BITS = 64

If OS_BITS = 32 Then WindowTitle = "QB64 x32" Else WindowTitle = "QB64 x64"
_Title WindowTitle

Dim Shared ConsoleMode, No_C_Compile_Mode, NoIDEMode
Dim Shared ShowWarnings As _Byte, QuietMode As _Byte, CMDLineFile As String
Dim Shared MonochromeLoggingMode As _Byte

Type usedVarList
    As Long id, linenumber, includeLevel, includedLine, scope, localIndex
    As Long arrayElementSize
    As _Byte used, watch, isarray, displayFormat 'displayFormat: 0=DEC;1=HEX;2=BIN;3=OCT
    As String name, cname, varType, includedFile, subfunc
    As String watchRange, indexes, elements, elementTypes 'for Arrays and UDTs
    As String elementOffset, storage
End Type

Dim Shared typeDefinitions$, backupTypeDefinitions$
Dim Shared totalVariablesCreated As Long, totalMainVariablesCreated As Long
Dim Shared bypassNextVariable As _Byte
Dim Shared totalWarnings As Long, warningListItems As Long, lastWarningHeader As String
Dim Shared duplicateConstWarning As _Byte, warningsissued As _Byte
Dim Shared emptySCWarning As _Byte, maxLineNumber As Long
Dim Shared ExeIconSet As Long, qb64prefix$

Dim Shared NoChecks

Dim Shared Console
Dim Shared ScreenHide
Dim Shared Asserts
Dim Shared OptMax As Long
OptMax = 256
ReDim Shared Opt(1 To OptMax, 1 To 10) As String * 256
'   (1,1)="READ"
'   (1,2)="WRITE"
'   (1,3)="READ WRITE"
ReDim Shared OptWords(1 To OptMax, 1 To 10) As Integer 'The number of words of each opt () element
'   (1,1)=1 '"READ"
'   (1,2)=1 '"WRITE"
'   (1,3)=2 '"READ WRITE"
ReDim Shared T(1 To OptMax) As Integer 'The type of the entry
'   t is 0 for ? opts
'   ---------- 0 means ? , 1+ means a symbol or {}block ----------
'   t is 1 for symbol opts
'   t is the number of rhs opt () index enteries for {READ|WRITE|READ WRITE} like opts
ReDim Shared Lev(1 To OptMax) As Integer 'The indwelling level of each opt () element (the lowest is 0)
ReDim Shared EntryLev(1 To OptMax) As Integer 'The level required from which this opt () can be validly be entered/checked-for
ReDim Shared DitchLev(1 To OptMax) As Integer 'The lowest level recorded between the previous Opt and this Opt
ReDim Shared DontPass(1 To OptMax) As Integer 'Set to 1 or 0, with 1 meaning don't pass
'Determines whether the opt () entry needs to actually be passed to the C++ sub/function
ReDim Shared TempList(1 To OptMax) As Integer
ReDim Shared PassRule(1 To OptMax) As Long
'0 means no pass rule
'negative values refer to an opt () element
'positive values refer to a flag value
ReDim Shared LevelEntered(OptMax) 'up to 64 levels supported
ReDim Shared separgs(OptMax + 1) As String
ReDim Shared separgslayout(OptMax + 1) As String
ReDim Shared separgs2(OptMax + 1) As String
ReDim Shared separgslayout2(OptMax + 1) As String

Dim Shared E

Dim Shared ResolveStaticFunctions
ReDim Shared ResolveStaticFunction_File(1 To 100) As String
ReDim Shared ResolveStaticFunction_Name(1 To 100) As String
ReDim Shared ResolveStaticFunction_Method(1 To 100) As Long

Dim Shared Error_Happened As Long
Dim Shared Error_Message As String

Dim Shared os As String
os = "LNX"

Dim Shared BATCHFILE_EXTENSION As String
BATCHFILE_EXTENSION = ".sh"

Dim inlinedatastr(255) As String
For i = 0 To 255
    inlinedatastr(i) = str2$(i) + ","
Next

Dim Shared extension As String
extension$ = "" 'no extension under Linux

Dim Shared path.exe$, path.source$, lastBinaryGenerated$

Dim Shared pathsep As String * 1
pathsep$ = "/"
'note: QB64 handles OS specific path separators automatically except under SHELL calls

On Error GoTo qberror_test

Dim Shared tmpdir As String, tmpdir2 As String
tmpdir$ = "./internal/temp/": tmpdir2$ = "../temp/"

If Not _DirExists(tmpdir$) Then MkDir tmpdir$

Declare Library
    Function getpid& ()
End Declare

thisinstancepid = getpid&
Dim Shared tempfolderindex

fh = FreeFile
Open ".\internal\temp\tempfoldersearch.bin" For Random As #fh Len = Len(tempfolderindex)
tempfolderrecords = LOF(fh) / Len(tempfolderindex)
i = 1
If tempfolderrecords = 0 Then
    'first run ever?
    Put #fh, 1, thisinstancepid
Else
    For i = 1 To tempfolderrecords
        'check if any of the temp folders is being used = pid still active
        Get #fh, i, tempfoldersearch

        Shell _Hide "ps -p " + Str$(tempfoldersearch) + " > /dev/null 2>&1; echo $? > internal/temp/checkpid.bin"
        fh2 = FreeFile
        Open "internal/temp/checkpid.bin" For Binary As #fh2
        Line Input #fh2, checkpid$
        Close #fh2
        If Val(checkpid$) = 1 Then
            'This temp folder was locked by an instance that's no longer active, so
            'this will be our temp folder
            Put #fh, i, thisinstancepid
            Exit For
        End If
    Next
    If i > tempfolderrecords Then
        'All indexes were busy. Let's initiate a new one:
        Put #fh, i, thisinstancepid
    End If
End If
Close #fh
If i > 1 Then
    tmpdir$ = "./internal/temp" + str2$(i) + "/": tmpdir2$ = "../temp" + str2$(i) + "/"
    If _DirExists(tmpdir$) = 0 Then
        MkDir tmpdir$
    End If
End If
Open tmpdir$ + "temp.bin" For Output Lock Write As #26

'temp folder established
tempfolderindex = i
If i > 1 Then
    'create modified version of qbx.cpp
    Open ".\internal\c\qbx" + str2$(i) + ".cpp" For Output As #2
    Open ".\internal\c\qbx.cpp" For Binary As #1
    Do Until EOF(1)
        Line Input #1, a$
        x = InStr(a$, "..\\temp\\"): If x Then a$ = Left$(a$, x - 1) + "..\\temp" + str2$(i) + "\\" + Right$(a$, Len(a$) - (x + 9))
        x = InStr(a$, "../temp/"): If x Then a$ = Left$(a$, x - 1) + "../temp" + str2$(i) + "/" + Right$(a$, Len(a$) - (x + 7))
        Print #2, a$
    Loop
    Close #1, #2
End If

On Error GoTo qberror

Dim Shared tempfolderindexstr As String 'appended to "Untitled"
Dim Shared tempfolderindexstr2 As String
If tempfolderindex <> 1 Then tempfolderindexstr$ = "(" + str2$(tempfolderindex) + ")": tempfolderindexstr2$ = str2$(tempfolderindex)

Dim Shared idedebuginfo
Dim Shared seperateargs_error
Dim Shared seperateargs_error_message As String

Dim Shared compfailed

Dim Shared reginternalsubfunc
Dim Shared reginternalvariable

Dim Shared symboltype_size
symboltype_size = 0

Dim Shared use_global_byte_elements
use_global_byte_elements = 0

'compiler-side IDE data & definitions
'SHARED variables "passed" to/from the compiler & IDE
Dim Shared idecommand As String 'a 1 byte message-type code, followed by optional string data
Dim Shared idereturn As String 'used to pass formatted-lines and return information back to the IDE
Dim Shared ideerror As Long
Dim Shared idecompiled As Long
Dim Shared idemode '1 if using the IDE to compile
Dim Shared ideerrorline As Long 'set by qb64-error(...) to the line number it would have reported, this number
'is later passed to the ide in message #8
Dim Shared idemessage As String 'set by qb64-error(...) to the error message to be reported, this
'is later passed to the ide in message #8

Dim Shared optionexplicit As _Byte
Dim Shared optionexplicitarray As _Byte
Dim Shared optionexplicit_cmd As _Byte
Dim Shared ideStartAtLine As Long, errorLineInInclude As Long
Dim Shared warningInInclude As Long, warningInIncludeLine As Long
Dim Shared outputfile_cmd$
Dim Shared compilelog$

Dim Shared IDECommentColor As _Unsigned Long, IDEMetaCommandColor As _Unsigned Long
Dim Shared IDEQuoteColor As _Unsigned Long, IDETextColor As _Unsigned Long
Dim Shared IDEBackgroundColor As _Unsigned Long, IDEChromaColor As _Unsigned Long
Dim Shared IDEBackgroundColor2 As _Unsigned Long, IDEBracketHighlightColor As _Unsigned Long
Dim Shared IDEKeywordColor As _Unsigned Long, IDENumbersColor As _Unsigned Long
Dim Shared IDE_AutoPosition As _Byte, IDE_TopPosition As Integer, IDE_LeftPosition As Integer
Dim Shared IDE_BypassAutoPosition As _Byte, idesortsubs As _Byte, IDESubsLength As _Byte
Dim Shared IDENormalCursorStart As Long, IDENormalCursorEnd As Long
Dim Shared MouseButtonSwapped As _Byte
Dim Shared PasteCursorAtEnd As _Byte
Dim Shared SaveExeWithSource As _Byte, EnableQuickNav As _Byte
Dim Shared IDEShowErrorsImmediately As _Byte
Dim Shared ShowLineNumbersSeparator As _Byte, ShowLineNumbersUseBG As _Byte
Dim Shared IgnoreWarnings As _Byte, qb64versionprinted As _Byte
Dim Shared DisableSyntaxHighlighter As _Byte, ExeToSourceFolderFirstTimeMsg As _Byte
Dim Shared WhiteListQB64FirstTimeMsg As _Byte, ideautolayoutkwcapitals As _Byte
Dim Shared windowSettingsSection$, colorSettingsSection$, customDictionarySection$
Dim Shared mouseSettingsSection$, generalSettingsSection$, displaySettingsSection$
Dim Shared colorSchemesSection$, debugSettingsSection$, iniFolderIndex$, DebugInfoIniWarning$, ConfigFile$

ConfigFile$ = "internal/config.ini"
iniFolderIndex$ = Str$(tempfolderindex)
DebugInfoIniWarning$ = " 'Do not change manually. Use 'qb64 -s', or Debug->Advanced in the IDE"

windowSettingsSection$ = "IDE WINDOW" + iniFolderIndex$
colorSettingsSection$ = "IDE COLOR SETTINGS" + iniFolderIndex$
colorSchemesSection$ = "IDE COLOR SCHEMES"
customDictionarySection$ = "CUSTOM DICTIONARIES"
mouseSettingsSection$ = "MOUSE SETTINGS"
generalSettingsSection$ = "GENERAL SETTINGS"
displaySettingsSection$ = "IDE DISPLAY SETTINGS"
debugSettingsSection$ = "DEBUG SETTINGS"

IniSetAddQuotes 0
IniSetForceReload -1
IniSetAllowBasicComments -1
IniSetAutoCommit -1

'General settings -------------------------------------------------------------
result = ReadConfigSetting(generalSettingsSection$, "DisableSyntaxHighlighter", value$)
If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
    DisableSyntaxHighlighter = -1
    WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "True"
Else
    DisableSyntaxHighlighter = 0
    WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "False"
End If

If ReadConfigSetting(generalSettingsSection$, "PasteCursorAtEnd", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        PasteCursorAtEnd = -1
    Else
        PasteCursorAtEnd = 0
        WriteConfigSetting generalSettingsSection$, "PasteCursorAtEnd", "False"
    End If
Else
    PasteCursorAtEnd = -1
    WriteConfigSetting generalSettingsSection$, "PasteCursorAtEnd", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "ExeToSourceFolderFirstTimeMsg", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        ExeToSourceFolderFirstTimeMsg = -1
    Else
        ExeToSourceFolderFirstTimeMsg = 0
        WriteConfigSetting generalSettingsSection$, "ExeToSourceFolderFirstTimeMsg", "False"
    End If
Else
    ExeToSourceFolderFirstTimeMsg = 0
    WriteConfigSetting generalSettingsSection$, "ExeToSourceFolderFirstTimeMsg", "False"
End If

If ReadConfigSetting(generalSettingsSection$, "WhiteListQB64FirstTimeMsg", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        WhiteListQB64FirstTimeMsg = -1
    Else
        WhiteListQB64FirstTimeMsg = 0
        WriteConfigSetting generalSettingsSection$, "WhiteListQB64FirstTimeMsg", "False"
    End If
Else
    WhiteListQB64FirstTimeMsg = 0
    WriteConfigSetting generalSettingsSection$, "WhiteListQB64FirstTimeMsg", "False"
End If

If ReadConfigSetting(generalSettingsSection$, "SaveExeWithSource", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        SaveExeWithSource = -1
    Else
        SaveExeWithSource = 0
        WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "False"
    End If
Else
    SaveExeWithSource = 0
    WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "False"
End If

If ReadConfigSetting(generalSettingsSection$, "EnableQuickNav", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        EnableQuickNav = -1
    Else
        EnableQuickNav = 0
        WriteConfigSetting generalSettingsSection$, "EnableQuickNav", "False"
    End If
Else
    EnableQuickNav = -1
    WriteConfigSetting generalSettingsSection$, "EnableQuickNav", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "ShowErrorsImmediately", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        IDEShowErrorsImmediately = -1
    Else
        IDEShowErrorsImmediately = 0
        WriteConfigSetting generalSettingsSection$, "ShowErrorsImmediately", "False"
    End If
Else
    IDEShowErrorsImmediately = -1
    WriteConfigSetting generalSettingsSection$, "ShowErrorsImmediately", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "ShowLineNumbers", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        ShowLineNumbers = -1
    Else
        ShowLineNumbers = 0
        WriteConfigSetting generalSettingsSection$, "ShowLineNumbers", "False"
    End If
Else
    ShowLineNumbers = -1
    WriteConfigSetting generalSettingsSection$, "ShowLineNumbers", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "ShowLineNumbersSeparator", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        ShowLineNumbersSeparator = -1
    Else
        ShowLineNumbersSeparator = 0
        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersSeparator", "False"
    End If
Else
    ShowLineNumbersSeparator = -1
    WriteConfigSetting generalSettingsSection$, "ShowLineNumbersSeparator", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "ShowLineNumbersUseBG", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        ShowLineNumbersUseBG = -1
    Else
        ShowLineNumbersUseBG = 0
        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersUseBG", "False"
    End If
Else
    ShowLineNumbersUseBG = -1
    WriteConfigSetting generalSettingsSection$, "ShowLineNumbersUseBG", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "BracketHighlight", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        brackethighlight = -1
    Else
        brackethighlight = 0
        WriteConfigSetting generalSettingsSection$, "BracketHighlight", "False"
    End If
Else
    brackethighlight = -1
    WriteConfigSetting generalSettingsSection$, "BracketHighlight", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "KeywordHighlight", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        keywordHighlight = -1
    Else
        keywordHighlight = 0
        WriteConfigSetting generalSettingsSection$, "KeywordHighlight", "False"
    End If
Else
    keywordHighlight = -1
    WriteConfigSetting generalSettingsSection$, "KeywordHighlight", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "MultiHighlight", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        multihighlight = -1
    Else
        multihighlight = 0
        WriteConfigSetting generalSettingsSection$, "MultiHighlight", "False"
    End If
Else
    multihighlight = -1
    WriteConfigSetting generalSettingsSection$, "MultiHighlight", "True"
End If

If ReadConfigSetting(generalSettingsSection$, "IgnoreWarnings", value$) Then
    If UCase$(value$) = "TRUE" Or Abs(Val(value$)) = 1 Then
        IgnoreWarnings = -1
    Else
        IgnoreWarnings = 0
        WriteConfigSetting generalSettingsSection$, "IgnoreWarnings", "False"
    End If
Else
    IgnoreWarnings = 0
    WriteConfigSetting generalSettingsSection$, "IgnoreWarnings", "False"
End If

result = ReadConfigSetting(generalSettingsSection$, "BackupSize", value$)
idebackupsize = Val(value$)
If idebackupsize < 10 Or idebackupsize > 2000 Then idebackupsize = 100: WriteConfigSetting generalSettingsSection$, "BackupSize", "100 'in MB"

result = ReadConfigSetting(generalSettingsSection$, "DebugInfo", value$)
idedebuginfo = Val(value$)
If UCase$(Left$(value$, 4)) = "TRUE" Then idedebuginfo = 1
If result = 0 Or idedebuginfo <> 1 Then
    WriteConfigSetting generalSettingsSection$, "DebugInfo", "False" + DebugInfoIniWarning$
    idedebuginfo = 0
End If
Include_GDB_Debugging_Info = idedebuginfo

'Mouse settings ---------------------------------------------------------------
result = ReadConfigSetting(mouseSettingsSection$, "SwapMouseButton", value$)
If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
    MouseButtonSwapped = -1
    WriteConfigSetting mouseSettingsSection$, "SwapMouseButton", "True"
Else
    MouseButtonSwapped = 0
    WriteConfigSetting mouseSettingsSection$, "SwapMouseButton", "False"
End If

'Display settings -------------------------------------------------------------
If ReadConfigSetting(displaySettingsSection$, "IDE_SortSUBs", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        idesortsubs = -1
    Else
        idesortsubs = 0
        WriteConfigSetting displaySettingsSection$, "IDE_SortSUBs", "False"
    End If
Else
    idesortsubs = 0
    WriteConfigSetting displaySettingsSection$, "IDE_SortSUBs", "False"
End If

If ReadConfigSetting(displaySettingsSection$, "IDE_KeywordCapital", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        ideautolayoutkwcapitals = -1
    Else
        ideautolayoutkwcapitals = 0
        WriteConfigSetting displaySettingsSection$, "IDE_KeywordCapital", "False"
    End If
Else
    ideautolayoutkwcapitals = 0
    WriteConfigSetting displaySettingsSection$, "IDE_KeywordCapital", "False"
End If

If ReadConfigSetting(displaySettingsSection$, "IDE_SUBsLength", value$) Then
    If UCase$(value$) = "TRUE" Or Val(value$) = -1 Then
        IDESubsLength = -1
    Else
        IDESubsLength = 0
        WriteConfigSetting displaySettingsSection$, "IDE_SUBsLength", "False"
    End If
Else
    IDESubsLength = -1
    WriteConfigSetting displaySettingsSection$, "IDE_SUBsLength", "True"
End If

If ReadConfigSetting(displaySettingsSection$, "IDE_AutoPosition", value$) Then
    If UCase$(value$) = "TRUE" Or Abs(Val(value$)) = 1 Then
        IDE_AutoPosition = -1
    Else
        IDE_AutoPosition = 0
        WriteConfigSetting displaySettingsSection$, "IDE_AutoPosition", "False"
    End If
Else
    IDE_AutoPosition = -1
    WriteConfigSetting displaySettingsSection$, "IDE_AutoPosition", "True"
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_NormalCursorStart", value$)
IDENormalCursorStart = Val(value$)
If IDENormalCursorStart < 0 Or IDENormalCursorStart > 31 Or result = 0 Then
    IDENormalCursorStart = 6
    WriteConfigSetting displaySettingsSection$, "IDE_NormalCursorStart", "6"
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_NormalCursorEnd", value$)
IDENormalCursorEnd = Val(value$)
If IDENormalCursorEnd < 0 Or IDENormalCursorEnd > 31 Or result = 0 Then
    IDENormalCursorEnd = 8
    WriteConfigSetting displaySettingsSection$, "IDE_NormalCursorEnd", "8"
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_AutoFormat", value$)
ideautolayout = Val(value$)
If UCase$(value$) = "TRUE" Or ideautolayout <> 0 Then
    ideautolayout = 1
Else
    If UCase$(value$) <> "FALSE" And value$ <> "0" Then
        WriteConfigSetting displaySettingsSection$, "IDE_AutoFormat", "True"
        ideautolayout = 1
    Else
        ideautolayout = 0
    End If
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_AutoIndent", value$)
ideautoindent = Val(value$)
If UCase$(value$) = "TRUE" Or ideautoindent <> 0 Then
    ideautoindent = 1
Else
    If UCase$(value$) <> "FALSE" And value$ <> "0" Then
        WriteConfigSetting displaySettingsSection$, "IDE_AutoIndent", "True"
        ideautoindent = 1
    Else
        ideautoindent = 0
    End If
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_IndentSUBs", value$)
ideindentsubs = Val(value$)
If UCase$(value$) = "TRUE" Or ideindentsubs <> 0 Then
    ideindentsubs = 1
Else
    If UCase$(value$) <> "FALSE" And value$ <> "0" Then
        WriteConfigSetting displaySettingsSection$, "IDE_IndentSUBs", "True"
        ideindentsubs = 1
    Else
        ideindentsubs = 0
    End If
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_IndentSize", value$)
ideautoindentsize = Val(value$)
If ideautoindentsize < 1 Or ideautoindentsize > 64 Then
    ideautoindentsize = 4
    WriteConfigSetting displaySettingsSection$, "IDE_IndentSize", "4"
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_CustomFont", value$)
idecustomfont = Val(value$)
If UCase$(value$) = "TRUE" Or idecustomfont <> 0 Then
    idecustomfont = 1
Else
    WriteConfigSetting displaySettingsSection$, "IDE_CustomFont", "False"
    idecustomfont = 0
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_UseFont8", value$)
If UCase$(value$) = "TRUE" Then
    IDE_UseFont8 = 1
Else
    WriteConfigSetting displaySettingsSection$, "IDE_UseFont8", "False"
    IDE_UseFont8 = 0
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_CustomFont$", value$)
idecustomfontfile$ = value$
If result = 0 Or idecustomfontfile$ = "" Then
    idecustomfontfile$ = "C:\Windows\Fonts\lucon.ttf"
    WriteConfigSetting displaySettingsSection$, "IDE_CustomFont$", idecustomfontfile$
End If

result = ReadConfigSetting(displaySettingsSection$, "IDE_CustomFontSize", value$)
idecustomfontheight = Val(value$)
If idecustomfontheight < 8 Or idecustomfontheight > 100 Then idecustomfontheight = 21: WriteConfigSetting displaySettingsSection$, "IDE_CustomFontSize", "21"

result = ReadConfigSetting(displaySettingsSection$, "IDE_CodePage", value$)
idecpindex = Val(value$)
If idecpindex < 0 Or idecpindex > idecpnum Then idecpindex = 0: WriteConfigSetting displaySettingsSection$, "IDE_CodePage", "0"

'Custom keywords --------------------------------------------------------------
If ReadConfigSetting(customDictionarySection$, "CustomKeywords$", value$) Then
    tempList$ = ""
    listOfCustomKeywords$ = "@" + UCase$(value$) + "@"
    For i = 1 To Len(listOfCustomKeywords$)
        checkChar = Asc(listOfCustomKeywords$, i)
        If checkChar = 64 Then
            If Right$(tempList$, 1) <> "@" Then tempList$ = tempList$ + "@"
        Else
            tempList$ = tempList$ + Chr$(checkChar)
        End If
    Next
    listOfCustomKeywords$ = tempList$
    customKeywordsLength = Len(listOfCustomKeywords$)
Else
    IniSetAddQuotes -1
    WriteConfigSetting customDictionarySection$, "Instructions1", "Add custom keywords separated by the 'at' sign."
    WriteConfigSetting customDictionarySection$, "Instructions2", "Useful to colorize constants (eg @true@false@)."
    IniSetAddQuotes 0
    WriteConfigSetting customDictionarySection$, "CustomKeywords$", "@"
End If

'Color schemes ---------------------------------------------------------------
IniSetAddQuotes -1
WriteConfigSetting colorSchemesSection$, "Instructions1", "Create custom color schemes in the IDE (Options->IDE Colors)."
WriteConfigSetting colorSchemesSection$, "Instructions2", "Custom color schemes will be stored in this section."
IniSetAddQuotes 0

'Individual window settings (different for each running instance) -------------
If ReadConfigSetting(windowSettingsSection$, "IDE_TopPosition", value$) Then
    IDE_TopPosition = Val(value$)
Else
    IDE_BypassAutoPosition = -1 'If there's no position saved in the file, then we certainly don't need to try and auto-position to our last setting.
    IDE_TopPosition = 0
End If

If ReadConfigSetting(windowSettingsSection$, "IDE_LeftPosition", value$) Then
    IDE_LeftPosition = Val(value$)
Else
    IDE_BypassAutoPosition = -1 'If there's no position saved in the file, then we certainly don't need to try and auto-position to our last setting.
    IDE_LeftPosition = 0
End If

result = ReadConfigSetting(windowSettingsSection$, "IDE_Width", value$)
idewx = Val(value$)
If idewx < 80 Or idewx > 1000 Then idewx = 80: WriteConfigSetting windowSettingsSection$, "IDE_Width", "80"

result = ReadConfigSetting(windowSettingsSection$, "IDE_Height", value$)
idewy = Val(value$)
If idewy < 25 Or idewy > 1000 Then idewy = 25: WriteConfigSetting windowSettingsSection$, "IDE_Height", "25"

'Color settings ---------------------------------------------------------------
'Defaults: (= Super Dark Blue scheme, as of v1.5)
IDETextColor = _RGB32(216, 216, 216)
IDEKeywordColor = _RGB32(69, 118, 147)
IDENumbersColor = _RGB32(216, 98, 78)
IDEQuoteColor = _RGB32(255, 167, 0)
IDEMetaCommandColor = _RGB32(85, 206, 85)
IDECommentColor = _RGB32(98, 98, 98)
IDEChromaColor = _RGB32(170, 170, 170)
IDEBackgroundColor = _RGB32(0, 0, 39)
IDEBackgroundColor2 = _RGB32(0, 49, 78)
IDEBracketHighlightColor = _RGB32(0, 88, 108)

'Manual/unsaved color settings:
If ReadConfigSetting(colorSettingsSection$, "SchemeID", value$) = 0 Then
    WriteConfigSetting colorSettingsSection$, "SchemeID", "1"
End If

If ReadConfigSetting(colorSettingsSection$, "TextColor", value$) Then
    IDETextColor = VRGBS(value$, IDETextColor)
Else WriteConfigSetting colorSettingsSection$, "TextColor", rgbs$(IDETextColor)
End If

If ReadConfigSetting(colorSettingsSection$, "KeywordColor", value$) Then
    IDEKeywordColor = VRGBS(value$, IDEKeywordColor)
Else WriteConfigSetting colorSettingsSection$, "KeywordColor", rgbs$(IDEKeywordColor)
End If

If ReadConfigSetting(colorSettingsSection$, "NumbersColor", value$) Then
    IDENumbersColor = VRGBS(value$, IDENumbersColor)
Else WriteConfigSetting colorSettingsSection$, "NumbersColor", rgbs$(IDENumbersColor)
End If

If ReadConfigSetting(colorSettingsSection$, "QuoteColor", value$) Then
    IDEQuoteColor = VRGBS(value$, IDEQuoteColor)
Else WriteConfigSetting colorSettingsSection$, "QuoteColor", rgbs$(IDEQuoteColor)
End If

If ReadConfigSetting(colorSettingsSection$, "CommentColor", value$) Then
    IDECommentColor = VRGBS(value$, IDECommentColor)
Else WriteConfigSetting colorSettingsSection$, "CommentColor", rgbs$(IDECommentColor)
End If

If ReadConfigSetting(colorSettingsSection$, "ChromaColor", value$) Then
    IDEChromaColor = VRGBS(value$, IDEChromaColor)
Else WriteConfigSetting colorSettingsSection$, "ChromaColor", rgbs$(IDEChromaColor)
End If

If ReadConfigSetting(colorSettingsSection$, "MetaCommandColor", value$) Then
    IDEMetaCommandColor = VRGBS(value$, IDEMetaCommandColor)
Else WriteConfigSetting colorSettingsSection$, "MetaCommandColor", rgbs$(IDEMetaCommandColor)
End If

If ReadConfigSetting(colorSettingsSection$, "HighlightColor", value$) Then
    IDEBracketHighlightColor = VRGBS(value$, IDEBracketHighlightColor)
Else WriteConfigSetting colorSettingsSection$, "HighlightColor", rgbs$(IDEBracketHighlightColor)
End If

If ReadConfigSetting(colorSettingsSection$, "BackgroundColor", value$) Then
    IDEBackgroundColor = VRGBS(value$, IDEBackgroundColor)
Else WriteConfigSetting colorSettingsSection$, "BackgroundColor", rgbs$(IDEBackgroundColor)
End If

If ReadConfigSetting(colorSettingsSection$, "BackgroundColor2", value$) Then
    IDEBackgroundColor2 = VRGBS(value$, IDEBackgroundColor2)
Else WriteConfigSetting colorSettingsSection$, "BackgroundColor2", rgbs$(IDEBackgroundColor2)
End If

'End of initial settings ------------------------------------------------------

CMDLineFile = ParseCMDLineArgs$

If ConsoleMode Then
    _Dest _Console
Else
    _Console Off
    _ScreenShow
    _Icon
End If

'the function ?=ide(?) should always be passed 0, it returns a message code number, any further information
'is passed back in idereturn

'message code numbers:
'0  no ide present  (auto defined array ide() return 0)

'1  launch ide & with passed filename (compiler->ide)

'2  begin new compilation with returned line of code (compiler<-ide)
'   [2][line of code]

'3  request next line (compiler->ide)
'   [3]

'4  next line of code returned (compiler<-ide)
'   [4][line of code]

'5  no more lines of code exist (compiler<-ide)
'   [5]

'6  code is OK/ready (compiler->ide)
'   [6]

'7  repass the code from the beginning (compiler->ide)
'   [7]

'8  an error has occurred with 'this' message on 'this' line(compiler->ide)
'   [8][error message][line as LONG]

'9  C++ compile (if necessary) and run with 'this' name (compiler<-ide)
'   [9][name(no path, no .bas)]

'10 The line requires more time to process
'       Pass-back 'line of code' using method [4] when ready
'   [10][line of code]

'11 ".EXE file created" message

'12     The name of the exe I'll create is '...' (compiler->ide)
'   [12][exe name without .exe]

'255    A qb error happened in the IDE (compiler->ide)
'   note: detected by the fact that ideerror was not set to 0
'   [255]

'hash table data
Type HashListItem
    Flags As Long
    Reference As Long
    NextItem As Long
    PrevItem As Long
    LastItem As Long 'note: this value is only valid on the first item in the list
    'note: name is stored in a seperate array of strings
End Type
Dim Shared HashFind_NextListItem As Long
Dim Shared HashFind_Reverse As Long
Dim Shared HashFind_SearchFlags As Long
Dim Shared HashFind_Name As String
Dim Shared HashRemove_LastFound As Long
Dim Shared HashListSize As Long
Dim Shared HashListNext As Long
Dim Shared HashListFreeSize As Long
Dim Shared HashListFreeLast As Long
'hash lookup tables
Dim Shared hash1char(255) As Integer
Dim Shared hash2char(65535) As Integer
For x = 1 To 26
    hash1char(64 + x) = x
    hash1char(96 + x) = x
Next
hash1char(95) = 27 '_
hash1char(48) = 28 '0
hash1char(49) = 29 '1
hash1char(50) = 30 '2
hash1char(51) = 31 '3
hash1char(52) = 23 '4 'note: x, y, z and beginning alphabet letters avoided because of common usage (eg. a2, y3)
hash1char(53) = 22 '5
hash1char(54) = 20 '6
hash1char(55) = 19 '7
hash1char(56) = 18 '8
hash1char(57) = 17 '9
For c1 = 0 To 255
    For c2 = 0 To 255
        hash2char(c1 + c2 * 256) = hash1char(c1) + hash1char(c2) * 32
    Next
Next
'init
HashListSize = 65536
HashListNext = 1
HashListFreeSize = 1024
HashListFreeLast = 0
ReDim Shared HashList(1 To HashListSize) As HashListItem
ReDim Shared HashListName(1 To HashListSize) As String * 256
ReDim Shared HashListFree(1 To HashListFreeSize) As Long
ReDim Shared HashTable(16777215) As Long '64MB lookup table with indexes to the hashlist

Const HASHFLAG_LABEL = 2
Const HASHFLAG_TYPE = 4
Const HASHFLAG_RESERVED = 8
Const HASHFLAG_OPERATOR = 16
Const HASHFLAG_CUSTOMSYNTAX = 32
Const HASHFLAG_SUB = 64
Const HASHFLAG_FUNCTION = 128
Const HASHFLAG_UDT = 256
Const HASHFLAG_UDTELEMENT = 512
Const HASHFLAG_CONSTANT = 1024
Const HASHFLAG_VARIABLE = 2048
Const HASHFLAG_ARRAY = 4096
Const HASHFLAG_XELEMENTNAME = 8192
Const HASHFLAG_XTYPENAME = 16384

Type Label_Type
    State As _Unsigned _Byte '0=label referenced, 1=label created
    cn As String * 256
    Scope As Long
    Data_Offset As _Integer64 'offset within data
    Data_Referenced As _Unsigned _Byte 'set to 1 if data is referenced (data_offset will be used to create the data offset variable)
    Error_Line As Long 'the line number to reference on errors
    Scope_Restriction As Long 'cannot exist inside this scope (post checked)
    SourceLineNumber As Long
End Type
Dim Shared nLabels, Labels_Ubound
Labels_Ubound = 100
ReDim Shared Labels(1 To Labels_Ubound) As Label_Type
Dim Shared Empty_Label As Label_Type

Dim Shared PossibleSubNameLabels As String 'format: name+sp+name+sp+name <-ucase$'d
Dim Shared SubNameLabels As String 'format: name+sp+name+sp+name <-ucase$'d
Dim Shared CreatingLabel As Long

Dim Shared AllowLocalName As Long

Dim Shared DataOffset

Dim Shared prepass

Dim Shared autoarray

Dim Shared ontimerid, onkeyid, onstrigid

Dim Shared revertmaymusthave(1 To 10000)
Dim Shared revertmaymusthaven

Dim Shared linecontinuation

Dim Shared dim2typepassback As String 'passes back correct case sensitive version of type

Dim Shared inclevel
Dim Shared incname(100) As String 'must be full path as given
Dim Shared inclinenumber(100) As Long
Dim Shared incerror As String

Dim Shared fix046 As String
fix046$ = "__" + "ASCII" + "_" + "CHR" + "_" + "046" + "__" 'broken up to avoid detection for layout reversion

Dim Shared layout As String 'passed to IDE
Dim Shared layoutok As Long 'tracks status of entire line

Dim Shared layoutcomment As String

Dim Shared tlayout As String 'temporary layout string set by supporting functions
Dim Shared layoutdone As Long 'tracks status of single command


Dim Shared fooindwel

Dim Shared alphanumeric(255)
For i = 48 To 57
    alphanumeric(i) = -1
Next
For i = 65 To 90
    alphanumeric(i) = -1
Next
For i = 97 To 122
    alphanumeric(i) = -1
Next
'_ is treated as an alphabet letter
alphanumeric(95) = -1

Dim Shared isalpha(255)
For i = 65 To 90
    isalpha(i) = -1
Next
For i = 97 To 122
    isalpha(i) = -1
Next
'_ is treated as an alphabet letter
isalpha(95) = -1

Dim Shared isnumeric(255)
For i = 48 To 57
    isnumeric(i) = -1
Next

Dim Shared lfsinglechar(255)
lfsinglechar(40) = 1 '(
lfsinglechar(41) = 1 ')
lfsinglechar(42) = 1 '*
lfsinglechar(43) = 1 '+
lfsinglechar(45) = 1 '-
lfsinglechar(47) = 1 '/
lfsinglechar(60) = 1 '<
lfsinglechar(61) = 1 '=
lfsinglechar(62) = 1 '>
lfsinglechar(92) = 1 '\
lfsinglechar(94) = 1 '^

lfsinglechar(44) = 1 ',
lfsinglechar(46) = 1 '.
lfsinglechar(58) = 1 ':
lfsinglechar(59) = 1 ';

lfsinglechar(35) = 1 '# (file no only)
lfsinglechar(36) = 1 '$ (metacommand only)
lfsinglechar(63) = 1 '? (print macro)
lfsinglechar(95) = 1 '_

Dim Shared nextrunlineindex As Long

Dim Shared lineinput3buffer As String
Dim Shared lineinput3index As Long

Dim Shared dimstatic As Long

Dim Shared staticarraylist As String
Dim Shared staticarraylistn As Long
Dim Shared commonarraylist As String
Dim Shared commonarraylistn As Long

'CONST support
Dim Shared constmax As Long
constmax = 100
Dim Shared constlast As Long
constlast = -1
ReDim Shared constname(constmax) As String
ReDim Shared constcname(constmax) As String
ReDim Shared constnamesymbol(constmax) As String 'optional name symbol
' `1 and `no-number must be handled correctly
'DIM SHARED constlastshared AS LONG 'so any defined inside a sub/function after this index can be "forgotten" when sub/function exits
'constlastshared = -1
ReDim Shared consttype(constmax) As Long 'variable type number
'consttype determines storage
ReDim Shared constinteger(constmax) As _Integer64
ReDim Shared constuinteger(constmax) As _Unsigned _Integer64
ReDim Shared constfloat(constmax) As _Float
ReDim Shared conststring(constmax) As String
ReDim Shared constsubfunc(constmax) As Long
ReDim Shared constdefined(constmax) As Long

'UDT
'names
Dim Shared lasttype As Long
Dim Shared lasttypeelement As Long

Type idstruct
    n As String * 256 'name
    cn As String * 256 'case sensitive version of n

    arraytype As Long 'similar to t
    arrayelements As Integer
    staticarray As Integer 'set for arrays declared in the main module with static elements

    mayhave As String * 8 'mayhave and musthave are exclusive of each other
    musthave As String * 8
    t As Long 'type

    tsize As Long

    subfunc As Integer 'if function=1, sub=2 (max 100 arguments)
    Dependency As Integer
    internal_subfunc As Integer

    callname As String * 256
    ccall As Integer
    overloaded As _Byte
    args As Integer
    minargs As Integer
    arg As String * 400 'similar to t
    argsize As String * 400 'similar to tsize (used for fixed length strings)
    specialformat As String * 256
    secondargmustbe As String * 256
    secondargcantbe As String * 256
    ret As Long 'the value it returns if it is a function (again like t)

    insubfunc As String * 256
    insubfuncn As Long

    share As Integer
    nele As String * 100
    nelereq As String * 100
    linkid As Long
    linkarg As Integer
    staticscope As Integer
    'For variables which are arguments passed to a sub/function
    sfid As Long 'id number of variable's parent sub/function
    sfarg As Integer 'argument/parameter # within call (1=first)

    hr_syntax As String
End Type

Dim Shared id As idstruct

Dim Shared idn As Long
Dim Shared ids_max As Long
ids_max = 1024
ReDim Shared ids(1 To ids_max) As idstruct
ReDim Shared cmemlist(1 To ids_max + 1) As Integer 'variables that must be in cmem
ReDim Shared sfcmemargs(1 To ids_max + 1) As String * 100 's/f arg that must be in cmem
ReDim Shared arrayelementslist(1 To ids_max + 1) As Integer 'arrayelementslist (like cmemlist) helps to resolve the number of elements in arrays with an unknown number of elements. Note: arrays with an unknown number of elements have .arrayelements=-1

'create blank id template for idclear to copy (stops strings being set to chr$(0))
Dim Shared cleariddata As idstruct
cleariddata.cn = ""
cleariddata.n = ""
cleariddata.mayhave = ""
cleariddata.musthave = ""
cleariddata.callname = ""
cleariddata.arg = ""
cleariddata.argsize = ""
cleariddata.specialformat = ""
cleariddata.secondargmustbe = ""
cleariddata.secondargcantbe = ""
cleariddata.insubfunc = ""
cleariddata.nele = ""
cleariddata.nelereq = ""

Dim Shared ISSTRING As Long
Dim Shared ISFLOAT As Long
Dim Shared ISUNSIGNED As Long
Dim Shared ISPOINTER As Long
Dim Shared ISFIXEDLENGTH As Long
Dim Shared ISINCONVENTIONALMEMORY As Long
Dim Shared ISOFFSETINBITS As Long
Dim Shared ISARRAY As Long
Dim Shared ISREFERENCE As Long
Dim Shared ISUDT As Long
Dim Shared ISOFFSET As Long

Dim Shared STRINGTYPE As Long
Dim Shared BITTYPE As Long
Dim Shared UBITTYPE As Long
Dim Shared BYTETYPE As Long
Dim Shared UBYTETYPE As Long
Dim Shared INTEGERTYPE As Long
Dim Shared UINTEGERTYPE As Long
Dim Shared LONGTYPE As Long
Dim Shared ULONGTYPE As Long
Dim Shared INTEGER64TYPE As Long
Dim Shared UINTEGER64TYPE As Long
Dim Shared SINGLETYPE As Long
Dim Shared DOUBLETYPE As Long
Dim Shared FLOATTYPE As Long
Dim Shared OFFSETTYPE As Long
Dim Shared UOFFSETTYPE As Long
Dim Shared UDTTYPE As Long

Dim Shared gosubid As Long
Dim Shared redimoption As Integer
Dim Shared dimoption As Integer
Dim Shared arraydesc As Integer
Dim Shared qberrorhappened As Integer
Dim Shared qberrorcode As Integer
Dim Shared qberrorline As Integer

Dim Shared sourcefile As String 'the full path and filename
Dim Shared file As String 'name of the file (without .bas or path)

Dim Shared constequation As Integer
Dim Shared DynamicMode As Integer
Dim Shared findidsecondarg As String
Dim Shared findanotherid As Integer
Dim Shared findidinternal As Long
Dim Shared currentid As Long 'is the index of the last ID accessed
Dim Shared linenumber As Long, reallinenumber As Long, totallinenumber As Long, definingtypeerror As Long
Dim Shared wholeline As String
Dim Shared firstLineNumberLabelvWatch As Long
Dim Shared vWatchUsedLabels As String, vWatchUsedSkipLabels As String
Dim Shared linefragment As String

Dim Shared arrayprocessinghappened As Integer
Dim Shared stringprocessinghappened As Integer
Dim Shared cleanupstringprocessingcall As String
Dim Shared inputfunctioncalled As _Byte
Dim Shared recompile As Integer 'forces recompilation

Dim Shared optionbase As Integer

Dim Shared addmetastatic As Integer
Dim Shared addmetadynamic As Integer
Dim Shared addmetainclude As String

Dim Shared closedmain As Integer
Dim Shared module As String

Dim Shared subfunc As String
Dim Shared subfuncn As Long
Dim Shared closedsubfunc As _Byte
Dim Shared subfuncid As Long

Dim Shared defdatahandle As Integer
Dim Shared dimsfarray As Integer
Dim Shared dimshared As Integer

'Allows passing of known elements to recompilation
Dim Shared sflistn As Integer
Dim Shared glinkid As Long
Dim Shared glinkarg As Integer
Dim Shared typname2typsize As Long
Dim Shared uniquenumbern As Long

Dim Shared bitmask(1 To 64) As _Integer64
Dim Shared bitmaskinv(1 To 64) As _Integer64

Dim Shared defineextaz(1 To 27) As String
Dim Shared defineaz(1 To 27) As String '27 is an underscore

ISSTRING = 1073741824
ISFLOAT = 536870912
ISUNSIGNED = 268435456
ISPOINTER = 134217728
ISFIXEDLENGTH = 67108864 'only set for strings with pointer flag
ISINCONVENTIONALMEMORY = 33554432
ISOFFSETINBITS = 16777216
ISARRAY = 8388608
ISREFERENCE = 4194304
ISUDT = 2097152
ISOFFSET = 1048576

STRINGTYPE = ISSTRING + ISPOINTER
BITTYPE = 1& + ISPOINTER + ISOFFSETINBITS
UBITTYPE = 1& + ISPOINTER + ISUNSIGNED + ISOFFSETINBITS 'QB64 will also support BIT*n, eg. DIM bitarray[10] AS _UNSIGNED _BIT*10
BYTETYPE = 8& + ISPOINTER
UBYTETYPE = 8& + ISPOINTER + ISUNSIGNED
INTEGERTYPE = 16& + ISPOINTER
UINTEGERTYPE = 16& + ISPOINTER + ISUNSIGNED
LONGTYPE = 32& + ISPOINTER
ULONGTYPE = 32& + ISPOINTER + ISUNSIGNED
INTEGER64TYPE = 64& + ISPOINTER
UINTEGER64TYPE = 64& + ISPOINTER + ISUNSIGNED
SINGLETYPE = 32& + ISFLOAT + ISPOINTER
DOUBLETYPE = 64& + ISFLOAT + ISPOINTER
FLOATTYPE = 256& + ISFLOAT + ISPOINTER '8-32 bytes
OFFSETTYPE = 64& + ISOFFSET + ISPOINTER: If OS_BITS = 32 Then OFFSETTYPE = 32& + ISOFFSET + ISPOINTER
UOFFSETTYPE = 64& + ISOFFSET + ISUNSIGNED + ISPOINTER: If OS_BITS = 32 Then UOFFSETTYPE = 32& + ISOFFSET + ISUNSIGNED + ISPOINTER
UDTTYPE = ISUDT + ISPOINTER

Dim Shared statementn As Long
Dim Shared everycasenewcase As Long

Dim Shared controllevel As Integer '0=not in a control block
Dim Shared controltype(1000) As Integer
'1=IF (awaiting END IF)
'2=FOR (awaiting NEXT)
'3=DO (awaiting LOOP [UNTIL|WHILE param])
'4=DO WHILE/UNTIL (awaiting LOOP)
'5=WHILE (awaiting WEND)
'6=$IF (precompiler)
'10=SELECT CASE qbs (awaiting END SELECT/CASE)
'11=SELECT CASE int64 (awaiting END SELECT/CASE)
'12=SELECT CASE uint64 (awaiting END SELECT/CASE)
'13=SELECT CASE LONG double (awaiting END SELECT/CASE/CASE ELSE)
'14=SELECT CASE float ...
'15=SELECT CASE double
'16=SELECT CASE int32
'17=SELECT CASE uint32
'18=CASE (awaiting END SELECT/CASE/CASE ELSE)
'19=CASE ELSE (awaiting END SELECT)
'32=SUB/FUNCTION (awaiting END SUB/FUNCTION)
Dim controlid(1000) As Long
Dim controlvalue(1000) As Long
Dim controlstate(1000) As Integer
Dim Shared controlref(1000) As Long 'the line number the control was created on

On Error GoTo qberror

i2&& = 1
For i&& = 1 To 64
    bitmask(i&&) = i2&&
    bitmaskinv(i&&) = Not i2&&
    i2&& = i2&& + 2 ^ i&&
Next

Dim id2 As idstruct

cleanupstringprocessingcall$ = "qbs_cleanup(qbs_tmp_base,"

Dim Shared sfidlist(1000) As Long
Dim Shared sfarglist(1000) As Integer
Dim Shared sfelelist(1000) As Integer

'----------------ripgl.bas--------------------------------------------------------------------------------
gl_scan_header
'----------------ripgl.bas--------------------------------------------------------------------------------

'-----------------------QB64 COMPILER ONCE ONLY SETUP CODE ENDS HERE---------------------------------------

If NoIDEMode Then IDE_AutoPosition = 0: GoTo noide
Dim FileDropEnabled As _Byte
If FileDropEnabled = 0 Then FileDropEnabled = -1: _AcceptFileDrop

If IDE_AutoPosition And Not IDE_BypassAutoPosition Then _ScreenMove IDE_LeftPosition, IDE_TopPosition
idemode = 1
sendc$ = "" 'no initial message
If CMDLineFile <> "" Then sendc$ = Chr$(1) + CMDLineFile
sendcommand:
idecommand$ = sendc$
C = ide(0)
ideerror = 0
If C = 0 Then idemode = 0: GoTo noide
c$ = idereturn$

If C = 2 Then 'begin
    ideerrorline = 0 'addresses invalid prepass error line numbers being reported
    idepass = 1
    GoTo fullrecompile
    ideret1:
    wholeline$ = c$
    GoTo ideprepass
    ideret2:
    If lastLineReturn Then GoTo lastLineReturn
    sendc$ = Chr$(3) 'request next line
    GoTo sendcommand
End If

If C = 4 Then 'next line
    If idepass = 1 Then
        wholeline$ = c$
        GoTo ideprepass
        '(returns to ideret2: above)
    End If
    'assume idepass>1
    a3$ = c$
    continuelinefrom = 0
    GoTo ide4
    ideret4:
    If lastLineReturn Then GoTo lastLineReturn
    sendc$ = Chr$(3) 'request next line
    GoTo sendcommand
End If

If C = 5 Then 'end of program reached

    lastLine = 1
    lastLineReturn = 1
    If idepass = 1 Then
        wholeline$ = ""
        GoTo ideprepass
        '(returns to ideret2: above, then to lastLinePrepassReturn below)
    End If
    'idepass>1
    a3$ = ""
    continuelinefrom = 0
    GoTo ide4 'returns to ideret4, then to lastLinePrepassReturn below
    lastLineReturn:
    lastLineReturn = 0
    lastLine = 0

    If idepass = 1 Then
        'prepass complete
        idepass = 2
        GoTo ide3
        ideret3:
        sendc$ = Chr$(7) 'repass request
        firstLine = 1
        GoTo sendcommand
    End If
    'assume idepass=2
    'finalize program
    GoTo ide5
    ideret5: 'note: won't return here if a recompile was required!
    sendc$ = Chr$(6) 'ready
    idecompiled = 0
    GoTo sendcommand
End If

If C = 9 Then 'run

    If idecompiled = 0 Then 'exe needs to be compiled
        file$ = c$

        'locate accessible file and truncate
        f$ = file$

        path.exe$ = ""
        If SaveExeWithSource Then
            If Len(ideprogname) Then path.exe$ = idepath$ + pathsep$
        End If

        i = 1
        nextexeindex:
        If _FileExists(path.exe$ + file$ + extension$) Then
            E = 0
            On Error GoTo qberror_test
            Kill path.exe$ + file$ + extension$
            On Error GoTo qberror
            If E = 1 Then
                i = i + 1
                file$ = f$ + "(" + str2$(i) + ")"
                GoTo nextexeindex
            End If
        End If

        If path.exe$ = "" Then
            path.exe$ = "../../"
        End If

        'inform IDE of name change if necessary (IDE will respond with message 9 and corrected name)
        If i <> 1 Then
            sendc$ = Chr$(12) + file$
            GoTo sendcommand
        End If

        ideerrorline = 0 'addresses C++ comp. error's line number
        GoTo ide6
        ideret6:
        idecompiled = 1
    End If

    If iderunmode = 2 Then
        sendc$ = Chr$(11) '.EXE file created
        GoTo sendcommand
    End If

    'execute program

    If iderunmode = 1 Then
        If path.exe$ = "" Then path.exe$ = "./"
        If Left$(lastBinaryGenerated$, Len(path.exe$)) = path.exe$ Then
            Shell _DontWait QuotedFilename$(lastBinaryGenerated$) + ModifyCOMMAND$
        Else
            Shell _DontWait QuotedFilename$(path.exe$ + lastBinaryGenerated$) + ModifyCOMMAND$
        End If
        If path.exe$ = "./" Then path.exe$ = ""
    Else
        If path.exe$ = "" Then path.exe$ = "./"
        If Left$(lastBinaryGenerated$, Len(path.exe$)) = path.exe$ Then
            Shell QuotedFilename$(lastBinaryGenerated$) + ModifyCOMMAND$
        Else
            Shell QuotedFilename$(path.exe$ + lastBinaryGenerated$) + ModifyCOMMAND$
        End If
        If path.exe$ = "./" Then path.exe$ = ""
        Do: Loop Until InKey$ = ""
        Do: Loop Until _KeyHit = 0
    End If

    If idemode Then
        'Darken fg/bg colors
        dummy = DarkenFGBG(0)
    End If

    sendc$ = Chr$(6) 'ready
    GoTo sendcommand
End If

Print "Invalid IDE message": End

ideerror:
If InStr(idemessage$, sp$) Then
    'Something went wrong here, so let's give a generic error message to the user.
    '(No error message should contain sp$ - that is, CHR$(13), when not in Debug mode)
    terrmsg$ = _ErrorMessage$
    If terrmsg$ = "No error" Then terrmsg$ = "Internal error"
    idemessage$ = "Compiler error (check for syntax errors) (" + terrmsg$ + ":"
    If Err Then idemessage$ = idemessage$ + str2$(Err) + "-"
    If _ErrorLine Then idemessage$ = idemessage$ + str2$(_ErrorLine)
    If _InclErrorLine Then idemessage$ = idemessage$ + "-" + _InclErrorFile$ + "-" + str2$(_InclErrorLine)
    idemessage$ = idemessage$ + ")"
    If inclevel > 0 Then idemessage$ = idemessage$ + incerror$
End If

sendc$ = Chr$(8) + idemessage$ + MKL$(ideerrorline)
GoTo sendcommand


noide:
If (qb64versionprinted = 0 Or ConsoleMode = 0) And Not QuietMode Then
    qb64versionprinted = -1
    Print "QB64 Compiler V" + Version$
End If

If CMDLineFile = "" Then
    Line Input ; "COMPILE (.bas)>", f$
Else
    f$ = CMDLineFile
End If

f$ = LTrim$(RTrim$(f$))

If FileHasExtension(f$) = 0 Then f$ = f$ + ".bas"

sourcefile$ = f$
CMDLineFile = sourcefile$
'derive name from sourcefile
f$ = RemoveFileExtension$(f$)

path.exe$ = ""
currentdir$ = _CWD$
path.source$ = getfilepath$(sourcefile$)
If Len(path.source$) Then
    If _DirExists(path.source$) = 0 Then
        Print
        Print "Cannot locate source file: " + sourcefile$
        If ConsoleMode Then System 1
        End 1
    End If
    ChDir path.source$
    path.source$ = _CWD$
    If Right$(path.source$, 1) <> pathsep$ Then path.source$ = path.source$ + pathsep$
    ChDir currentdir$
End If
If SaveExeWithSource Then path.exe$ = path.source$
If path.exe$ = "" Then
    path.exe$ = "../../"
End If

For x = Len(f$) To 1 Step -1
    a$ = Mid$(f$, x, 1)
    If a$ = "/" Or a$ = "\" Then
        f$ = Right$(f$, Len(f$) - x)
        Exit For
    End If
Next
file$ = f$

'if cmemlist(currentid+1)<>0 before calling regid the variable
'MUST be defined in cmem!

fullrecompile:

BU_DEPENDENCY_CONSOLE_ONLY = DEPENDENCY(DEPENDENCY_CONSOLE_ONLY)
For i = 1 To UBound(DEPENDENCY): DEPENDENCY(i) = 0: Next
DEPENDENCY(DEPENDENCY_CONSOLE_ONLY) = BU_DEPENDENCY_CONSOLE_ONLY And 2 'Restore -g switch if used

Error_Happened = 0

For closeall = 1 To 255: Close closeall: Next

Open tmpdir$ + "temp.bin" For Output Lock Write As #26 'relock

fh = FreeFile: Open tmpdir$ + "dyninfo.txt" For Output As #fh: Close #fh

For i = 1 To ids_max + 1
    arrayelementslist(i) = 0
    cmemlist(i) = 0
    sfcmemargs(i) = ""
Next

'erase cmemlist
'erase sfcmemargs

lastunresolved = -1 'first pass
sflistn = -1 'no entries

SubNameLabels = sp 'QB64 will perform a repass to resolve sub names used as labels

opex_desiredState = 0
opex_recompileAttempts = 0

opexarray_desiredState = 0
opexarray_recompileAttempts = 0

recompile:

qb64prefix$ = "_"

optionexplicit = opex_desiredState
If optionexplicit_cmd = -1 And NoIDEMode = 1 Then optionexplicit = -1
optionexplicitarray = opexarray_desiredState

lastLineReturn = 0
lastLine = 0
firstLine = 1

Resize = 0
Resize_Scale = 0

UseGL = 0

Error_Happened = 0

HashClear 'clear the hash table

'add reserved words to hashtable

f = HASHFLAG_TYPE + HASHFLAG_RESERVED
HashAdd "_UNSIGNED", f, 0
HashAdd "_BIT", f, 0
HashAdd "_BYTE", f, 0
HashAdd "INTEGER", f, 0
HashAdd "LONG", f, 0
HashAdd "_INTEGER64", f, 0
HashAdd "_OFFSET", f, 0
HashAdd "SINGLE", f, 0
HashAdd "DOUBLE", f, 0
HashAdd "_FLOAT", f, 0
HashAdd "STRING", f, 0
HashAdd "ANY", f, 0

f = HASHFLAG_OPERATOR + HASHFLAG_RESERVED
HashAdd "NOT", f, 0
HashAdd "IMP", f, 0
HashAdd "EQV", f, 0
HashAdd "AND", f, 0
HashAdd "OR", f, 0
HashAdd "XOR", f, 0
HashAdd "MOD", f, 0

f = HASHFLAG_RESERVED + HASHFLAG_CUSTOMSYNTAX
HashAdd "LIST", f, 0
HashAdd "BASE", f, 0
HashAdd "_EXPLICIT", f, 0
HashAdd "AS", f, 0
HashAdd "IS", f, 0
HashAdd "OFF", f, 0
HashAdd "ON", f, 0
HashAdd "STOP", f, 0
HashAdd "TO", f, 0
HashAdd "USING", f, 0
'PUT(graphics) statement:
HashAdd "PRESET", f, 0
HashAdd "PSET", f, 0
'OPEN statement:
HashAdd "FOR", f, 0
HashAdd "OUTPUT", f, 0
HashAdd "RANDOM", f, 0
HashAdd "BINARY", f, 0
HashAdd "APPEND", f, 0
HashAdd "SHARED", f, 0
HashAdd "ACCESS", f, 0
HashAdd "LOCK", f, 0
HashAdd "READ", f, 0
HashAdd "WRITE", f, 0
'LINE statement:
HashAdd "STEP", f, 0
'WIDTH statement:
HashAdd "LPRINT", f, 0
'VIEW statement:
HashAdd "PRINT", f, 0

f = HASHFLAG_RESERVED + HASHFLAG_XELEMENTNAME + HASHFLAG_XTYPENAME
'A
'B
'C
HashAdd "COMMON", f, 0
HashAdd "CALL", f, 0
HashAdd "CASE", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "COM", f, 0 '(ON...)
HashAdd "CONST", f, 0
'D
HashAdd "DATA", f, 0
HashAdd "DECLARE", f, 0
HashAdd "DEF", f, 0
HashAdd "DEFDBL", f, 0
HashAdd "DEFINT", f, 0
HashAdd "DEFLNG", f, 0
HashAdd "DEFSNG", f, 0
HashAdd "DEFSTR", f, 0
HashAdd "DIM", f, 0
HashAdd "DO", f - HASHFLAG_XELEMENTNAME, 0
'E
HashAdd "ERROR", f - HASHFLAG_XELEMENTNAME, 0 '(ON ...)
HashAdd "ELSE", f, 0
HashAdd "ELSEIF", f, 0
HashAdd "ENDIF", f, 0
HashAdd "EXIT", f - HASHFLAG_XELEMENTNAME, 0
'F
HashAdd "FIELD", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "FUNCTION", f, 0
'G
HashAdd "GOSUB", f, 0
HashAdd "GOTO", f, 0
'H
'I
HashAdd "INPUT", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0 '(INPUT$ function exists, so conflicts if allowed as custom syntax)
HashAdd "IF", f, 0
'K
HashAdd "KEY", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0 '(ON...)
'L
HashAdd "LET", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "LOOP", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "LEN", f - HASHFLAG_XELEMENTNAME, 0 '(LEN function exists, so conflicts if allowed as custom syntax)
'M
'N
HashAdd "NEXT", f - HASHFLAG_XELEMENTNAME, 0
'O
'P
HashAdd "PLAY", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0 '(ON...)
HashAdd "PEN", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0 '(ON...)
'Q
'R
HashAdd "REDIM", f, 0
HashAdd "REM", f, 0
HashAdd "RESTORE", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "RESUME", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "RETURN", f - HASHFLAG_XELEMENTNAME, 0
HashAdd "RUN", f - HASHFLAG_XELEMENTNAME, 0
'S
HashAdd "STATIC", f, 0
HashAdd "STRIG", f, 0 '(ON...)
HashAdd "SEG", f, 0
HashAdd "SELECT", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0
HashAdd "SUB", f, 0
HashAdd "SCREEN", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0
'T
HashAdd "THEN", f, 0
HashAdd "TIMER", f - HASHFLAG_XELEMENTNAME - HASHFLAG_XTYPENAME, 0 '(ON...)
HashAdd "TYPE", f - HASHFLAG_XELEMENTNAME, 0
'U
HashAdd "UNTIL", f, 0
HashAdd "UEVENT", f, 0
'V
'W
HashAdd "WEND", f, 0
HashAdd "WHILE", f, 0
'X
'Y
'Z

'clear/init variables
Console = 0
ScreenHide = 0
Asserts = 0
ResolveStaticFunctions = 0
dynamiclibrary = 0
dimsfarray = 0
dimstatic = 0
AllowLocalName = 0
PossibleSubNameLabels = sp 'QB64 will perform a repass to resolve sub names used as labels
use_global_byte_elements = 0
dimshared = 0: dimmethod = 0: dimoption = 0: redimoption = 0: commonoption = 0
mylib$ = "": mylibopt$ = ""
declaringlibrary = 0
nLabels = 0
dynscope = 0
elsefollowup = 0
ontimerid = 0: onkeyid = 0: onstrigid = 0
commonarraylist = "": commonarraylistn = 0
staticarraylist = "": staticarraylistn = 0
fooindwel = 0
layout = ""
layoutok = 0
NoChecks = 0
inclevel = 0
errorLineInInclude = 0
addmetainclude$ = ""
nextrunlineindex = 1
lasttype = 0
lasttypeelement = 0
ReDim Shared udtxname(1000) As String * 256
ReDim Shared udtxcname(1000) As String * 256
ReDim Shared udtxsize(1000) As Long
ReDim Shared udtxbytealign(1000) As Integer 'first element MUST be on a byte alignment & size is a multiple of 8
ReDim Shared udtxnext(1000) As Long
ReDim Shared udtxvariable(1000) As Integer 'true if the udt contains variable length elements
'elements
ReDim Shared udtename(1000) As String * 256
ReDim Shared udtecname(1000) As String * 256
ReDim Shared udtebytealign(1000) As Integer
ReDim Shared udtesize(1000) As Long
ReDim Shared udtetype(1000) As Long
ReDim Shared udtetypesize(1000) As Long
ReDim Shared udtearrayelements(1000) As Long
ReDim Shared udtenext(1000) As Long
definingtype = 0
definingtypeerror = 0
constlast = -1
'constlastshared = -1
defdatahandle = 18
closedmain = 0
addmetastatic = 0
addmetadynamic = 0
DynamicMode = 0
optionbase = 0
ExeIconSet = 0
DataOffset = 0
statementn = 0
everycasenewcase = 0
qberrorhappened = 0: qberrorcode = 0: qberrorline = 0
For i = 1 To 27: defineaz(i) = "SINGLE": defineextaz(i) = "!": Next
controllevel = 0
findidsecondarg$ = "": findanotherid = 0: findidinternal = 0: currentid = 0
linenumber = 0
wholeline$ = ""
linefragment$ = ""
idn = 0
arrayprocessinghappened = 0
stringprocessinghappened = 0
inputfunctioncalled = 0
subfuncn = 0
closedsubfunc = 0
subfunc = ""
SelectCaseCounter = 0
ExecCounter = 0
UserDefineCount = 7
totalVariablesCreated = 0
typeDefinitions$ = ""
totalMainVariablesCreated = 0
ReDim Shared usedVariableList(1000) As usedVarList
totalWarnings = 0
duplicateConstWarning = 0
emptySCWarning = 0
warningListItems = 0
lastWarningHeader = ""
vWatchUsedLabels = Space$(1000)
vWatchUsedSkipLabels = Space$(1000)
firstLineNumberLabelvWatch = 0
ReDim Shared warning$(1000)
ReDim Shared warningLines(1000) As Long
ReDim Shared warningIncLines(1000) As Long
ReDim Shared warningIncFiles(1000) As String
maxLineNumber = 0
uniquenumbern = 0

'import _MEM type
ptrsz = OS_BITS \ 8

lasttype = lasttype + 1: i = lasttype
udtxname(i) = "_MEM"
udtxcname(i) = "_MEM"
udtxsize(i) = ((ptrsz) * 5 + (4) * 2 + (8) * 1) * 8
udtxbytealign(i) = 1
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "OFFSET"
udtecname(i2) = "OFFSET"
udtebytealign(i2) = 1
udtetype(i2) = OFFSETTYPE: udtesize(i2) = ptrsz * 8
udtetypesize(i2) = 0 'tsize
udtxnext(i) = i2
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "SIZE"
udtecname(i2) = "SIZE"
udtebytealign(i2) = 1
udtetype(i2) = OFFSETTYPE: udtesize(i2) = ptrsz * 8
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "$_LOCK_ID"
udtecname(i2) = "$_LOCK_ID"
udtebytealign(i2) = 1
udtetype(i2) = INTEGER64TYPE: udtesize(i2) = 64
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "$_LOCK_OFFSET"
udtecname(i2) = "$_LOCK_OFFSET"
udtebytealign(i2) = 1
udtetype(i2) = OFFSETTYPE: udtesize(i2) = ptrsz * 8
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "TYPE"
udtecname(i2) = "TYPE"
udtebytealign(i2) = 1
udtetype(i2) = OFFSETTYPE: udtesize(i2) = ptrsz * 8
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "ELEMENTSIZE"
udtecname(i2) = "ELEMENTSIZE"
udtebytealign(i2) = 1
udtetype(i2) = OFFSETTYPE: udtesize(i2) = ptrsz * 8
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
udtenext(i2) = 0
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "IMAGE"
udtecname(i2) = "IMAGE"
udtebytealign(i2) = 1
udtetype(i2) = LONGTYPE: udtesize(i2) = 32
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
udtenext(i2) = 0
i3 = i2
lasttypeelement = lasttypeelement + 1: i2 = lasttypeelement
udtename(i2) = "SOUND"
udtecname(i2) = "SOUND"
udtebytealign(i2) = 1
udtetype(i2) = LONGTYPE: udtesize(i2) = 32
udtetypesize(i2) = 0 'tsize
udtenext(i3) = i2
udtenext(i2) = 0

'begin compilation
For closeall = 1 To 255: Close closeall: Next
Open tmpdir$ + "temp.bin" For Output Lock Write As #26 'relock

ff = FreeFile: Open tmpdir$ + "icon.rc" For Output As #ff: Close #ff

If idemode = 0 Then
    qberrorhappened = -1
    Open sourcefile$ For Input As #1
    qberrorhappened1:
    If qberrorhappened = 1 Then
        Print
        Print "Cannot locate source file: " + sourcefile$
        If ConsoleMode Then System 1
        End 1
    Else
        Close #1
    End If
    qberrorhappened = 0
End If

reginternal

Open tmpdir$ + "global.txt" For Output As #18

If iderecompile Then
    iderecompile = 0
    idepass = 1 'prepass must be done again
    sendc$ = Chr$(7) 'repass request
    GoTo sendcommand
End If

If idemode Then GoTo ideret1

If Not QuietMode Then
    Print
    Print "Beginning C++ output from QB64 code... "
End If

lineinput3load sourcefile$

Do

    '### STEVE EDIT FOR CONST EXPANSION 10/11/2013

    wholeline$ = lineinput3$
    If wholeline$ = Chr$(13) Then Exit Do

    ideprepass:
    prepassLastLine:

    If lastLine <> 0 Or firstLine <> 0 Then
        lineBackup$ = wholeline$ 'backup the real line (will be blank when lastline is set)
        forceIncludeFromRoot$ = ""
        firstLine = 0: lastLine = 0
        If Len(forceIncludeFromRoot$) Then GoTo forceInclude_prepass
        forceIncludeCompleted_prepass:
        addingvWatch = 0
        wholeline$ = lineBackup$
    End If

    wholestv$ = wholeline$ '### STEVE EDIT FOR CONST EXPANSION 10/11/2013

    prepass = 1
    layout = ""
    layoutok = 0

    linenumber = linenumber + 1
    reallinenumber = reallinenumber + 1

    Do Until linenumber < UBound(InValidLine) 'color information flag for each line
        ReDim _Preserve InValidLine(UBound(InValidLine) + 1000) As _Byte
    Loop
    InValidLine(linenumber) = 0

    If Len(wholeline$) Then

        wholeline$ = lineformat(wholeline$)
        If Error_Happened Then GoTo errmes


        temp$ = LTrim$(RTrim$(UCase$(wholestv$)))

        If temp$ = "$COLOR:0" Then
            addmetainclude$ = getfilepath$(Command$(0)) + "internal" + pathsep$ + "support" + pathsep$ + "color" + pathsep$ + "color0.bi"
            GoTo finishedlinepp
        End If

        If temp$ = "$COLOR:32" Then
            addmetainclude$ = getfilepath$(Command$(0)) + "internal" + pathsep$ + "support" + pathsep$ + "color" + pathsep$ + "color32.bi"
            GoTo finishedlinepp
        End If

        If Left$(temp$, 4) = "$IF " Then
            If Right$(temp$, 5) <> " THEN" Then a$ = "$IF without THEN": GoTo errmes
            temp$ = LTrim$(Mid$(temp$, 4)) 'strip off the $IF and extra spaces
            temp$ = RTrim$(Left$(temp$, Len(temp$) - 4)) 'and strip off the THEN and extra spaces
            temp = InStr(temp$, "=")
            ExecCounter = ExecCounter + 1
            ExecLevel(ExecCounter) = -1 'default to a skip value
            DefineElse(ExecCounter) = 1 '1 says we have an $IF statement at this level
            result = EvalPreIF(temp$, a$)
            If a$ <> "" Then GoTo errmes
            If result <> 0 Then
                ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'So we inherit the execlevel from above
                If ExecLevel(ExecCounter) = 0 Then DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 4 'Else if used and conditon found
            End If
            GoTo finishedlinepp 'and then we're finished -- and at this point we didn't make a match so we exit with a DONT READ type flag on our code.
        End If

        If temp$ = "$ELSE" Then
            If DefineElse(ExecCounter) = 0 Then a$ = "$ELSE without $IF": GoTo errmes
            If DefineElse(ExecCounter) And 2 Then a$ = "$IF block already has $ELSE statement in it": GoTo errmes
            DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 2 'set the flag to declare an $ELSE already in this block
            If DefineElse(ExecCounter) And 4 Then 'If we executed code in a previous IF or ELSE IF statement, we can't do it here
                ExecLevel(ExecCounter) = -1 'So we inherit the execlevel from above
            Else
                ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'If we were processing code before, code after this segment is going to be SKIPPED
            End If
            GoTo finishedlinepp
        End If

        If Left$(temp$, 5) = "$ELSE" Then 'looking for $ELSE IF
            temp$ = LTrim$(Mid$(temp$, 6))
            If Left$(temp$, 3) = "IF " Then
                If DefineElse(ExecCounter) = 0 Then a$ = "$ELSE IF without $IF": GoTo errmes
                If DefineElse(ExecCounter) And 2 Then a$ = "$ELSE IF cannot follow $ELSE": GoTo errmes
                If Right$(temp$, 5) <> " THEN" Then a$ = "$ELSE IF without THEN": GoTo errmes
                If DefineElse(ExecCounter) And 4 Then 'If we executed code in a previous IF or ELSE IF statement, we can't do it here
                    ExecLevel(ExecCounter) = -1
                    GoTo finishedlinepp
                End If
                temp$ = LTrim$(Mid$(temp$, 3)) 'strip off the IF and extra spaces
                temp$ = RTrim$(Left$(temp$, Len(temp$) - 4)) 'and strip off the THEN and extra spaces
                result = EvalPreIF(temp$, a$)
                If a$ <> "" Then GoTo errmes
                If result <> 0 Then
                    ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'So we inherit the execlevel from above
                    If ExecLevel(ExecCounter) = 0 Then DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 4 'Else if used and conditon found
                End If
                GoTo finishedlinepp 'and then we're finished -- and at this point we didn't make a match so we exit with a DONT READ type flag on our code.
            End If
        End If

        If temp$ = "$END IF" Or temp$ = "$ENDIF" Then
            If DefineElse(ExecCounter) = 0 Then a$ = "$END IF without $IF": GoTo errmes
            DefineElse(ExecCounter) = 0 'We no longer have an $IF block at this level
            ExecCounter = ExecCounter - 1
            GoTo finishedlinepp
        End If

        If ExecLevel(ExecCounter) Then
            Do Until linenumber < UBound(InValidLine)
                ReDim _Preserve InValidLine(UBound(InValidLine) + 1000) As _Byte
            Loop

            InValidLine(linenumber) = -1
            GoTo finishedlinepp 'we don't check for anything inside lines that we've marked for skipping
        End If

        If Left$(temp$, 7) = "$ERROR " Then
            temp$ = LTrim$(Mid$(temp$, 7))
            a$ = "Compilation check failed: " + temp$
            GoTo errmes
        End If

        If Left$(temp$, 5) = "$LET " Then
            temp$ = LTrim$(Mid$(temp$, 5)) 'simply shorten our string to parse
            'For starters, let's make certain that we have 3 elements to deal with
            temp = InStr(temp$, "=") 'without an = in there, we can't get a value from the left and right side
            If temp = 0 Then a$ = "Invalid Syntax.  $LET <flag> = <value>": GoTo errmes
            l$ = RTrim$(Left$(temp$, temp - 1)): r$ = LTrim$(Mid$(temp$, temp + 1))
            'then validate to make certain the left side looks proper
            If validname(l$) = 0 Then a$ = "Invalid flag name": GoTo errmes
            If Left$(r$, 1) = Chr$(34) Then r$ = LTrim$(Mid$(r$, 2))
            If Right$(r$, 1) = Chr$(34) Then r$ = RTrim$(Left$(r$, Len(r$) - 1))
            If Left$(r$, 1) = "-" Then
                r1$ = "-"
                r$ = LTrim$(Mid$(r$, 2))
            Else
                r1$ = ""
            End If
            'then validate to make certain the left side looks proper
            For i = 1 To Len(r$)
                a = Asc(r$, i)
                Select Case a
                    Case 32
                    Case 46 'periods are fine.
                        r1$ = r1$ + "."
                    Case Is < 48, Is > 90
                        a$ = "Invalid value": GoTo errmes
                    Case Else
                        r1$ = r1$ + Chr$(a)
                End Select
            Next
            r$ = r1$
            'First look to see if we have an existing setting like this and if so, update it
            For i = 8 To UserDefineCount 'UserDefineCount 1-7 are reserved for automatic OS/BIT detection & version
                If UserDefine(0, i) = l$ Then UserDefine(1, i) = r$: GoTo finishedlinepp
            Next
            'Otherwise create a new setting and set the initial value for it
            UserDefineCount = UserDefineCount + 1
            If UserDefineCount > UBound(UserDefine, 2) Then
                ReDim _Preserve UserDefine(1, UBound(UserDefine, 2) + 10) 'Add another 10 elements to the array so it'll expand as the user adds to it
            End If
            UserDefine(0, UserDefineCount) = l$
            UserDefine(1, UserDefineCount) = r$
            GoTo finishedlinepp
        End If

        cwholeline$ = wholeline$
        wholeline$ = eleucase$(wholeline$) '********REMOVE THIS LINE LATER********

        addmetadynamic = 0: addmetastatic = 0
        wholelinen = numelements(wholeline$)

        If wholelinen Then

            wholelinei = 1

            'skip line number?
            e$ = getelement$(wholeline$, 1)
            If (Asc(e$) >= 48 And Asc(e$) <= 59) Or Asc(e$) = 46 Then wholelinei = 2: GoTo ppskpl

            'skip 'POSSIBLE' line label?
            If wholelinen >= 2 Then
                x2 = InStr(wholeline$, sp + ":" + sp): x3 = x2 + 2
                If x2 = 0 Then
                    If Right$(wholeline$, 2) = sp + ":" Then x2 = Len(wholeline$) - 1: x3 = x2 + 1
                End If

                If x2 Then
                    e$ = Left$(wholeline$, x2 - 1)
                    If validlabel(e$) Then
                        wholeline$ = Right$(wholeline$, Len(wholeline$) - x3)
                        cwholeline$ = Right$(cwholeline$, Len(wholeline$) - x3)
                        wholelinen = numelements(wholeline$)
                        GoTo ppskpl
                    End If 'valid
                End If 'includes ":"
            End If 'wholelinen>=2

            ppskpl:
            If wholelinei <= wholelinen Then
                '----------------------------------------
                a$ = ""
                ca$ = ""
                ppblda:
                e$ = getelement$(wholeline$, wholelinei)
                ce$ = getelement$(cwholeline$, wholelinei)
                If e$ = ":" Or e$ = "ELSE" Or e$ = "THEN" Or e$ = "" Then
                    If Len(a$) Then
                        n = numelements(a$)
                        firstelement$ = getelement(a$, 1)
                        secondelement$ = getelement(a$, 2)
                        thirdelement$ = getelement(a$, 3)
                        '========================================

                        If n = 2 And firstelement$ = "END" And (secondelement$ = "SUB" Or secondelement$ = "FUNCTION") Then
                            closedsubfunc = -1
                        End If

                        'declare library
                        If declaringlibrary Then

                            If firstelement$ = "END" Then
                                If n <> 2 Or secondelement$ <> "DECLARE" Then a$ = "Expected END DECLARE": GoTo errmes
                                declaringlibrary = 0
                                GoTo finishedlinepp
                            End If 'end declare

                            declaringlibrary = 2

                            If firstelement$ = "SUB" Or firstelement$ = "FUNCTION" Then subfuncn = subfuncn - 1: GoTo declaresubfunc

                            a$ = "Expected SUB/FUNCTION definition or END DECLARE (#2)": GoTo errmes
                        End If

                        'UDT TYPE definition
                        If definingtype Then
                            i = definingtype

                            If n >= 1 Then
                                If firstelement$ = "END" Then
                                    If n <> 2 Or secondelement$ <> "TYPE" Then a$ = "Expected END TYPE": GoTo errmes
                                    If udtxnext(i) = 0 Then a$ = "No elements defined in TYPE": GoTo errmes
                                    definingtype = 0

                                    'create global buffer for SWAP space
                                    siz$ = str2$(udtxsize(i) \ 8)
                                    Print #18, "char *g_tmp_udt_" + RTrim$(udtxname(i)) + "=(char*)malloc(" + siz$ + ");"

                                    'print "END TYPE";udtxsize(i);udtxbytealign(i)
                                    GoTo finishedlinepp
                                End If
                            End If

                            If n < 3 Then a$ = "Expected element-name AS type, AS type element-list, or END TYPE": GoTo errmes
                            n$ = firstelement$

                            If n$ <> "AS" Then
                                'traditional variable-name AS type syntax, single-element
                                lasttypeelement = lasttypeelement + 1
                                i2 = lasttypeelement
                                While i2 > UBound(udtenext): increaseUDTArrays: Wend
                                udtenext(i2) = 0

                                ii = 2

                                udtearrayelements(i2) = 0

                                If ii >= n Or getelement$(a$, ii) <> "AS" Then a$ = "Expected element-name AS type, AS type element-list, or END TYPE": GoTo errmes
                                t$ = getelements$(a$, ii + 1, n)

                                If t$ = RTrim$(udtxname(definingtype)) Then a$ = "Invalid self-reference": GoTo errmes
                                typ = typname2typ(t$)
                                If Error_Happened Then GoTo errmes
                                If typ = 0 Then a$ = "Undefined type": GoTo errmes
                                typsize = typname2typsize

                                If validname(n$) = 0 Then a$ = "Invalid name": GoTo errmes
                                udtename(i2) = n$
                                udtecname(i2) = getelement$(ca$, 1)
                                NormalTypeBlock:
                                typeDefinitions$ = typeDefinitions$ + MKL$(i2) + MKL$(Len(n$)) + n$
                                udtetype(i2) = typ
                                udtetypesize(i2) = typsize

                                hashname$ = n$

                                'check for name conflicts (any similar reserved or element from current UDT)
                                hashchkflags = HASHFLAG_RESERVED + HASHFLAG_UDTELEMENT
                                hashres = HashFind(hashname$, hashchkflags, hashresflags, hashresref)
                                Do While hashres
                                    If hashresflags And HASHFLAG_UDTELEMENT Then
                                        If hashresref = i Then a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                    End If
                                    If hashresflags And HASHFLAG_RESERVED Then
                                        If hashresflags And (HASHFLAG_TYPE + HASHFLAG_CUSTOMSYNTAX + HASHFLAG_OPERATOR + HASHFLAG_XELEMENTNAME) Then a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                    End If
                                    If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
                                Loop
                                'add to hash table
                                HashAdd hashname$, HASHFLAG_UDTELEMENT, i

                                'Calculate element's size
                                If typ And ISUDT Then
                                    u = typ And 511
                                    udtesize(i2) = udtxsize(u)
                                    If udtxbytealign(u) Then udtxbytealign(i) = 1: udtebytealign(i2) = 1
                                    If udtxvariable(u) Then udtxvariable(i) = -1
                                Else
                                    If (typ And ISSTRING) Then
                                        If (typ And ISFIXEDLENGTH) = 0 Then
                                            udtesize(i2) = OFFSETTYPE And 511
                                            udtxvariable(i) = -1
                                        Else
                                            udtesize(i2) = typsize * 8
                                        End If
                                        udtxbytealign(i) = 1: udtebytealign(i2) = 1
                                    Else
                                        udtesize(i2) = typ And 511
                                        If (typ And ISOFFSETINBITS) = 0 Then udtxbytealign(i) = 1: udtebytealign(i2) = 1
                                    End If
                                End If

                                'Increase block size
                                If udtebytealign(i2) Then
                                    If udtxsize(i) Mod 8 Then
                                        udtxsize(i) = udtxsize(i) + (8 - (udtxsize(i) Mod 8))
                                    End If
                                End If
                                udtxsize(i) = udtxsize(i) + udtesize(i2)

                                'Link element to previous element
                                If udtxnext(i) = 0 Then
                                    udtxnext(i) = i2
                                Else
                                    udtenext(i2 - 1) = i2
                                End If

                                'print "+"+rtrim$(udtename(i2));udtetype(i2);udtesize(i2);udtebytealign(i2);udtxsize(i)
                                If newAsTypeBlockSyntax Then Return
                                GoTo finishedlinepp
                            Else
                                'new AS type variable-list syntax, multiple elements
                                ii = 2

                                If ii >= n Then a$ = "Expected element-name AS type, AS type element-list, or END TYPE": GoTo errmes
                                previousElement$ = ""
                                t$ = ""
                                lastElement$ = ""
                                buildTypeName:
                                lastElement$ = getelement$(a$, ii)
                                If lastElement$ <> "," And lastElement$ <> "" Then
                                    n$ = lastElement$
                                    cn$ = getelement$(ca$, ii)
                                    If Len(previousElement$) Then t$ = t$ + previousElement$ + " "
                                    previousElement$ = n$
                                    lastElement$ = ""
                                    ii = ii + 1
                                    GoTo buildTypeName
                                End If

                                t$ = RTrim$(t$)
                                If t$ = RTrim$(udtxname(definingtype)) Then a$ = "Invalid self-reference": GoTo errmes
                                typ = typname2typ(t$)
                                If Error_Happened Then GoTo errmes
                                If typ = 0 Then a$ = "Undefined type": GoTo errmes
                                typsize = typname2typsize

                                previousElement$ = lastElement$
                                nexttypeelement:
                                lasttypeelement = lasttypeelement + 1
                                i2 = lasttypeelement
                                While i2 > UBound(udtenext): increaseUDTArrays: Wend
                                udtenext(i2) = 0
                                udtearrayelements(i2) = 0

                                udtename(i2) = n$
                                udtecname(i2) = cn$

                                If validname(n$) = 0 Then a$ = "Invalid name": GoTo errmes

                                newAsTypeBlockSyntax = -1
                                GoSub NormalTypeBlock
                                newAsTypeBlockSyntax = 0

                                getNextElement:
                                ii = ii + 1
                                lastElement$ = getelement$(a$, ii)
                                If lastElement$ = "" Then GoTo finishedlinepp
                                If ii = n And lastElement$ = "," Then a$ = "Expected element-name": GoTo errmes
                                If lastElement$ = "," Then
                                    If previousElement$ = "," Then a$ = "Expected element-name": GoTo errmes
                                    previousElement$ = lastElement$
                                    GoTo getNextElement
                                End If
                                n$ = lastElement$
                                If previousElement$ <> "," Then a$ = "Expected ,": GoTo errmes
                                previousElement$ = lastElement$
                                cn$ = getelement$(ca$, ii)
                                GoTo nexttypeelement
                            End If
                        End If 'definingtype

                        If definingtype And n >= 1 Then a$ = "Expected END TYPE": GoTo errmes

                        If n >= 1 Then
                            If firstelement$ = "TYPE" Then
                                If n <> 2 Then a$ = "Expected TYPE typename": GoTo errmes
                                lasttype = lasttype + 1
                                typeDefinitions$ = typeDefinitions$ + MKL$(-1) + MKL$(lasttype)
                                definingtype = lasttype
                                i = definingtype
                                While i > UBound(udtenext): increaseUDTArrays: Wend
                                If validname(secondelement$) = 0 Then a$ = "Invalid name": GoTo errmes
                                typeDefinitions$ = typeDefinitions$ + MKL$(Len(secondelement$)) + secondelement$
                                udtxname(i) = secondelement$
                                udtxcname(i) = getelement(ca$, 2)
                                udtxnext(i) = 0
                                udtxsize(i) = 0
                                udtxvariable(i) = 0

                                hashname$ = secondelement$
                                hashflags = HASHFLAG_UDT
                                'check for name conflicts (any similar reserved/sub/function/UDT name)
                                hashchkflags = HASHFLAG_RESERVED + HASHFLAG_SUB + HASHFLAG_FUNCTION + HASHFLAG_UDT
                                hashres = HashFind(hashname$, hashchkflags, hashresflags, hashresref)
                                Do While hashres
                                    allow = 0
                                    If hashresflags And (HASHFLAG_SUB + HASHFLAG_FUNCTION) Then
                                        allow = 1
                                    End If
                                    If hashresflags And HASHFLAG_RESERVED Then
                                        If (hashresflags And (HASHFLAG_TYPE + HASHFLAG_OPERATOR + HASHFLAG_CUSTOMSYNTAX + HASHFLAG_XTYPENAME)) = 0 Then allow = 1
                                    End If
                                    If allow = 0 Then a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                    If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
                                Loop

                                'add to hash table
                                HashAdd hashname$, hashflags, i

                                GoTo finishedlinepp
                            End If
                        End If

                        If n >= 1 And firstelement$ = "CONST" Then
                            'l$ = "CONST"
                            'DEF... do not change type, the expression is stored in a suitable type
                            'based on its value if type isn't forced/specified

                            If subfuncn > 0 And closedsubfunc <> 0 Then a$ = "Statement cannot be placed between SUB/FUNCTIONs": GoTo errmes

                            'convert periods to _046_
                            i2 = InStr(a$, sp + "." + sp)
                            If i2 Then
                                Do
                                    a$ = Left$(a$, i2 - 1) + fix046$ + Right$(a$, Len(a$) - i2 - 2)
                                    ca$ = Left$(ca$, i2 - 1) + fix046$ + Right$(ca$, Len(ca$) - i2 - 2)
                                    i2 = InStr(a$, sp + "." + sp)
                                Loop Until i2 = 0
                                n = numelements(a$)
                                firstelement$ = getelement(a$, 1): secondelement$ = getelement(a$, 2): thirdelement$ = getelement(a$, 3)
                            End If

                            If n < 3 Then a$ = "Expected CONST name = value/expression": GoTo errmes
                            i = 2
                            constdefpendingpp:
                            pending = 0

                            n$ = getelement$(ca$, i): i = i + 1
                            typeoverride = 0
                            s$ = removesymbol$(n$)
                            If Error_Happened Then GoTo errmes
                            If s$ <> "" Then
                                typeoverride = typname2typ(s$)
                                If Error_Happened Then GoTo errmes
                                If typeoverride And ISFIXEDLENGTH Then a$ = "Invalid constant type": GoTo errmes
                                If typeoverride = 0 Then a$ = "Invalid constant type": GoTo errmes
                            End If

                            If getelement$(a$, i) <> "=" Then a$ = "Expected =": GoTo errmes
                            i = i + 1

                            'get expression
                            e$ = ""
                            readable_e$ = ""
                            B = 0
                            For i2 = i To n
                                e2$ = getelement$(ca$, i2)
                                If e2$ = "(" Then B = B + 1
                                If e2$ = ")" Then B = B - 1
                                If e2$ = "," And B = 0 Then
                                    pending = 1
                                    i = i2 + 1
                                    If i > n - 2 Then a$ = "Expected CONST ... , name = value/expression": GoTo errmes
                                    Exit For
                                End If
                                If Len(e$) = 0 Then e$ = e2$ Else e$ = e$ + sp + e2$

                                e3$ = e2$
                                If Len(e2$) > 1 Then
                                    If Asc(e2$, 1) = 34 Then
                                        removeComma = _InStrRev(e2$, ",")
                                        e3$ = Left$(e2$, removeComma - 1)
                                    Else
                                        removeComma = InStr(e2$, ",")
                                        e3$ = Mid$(e2$, removeComma + 1)
                                    End If
                                End If

                                If Len(readable_e$) = 0 Then
                                    readable_e$ = e3$
                                Else
                                    readable_e$ = readable_e$ + " " + e3$
                                End If
                            Next

                            'intercept current expression and pass it through Evaluate_Expression$
                            '(unless it is a literal string)
                            If Left$(readable_e$, 1) <> Chr$(34) Then
                                temp1$ = _Trim$(Evaluate_Expression$(readable_e$))
                                If Left$(temp1$, 5) <> "ERROR" And e$ <> temp1$ Then
                                    e$ = lineformat(temp1$) 'retrieve parseable format
                                Else
                                    If temp1$ = "ERROR - Division By Zero" Then a$ = temp1$: GoTo errmes
                                    If InStr(temp1$, "Improper operations") Then
                                        a$ = "Invalid CONST expression.14": GoTo errmes
                                    End If
                                End If
                            End If

                            'Proceed as usual
                            e$ = fixoperationorder(e$)
                            If Error_Happened Then GoTo errmes

                            e$ = evaluateconst(e$, t)
                            If Error_Happened Then GoTo errmes

                            If t And ISSTRING Then 'string type

                                If typeoverride Then
                                    If (typeoverride And ISSTRING) = 0 Then a$ = "Type mismatch": GoTo errmes
                                End If

                            Else 'not a string type

                                If typeoverride Then
                                    If typeoverride And ISSTRING Then a$ = "Type mismatch": GoTo errmes
                                End If

                                If t And ISFLOAT Then
                                    constval## = _CV(_Float, e$)
                                    constval&& = constval##
                                    constval~&& = constval&&
                                Else
                                    If (t And ISUNSIGNED) And (t And 511) = 64 Then
                                        constval~&& = _CV(_Unsigned _Integer64, e$)
                                        constval&& = constval~&&
                                        constval## = constval&&
                                    Else
                                        constval&& = _CV(_Integer64, e$)
                                        constval## = constval&&
                                        constval~&& = constval&&
                                    End If
                                End If

                                'override type?
                                If typeoverride Then
                                    'range check required here (noted in todo)
                                    t = typeoverride
                                End If

                            End If 'not a string type

                            constlast = constlast + 1
                            If constlast > constmax Then
                                constmax = constmax * 2
                                ReDim _Preserve constname(constmax) As String
                                ReDim _Preserve constcname(constmax) As String
                                ReDim _Preserve constnamesymbol(constmax) As String 'optional name symbol
                                ReDim _Preserve consttype(constmax) As Long 'variable type number
                                ReDim _Preserve constinteger(constmax) As _Integer64
                                ReDim _Preserve constuinteger(constmax) As _Unsigned _Integer64
                                ReDim _Preserve constfloat(constmax) As _Float
                                ReDim _Preserve conststring(constmax) As String
                                ReDim _Preserve constsubfunc(constmax) As Long
                                ReDim _Preserve constdefined(constmax) As Long
                            End If

                            i2 = constlast

                            constsubfunc(i2) = subfuncn
                            'IF subfunc = "" THEN constlastshared = i2

                            If validname(n$) = 0 Then a$ = "Invalid name": GoTo errmes
                            constname(i2) = UCase$(n$)

                            hashname$ = n$
                            'check for name conflicts (any similar: reserved, sub, function, constant)

                            allow = 0
                            const_recheck:
                            hashchkflags = HASHFLAG_RESERVED + HASHFLAG_SUB + HASHFLAG_FUNCTION + HASHFLAG_CONSTANT
                            hashres = HashFind(hashname$, hashchkflags, hashresflags, hashresref)
                            Do While hashres
                                If hashresflags And HASHFLAG_CONSTANT Then
                                    If constsubfunc(hashresref) = subfuncn Then
                                        'If merely redefining a CONST with same value
                                        'just issue a warning instead of an error
                                        issueWarning = 0
                                        If t And ISSTRING Then
                                            If conststring(hashresref) = e$ Then issueWarning = -1: thisconstval$ = e$
                                        Else
                                            If t And ISFLOAT Then
                                                If constfloat(hashresref) = constval## Then issueWarning = -1: thisconstval$ = Str$(constval##)
                                            Else
                                                If t And ISUNSIGNED Then
                                                    If constuinteger(hashresref) = constval~&& Then issueWarning = -1: thisconstval$ = Str$(constval~&&)
                                                Else
                                                    If constinteger(hashresref) = constval&& Then issueWarning = -1: thisconstval$ = Str$(constval&&)
                                                End If
                                            End If
                                        End If
                                        If issueWarning Then
                                            If Not IgnoreWarnings Then
                                                addWarning linenumber, inclevel, inclinenumber(inclevel), incname$(inclevel), "duplicate constant definition", n$ + " =" + thisconstval$
                                            End If
                                            GoTo constAddDone
                                        Else
                                            a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                        End If
                                    End If
                                End If
                                If hashresflags And HASHFLAG_RESERVED Then
                                    a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                End If
                                If hashresflags And (HASHFLAG_SUB + HASHFLAG_FUNCTION) Then
                                    If ids(hashresref).internal_subfunc = 0 Or RTrim$(ids(hashresref).musthave) <> "$" Then a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                    If t And ISSTRING Then a$ = "Name already in use (" + hashname$ + ")": GoTo errmes
                                End If
                                If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
                            Loop

                            'add to hash table
                            HashAdd hashname$, HASHFLAG_CONSTANT, i2

                            constdefined(i2) = 1
                            constcname(i2) = n$
                            constnamesymbol(i2) = typevalue2symbol$(t)
                            If Error_Happened Then GoTo errmes
                            consttype(i2) = t
                            If t And ISSTRING Then
                                conststring(i2) = e$
                            Else
                                If t And ISFLOAT Then
                                    constfloat(i2) = constval##
                                Else
                                    If t And ISUNSIGNED Then
                                        constuinteger(i2) = constval~&&
                                    Else
                                        constinteger(i2) = constval&&
                                    End If
                                End If
                            End If

                            constAddDone:

                            If pending Then
                                'l$ = l$ + sp2 + ","
                                GoTo constdefpendingpp
                            End If

                            'layoutdone = 1: IF LEN(layout$) THEN layout$ = layout$ + sp + l$ ELSE layout$ = l$
                            GoTo finishedlinepp
                        End If

                        'DEFINE
                        d = 0
                        If firstelement$ = "DEFINT" Then d = 1
                        If firstelement$ = "DEFLNG" Then d = 1
                        If firstelement$ = "DEFSNG" Then d = 1
                        If firstelement$ = "DEFDBL" Then d = 1
                        If firstelement$ = "DEFSTR" Then d = 1
                        If firstelement$ = "_DEFINE" Then d = 1
                        If d Then
                            predefining = 1: GoTo predefine
                            predefined: predefining = 0
                            GoTo finishedlinepp
                        End If

                        'declare library
                        If firstelement$ = "DECLARE" Then
                            If secondelement$ = "LIBRARY" Or secondelement$ = "DYNAMIC" Or secondelement$ = "CUSTOMTYPE" Or secondelement$ = "STATIC" Then
                                declaringlibrary = 1
                                indirectlibrary = 0
                                If secondelement$ = "CUSTOMTYPE" Or secondelement$ = "DYNAMIC" Then indirectlibrary = 1
                                GoTo finishedlinepp
                            End If
                        End If

                        'SUB/FUNCTION
                        dynamiclibrary = 0
                        declaresubfunc:
                        firstelement$ = getelement$(a$, 1)
                        sf = 0
                        If firstelement$ = "FUNCTION" Then sf = 1
                        If firstelement$ = "SUB" Then sf = 2
                        If sf Then

                            subfuncn = subfuncn + 1
                            closedsubfunc = 0

                            If n = 1 Then a$ = "Expected name after SUB/FUNCTION": GoTo errmes

                            'convert periods to _046_
                            i2 = InStr(a$, sp + "." + sp)
                            If i2 Then
                                Do
                                    a$ = Left$(a$, i2 - 1) + fix046$ + Right$(a$, Len(a$) - i2 - 2)
                                    ca$ = Left$(ca$, i2 - 1) + fix046$ + Right$(ca$, Len(ca$) - i2 - 2)
                                    i2 = InStr(a$, sp + "." + sp)
                                Loop Until i2 = 0
                                n = numelements(a$)
                                firstelement$ = getelement(a$, 1): secondelement$ = getelement(a$, 2): thirdelement$ = getelement(a$, 3)
                            End If

                            n$ = getelement$(ca$, 2)
                            symbol$ = removesymbol$(n$)
                            If Error_Happened Then GoTo errmes
                            If sf = 2 And symbol$ <> "" Then a$ = "Type symbols after a SUB name are invalid": GoTo errmes

                            'remove STATIC (which is ignored)
                            e$ = getelement$(a$, n): If e$ = "STATIC" Then a$ = Left$(a$, Len(a$) - 7): ca$ = Left$(ca$, Len(ca$) - 7): n = n - 1

                            'check for ALIAS
                            aliasname$ = n$ 'use given name by default
                            If n > 2 Then
                                e$ = getelement$(a$, 3)
                                If e$ = "ALIAS" Then
                                    If declaringlibrary = 0 Then a$ = "ALIAS can only be used with DECLARE LIBRARY": GoTo errmes
                                    If n = 3 Then a$ = "Expected ALIAS name-in-library": GoTo errmes
                                    e$ = getelement$(ca$, 4)
                                    'strip string content (optional)
                                    If Left$(e$, 1) = Chr$(34) Then
                                        e$ = Right$(e$, Len(e$) - 1)
                                        x = InStr(e$, Chr$(34)): If x = 0 Then a$ = "Expected " + Chr$(34): GoTo errmes
                                        e$ = Left$(e$, x - 1)
                                    End If
                                    'strip fix046$ (created by unquoted periods)
                                    Do While InStr(e$, fix046$)
                                        x = InStr(e$, fix046$): e$ = Left$(e$, x - 1) + "." + Right$(e$, Len(e$) - x + 1 - Len(fix046$))
                                    Loop
                                    'validate alias name
                                    If Len(e$) = 0 Then a$ = "Expected ALIAS name-in-library": GoTo errmes
                                    For x = 1 To Len(e$)
                                        a = Asc(e$, x)
                                        If alphanumeric(a) = 0 And a <> ASC_FULLSTOP And a <> ASC_COLON Then a$ = "Expected ALIAS name-in-library": GoTo errmes
                                    Next
                                    aliasname$ = e$
                                    'remove ALIAS section from line
                                    If n <= 4 Then a$ = getelements(a$, 1, 2)
                                    If n >= 5 Then a$ = getelements(a$, 1, 2) + sp + getelements(a$, 5, n)
                                    If n <= 4 Then ca$ = getelements(ca$, 1, 2)
                                    If n >= 5 Then ca$ = getelements(ca$, 1, 2) + sp + getelements(ca$, 5, n)
                                    n = n - 2
                                End If
                            End If

                            If declaringlibrary Then
                                If indirectlibrary Then
                                    aliasname$ = n$ 'override the alias name
                                End If
                            End If

                            params = 0
                            params$ = ""
                            paramsize$ = ""
                            nele$ = ""
                            nelereq$ = ""
                            If n > 2 Then
                                e$ = getelement$(a$, 3)
                                If e$ <> "(" Then a$ = "Expected (": GoTo errmes
                                e$ = getelement$(a$, n)
                                If e$ <> ")" Then a$ = "Expected )": GoTo errmes
                                If n < 4 Then a$ = "Expected ( ... )": GoTo errmes
                                If n = 4 Then GoTo nosfparams
                                B = 0
                                a2$ = ""
                                For i = 4 To n - 1
                                    e$ = getelement$(a$, i)
                                    If e$ = "(" Then B = B + 1
                                    If e$ = ")" Then B = B - 1
                                    If e$ = "," And B = 0 Then
                                        If i = n - 1 Then a$ = "Expected , ... )": GoTo errmes
                                        getlastparam:
                                        If a2$ = "" Then a$ = "Expected ... ,": GoTo errmes
                                        a2$ = Left$(a2$, Len(a2$) - 1)
                                        'possible format: [BYVAL]a[%][(1)][AS][type]
                                        n2 = numelements(a2$)
                                        array = 0
                                        t2$ = ""

                                        i2 = 1
                                        e$ = getelement$(a2$, i2): i2 = i2 + 1

                                        byvalue = 0
                                        If e$ = "BYVAL" Then
                                            If declaringlibrary = 0 Then a$ = "BYVAL can currently only be used with DECLARE LIBRARY": GoTo errmes
                                            e$ = getelement$(a2$, i2): i2 = i2 + 1: byvalue = 1
                                        End If

                                        n2$ = e$
                                        symbol2$ = removesymbol$(n2$)
                                        If validname(n2$) = 0 Then a$ = "Invalid name": GoTo errmes

                                        If Error_Happened Then GoTo errmes
                                        m = 0
                                        For i2 = i2 To n2
                                            e$ = getelement$(a2$, i2)
                                            If e$ = "(" Then
                                                If m <> 0 Then a$ = "Syntax error - too many opening brackets": GoTo errmes
                                                m = 1
                                                array = 1
                                                GoTo gotaa
                                            End If
                                            If e$ = ")" Then
                                                If m <> 1 Then a$ = "Syntax error - closing bracket without opening bracket": GoTo errmes
                                                m = 2
                                                GoTo gotaa
                                            End If
                                            If e$ = "AS" Then
                                                If m <> 0 And m <> 2 Then a$ = "Syntax error - check your brackets": GoTo errmes
                                                m = 3
                                                GoTo gotaa
                                            End If
                                            If m = 1 Then GoTo gotaa 'ignore contents of bracket
                                            If m <> 3 Then a$ = "Syntax error - check your brackets": GoTo errmes
                                            If t2$ = "" Then t2$ = e$ Else t2$ = t2$ + " " + e$
                                            gotaa:
                                        Next i2

                                        params = params + 1: If params > 100 Then a$ = "SUB/FUNCTION exceeds 100 parameter limit": GoTo errmes

                                        argnelereq = 0

                                        If symbol2$ <> "" And t2$ <> "" Then a$ = "Syntax error - check parameter types": GoTo errmes
                                        If t2$ = "" And e$ = "AS" Then a$ = "Expected AS type": GoTo errmes
                                        If t2$ = "" Then t2$ = symbol2$
                                        If t2$ = "" Then
                                            If Left$(n2$, 1) = "_" Then v = 27 Else v = Asc(UCase$(n2$)) - 64
                                            t2$ = defineaz(v)
                                        End If

                                        paramsize = 0
                                        If array = 1 Then
                                            t = typname2typ(t2$)
                                            If Error_Happened Then GoTo errmes
                                            If t = 0 Then a$ = "Illegal SUB/FUNCTION parameter": GoTo errmes
                                            If (t And ISFIXEDLENGTH) Then paramsize = typname2typsize
                                            t = t + ISARRAY
                                            'check for recompilation override
                                            For i10 = 0 To sflistn
                                                If sfidlist(i10) = idn + 1 Then
                                                    If sfarglist(i10) = params Then
                                                        argnelereq = sfelelist(i10)
                                                    End If
                                                End If
                                            Next
                                        Else
                                            t = typname2typ(t2$)
                                            If Error_Happened Then GoTo errmes
                                            If t = 0 Then a$ = "Illegal SUB/FUNCTION parameter": GoTo errmes
                                            If (t And ISFIXEDLENGTH) Then paramsize = typname2typsize

                                            If byvalue Then
                                                If t And ISPOINTER Then t = t - ISPOINTER
                                            End If

                                        End If
                                        nelereq$ = nelereq$ + Chr$(argnelereq)

                                        'consider changing 0 in following line too!
                                        nele$ = nele$ + Chr$(0)

                                        paramsize$ = paramsize$ + MKL$(paramsize)
                                        params$ = params$ + MKL$(t)
                                        a2$ = ""
                                    Else
                                        a2$ = a2$ + e$ + sp
                                        If i = n - 1 Then GoTo getlastparam
                                    End If
                                Next i
                            End If 'n>2
                            nosfparams:

                            If sf = 1 Then
                                'function
                                clearid
                                id.n = n$
                                id.subfunc = 1

                                id.callname = "FUNC_" + UCase$(n$)
                                If declaringlibrary Then
                                    id.ccall = 1
                                    If indirectlibrary = 0 Then id.callname = aliasname$
                                End If
                                id.args = params
                                id.arg = params$
                                id.argsize = paramsize$
                                id.nele = nele$
                                id.nelereq = nelereq$
                                If symbol$ <> "" Then
                                    id.ret = typname2typ(symbol$)
                                    If Error_Happened Then GoTo errmes
                                Else
                                    If Left$(n$, 1) = "_" Then v = 27 Else v = Asc(UCase$(n$)) - 64
                                    symbol$ = defineaz(v)
                                    id.ret = typname2typ(symbol$)
                                    If Error_Happened Then GoTo errmes
                                End If
                                If id.ret = 0 Then a$ = "Invalid FUNCTION return type": GoTo errmes

                                If declaringlibrary Then

                                    ctype$ = typ2ctyp$(id.ret, "")
                                    If Error_Happened Then GoTo errmes
                                    If ctype$ = "qbs" Then ctype$ = "char*"
                                    id.callname = "(  " + ctype$ + "  )" + RTrim$(id.callname)

                                End If

                                s$ = Left$(symbol$, 1)
                                If s$ <> "~" And s$ <> "`" And s$ <> "%" And s$ <> "&" And s$ <> "!" And s$ <> "#" And s$ <> "$" Then
                                    symbol$ = type2symbol$(symbol$)
                                    If Error_Happened Then GoTo errmes
                                End If
                                id.mayhave = symbol$
                                If id.ret And ISPOINTER Then
                                    If (id.ret And ISSTRING) = 0 Then id.ret = id.ret - ISPOINTER
                                End If
                                regid
                                If Error_Happened Then GoTo errmes
                            Else
                                'sub
                                clearid
                                id.n = n$
                                id.subfunc = 2
                                id.callname = "SUB_" + UCase$(n$)
                                If declaringlibrary Then
                                    id.ccall = 1
                                    If indirectlibrary = 0 Then id.callname = aliasname$
                                End If
                                id.args = params
                                id.arg = params$
                                id.argsize = paramsize$
                                id.nele = nele$
                                id.nelereq = nelereq$

                                If UCase$(n$) = "_GL" And params = 0 And UseGL = 0 Then reginternalsubfunc = 1: UseGL = 1: id.n = "_GL": DEPENDENCY(DEPENDENCY_GL) = 1
                                regid
                                reginternalsubfunc = 0

                                If Error_Happened Then GoTo errmes
                            End If


                        End If

                        '========================================
                        finishedlinepp:
                        firstLine = 0
                    End If
                    a$ = ""
                    ca$ = ""
                Else
                    If a$ = "" Then a$ = e$: ca$ = ce$ Else a$ = a$ + sp + e$: ca$ = ca$ + sp + ce$
                End If
                If wholelinei <= wholelinen Then wholelinei = wholelinei + 1: GoTo ppblda
                '----------------------------------------
            End If 'wholelinei<=wholelinen
        End If 'wholelinen
    End If 'len(wholeline$)

    'Include Manager #1

    If Len(addmetainclude$) Then
        a$ = addmetainclude$: addmetainclude$ = "" 'read/clear message

        If inclevel = 0 Then
            includingFromRoot = 0
            forceIncludingFile = 0
            forceInclude_prepass:
            If forceIncludeFromRoot$ <> "" Then
                a$ = forceIncludeFromRoot$
                forceIncludeFromRoot$ = ""
                forceIncludingFile = 1
                includingFromRoot = 1
            End If
        End If

        If inclevel = 100 Then a$ = "Too many indwelling INCLUDE files": GoTo errmes
        '1. Verify file exists (location is either (a)relative to source file or (b)absolute)
        fh = 99 + inclevel + 1

        firstTryMethod = 1
        If includingFromRoot <> 0 And inclevel = 0 Then firstTryMethod = 2
        For try = firstTryMethod To 2 'if including file from root, do not attempt including from relative location
            If try = 1 Then
                If inclevel = 0 Then
                    If idemode Then p$ = idepath$ + pathsep$ Else p$ = getfilepath$(sourcefile$)
                Else
                    p$ = getfilepath$(incname(inclevel))
                End If
                f$ = p$ + a$
            End If
            If try = 2 Then f$ = a$
            If _FileExists(f$) Then
                qberrorhappened = -3
                'We're using the faster LINE INPUT, which requires a BINARY open.
                Open f$ For Binary As #fh
                'And another line below edited
                qberrorhappened3:
                If qberrorhappened = -3 Then Exit For
            End If
            qberrorhappened = 0
        Next
        If qberrorhappened <> -3 Then qberrorhappened = 0: a$ = "File " + a$ + " not found": GoTo errmes
        inclevel = inclevel + 1: incname$(inclevel) = f$: inclinenumber(inclevel) = 0
    End If 'fall through to next section...
    '--------------------
    Do While inclevel

        fh = 99 + inclevel
        '2. Feed next line
        If EOF(fh) = 0 Then
            Line Input #fh, x$

            wholeline$ = x$
            inclinenumber(inclevel) = inclinenumber(inclevel) + 1
            'create extended error string 'incerror$'
            errorLineInInclude = inclinenumber(inclevel)
            e$ = " in line " + str2(inclinenumber(inclevel)) + " of " + incname$(inclevel) + " included"
            If inclevel > 1 Then
                e$ = e$ + " (through "
                For x = 1 To inclevel - 1 Step 1
                    e$ = e$ + incname$(x)
                    If x < inclevel - 1 Then 'a sep is req
                        If x = inclevel - 2 Then
                            e$ = e$ + " then "
                        Else
                            e$ = e$ + ", "
                        End If
                    End If
                Next
                e$ = e$ + ")"
            End If
            incerror$ = e$
            linenumber = linenumber - 1 'lower official linenumber to counter later increment

            If idemode Then sendc$ = Chr$(10) + wholeline$: GoTo sendcommand 'passback
            GoTo ideprepass
        End If
        '3. Close & return control
        Close #fh
        inclevel = inclevel - 1
        If forceIncludingFile = 1 And inclevel = 0 Then
            forceIncludingFile = 0
            GoTo forceIncludeCompleted_prepass
        End If
    Loop
    '(end manager)

    If idemode Then GoTo ideret2
Loop

'add final line
If lastLineReturn = 0 Then
    lastLineReturn = 1
    lastLine = 1
    wholeline$ = ""
    GoTo prepassLastLine
End If

If definingtype Then definingtype = 0 'ignore this error so that auto-formatting can be performed and catch it again later
If declaringlibrary Then declaringlibrary = 0 'ignore this error so that auto-formatting can be performed and catch it again later

totallinenumber = reallinenumber

'IF idemode = 0 AND NOT QuietMode THEN PRINT "first pass finished.": PRINT "Translating code... "

'prepass finished

lineinput3index = 1 'reset input line

'ide specific
ide3:

addmetainclude$ = "" 'reset stray meta-includes

'reset altered variables
DataOffset = 0
inclevel = 0
subfuncn = 0
lastLineReturn = 0
lastLine = 0
firstLine = 1
UserDefineCount = 7

For i = 0 To constlast: constdefined(i) = 0: Next 'undefine constants

For i = 1 To 27: defineaz(i) = "SINGLE": defineextaz(i) = "!": Next

Open tmpdir$ + "data.bin" For Output As #16: Close #16
Open tmpdir$ + "data.bin" For Binary As #16


Open tmpdir$ + "main.txt" For Output As #12
Open tmpdir$ + "maindata.txt" For Output As #13

Open tmpdir$ + "regsf.txt" For Output As #17

Open tmpdir$ + "mainfree.txt" For Output As #19
Open tmpdir$ + "runline.txt" For Output As #21

Open tmpdir$ + "mainerr.txt" For Output As #14 'main error handler
'i. check the value of error_line
'ii. jump to the appropriate label
errorlabels = 0
Print #14, "if (error_occurred){ error_occurred=0;"

Open tmpdir$ + "chain.txt" For Output As #22: Close #22 'will be appended to as necessary
Open tmpdir$ + "inpchain.txt" For Output As #23: Close #23 'will be appended to as necessary
'*** #22 & #23 are reserved for usage by chain & inpchain ***

Open tmpdir$ + "ontimer.txt" For Output As #24
Open tmpdir$ + "ontimerj.txt" For Output As #25

'*****#26 used for locking qb64

Open tmpdir$ + "onkey.txt" For Output As #27
Open tmpdir$ + "onkeyj.txt" For Output As #28

Open tmpdir$ + "onstrig.txt" For Output As #29
Open tmpdir$ + "onstrigj.txt" For Output As #30

gosubid = 1
'to be included whenever return without a label is called

'return [label] in QBASIC was not possible in a sub/function, but QB64 will support this
'special codes will represent special return conditions:
'0=return from main to calling sub/function/proc by return [NULL];
'1... a global number representing a return point after a gosub
'note: RETURN [label] should fail if a "return [NULL];" type return is required
Open tmpdir$ + "ret0.txt" For Output As #15
Print #15, "if (next_return_point){"
Print #15, "next_return_point--;"
Print #15, "switch(return_point[next_return_point]){"
Print #15, "case 0:"

Print #15, "return;"

Print #15, "break;"

continueline = 0
endifs = 0
lineelseused = 0
continuelinefrom = 0
linenumber = 0
reallinenumber = 0
declaringlibrary = 0

Print #12, "S_0:;" 'note: REQUIRED by run statement

If UseGL Then gl_include_content


'ide specific
If idemode Then GoTo ideret3

Do
    ide4:
    includeline:
    mainpassLastLine:

    If lastLine <> 0 Or firstLine <> 0 Then
        lineBackup$ = a3$ 'backup the real first line (will be blank when lastline is set)
        forceIncludeFromRoot$ = ""
        firstLine = 0: lastLine = 0
        If Len(forceIncludeFromRoot$) Then GoTo forceInclude
        forceIncludeCompleted:
        addingvWatch = 0
        a3$ = lineBackup$
    End If

    prepass = 0

    stringprocessinghappened = 0

    If continuelinefrom Then
        start = continuelinefrom
        continuelinefrom = 0
        GoTo contline
    End If

    'begin a new line

    impliedendif = 0
    THENGOTO = 0
    continueline = 0
    endifs = 0
    lineelseused = 0
    newif = 0

    'apply metacommands from previous line
    If addmetadynamic = 1 Then addmetadynamic = 0: DynamicMode = 1
    If addmetastatic = 1 Then addmetastatic = 0: DynamicMode = 0

    'a3$ is passed in idemode and when using $include
    If idemode = 0 And inclevel = 0 Then a3$ = lineinput3$
    If a3$ = Chr$(13) Then Exit Do
    linenumber = linenumber + 1
    reallinenumber = reallinenumber + 1

    If InValidLine(linenumber) Then
        layoutok = 1
        layout$ = Space$(controllevel + 1) + LTrim$(RTrim$(a3$))
        If idemode GoTo ideret4 Else GoTo skipide4
    End If

    layout = ""
    layoutok = 1

    If idemode = 0 And Not QuietMode Then
        'IF LEN(a3$) THEN
        '    dotlinecount = dotlinecount + 1: IF dotlinecount >= 100 THEN dotlinecount = 0: PRINT ".";
        'END IF
        maxprogresswidth = 50 'arbitrary
        percentage = Int(reallinenumber / totallinenumber * 100)
        percentagechars = Int(maxprogresswidth * reallinenumber / totallinenumber)
        If percentage <> prevpercentage And percentagechars <> prevpercentagechars Then
            prevpercentage = percentage
            prevpercentagechars = percentagechars
            If ConsoleMode Then
                Print "[" + String$(percentagechars, ".") + Space$(maxprogresswidth - percentagechars) + "]" + Str$(percentage) + "%";

                Print Chr$(27) + "[A"
            Else
                Locate , 1
                Print String$(percentagechars, 219) + String$(maxprogresswidth - percentagechars, 176) + Str$(percentage) + "%";
            End If
        End If
    End If

    a3$ = LTrim$(RTrim$(a3$))
    wholeline = a3$

    layoutoriginal$ = a3$
    layoutcomment$ = "" 'clear any previous layout comment
    lhscontrollevel = controllevel

    linefragment = "[INFORMATION UNAVAILABLE]"
    If Len(a3$) = 0 Then GoTo finishednonexec
    layoutdone = 1 'validates layout of any following goto finishednonexec/finishedline

    'We've already figured out in the prepass which lines are invalidated by the precompiler
    'No need to go over those lines again.
    'IF InValidLine(linenumber) THEN goto skipide4 'layoutdone = 0: GOTO finishednonexec

    a3u$ = UCase$(a3$)

    'QB64 Metacommands
    If Asc(a3$) = 36 Then '$

        'precompiler commands should always be executed FIRST.
        If a3u$ = "$END IF" Or a3u$ = "$ENDIF" Then
            If DefineElse(ExecCounter) = 0 Then a$ = "$END IF without $IF": GoTo errmes
            DefineElse(ExecCounter) = 0 'We no longer have an $IF block at this level
            ExecCounter = ExecCounter - 1
            layout$ = SCase$("$End If")
            controltype(controllevel) = 0
            controllevel = controllevel - 1
            GoTo finishednonexec
        End If

        If Left$(a3u$, 4) = "$IF " Then
            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            temp$ = LTrim$(Mid$(a3u$, 4)) 'strip off the $IF and extra spaces
            temp$ = RTrim$(Left$(temp$, Len(temp$) - 4)) 'and strip off the THEN and extra spaces
            temp = 0
            If temp = 0 Then tempOp$ = "<=": temp = InStr(temp$, tempOp$)
            If temp = 0 Then tempOp$ = "=<": temp = InStr(temp$, tempOp$): tempOp$ = "<="
            If temp = 0 Then tempOp$ = ">=": temp = InStr(temp$, tempOp$)
            If temp = 0 Then tempOp$ = "=>": temp = InStr(temp$, tempOp$): tempOp$ = ">="
            If temp = 0 Then tempOp$ = "<>": temp = InStr(temp$, tempOp$)
            If temp = 0 Then tempOp$ = "><": temp = InStr(temp$, tempOp$): tempOp$ = "<>"
            If temp = 0 Then tempOp$ = "=": temp = InStr(temp$, tempOp$)
            If temp = 0 Then tempOp$ = ">": temp = InStr(temp$, tempOp$)
            If temp = 0 Then tempOp$ = "<": temp = InStr(temp$, tempOp$)

            ExecCounter = ExecCounter + 1
            ExecLevel(ExecCounter) = -1 'default to a skip value
            DefineElse(ExecCounter) = 1 '1 says we have an $IF statement at this level
            result = EvalPreIF(temp$, a$)
            If a$ <> "" Then GoTo errmes
            If result <> 0 Then
                ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'So we inherit the execlevel from above
                If ExecLevel(ExecCounter) = 0 Then DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 4 'Else if used and conditon found
            End If

            controllevel = controllevel + 1
            controltype(controllevel) = 6
            If temp = 0 Then layout$ = SCase$("$If ") + temp$ + SCase$(" Then"): GoTo finishednonexec 'no = sign in the $IF statement, so we're going to assume the user is doing something like $IF flag
            l$ = RTrim$(Left$(temp$, temp - 1)): r$ = LTrim$(Mid$(temp$, temp + Len(tempOp$)))
            layout$ = SCase$("$If ") + l$ + " " + tempOp$ + " " + r$ + SCase$(" Then")
            GoTo finishednonexec
        End If

        If a3u$ = "$ELSE" Then
            If DefineElse(ExecCounter) = 0 Then a$ = "$ELSE without $IF": GoTo errmes
            If DefineElse(ExecCounter) And 2 Then a$ = "$IF block already has $ELSE statement in it": GoTo errmes
            DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 2 'set the flag to declare an $ELSE already in this block
            If DefineElse(ExecCounter) And 4 Then 'If we executed code in a previous IF or ELSE IF statement, we can't do it here
                ExecLevel(ExecCounter) = -1 'So we inherit the execlevel from above
            Else
                ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'If we were processing code before, code after this segment is going to be SKIPPED
            End If
            layout$ = SCase$("$Else")
            lhscontrollevel = lhscontrollevel - 1
            GoTo finishednonexec
        End If

        If Left$(a3u$, 5) = "$ELSE" Then
            temp$ = LTrim$(Mid$(a3u$, 6))
            If Left$(temp$, 3) = "IF " Then
                If DefineElse(ExecCounter) = 0 Then a$ = "$ELSE IF without $IF": GoTo errmes
                If DefineElse(ExecCounter) And 2 Then a$ = "$ELSE IF cannot follow $ELSE": GoTo errmes
                If Right$(temp$, 5) <> " THEN" Then a$ = "$ELSE IF without THEN": GoTo errmes
                temp$ = LTrim$(Mid$(temp$, 3)) 'strip off the IF and extra spaces
                temp$ = RTrim$(Left$(temp$, Len(temp$) - 4)) 'and strip off the THEN and extra spaces
                If DefineElse(ExecCounter) And 4 Then 'If we executed code in a previous IF or ELSE IF statement, we can't do it here
                    ExecLevel(ExecCounter) = -1
                Else
                    result = EvalPreIF(temp$, a$)
                    If a$ <> "" Then GoTo errmes
                    If result <> 0 Then
                        ExecLevel(ExecCounter) = ExecLevel(ExecCounter - 1) 'So we inherit the execlevel from above
                        If ExecLevel(ExecCounter) = 0 Then DefineElse(ExecCounter) = DefineElse(ExecCounter) Or 4 'Else if used and conditon found
                    End If
                End If


                lhscontrollevel = lhscontrollevel - 1
                temp = InStr(temp$, "=")
                If temp = 0 Then layout$ = SCase$("$ElseIf ") + temp$ + SCase$(" Then"): GoTo finishednonexec 'no = sign in the $IF statement, so we're going to assume the user is doing something like $IF flag
                l$ = RTrim$(Left$(temp$, temp - 1)): r$ = LTrim$(Mid$(temp$, temp + 1))
                layout$ = SCase$("$ElseIf ") + l$ + " = " + r$ + SCase$(" Then")
                GoTo finishednonexec
            End If
        End If

        If ExecLevel(ExecCounter) Then 'don't check for any more metacommands except the one's which worth with the precompiler
            layoutdone = 0
            GoTo finishednonexec 'we don't check for anything inside lines that we've marked for skipping
        End If

        If Left$(a3u$, 5) = "$LET " Then
            temp$ = a3u$
            temp$ = LTrim$(Mid$(temp$, 5)) 'simply shorten our string to parse
            'For starters, let's make certain that we have 3 elements to deal with
            temp = InStr(temp$, "=") 'without an = in there, we can't get a value from the left and right side
            l$ = RTrim$(Left$(temp$, temp - 1)): r$ = LTrim$(Mid$(temp$, temp + 1))
            layout$ = SCase$("$Let ") + l$ + " = " + r$
            'First look to see if we have an existing setting like this and if so, update it
            For i = 7 To UserDefineCount 'UserDefineCount 1-7 are reserved for automatic OS/BIT detection & version
                If UserDefine(0, i) = l$ Then UserDefine(1, i) = r$: GoTo finishednonexec
            Next
            'Otherwise create a new setting and set the initial value for it
            UserDefineCount = UserDefineCount + 1
            If UserDefineCount > UBound(UserDefine, 2) Then
                ReDim _Preserve UserDefine(1, UBound(UserDefine, 2) + 10) 'Add another 10 elements to the array so it'll expand as the user adds to it
            End If
            UserDefine(0, UserDefineCount) = l$
            UserDefine(1, UserDefineCount) = r$
            GoTo finishednonexec
        End If

        If a3u$ = "$COLOR:0" Then
            layout$ = SCase$("$Color:0")
            addmetainclude$ = getfilepath$(Command$(0)) + "internal" + pathsep$ + "support" + pathsep$ + "color" + pathsep$ + "color0.bi"
            layoutdone = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$COLOR:32" Then
            layout$ = SCase$("$Color:32")
            addmetainclude$ = getfilepath$(Command$(0)) + "internal" + pathsep$ + "support" + pathsep$ + "color" + pathsep$ + "color32.bi"
            layoutdone = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$NOPREFIX" Then
            'already set in prepass
            layout$ = SCase$("$NoPrefix")
            GoTo finishednonexec
        End If

        If a3u$ = "$VIRTUALKEYBOARD:ON" Then
            'Deprecated; does nothing.
            layout$ = SCase$("$VirtualKeyboard:On")
            addWarning linenumber, inclevel, inclinenumber(inclevel), incname$(inclevel), "Deprecated feature", "$VirtualKeyboard"
            GoTo finishednonexec
        End If

        If a3u$ = "$VIRTUALKEYBOARD:OFF" Then
            'Deprecated; does nothing.
            layout$ = SCase$("$VirtualKeyboard:Off")
            addWarning linenumber, inclevel, inclinenumber(inclevel), incname$(inclevel), "Deprecated feature", "$VirtualKeyboard"
            GoTo finishednonexec
        End If

        If a3u$ = "$CHECKING:OFF" Then
            layout$ = SCase$("$Checking:Off")
            NoChecks = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$CHECKING:ON" Then
            layout$ = SCase$("$Checking:On")
            NoChecks = 0
            GoTo finishednonexec
        End If

        If a3u$ = "$CONSOLE" Then
            layout$ = SCase$("$Console")
            Console = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$CONSOLE:ONLY" Then
            layout$ = SCase$("$Console:Only")
            DEPENDENCY(DEPENDENCY_CONSOLE_ONLY) = DEPENDENCY(DEPENDENCY_CONSOLE_ONLY) Or 1
            Console = 1
            If prepass = 0 Then
                If NoChecks = 0 Then Print #12, "do{"
                Print #12, "sub__dest(func__console());"
                Print #12, "sub__source(func__console());"
                GoTo finishedline2
            Else
                GoTo finishednonexec
            End If
        End If

        If a3u$ = "$ASSERTS" Then
            layout$ = SCase$("$Asserts")
            Asserts = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$ASSERTS:CONSOLE" Then
            layout$ = SCase$("$Asserts:Console")
            Asserts = 1
            Console = 1
            GoTo finishednonexec
        End If

        If a3u$ = "$SCREENHIDE" Then
            layout$ = SCase$("$ScreenHide")
            ScreenHide = 1
            GoTo finishednonexec
        End If
        If a3u$ = "$SCREENSHOW" Then
            layout$ = SCase$("$ScreenShow")
            ScreenHide = 0
            GoTo finishednonexec
        End If

        If a3u$ = "$RESIZE:OFF" Then
            layout$ = SCase$("$Resize:Off")
            Resize = 0: Resize_Scale = 0
            GoTo finishednonexec
        End If
        If a3u$ = "$RESIZE:ON" Then
            layout$ = SCase$("$Resize:On")
            Resize = 1: Resize_Scale = 0
            GoTo finishednonexec
        End If

        If a3u$ = "$RESIZE:STRETCH" Then
            layout$ = SCase$("$Resize:Stretch")
            Resize = 1: Resize_Scale = 1
            GoTo finishednonexec
        End If
        If a3u$ = "$RESIZE:SMOOTH" Then
            layout$ = SCase$("$Resize:Smooth")
            Resize = 1: Resize_Scale = 2
            GoTo finishednonexec
        End If

        If Left$(a3u$, 8) = "$EXEICON" Then
            'Basic syntax check. Multi-platform.
            If ExeIconSet Then a$ = "$EXEICON already defined": GoTo errmes
            FirstDelimiter = InStr(a3u$, "'")
            If FirstDelimiter = 0 Then
                a$ = "Expected $EXEICON:'filename'": GoTo errmes
            Else
                SecondDelimiter = InStr(FirstDelimiter + 1, a3u$, "'")
                If SecondDelimiter = 0 Then a$ = "Expected $EXEICON:'filename'": GoTo errmes
            End If
            ExeIconFile$ = RTrim$(LTrim$(Mid$(a3$, FirstDelimiter + 1, SecondDelimiter - FirstDelimiter - 1)))
            If Len(ExeIconFile$) = 0 Then a$ = "Expected $EXEICON:'filename'": GoTo errmes
            layout$ = SCase$("$ExeIcon:'") + ExeIconFile$ + "'" + Mid$(a3$, SecondDelimiter + 1)

            ExeIconSet = linenumber
            SetDependency DEPENDENCY_ICON
            If NoChecks = 0 Then Print #12, "do{"
            Print #12, "sub__icon(NULL,NULL,0);"
            GoTo finishedline2
        End If

    End If 'QB64 Metacommands

    If ExecLevel(ExecCounter) Then
        layoutdone = 0
        GoTo finishednonexec 'we don't check for anything inside lines that we've marked for skipping
    End If

    linedataoffset = DataOffset

    entireline$ = lineformat(a3$): If Len(entireline$) = 0 Then GoTo finishednonexec
    If Error_Happened Then GoTo errmes
    u$ = UCase$(entireline$)

    newif = 0

    'Convert "CASE ELSE" to "CASE C-EL" to avoid confusing compiler
    'note: CASE does not have to begin on a new line
    s = 1
    i = InStr(s, u$, "CASE" + sp + "ELSE")
    Do While i
        skip = 0
        If i <> 1 Then
            If Mid$(u$, i - 1, 1) <> sp Then skip = 1
        End If
        If i <> Len(u$) - 8 Then
            If Mid$(u$, i + 9, 1) <> sp Then skip = 1
        End If
        If skip = 0 Then
            Mid$(entireline$, i) = "CASE" + sp + "C-EL"
            u$ = UCase$(entireline$)
        End If
        s = i + 9
        i = InStr(s, u$, "CASE" + sp + "ELSE")
    Loop

    n = numelements(entireline$)

    'line number?
    a = Asc(entireline$)
    If (a >= 48 And a <= 57) Or a = 46 Then 'numeric
        label$ = getelement(entireline$, 1)
        If validlabel(label$) Then

            If closedmain <> 0 And subfunc = "" Then a$ = "Labels cannot be placed between SUB/FUNCTIONs": GoTo errmes

            v = HashFind(label$, HASHFLAG_LABEL, ignore, r)
            addlabchk100:
            If v Then
                s = Labels(r).Scope
                If s = subfuncn Or s = -1 Then 'same scope?
                    If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                    If Labels(r).State = 1 Then a$ = "Duplicate label (" + RTrim$(Labels(r).cn) + ")": GoTo errmes
                    'aquire state 0 types
                    tlayout$ = RTrim$(Labels(r).cn)
                    GoTo addlabaq100
                End If 'same scope
                If v = 2 Then v = HashFindCont(ignore, r): GoTo addlabchk100
            End If

            'does not exist
            nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
            Labels(nLabels) = Empty_Label
            HashAdd label$, HASHFLAG_LABEL, nLabels
            r = nLabels
            Labels(r).cn = tlayout$
            Labels(r).Scope = subfuncn
            addlabaq100:
            Labels(r).State = 1
            Labels(r).Data_Offset = linedataoffset

            layout$ = tlayout$
            Print #12, "LABEL_" + label$ + ":;"


            If InStr(label$, "p") Then Mid$(label$, InStr(label$, "p"), 1) = "."
            If Right$(label$, 1) = "d" Or Right$(label$, 1) = "s" Then label$ = Left$(label$, Len(label$) - 1)
            Print #12, "last_line=" + label$ + ";"
            inclinenump$ = ""
            If inclinenumber(inclevel) Then
                inclinenump$ = "," + str2$(inclinenumber(inclevel))
                thisincname$ = getfilepath$(incname$(inclevel))
                thisincname$ = Mid$(incname$(inclevel), Len(thisincname$) + 1)
                inclinenump$ = inclinenump$ + "," + Chr$(34) + thisincname$ + Chr$(34)
            End If
            If NoChecks = 0 Then
                temp$ = ""
                Print #12, "if(qbevent){" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");r=0;}"
            End If
            If n = 1 Then GoTo finishednonexec
            entireline$ = getelements(entireline$, 2, n): u$ = UCase$(entireline$): n = n - 1
            'note: fall through, numeric labels can be followed by alphanumeric label
        End If 'validlabel
    End If 'numeric
    'it wasn't a line number

    'label?
    'note: ignores possibility that this could be a single command SUB/FUNCTION (as in QBASIC?)
    If n >= 2 Then
        x2 = InStr(entireline$, sp + ":")
        If x2 Then
            If x2 = Len(entireline$) - 1 Then x3 = x2 + 1 Else x3 = x2 + 2
            a$ = Left$(entireline$, x2 - 1)

            CreatingLabel = 1
            If validlabel(a$) Then

                If validname(a$) = 0 Then a$ = "Invalid name": GoTo errmes

                If closedmain <> 0 And subfunc = "" Then a$ = "Labels cannot be placed between SUB/FUNCTIONs": GoTo errmes

                v = HashFind(a$, HASHFLAG_LABEL, ignore, r)
                addlabchk:
                If v Then
                    s = Labels(r).Scope
                    If s = subfuncn Or s = -1 Then 'same scope?
                        If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                        If Labels(r).State = 1 Then a$ = "Duplicate label (" + RTrim$(Labels(r).cn) + ")": GoTo errmes
                        'aquire state 0 types
                        tlayout$ = RTrim$(Labels(r).cn)
                        GoTo addlabaq
                    End If 'same scope
                    If v = 2 Then v = HashFindCont(ignore, r): GoTo addlabchk
                End If
                'does not exist
                nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                Labels(nLabels) = Empty_Label
                HashAdd a$, HASHFLAG_LABEL, nLabels
                r = nLabels
                Labels(r).cn = tlayout$
                Labels(r).Scope = subfuncn
                addlabaq:
                Labels(r).State = 1
                Labels(r).Data_Offset = linedataoffset
                Labels(r).SourceLineNumber = linenumber

                If Len(layout$) Then layout$ = layout$ + sp + tlayout$ + ":" Else layout$ = tlayout$ + ":"

                Print #12, "LABEL_" + a$ + ":;"
                inclinenump$ = ""
                If inclinenumber(inclevel) Then
                    inclinenump$ = "," + str2$(inclinenumber(inclevel))
                    thisincname$ = getfilepath$(incname$(inclevel))
                    thisincname$ = Mid$(incname$(inclevel), Len(thisincname$) + 1)
                    inclinenump$ = inclinenump$ + "," + Chr$(34) + thisincname$ + Chr$(34)
                End If
                If NoChecks = 0 Then
                    temp$ = ""
                    Print #12, "if(qbevent){" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");r=0;}"
                End If
                entireline$ = Right$(entireline$, Len(entireline$) - x3): u$ = UCase$(entireline$)
                n = numelements(entireline$): If n = 0 Then GoTo finishednonexec
            End If 'valid
        End If 'includes sp+":"
    End If 'n>=2

    'remove leading ":"
    Do While Asc(u$) = 58 '":"
        If Len(layout$) Then layout$ = layout$ + sp2 + ":" Else layout$ = ":"
        If Len(u$) = 1 Then GoTo finishednonexec
        entireline$ = getelements(entireline$, 2, n): u$ = UCase$(entireline$): n = n - 1
    Loop

    'ELSE at the beginning of a line
    If Asc(u$) = 69 Then '"E"

        e1$ = getelement(u$, 1)

        If e1$ = "ELSE" Then
            a$ = "ELSE"
            If n > 1 Then continuelinefrom = 2
            GoTo gotcommand
        End If

        If e1$ = "ELSEIF" Then
            If n < 3 Then a$ = "Expected ... THEN": GoTo errmes
            If getelement(u$, n) = "THEN" Then a$ = entireline$: GoTo gotcommand
            For i = 3 To n - 1
                If getelement(u$, i) = "THEN" Then
                    a$ = getelements(entireline$, 1, i)
                    continuelinefrom = i + 1
                    GoTo gotcommand
                End If
            Next
            a$ = "Expected THEN": GoTo errmes
        End If

    End If '"E"

    start = 1

    GoTo skipcontinit

    contline:

    n = numelements(entireline$)
    u$ = UCase$(entireline$)

    skipcontinit:

    'jargon:
    'lineelseused - counts how many line ELSEs can POSSIBLY follow
    'endifs - how many C++ endifs "}" need to be added at the end of the line
    'lineelseused - counts the number of indwelling ELSE statements on a line
    'impliedendif - stops autoformat from adding "END IF"

    a$ = ""

    For i = start To n
        e$ = getelement(u$, i)


        If e$ = ":" Then
            If i = start Then
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp2 + ":" Else layout$ = ":"
                If i <> n Then continuelinefrom = i + 1
                GoTo finishednonexec
            End If
            If i <> n Then continuelinefrom = i
            GoTo gotcommand
        End If


        'begin scanning an 'IF' statement
        If e$ = "IF" And a$ = "" Then newif = 1


        If e$ = "THEN" Or (e$ = "GOTO" And newif = 1) Then
            If newif = 0 Then a$ = "THEN without IF": GoTo errmes
            newif = 0
            If lineelseused > 0 Then lineelseused = lineelseused - 1
            If e$ = "GOTO" Then
                If i = n Then a$ = "Expected IF expression GOTO label": GoTo errmes
                i = i - 1
            End If
            a$ = a$ + sp + e$ '+"THEN"/"GOTO"
            If i <> n Then continuelinefrom = i + 1: endifs = endifs + 1
            GoTo gotcommand
        End If


        If e$ = "ELSE" Then

            If start = i Then
                If lineelseused >= 1 Then
                    'note: more than one else used (in a row) on this line, so close first if with an 'END IF' first
                    'note: parses 'END IF' then (after continuelinefrom) parses 'ELSE'
                    'consider the following: (square brackets make reading easier)
                    'eg. if a=1 then [if b=2 then c=2 else d=2] else e=3
                    impliedendif = 1: a$ = "END" + sp + "IF"
                    endifs = endifs - 1
                    continuelinefrom = i
                    lineelseused = lineelseused - 1
                    GoTo gotcommand
                End If
                'follow up previously encountered 'ELSE' by applying 'ELSE'
                a$ = "ELSE": continuelinefrom = i + 1
                lineelseused = lineelseused + 1
                GoTo gotcommand
            End If 'start=i

            'apply everything up to (but not including) 'ELSE'
            continuelinefrom = i
            GoTo gotcommand
        End If '"ELSE"

        e$ = getelement(entireline$, i): If a$ = "" Then a$ = e$ Else a$ = a$ + sp + e$
    Next

    'we're reached the end of the line
    If endifs > 0 Then
        endifs = endifs - 1
        impliedendif = 1: entireline$ = entireline$ + sp + ":" + sp + "END" + sp + "IF": n = n + 3
        i = i + 1 'skip the ":" (i is now equal to n+2)
        continuelinefrom = i
        GoTo gotcommand
    End If

    gotcommand:

    dynscope = 0

    ca$ = a$
    a$ = eleucase$(ca$) '***REVISE THIS SECTION LATER***

    layoutdone = 0

    linefragment = a$

    n = numelements(a$)
    If n = 0 Then GoTo finishednonexec

    'convert non-UDT dimensioned periods to _046_
    If InStr(ca$, sp + "." + sp) Then
        a3$ = getelement(ca$, 1)
        except = 0
        aa$ = a3$ + sp 'rebuilt a$ (always has a trailing spacer)
        lastfuse = -1
        For x = 2 To n
            a2$ = getelement(ca$, x)
            If except = 1 Then except = 2: GoTo udtperiod 'skip element name
            If a2$ = "." And x <> n Then
                If except = 2 Then except = 1: GoTo udtperiod 'sub-element of UDT

                If a3$ = ")" Then
                    'assume it was something like typevar(???).x and treat as a UDT
                    except = 1
                    GoTo udtperiod
                End If

                'find an ID of that type
                try = findid(UCase$(a3$))
                If Error_Happened Then GoTo errmes
                Do While try
                    If ((id.t And ISUDT) <> 0) Or ((id.arraytype And ISUDT) <> 0) Then
                        except = 1
                        GoTo udtperiod
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(UCase$(a3$)) Else try = 0
                    If Error_Happened Then GoTo errmes
                Loop
                'not a udt; fuse lhs & rhs with _046_
                If isalpha(Asc(a3$)) = 0 And lastfuse <> x - 2 Then a$ = "Invalid '.'": GoTo errmes
                aa$ = Left$(aa$, Len(aa$) - 1) + fix046$
                lastfuse = x
                GoTo periodfused
            End If '"."
            except = 0
            udtperiod:
            aa$ = aa$ + a2$ + sp
            periodfused:
            a3$ = a2$
        Next
        a$ = Left$(aa$, Len(aa$) - 1)
        ca$ = a$
        a$ = eleucase$(ca$)
        n = numelements(a$)
    End If

    arrayprocessinghappened = 0

    firstelement$ = getelement(a$, 1)
    secondelement$ = getelement(a$, 2)
    thirdelement$ = getelement(a$, 3)

    'non-executable section

    If n = 1 Then
        If firstelement$ = "'" Then layoutdone = 1: GoTo finishednonexec 'nop
    End If

    If n <= 2 Then
        If firstelement$ = "DATA" Then
            l$ = SCase$("Data")
            If n = 2 Then

                e$ = Space$((Len(secondelement$) - 1) \ 2)
                For x = 1 To Len(e$)
                    v1 = Asc(secondelement$, x * 2)
                    v2 = Asc(secondelement$, x * 2 + 1)
                    If v1 < 65 Then v1 = v1 - 48 Else v1 = v1 - 55
                    If v2 < 65 Then v2 = v2 - 48 Else v2 = v2 - 55
                    Asc(e$, x) = v1 + v2 * 16
                Next
                l$ = l$ + sp + e$
            End If 'n=2

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$

            GoTo finishednonexec
        End If
    End If

    'declare library
    If declaringlibrary Then

        If firstelement$ = "END" Then
            If n <> 2 Or secondelement$ <> "DECLARE" Then a$ = "Expected END DECLARE": GoTo errmes
            declaringlibrary = 0
            l$ = SCase$("End" + sp + "Declare")
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishednonexec
        End If 'end declare

        declaringlibrary = 2

        If firstelement$ = "SUB" Or firstelement$ = "FUNCTION" Then
            GoTo declaresubfunc2
        End If

        a$ = "Expected SUB/FUNCTION definition or END DECLARE": GoTo errmes
    End If 'declaringlibrary

    'check TYPE declarations (created on prepass)
    If definingtype Then

        If firstelement$ = "END" Then
            If n <> 2 Or secondelement$ <> "TYPE" Then a$ = "Expected END TYPE": GoTo errmes
            definingtype = 0
            l$ = SCase$("End" + sp + "Type")
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishednonexec
        End If

        'IF n < 3 THEN definingtypeerror = linenumber: a$ = "Expected element-name AS type or AS type element-list": GOTO errmes
        If n < 3 Then a$ = "Expected element-name AS type or AS type element-list": GoTo errmes
        definingtype = 2
        If firstelement$ = "AS" Then
            l$ = SCase$("As")
            t$ = ""
            wordsInTypeName = 0
            Do
                nextElement$ = getelement$(a$, 2 + wordsInTypeName)
                If nextElement$ = "," Then
                    'element-list
                    wordsInTypeName = wordsInTypeName - 2
                    Exit Do
                End If

                wordsInTypeName = wordsInTypeName + 1
                If wordsInTypeName = n - 2 Then
                    'single element in line
                    wordsInTypeName = wordsInTypeName - 1
                    Exit Do
                End If
            Loop

            t$ = getelements$(a$, 2, 2 + wordsInTypeName)
            typ = typname2typ(t$)
            If Error_Happened Then GoTo errmes
            If typ = 0 Then a$ = "Undefined type": GoTo errmes
            If typ And ISUDT Then
                t$ = RTrim$(udtxcname(typ And 511))
                l$ = l$ + sp + t$
            Else
                l$ = l$ + sp + SCase2$(t$)
            End If

            'Now add each variable:
            For i = 3 + wordsInTypeName To n
                thisElement$ = getelement$(ca$, i)
                If thisElement$ = "," Then
                    l$ = l$ + thisElement$
                Else
                    l$ = l$ + sp + thisElement$
                End If
            Next
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        Else
            l$ = getelement(ca$, 1) + sp + SCase$("As")
            t$ = getelements$(a$, 3, n)
            typ = typname2typ(t$)
            If Error_Happened Then GoTo errmes
            If typ = 0 Then a$ = "Undefined type": GoTo errmes
            If typ And ISUDT Then
                t$ = RTrim$(udtxcname(typ And 511))
                l$ = l$ + sp + t$
            Else
                l$ = l$ + sp + SCase2$(t$)
            End If
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        End If
        GoTo finishednonexec

    End If 'defining type

    If firstelement$ = "TYPE" Then
        If n <> 2 Then a$ = "Expected TYPE type-name": GoTo errmes
        l$ = SCase$("Type") + sp + getelement(ca$, 2)
        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        definingtype = 1
        definingtypeerror = linenumber
        GoTo finishednonexec
    End If

    'skip DECLARE SUB/FUNCTION
    If n >= 1 Then
        If firstelement$ = "DECLARE" Then

            If secondelement$ = "LIBRARY" Or secondelement$ = "DYNAMIC" Or secondelement$ = "CUSTOMTYPE" Or secondelement$ = "STATIC" Then

                declaringlibrary = 1
                dynamiclibrary = 0
                customtypelibrary = 0
                indirectlibrary = 0
                staticlinkedlibrary = 0

                x = 3
                l$ = SCase$("Declare" + sp + "Library")

                If secondelement$ = "DYNAMIC" Then
                    e$ = getelement$(a$, 3): If e$ <> "LIBRARY" Then a$ = "Expected DYNAMIC LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes
                    dynamiclibrary = 1
                    x = 4
                    l$ = SCase$("Declare" + sp + "Dynamic" + sp + "Library")
                    If n = 3 Then a$ = "Expected DECLARE DYNAMIC LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes
                    indirectlibrary = 1
                End If

                If secondelement$ = "CUSTOMTYPE" Then
                    e$ = getelement$(a$, 3): If e$ <> "LIBRARY" Then a$ = "Expected CUSTOMTYPE LIBRARY": GoTo errmes
                    customtypelibrary = 1
                    x = 4
                    l$ = SCase$("Declare" + sp + "CustomType" + sp + "Library")
                    indirectlibrary = 1
                End If

                If secondelement$ = "STATIC" Then
                    e$ = getelement$(a$, 3): If e$ <> "LIBRARY" Then a$ = "Expected STATIC LIBRARY": GoTo errmes
                    x = 4
                    l$ = SCase$("Declare" + sp + "Static" + sp + "Library")
                    staticlinkedlibrary = 1
                End If

                sfdeclare = 0: sfheader = 0

                If n >= x Then

                    sfdeclare = 1

                    addlibrary:

                    libname$ = ""
                    headername$ = ""

                    'assume library name in double quotes follows
                    'assume library is in main qb64 folder
                    x$ = getelement$(ca$, x)
                    If Asc(x$) <> 34 Then a$ = "Expected LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes
                    x$ = Right$(x$, Len(x$) - 1)
                    z = InStr(x$, Chr$(34))
                    If z = 0 Then a$ = "Expected LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes
                    x$ = Left$(x$, z - 1)

                    If dynamiclibrary <> 0 And Len(x$) = 0 Then a$ = "Expected DECLARE DYNAMIC LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes
                    If customtypelibrary <> 0 And Len(x$) = 0 Then a$ = "Expected DECLARE CUSTOMTYPE LIBRARY " + Chr$(34) + "..." + Chr$(34): GoTo errmes

                    'convert '\\' to '\'
                    While InStr(x$, "\\")
                        z = InStr(x$, "\\")
                        x$ = Left$(x$, z - 1) + Right$(x$, Len(x$) - z)
                    Wend

                    autoformat_x$ = x$ 'used for autolayout purposes

                    'Remove version number from library name
                    'Eg. libname:1.0 becomes libname <-> 1.0 which later becomes libname.so.1.0
                    v$ = ""
                    striplibver:
                    For z = Len(x$) To 1 Step -1
                        a = Asc(x$, z)
                        If a = ASC_BACKSLASH Or a = ASC_FORWARDSLASH Then Exit For
                        If a = ASC_FULLSTOP Or a = ASC_COLON Then
                            If isuinteger(Right$(x$, Len(x$) - z)) Then
                                If Len(v$) Then v$ = Right$(x$, Len(x$) - z) + "." + v$ Else v$ = Right$(x$, Len(x$) - z)
                                x$ = Left$(x$, z - 1)
                                If a = ASC_COLON Then Exit For
                                GoTo striplibver
                            Else
                                Exit For
                            End If
                        End If
                    Next
                    libver$ = v$

                    'convert any back-slashes to forward-slashes
                    Do While InStr(x$, "\")
                        z = InStr(x$, "\")
                        x$ = Left$(x$, z - 1) + "/" + Right$(x$, Len(x$) - z)
                    Loop

                    'Separate path from name
                    libpath$ = ""
                    For z = Len(x$) To 1 Step -1
                        a = Asc(x$, z)
                        If a = 47 Or a = 92 Then '\ or /
                            libpath$ = Left$(x$, z)
                            x$ = Right$(x$, Len(x$) - z)
                            Exit For
                        End If
                    Next

                    'Accept ./ and .\ as a reference to the source file
                    'folder, replacing it with the actual full path, if available
                    If libpath$ = "./" Or libpath$ = ".\" Then
                        libpath$ = ""
                        If NoIDEMode Then
                            libpath$ = path.source$
                            If Len(libpath$) > 0 And Right$(libpath$, 1) <> pathsep$ Then libpath$ = libpath$ + pathsep$
                        Else
                            If Len(ideprogname) Then libpath$ = idepath$ + pathsep$
                        End If
                    End If

                    'Create a path which can be used for inline code (uses \\ instead of \)
                    libpath_inline$ = ""
                    For z = 1 To Len(libpath$)
                        a = Asc(libpath$, z)
                        libpath_inline$ = libpath_inline$ + Chr$(a)
                        If a = 92 Then libpath_inline$ = libpath_inline$ + "\"
                    Next

                    If Len(x$) Then
                        If dynamiclibrary = 0 Then
                            'Static library

                            If staticlinkedlibrary = 0 Then

                                'check for .so (direct)
                                If Len(libname$) = 0 Then
                                    If _FileExists(libpath$ + "lib" + x$ + ".so." + libver$) Then
                                        libname$ = libpath$ + "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = libpath_inline$ + "lib" + x$ + ".so." + libver$
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath " + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath ./ "
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists(libpath$ + "lib" + x$ + ".so") Then
                                        libname$ = libpath$ + "lib" + x$ + ".so"
                                        inlinelibname$ = libpath_inline$ + "lib" + x$ + ".so"
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath " + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath ./ "
                                    End If
                                End If
                            End If
                            'check for .a (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists(libpath$ + "lib" + x$ + ".a") Then
                                    libname$ = libpath$ + "lib" + x$ + ".a"
                                    inlinelibname$ = libpath_inline$ + "lib" + x$ + ".a"
                                End If
                            End If
                            'check for .o (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists(libpath$ + "lib" + x$ + ".o") Then
                                    libname$ = libpath$ + "lib" + x$ + ".o"
                                    inlinelibname$ = libpath_inline$ + "lib" + x$ + ".o"
                                End If
                            End If
                            If staticlinkedlibrary = 0 Then
                                'check for .so (usr/lib64)
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib64/" + libpath$ + "lib" + x$ + ".so." + libver$) Then
                                        libname$ = "/usr/lib64/" + libpath$ + "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = "/usr/lib64/" + libpath_inline$ + "lib" + x$ + ".so." + libver$
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/" + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/ "
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib64/" + libpath$ + "lib" + x$ + ".so") Then
                                        libname$ = "/usr/lib64/" + libpath$ + "lib" + x$ + ".so"
                                        inlinelibname$ = "/usr/lib64/" + libpath_inline$ + "lib" + x$ + ".so"
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/" + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/ "
                                    End If
                                End If
                            End If
                            'check for .a (usr/lib64)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + libpath$ + "lib" + x$ + ".a") Then
                                    libname$ = "/usr/lib64/" + libpath$ + "lib" + x$ + ".a"
                                    inlinelibname$ = "/usr/lib64/" + libpath_inline$ + "lib" + x$ + ".a"
                                End If
                            End If
                            If staticlinkedlibrary = 0 Then

                                'check for .so (usr/lib)
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib/" + libpath$ + "lib" + x$ + ".so." + libver$) Then
                                        libname$ = "/usr/lib/" + libpath$ + "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = "/usr/lib/" + libpath_inline$ + "lib" + x$ + ".so." + libver$
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/" + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/ "
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib/" + libpath$ + "lib" + x$ + ".so") Then
                                        libname$ = "/usr/lib/" + libpath$ + "lib" + x$ + ".so"
                                        inlinelibname$ = "/usr/lib/" + libpath_inline$ + "lib" + x$ + ".so"
                                        If Len(libpath$) Then mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/" + libpath$ + " " Else mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/ "
                                    End If
                                End If
                            End If
                            'check for .a (usr/lib)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + libpath$ + "lib" + x$ + ".a") Then
                                    libname$ = "/usr/lib/" + libpath$ + "lib" + x$ + ".a"
                                    inlinelibname$ = "/usr/lib/" + libpath_inline$ + "lib" + x$ + ".a"
                                End If
                            End If
                            '--------------------------(without path)------------------------------
                            If staticlinkedlibrary = 0 Then

                                'check for .so (direct)
                                If Len(libname$) = 0 Then
                                    If _FileExists("lib" + x$ + ".so." + libver$) Then
                                        libname$ = "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = "lib" + x$ + ".so." + libver$
                                        mylibopt$ = mylibopt$ + " -Wl,-rpath ./ "
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists("lib" + x$ + ".so") Then
                                        libname$ = "lib" + x$ + ".so"
                                        inlinelibname$ = "lib" + x$ + ".so"
                                        mylibopt$ = mylibopt$ + " -Wl,-rpath ./ "
                                    End If
                                End If
                            End If
                            'check for .a (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists("lib" + x$ + ".a") Then
                                    libname$ = "lib" + x$ + ".a"
                                    inlinelibname$ = "lib" + x$ + ".a"
                                End If
                            End If
                            'check for .o (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists("lib" + x$ + ".o") Then
                                    libname$ = "lib" + x$ + ".o"
                                    inlinelibname$ = "lib" + x$ + ".o"
                                End If
                            End If
                            If staticlinkedlibrary = 0 Then
                                'check for .so (usr/lib64)
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib64/" + "lib" + x$ + ".so." + libver$) Then
                                        libname$ = "/usr/lib64/" + "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = "/usr/lib64/" + "lib" + x$ + ".so." + libver$
                                        mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/ "
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib64/" + "lib" + x$ + ".so") Then
                                        libname$ = "/usr/lib64/" + "lib" + x$ + ".so"
                                        inlinelibname$ = "/usr/lib64/" + "lib" + x$ + ".so"
                                        mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib64/ "
                                    End If
                                End If
                            End If
                            'check for .a (usr/lib64)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + "lib" + x$ + ".a") Then
                                    libname$ = "/usr/lib64/" + "lib" + x$ + ".a"
                                    inlinelibname$ = "/usr/lib64/" + "lib" + x$ + ".a"
                                End If
                            End If
                            If staticlinkedlibrary = 0 Then

                                'check for .so (usr/lib)
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib/" + "lib" + x$ + ".so." + libver$) Then
                                        libname$ = "/usr/lib/" + "lib" + x$ + ".so." + libver$
                                        inlinelibname$ = "/usr/lib/" + "lib" + x$ + ".so." + libver$
                                    End If
                                End If
                                If Len(libname$) = 0 Then
                                    If _FileExists("/usr/lib/" + "lib" + x$ + ".so") Then
                                        libname$ = "/usr/lib/" + "lib" + x$ + ".so"
                                        inlinelibname$ = "/usr/lib/" + "lib" + x$ + ".so"
                                        mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/ "
                                    End If
                                End If
                            End If
                            'check for .a (usr/lib)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + "lib" + x$ + ".a") Then
                                    libname$ = "/usr/lib/" + "lib" + x$ + ".a"
                                    inlinelibname$ = "/usr/lib/" + "lib" + x$ + ".a"
                                    mylibopt$ = mylibopt$ + " -Wl,-rpath /usr/lib/ "
                                End If
                            End If

                            'check for header
                            If Len(headername$) = 0 Then


                                If _FileExists(libpath$ + x$ + ".h") Then
                                    headername$ = libpath_inline$ + x$ + ".h"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists(libpath$ + x$ + ".hpp") Then
                                    headername$ = libpath_inline$ + x$ + ".hpp"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists("/usr/include/" + libpath$ + x$ + ".h") Then
                                    headername$ = "/usr/include/" + libpath_inline$ + x$ + ".h"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists("/usr/include/" + libpath$ + x$ + ".hpp") Then
                                    headername$ = "/usr/include/" + libpath_inline$ + x$ + ".hpp"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                '--------------------------(without path)------------------------------
                                If _FileExists(x$ + ".h") Then
                                    headername$ = x$ + ".h"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists(x$ + ".hpp") Then
                                    headername$ = x$ + ".hpp"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists("/usr/include/" + x$ + ".h") Then
                                    headername$ = "/usr/include/" + x$ + ".h"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If
                                If _FileExists("/usr/include/" + x$ + ".hpp") Then
                                    headername$ = "/usr/include/" + x$ + ".hpp"
                                    If customtypelibrary = 0 Then sfdeclare = 0
                                    sfheader = 1
                                    GoTo GotHeader
                                End If

                                GotHeader:
                            End If

                        Else
                            'dynamic library

                            'Note: STATIC libraries (.a/.o) cannot be loaded as dynamic objects

                            'check for .so (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists(libpath$ + "lib" + x$ + ".so." + libver$) Then
                                    libname$ = libpath$ + "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = libpath_inline$ + "lib" + x$ + ".so." + libver$
                                    If Left$(libpath$, 1) <> "/" Then libname$ = "./" + libname$: inlinelibname$ = "./" + inlinelibname$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists(libpath$ + "lib" + x$ + ".so") Then
                                    libname$ = libpath$ + "lib" + x$ + ".so"
                                    inlinelibname$ = libpath_inline$ + "lib" + x$ + ".so"
                                    If Left$(libpath$, 1) <> "/" Then libname$ = "./" + libname$: inlinelibname$ = "./" + inlinelibname$
                                End If
                            End If
                            'check for .so (usr/lib64)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + libpath$ + "lib" + x$ + ".so." + libver$) Then
                                    libname$ = "/usr/lib64/" + libpath$ + "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = "/usr/lib64/" + libpath_inline$ + "lib" + x$ + ".so." + libver$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + libpath$ + "lib" + x$ + ".so") Then
                                    libname$ = "/usr/lib64/" + libpath$ + "lib" + x$ + ".so"
                                    inlinelibname$ = "/usr/lib64/" + libpath_inline$ + "lib" + x$ + ".so"
                                End If
                            End If

                            'check for .so (usr/lib)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + libpath$ + "lib" + x$ + ".so." + libver$) Then
                                    libname$ = "/usr/lib/" + libpath$ + "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = "/usr/lib/" + libpath_inline$ + "lib" + x$ + ".so." + libver$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + libpath$ + "lib" + x$ + ".so") Then
                                    libname$ = "/usr/lib/" + libpath$ + "lib" + x$ + ".so"
                                    inlinelibname$ = "/usr/lib/" + libpath_inline$ + "lib" + x$ + ".so"
                                End If
                            End If
                            '--------------------------(without path)------------------------------

                            'check for .so (direct)
                            If Len(libname$) = 0 Then
                                If _FileExists("lib" + x$ + ".so." + libver$) Then
                                    libname$ = "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = "lib" + x$ + ".so." + libver$
                                    libname$ = "./" + libname$: inlinelibname$ = "./" + inlinelibname$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists("lib" + x$ + ".so") Then
                                    libname$ = "lib" + x$ + ".so"
                                    inlinelibname$ = "lib" + x$ + ".so"
                                    libname$ = "./" + libname$: inlinelibname$ = "./" + inlinelibname$
                                End If
                            End If
                            'check for .so (usr/lib64)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + "lib" + x$ + ".so." + libver$) Then
                                    libname$ = "/usr/lib64/" + "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = "/usr/lib64/" + "lib" + x$ + ".so." + libver$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib64/" + "lib" + x$ + ".so") Then
                                    libname$ = "/usr/lib64/" + "lib" + x$ + ".so"
                                    inlinelibname$ = "/usr/lib64/" + "lib" + x$ + ".so"
                                End If
                            End If

                            'check for .so (usr/lib)
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + "lib" + x$ + ".so." + libver$) Then
                                    libname$ = "/usr/lib/" + "lib" + x$ + ".so." + libver$
                                    inlinelibname$ = "/usr/lib/" + "lib" + x$ + ".so." + libver$
                                End If
                            End If
                            If Len(libname$) = 0 Then
                                If _FileExists("/usr/lib/" + "lib" + x$ + ".so") Then
                                    libname$ = "/usr/lib/" + "lib" + x$ + ".so"
                                    inlinelibname$ = "/usr/lib/" + "lib" + x$ + ".so"
                                End If
                            End If
                        End If 'Dynamic

                        'library found?
                        If dynamiclibrary <> 0 And Len(libname$) = 0 Then a$ = "DYNAMIC LIBRARY not found": GoTo errmes
                        If Len(libname$) = 0 And Len(headername$) = 0 Then a$ = "LIBRARY not found": GoTo errmes

                        '***actual method should cull redundant header and library entries***

                        If dynamiclibrary = 0 Then

                            'static
                            If Len(libname$) Then
                                If Left$(libname$, 1) = "/" Then
                                    mylib$ = mylib$ + " " + libname$ + " "
                                Else
                                    mylib$ = mylib$ + " ../../" + libname$ + " "
                                End If
                            End If

                        Else

                            'dynamic
                            If Len(headername$) = 0 Then 'no header

                                If subfuncn Then
                                    f = FreeFile
                                    Open tmpdir$ + "maindata.txt" For Append As #f
                                Else
                                    f = 13
                                End If

                                'make name a C-appropriate variable name
                                'by converting everything except numbers and
                                'letters to underscores
                                x2$ = x$
                                For x2 = 1 To Len(x2$)
                                    If Asc(x2$, x2) < 48 Then Asc(x2$, x2) = 95
                                    If Asc(x2$, x2) > 57 And Asc(x2$, x2) < 65 Then Asc(x2$, x2) = 95
                                    If Asc(x2$, x2) > 90 And Asc(x2$, x2) < 97 Then Asc(x2$, x2) = 95
                                    If Asc(x2$, x2) > 122 Then Asc(x2$, x2) = 95
                                Next
                                DLLname$ = x2$

                                If sfdeclare Then
                                    Print #17, "void *DLL_" + x2$ + "=NULL;"
                                    Print #f, "if (!DLL_" + x2$ + "){"
                                    Print #f, "DLL_" + x2$ + "=dlopen(" + Chr$(34) + inlinelibname$ + Chr$(34) + ",RTLD_LAZY);"
                                    Print #f, "if (!DLL_" + x2$ + ") error(259);"
                                    Print #f, "}"
                                End If

                                If subfuncn Then Close #f

                            End If 'no header

                        End If 'dynamiclibrary

                        If Len(headername$) Then
                            If Left$(headername$, 1) = "/" Then
                                Print #17, "#include " + Chr$(34) + headername$ + Chr$(34)
                            Else
                                Print #17, "#include " + Chr$(34) + "../../" + headername$ + Chr$(34)
                            End If
                        End If
                    End If

                    l$ = l$ + sp + Chr$(34) + autoformat_x$ + Chr$(34)

                    If n > x Then
                        If dynamiclibrary Then a$ = "Cannot specify multiple DYNAMIC LIBRARY names in a single DECLARE statement": GoTo errmes
                        x = x + 1: x2$ = getelement$(a$, x): If x2$ <> "," Then a$ = "Expected ,": GoTo errmes
                        l$ = l$ + sp2 + ","
                        x = x + 1: If x > n Then a$ = "Expected , ...": GoTo errmes
                        GoTo addlibrary
                    End If
                End If 'n>=x

                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishednonexec
            End If

            GoTo finishednonexec 'note: no layout required
        End If
    End If

    'begin SUB/FUNCTION
    If n >= 1 Then
        dynamiclibrary = 0
        declaresubfunc2:
        sf = 0
        If firstelement$ = "FUNCTION" Then sf = 1
        If firstelement$ = "SUB" Then sf = 2
        If sf Then

            If declaringlibrary = 0 Then
                If Len(subfunc) Then a$ = "Expected END SUB/FUNCTION before " + firstelement$: GoTo errmes
            End If

            If n = 1 Then a$ = "Expected name after SUB/FUNCTION": GoTo errmes
            e$ = getelement$(ca$, 2)
            symbol$ = removesymbol$(e$) '$,%,etc.
            If Error_Happened Then GoTo errmes
            If sf = 2 And symbol$ <> "" Then a$ = "Type symbols after a SUB name are invalid": GoTo errmes
            try = findid(e$)
            If Error_Happened Then GoTo errmes
            Do While try
                If id.subfunc = sf Then GoTo createsf
                If try = 2 Then findanotherid = 1: try = findid(e$) Else try = 0
                If Error_Happened Then GoTo errmes
            Loop
            a$ = "Unregistered SUB/FUNCTION encountered": GoTo errmes
            createsf:
            If UCase$(e$) = "_GL" Then e$ = "_GL"
            If firstelement$ = "SUB" Then
                l$ = SCase$("Sub") + sp + e$ + symbol$
            Else
                l$ = SCase$("Function") + sp + e$ + symbol$
            End If
            id2 = id
            targetid = currentid

            'check for ALIAS
            aliasname$ = RTrim$(id.cn)
            If n > 2 Then
                ee$ = getelement$(a$, 3)
                If ee$ = "ALIAS" Then
                    If declaringlibrary = 0 Then a$ = "ALIAS can only be used with DECLARE LIBRARY": GoTo errmes
                    If n = 3 Then a$ = "Expected ALIAS name-in-library": GoTo errmes
                    ee$ = getelement$(ca$, 4)

                    'strip string content (optional)
                    If Left$(ee$, 1) = Chr$(34) Then
                        ee$ = Right$(ee$, Len(ee$) - 1)
                        x = InStr(ee$, Chr$(34)): If x = 0 Then a$ = "Expected " + Chr$(34): GoTo errmes
                        ee$ = Left$(ee$, x - 1)
                        l$ = l$ + sp + SCase$("Alias") + sp + CHR_QUOTE + ee$ + CHR_QUOTE
                    Else
                        l$ = l$ + sp + SCase$("Alias") + sp + ee$
                    End If

                    'strip fix046$ (created by unquoted periods)
                    Do While InStr(ee$, fix046$)
                        x = InStr(ee$, fix046$): ee$ = Left$(ee$, x - 1) + "." + Right$(ee$, Len(ee$) - x + 1 - Len(fix046$))
                    Loop
                    aliasname$ = ee$
                    'remove ALIAS section from line
                    If n <= 4 Then a$ = getelements(a$, 1, 2)
                    If n >= 5 Then a$ = getelements(a$, 1, 2) + sp + getelements(a$, 5, n)
                    If n <= 4 Then ca$ = getelements(ca$, 1, 2)
                    If n >= 5 Then ca$ = getelements(ca$, 1, 2) + sp + getelements(ca$, 5, n)
                    n = n - 2
                End If
            End If

            If declaringlibrary Then GoTo declibjmp1

            If closedmain = 0 Then closemain

            'check for open controls (copy #2)
            If controllevel <> 0 And controltype(controllevel) <> 6 Then 'It's OK for subs to be inside $IF blocks
                a$ = "Unidentified open control block"
                Select Case controltype(controllevel)
                    Case 1: a$ = "IF without END IF"
                    Case 2: a$ = "FOR without NEXT"
                    Case 3, 4: a$ = "DO without LOOP"
                    Case 5: a$ = "WHILE without WEND"
                    Case 10 To 19: a$ = "SELECT CASE without END SELECT"
                End Select
                linenumber = controlref(controllevel)
                GoTo errmes
            End If

            If ideindentsubs Then
                controllevel = controllevel + 1
                controltype(controllevel) = 32
                controlref(controllevel) = linenumber
            End If

            subfunc = RTrim$(id.callname) 'SUB_..."
            If id.subfunc = 1 Then subfuncoriginalname$ = "FUNCTION " Else subfuncoriginalname$ = "SUB "
            subfuncoriginalname$ = subfuncoriginalname$ + RTrim$(id.cn)
            subfuncn = subfuncn + 1
            closedsubfunc = 0
            subfuncid = targetid

            subfuncret$ = ""

            Close #13: Open tmpdir$ + "data" + str2$(subfuncn) + ".txt" For Output As #13
            Close #19: Open tmpdir$ + "free" + str2$(subfuncn) + ".txt" For Output As #19
            Close #15: Open tmpdir$ + "ret" + str2$(subfuncn) + ".txt" For Output As #15
            Print #15, "if (next_return_point){"
            Print #15, "next_return_point--;"
            Print #15, "switch(return_point[next_return_point]){"
            Print #15, "case 0:"
            Print #15, "error(3);" 'return without gosub!
            Print #15, "break;"
            defdatahandle = 13

            declibjmp1:

            If declaringlibrary Then
                If sfdeclare = 0 And indirectlibrary = 0 Then
                    Close #17
                    Open tmpdir$ + "regsf_ignore.txt" For Output As #17
                End If
                If sfdeclare = 1 And customtypelibrary = 0 And dynamiclibrary = 0 And indirectlibrary = 0 Then
                    Print #17, "#include " + Chr$(34) + "externtype" + str2(ResolveStaticFunctions + 1) + ".txt" + Chr$(34)
                    fh = FreeFile: Open tmpdir$ + "externtype" + str2(ResolveStaticFunctions + 1) + ".txt" For Output As #fh: Close #fh
                End If
            End If

            If sf = 1 Then
                rettyp = id.ret
                t$ = typ2ctyp$(id.ret, "")
                If Error_Happened Then GoTo errmes
                If t$ = "qbs" Then t$ = "qbs*"

                If declaringlibrary Then
                    If rettyp And ISSTRING Then
                        t$ = "char*"
                    End If
                End If

                If declaringlibrary <> 0 And dynamiclibrary <> 0 Then
                    Print #17, "typedef " + t$ + " (*DLLCALL_" + removecast$(RTrim$(id.callname)) + ")(";
                ElseIf declaringlibrary <> 0 And customtypelibrary <> 0 Then
                    Print #17, "typedef " + t$ + " CUSTOMCALL_" + removecast$(RTrim$(id.callname)) + "(";
                Else
                    Print #17, t$ + " " + removecast$(RTrim$(id.callname)) + "(";
                End If
                If declaringlibrary Then GoTo declibjmp2
                Print #12, t$ + " " + removecast$(RTrim$(id.callname)) + "(";

                'create variable to return result
                'if type wasn't specified, define it
                If symbol$ = "" Then
                    a = Asc(UCase$(e$)): If a = 95 Then a = 91
                    a = a - 64 'so A=1, Z=27 and _=28
                    symbol$ = defineextaz(a)
                End If
                reginternalvariable = 1
                ignore = dim2(e$, symbol$, 0, "")
                If Error_Happened Then GoTo errmes
                reginternalvariable = 0
                'the following line stops the return variable from being free'd before being returned
                Close #19: Open tmpdir$ + "free" + str2$(subfuncn) + ".txt" For Output As #19
                'create return
                If (rettyp And ISSTRING) Then
                    r$ = refer$(str2$(currentid), id.t, 1)
                    If Error_Happened Then GoTo errmes
                    subfuncret$ = subfuncret$ + "qbs_maketmp(" + r$ + ");"
                    subfuncret$ = subfuncret$ + "return " + r$ + ";"
                Else
                    r$ = refer$(str2$(currentid), id.t, 0)
                    If Error_Happened Then GoTo errmes
                    subfuncret$ = "return " + r$ + ";"
                End If
            Else
                If declaringlibrary <> 0 And dynamiclibrary <> 0 Then
                    Print #17, "typedef void (*DLLCALL_" + removecast$(RTrim$(id.callname)) + ")(";
                ElseIf declaringlibrary <> 0 And customtypelibrary <> 0 Then
                    Print #17, "typedef void CUSTOMCALL_" + removecast$(RTrim$(id.callname)) + "(";
                Else
                    Print #17, "void " + removecast$(RTrim$(id.callname)) + "(";
                End If
                If declaringlibrary Then GoTo declibjmp2
                Print #12, "void " + removecast$(RTrim$(id.callname)) + "(";
            End If
            declibjmp2:

            addstatic2layout = 0
            staticsf = 0
            e$ = getelement$(a$, n)
            If e$ = "STATIC" Then
                If declaringlibrary Then a$ = "STATIC cannot be used in a library declaration": GoTo errmes
                addstatic2layout = 1
                staticsf = 2
                a$ = Left$(a$, Len(a$) - 7): n = n - 1 'remove STATIC
            End If

            'check items to pass
            params = 0
            AllowLocalName = 1
            If n > 2 Then
                e$ = getelement$(a$, 3)
                If e$ <> "(" Then a$ = "Expected (": GoTo errmes
                e$ = getelement$(a$, n)
                If e$ <> ")" Then a$ = "Expected )": GoTo errmes
                l$ = l$ + sp + "("
                If n = 4 Then GoTo nosfparams2
                If n < 4 Then a$ = "Expected ( ... )": GoTo errmes
                B = 0
                a2$ = ""
                For i = 4 To n - 1
                    e$ = getelement$(ca$, i)
                    If e$ = "(" Then B = B + 1
                    If e$ = ")" Then B = B - 1
                    If e$ = "," And B = 0 Then
                        If i = n - 1 Then a$ = "Expected , ... )": GoTo errmes
                        getlastparam2:
                        If a2$ = "" Then a$ = "Expected ... ,": GoTo errmes
                        a2$ = Left$(a2$, Len(a2$) - 1)
                        'possible format: [BYVAL]a[%][(1)][AS][type]
                        params = params + 1
                        glinkid = targetid
                        glinkarg = params

                        If params > 1 Then
                            Print #17, ",";

                            If declaringlibrary = 0 Then
                                Print #12, ",";
                            End If

                        End If
                        n2 = numelements(a2$)
                        array = 0
                        t2$ = ""
                        e$ = getelement$(a2$, 1)

                        byvalue = 0
                        If UCase$(e$) = "BYVAL" Then
                            If declaringlibrary = 0 Then a$ = "BYVAL can only be used with DECLARE LIBRARY": GoTo errmes
                            byvalue = 1: a2$ = Right$(a2$, Len(a2$) - 6)
                            If Right$(l$, 1) = "(" Then l$ = l$ + sp2 + SCase$("ByVal") Else l$ = l$ + sp + SCase$("Byval")
                            n2 = numelements(a2$): e$ = getelement$(a2$, 1)
                        End If

                        If Right$(l$, 1) = "(" Then l$ = l$ + sp2 + e$ Else l$ = l$ + sp + e$

                        n2$ = e$
                        dimmethod = 0

                        symbol2$ = removesymbol$(n2$)
                        If validname(n2$) = 0 Then a$ = "Invalid name": GoTo errmes

                        If Error_Happened Then GoTo errmes
                        If symbol2$ <> "" Then dimmethod = 1
                        m = 0
                        For i2 = 2 To n2
                            e$ = getelement$(a2$, i2)
                            If e$ = "(" Then
                                If m <> 0 Then a$ = "Syntax error - too many opening brackets": GoTo errmes
                                m = 1
                                array = 1
                                l$ = l$ + sp2 + "("
                                GoTo gotaa2
                            End If
                            If e$ = ")" Then
                                If m <> 1 Then a$ = "Syntax error - closing bracket without opening bracket": GoTo errmes
                                m = 2
                                l$ = l$ + sp2 + ")"
                                GoTo gotaa2
                            End If
                            If UCase$(e$) = "AS" Then
                                If m <> 0 And m <> 2 Then a$ = "Syntax error - check your brackets": GoTo errmes
                                m = 3
                                l$ = l$ + sp + SCase$("As")
                                GoTo gotaa2
                            End If
                            If m = 1 Then l$ = l$ + sp + e$: GoTo gotaa2 'ignore contents of option bracket telling how many dimensions (add to layout as is)
                            If m <> 3 Then a$ = "Syntax error - check your brackets": GoTo errmes
                            If t2$ = "" Then t2$ = e$ Else t2$ = t2$ + " " + e$
                            gotaa2:
                        Next i2
                        If m = 1 Then a$ = "Syntax error - check your brackets": GoTo errmes
                        If symbol2$ <> "" And t2$ <> "" Then a$ = "Syntax error - check parameter types": GoTo errmes

                        If Len(t2$) Then 'add type-name after AS
                            t2$ = UCase$(t2$)
                            t3$ = t2$
                            typ = typname2typ(t3$)
                            If Error_Happened Then GoTo errmes
                            If typ = 0 Then a$ = "Undefined type": GoTo errmes
                            If typ And ISUDT Then
                                t3$ = RTrim$(udtxcname(typ And 511))
                                l$ = l$ + sp + t3$
                            Else
                                For t3i = 1 To Len(t3$)
                                    If Asc(t3$, t3i) = 32 Then Asc(t3$, t3i) = Asc(sp)
                                Next
                                t3$ = SCase2$(t3$)
                                l$ = l$ + sp + t3$
                            End If
                        End If

                        If t2$ = "" Then t2$ = symbol2$
                        If t2$ = "" Then
                            If Left$(n2$, 1) = "_" Then v = 27 Else v = Asc(UCase$(n2$)) - 64
                            t2$ = defineaz(v)
                            dimmethod = 1
                        End If

                        If array = 1 Then
                            If declaringlibrary Then a$ = "Arrays cannot be passed to a library": GoTo errmes
                            dimsfarray = 1
                            'note: id2.nele is currently 0
                            nelereq = Asc(Mid$(id2.nelereq, params, 1))
                            If nelereq Then
                                nele = nelereq
                                Mid$(id2.nele, params, 1) = Chr$(nele)

                                ids(targetid) = id2

                                ignore = dim2(n2$, t2$, dimmethod, str2$(nele))
                                If Error_Happened Then GoTo errmes
                            Else
                                nele = 1
                                Mid$(id2.nele, params, 1) = Chr$(nele)

                                ids(targetid) = id2

                                ignore = dim2(n2$, t2$, dimmethod, "?")
                                If Error_Happened Then GoTo errmes
                            End If

                            dimsfarray = 0
                            r$ = refer$(str2$(currentid), id.t, 1)
                            If Error_Happened Then GoTo errmes
                            Print #17, "ptrszint*" + r$;
                            Print #12, "ptrszint*" + r$;
                        Else

                            If declaringlibrary Then
                                'is it a udt?
                                For xx = 1 To lasttype
                                    If t2$ = RTrim$(udtxname(xx)) Then
                                        Print #17, "void*"
                                        GoTo decudt
                                    End If
                                Next
                                t$ = typ2ctyp$(0, t2$)

                                If Error_Happened Then GoTo errmes
                                If t$ = "qbs" Then
                                    t$ = "char*"
                                    If byvalue = 1 Then a$ = "STRINGs cannot be passed using BYVAL": GoTo errmes
                                    byvalue = 1 'use t$ as is
                                End If
                                If byvalue Then Print #17, t$; Else Print #17, t$ + "*";
                                decudt:
                                GoTo declibjmp3
                            End If

                            dimsfarray = 1
                            ignore = dim2(n2$, t2$, dimmethod, "")
                            If Error_Happened Then GoTo errmes


                            dimsfarray = 0
                            t$ = ""
                            typ = id.t 'the typ of the ID created by dim2

                            t$ = typ2ctyp$(typ, "")
                            If Error_Happened Then GoTo errmes

                            If t$ = "" Then a$ = "Cannot find C type to return array data": GoTo errmes
                            'searchpoint
                            'get the name of the variable
                            r$ = refer$(str2$(currentid), id.t, 1)
                            If Error_Happened Then GoTo errmes
                            Print #17, t$ + "*" + r$;
                            Print #12, t$ + "*" + r$;
                            If t$ = "qbs" Then
                                u$ = str2$(uniquenumber)
                                Print #13, "qbs*oldstr" + u$ + "=NULL;"
                                Print #13, "if(" + r$ + "->tmp||" + r$ + "->fixed||" + r$ + "->readonly){"
                                Print #13, "oldstr" + u$ + "=" + r$ + ";"

                                Print #13, "if (oldstr" + u$ + "->cmem_descriptor){"
                                Print #13, r$ + "=qbs_new_cmem(oldstr" + u$ + "->len,0);"
                                Print #13, "}else{"
                                Print #13, r$ + "=qbs_new(oldstr" + u$ + "->len,0);"
                                Print #13, "}"

                                Print #13, "memcpy(" + r$ + "->chr,oldstr" + u$ + "->chr,oldstr" + u$ + "->len);"
                                Print #13, "}"

                                Print #19, "if(oldstr" + u$ + "){"
                                Print #19, "if(oldstr" + u$ + "->fixed)qbs_set(oldstr" + u$ + "," + r$ + ");"
                                Print #19, "qbs_free(" + r$ + ");"
                                Print #19, "}"
                            End If
                        End If
                        declibjmp3:
                        If i <> n - 1 Then l$ = l$ + sp2 + ","

                        a2$ = ""
                    Else
                        a2$ = a2$ + e$ + sp
                        If i = n - 1 Then GoTo getlastparam2
                    End If
                Next i
                nosfparams2:
                l$ = l$ + sp2 + ")"
            End If 'n>2
            AllowLocalName = 0

            If addstatic2layout Then l$ = l$ + sp + SCase$("Static")
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$

            Print #17, ");"

            If declaringlibrary Then GoTo declibjmp4

            Print #12, "){"
            Print #12, "qbs *tqbs;"
            Print #12, "ptrszint tmp_long;"
            Print #12, "int32 tmp_fileno;"
            Print #12, "uint32 qbs_tmp_base=qbs_tmp_list_nexti;"
            Print #12, "uint8 *tmp_mem_static_pointer=mem_static_pointer;"
            Print #12, "uint32 tmp_cmem_sp=cmem_sp;"
            Print #12, "#include " + Chr$(34) + "data" + str2$(subfuncn) + ".txt" + Chr$(34)

            'create new _MEM lock for this scope
            Print #12, "mem_lock *sf_mem_lock;" 'MUST not be static for recursion reasons
            Print #12, "new_mem_lock();"
            Print #12, "sf_mem_lock=mem_lock_tmp;"
            Print #12, "sf_mem_lock->type=3;"

            Print #12, "if (new_error) goto exit_subfunc;"

            'statementn = statementn + 1
            'if nochecks=0 then PRINT #12, "S_" + str2$(statementn) + ":;"

            dimstatic = staticsf

            declibjmp4:

            If declaringlibrary Then

                If customtypelibrary Then

                    callname$ = removecast$(RTrim$(id2.callname))

                    Print #17, "CUSTOMCALL_" + callname$ + " *" + callname$ + "=NULL;"

                    If subfuncn Then
                        f = FreeFile
                        Open tmpdir$ + "maindata.txt" For Append As #f
                    Else
                        f = 13
                    End If


                    Print #f, callname$ + "=(CUSTOMCALL_" + callname$ + "*)&" + aliasname$ + ";"

                    If subfuncn Then Close #f

                    'if no header exists to make the external function available, the function definition must be found
                    If sfheader = 0 And sfdeclare <> 0 Then
                        ResolveStaticFunctions = ResolveStaticFunctions + 1
                        'expand array if necessary
                        If ResolveStaticFunctions > UBound(ResolveStaticFunction_Name) Then
                            ReDim _Preserve ResolveStaticFunction_Name(1 To ResolveStaticFunctions + 100) As String
                            ReDim _Preserve ResolveStaticFunction_File(1 To ResolveStaticFunctions + 100) As String
                            ReDim _Preserve ResolveStaticFunction_Method(1 To ResolveStaticFunctions + 100) As Long
                        End If
                        ResolveStaticFunction_File(ResolveStaticFunctions) = libname$
                        ResolveStaticFunction_Name(ResolveStaticFunctions) = aliasname$
                        ResolveStaticFunction_Method(ResolveStaticFunctions) = 1
                    End If 'sfheader=0

                End If

                If dynamiclibrary Then
                    If sfdeclare Then
                        Print #17, "DLLCALL_" + removecast$(RTrim$(id2.callname)) + " " + removecast$(RTrim$(id2.callname)) + "=NULL;"

                        If subfuncn Then
                            f = FreeFile
                            Open tmpdir$ + "maindata.txt" For Append As #f
                        Else
                            f = 13
                        End If

                        Print #f, "if (!" + removecast$(RTrim$(id2.callname)) + "){"
                        Print #f, removecast$(RTrim$(id2.callname)) + "=(DLLCALL_" + removecast$(RTrim$(id2.callname)) + ")dlsym(DLL_" + DLLname$ + "," + Chr$(34) + aliasname$ + Chr$(34) + ");"
                        Print #f, "if (dlerror()) error(260);"
                        Print #f, "}"
                        If subfuncn Then Close #f
                    End If 'sfdeclare
                End If 'dynamic

                If sfdeclare = 1 And customtypelibrary = 0 And dynamiclibrary = 0 And indirectlibrary = 0 Then
                    ResolveStaticFunctions = ResolveStaticFunctions + 1
                    'expand array if necessary
                    If ResolveStaticFunctions > UBound(ResolveStaticFunction_Name) Then
                        ReDim _Preserve ResolveStaticFunction_Name(1 To ResolveStaticFunctions + 100) As String
                        ReDim _Preserve ResolveStaticFunction_File(1 To ResolveStaticFunctions + 100) As String
                        ReDim _Preserve ResolveStaticFunction_Method(1 To ResolveStaticFunctions + 100) As Long
                    End If
                    ResolveStaticFunction_File(ResolveStaticFunctions) = libname$
                    ResolveStaticFunction_Name(ResolveStaticFunctions) = aliasname$
                    ResolveStaticFunction_Method(ResolveStaticFunctions) = 2
                End If

                If sfdeclare = 0 And indirectlibrary = 0 Then
                    Close #17
                    Open tmpdir$ + "regsf.txt" For Append As #17
                End If

            End If 'declaring library

            GoTo finishednonexec
        End If
    End If

    'END SUB/FUNCTION
    If n = 2 Then
        If firstelement$ = "END" Then
            sf = 0
            If secondelement$ = "FUNCTION" Then sf = 1
            If secondelement$ = "SUB" Then sf = 2
            If sf Then

                If Len(subfunc) = 0 Then a$ = "END " + secondelement$ + " without " + secondelement$: GoTo errmes

                'check for open controls (copy #3)
                If controllevel <> 0 And controltype(controllevel) <> 6 And controltype(controllevel) <> 32 Then 'It's OK for subs to be inside $IF blocks
                    a$ = "Unidentified open control block"
                    Select Case controltype(controllevel)
                        Case 1: a$ = "IF without END IF"
                        Case 2: a$ = "FOR without NEXT"
                        Case 3, 4: a$ = "DO without LOOP"
                        Case 5: a$ = "WHILE without WEND"
                        Case 10 To 19: a$ = "SELECT CASE without END SELECT"
                    End Select
                    linenumber = controlref(controllevel)
                    GoTo errmes
                End If

                If controltype(controllevel) = 32 And ideindentsubs Then
                    controltype(controllevel) = 0
                    controllevel = controllevel - 1
                End If

                If Left$(subfunc, 4) = "SUB_" Then secondelement$ = SCase$("Sub") Else secondelement$ = SCase$("Function")
                l$ = SCase$("End") + sp + secondelement$
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$

                staticarraylist = "": staticarraylistn = 0 'remove previously listed arrays
                dimstatic = 0
                Print #12, "exit_subfunc:;"

                'release _MEM lock for this scope
                Print #12, "free_mem_lock(sf_mem_lock);"

                Print #12, "#include " + Chr$(34) + "free" + str2$(subfuncn) + ".txt" + Chr$(34)
                Print #12, "if ((tmp_mem_static_pointer>=mem_static)&&(tmp_mem_static_pointer<=mem_static_limit)) mem_static_pointer=tmp_mem_static_pointer; else mem_static_pointer=mem_static;"
                Print #12, "cmem_sp=tmp_cmem_sp;"
                If subfuncret$ <> "" Then Print #12, subfuncret$

                Print #12, "}" 'skeleton sub
                'ret???.txt
                Print #15, "}" 'end case
                Print #15, "}"
                Print #15, "error(3);" 'no valid return possible
                subfunc = ""
                closedsubfunc = -1

                'unshare temp. shared variables
                For i = 1 To idn
                    If ids(i).share And 2 Then ids(i).share = ids(i).share - 2
                Next

                For i = 1 To revertmaymusthaven
                    x = revertmaymusthave(i)
                    Swap ids(x).musthave, ids(x).mayhave
                Next
                revertmaymusthaven = 0

                'undeclare constants in sub/function's scope
                'constlast = constlastshared
                GoTo finishednonexec

            End If
        End If
    End If

    If n >= 1 And firstelement$ = "CONST" Then
        l$ = SCase$("Const")
        'DEF... do not change type, the expression is stored in a suitable type
        'based on its value if type isn't forced/specified
        If n < 3 Then a$ = "Expected CONST name = value/expression": GoTo errmes
        i = 2

        constdefpending:
        pending = 0

        n$ = getelement$(ca$, i): i = i + 1
        l$ = l$ + sp + n$ + sp + "="
        typeoverride = 0
        s$ = removesymbol$(n$)
        If Error_Happened Then GoTo errmes
        If s$ <> "" Then
            typeoverride = typname2typ(s$)
            If Error_Happened Then GoTo errmes
            If typeoverride And ISFIXEDLENGTH Then a$ = "Invalid constant type": GoTo errmes
            If typeoverride = 0 Then a$ = "Invalid constant type": GoTo errmes
        End If

        If getelement$(a$, i) <> "=" Then a$ = "Expected =": GoTo errmes
        i = i + 1

        'get expression
        e$ = ""
        B = 0
        For i2 = i To n
            e2$ = getelement$(ca$, i2)
            If e2$ = "(" Then B = B + 1
            If e2$ = ")" Then B = B - 1
            If e2$ = "," And B = 0 Then
                pending = 1
                i = i2 + 1
                If i > n - 2 Then a$ = "Expected CONST ... , name = value/expression": GoTo errmes
                Exit For
            End If
            If Len(e$) = 0 Then e$ = e2$ Else e$ = e$ + sp + e2$
        Next

        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + sp + tlayout$

        'Note: Actual CONST definition handled in prepass

        'Set CONST as defined
        hashname$ = n$
        hashchkflags = HASHFLAG_CONSTANT
        hashres = HashFind(hashname$, hashchkflags, hashresflags, hashresref)
        Do While hashres
            If constsubfunc(hashresref) = subfuncn Then constdefined(hashresref) = 1: Exit Do
            If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
        Loop

        If pending Then l$ = l$ + sp2 + ",": GoTo constdefpending

        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$

        GoTo finishednonexec
    End If

    predefine:
    If n >= 2 Then
        asreq = 0
        If firstelement$ = "DEFINT" Then l$ = SCase$("DefInt"): a$ = a$ + sp + "AS" + sp + "INTEGER": n = n + 2: GoTo definetype
        If firstelement$ = "DEFLNG" Then l$ = SCase$("DefLng"): a$ = a$ + sp + "AS" + sp + "LONG": n = n + 2: GoTo definetype
        If firstelement$ = "DEFSNG" Then l$ = SCase$("DefSng"): a$ = a$ + sp + "AS" + sp + "SINGLE": n = n + 2: GoTo definetype
        If firstelement$ = "DEFDBL" Then l$ = SCase$("DefDbl"): a$ = a$ + sp + "AS" + sp + "DOUBLE": n = n + 2: GoTo definetype
        If firstelement$ = "DEFSTR" Then l$ = SCase$("DefStr"): a$ = a$ + sp + "AS" + sp + "STRING": n = n + 2: GoTo definetype
        If firstelement$ = "_DEFINE" Then
            asreq = 1
            If firstelement$ = "_DEFINE" Then l$ = SCase$("_Define") Else l$ = SCase$("Define")
            definetype:
            'get type from rhs
            typ$ = ""
            typ2$ = ""
            t$ = ""
            For i = n To 2 Step -1
                t$ = getelement$(a$, i)
                If t$ = "AS" Then Exit For
                typ$ = t$ + " " + typ$
                typ2$ = t$ + sp + typ2$
            Next
            typ$ = RTrim$(typ$)
            If t$ <> "AS" Then a$ = qb64prefix$ + "DEFINE: Expected ... AS ...": GoTo errmes
            If i = n Or i = 2 Then a$ = qb64prefix$ + "DEFINE: Expected ... AS ...": GoTo errmes


            n = i - 1
            'the data is from element 2 to element n
            i = 2 - 1
            definenext:
            'expects an alphabet letter or underscore
            i = i + 1: e$ = getelement$(a$, i): E = Asc(UCase$(e$))
            If Len(e$) > 1 Then a$ = qb64prefix$ + "DEFINE: Expected an alphabet letter or the underscore character (_)": GoTo errmes
            If E <> 95 And (E > 90 Or E < 65) Then a$ = qb64prefix$ + "DEFINE: Expected an alphabet letter or the underscore character (_)": GoTo errmes
            If E = 95 Then E = 27 Else E = E - 64
            defineaz(E) = typ$
            defineextaz(E) = type2symbol(typ$)
            If Error_Happened Then GoTo errmes
            firste = E
            l$ = l$ + sp + e$

            If i = n Then
                If predefining = 1 Then GoTo predefined
                If asreq Then l$ = l$ + sp + SCase$("As") + sp + typ2$
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishednonexec
            End If

            'expects "-" or ","
            i = i + 1: e$ = getelement$(a$, i)
            If e$ <> "-" And e$ <> "," Then a$ = qb64prefix$ + "DEFINE: Expected - or ,": GoTo errmes
            If e$ = "-" Then
                l$ = l$ + sp2 + "-"
                If i = n Then a$ = qb64prefix$ + "DEFINE: Syntax incomplete": GoTo errmes
                'expects an alphabet letter or underscore
                i = i + 1: e$ = getelement$(a$, i): E = Asc(UCase$(e$))
                If Len(e$) > 1 Then a$ = qb64prefix$ + "DEFINE: Expected an alphabet letter or the underscore character (_)": GoTo errmes
                If E <> 95 And (E > 90 Or E < 65) Then a$ = qb64prefix$ + "DEFINE: Expected an alphabet letter or the underscore character (_)": GoTo errmes
                If E = 95 Then E = 27 Else E = E - 64
                If firste > E Then Swap E, firste
                For e2 = firste To E
                    defineaz(e2) = typ$
                    defineextaz(e2) = type2symbol(typ$)
                    If Error_Happened Then GoTo errmes
                Next
                l$ = l$ + sp2 + e$
                If i = n Then
                    If predefining = 1 Then GoTo predefined
                    If asreq Then l$ = l$ + sp + SCase$("As") + sp + typ2$
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishednonexec
                End If
                'expects ","
                i = i + 1: e$ = getelement$(a$, i)
                If e$ <> "," Then a$ = qb64prefix$ + "DEFINE: Expected ,": GoTo errmes
            End If
            l$ = l$ + sp2 + ","
            GoTo definenext
        End If '_DEFINE
    End If '2
    If predefining = 1 Then GoTo predefined

    If closedmain <> 0 And subfunc = "" Then a$ = "Statement cannot be placed between SUB/FUNCTIONs": GoTo errmes

    'executable section:

    statementn = statementn + 1

    If n >= 1 Then
        If firstelement$ = "NEXT" Then

            l$ = SCase$("Next")
            If n = 1 Then GoTo simplenext
            v$ = ""
            For i = 2 To n
                a2$ = getelement(ca$, i)

                If a2$ = "," Then

                    lastnextele:
                    e$ = fixoperationorder(v$)
                    If Error_Happened Then GoTo errmes
                    If Len(l$) = 4 Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp2 + "," + sp + tlayout$
                    e$ = evaluate(e$, typ)
                    If Error_Happened Then GoTo errmes
                    If (typ And ISREFERENCE) Then
                        getid Val(e$)
                        If Error_Happened Then GoTo errmes
                        If (id.t And ISPOINTER) Then
                            If (id.t And ISSTRING) = 0 Then
                                If (id.t And ISOFFSETINBITS) = 0 Then
                                    If (id.t And ISARRAY) = 0 Then
                                        GoTo fornextfoundvar2
                                    End If
                                End If
                            End If
                        End If
                    End If
                    a$ = "Unsupported variable after NEXT": GoTo errmes
                    fornextfoundvar2:
                    simplenext:
                    If controltype(controllevel) <> 2 Then a$ = "NEXT without FOR": GoTo errmes
                    If n <> 1 And controlvalue(controllevel) <> currentid Then a$ = "Incorrect variable after NEXT": GoTo errmes
                    Print #12, "fornext_continue_" + str2$(controlid(controllevel)) + ":;"
                    Print #12, "}"
                    Print #12, "fornext_exit_" + str2$(controlid(controllevel)) + ":;"
                    controllevel = controllevel - 1
                    If n = 1 Then Exit For
                    v$ = ""

                Else

                    If Len(v$) Then v$ = v$ + sp + a2$ Else v$ = a2$
                    If i = n Then GoTo lastnextele

                End If

            Next

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishednonexec '***no error causing code, event checking done by FOR***
        End If
    End If



    If n >= 1 Then
        If firstelement$ = "WHILE" Then
            If NoChecks = 0 Then Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1

            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            controllevel = controllevel + 1
            controlref(controllevel) = linenumber
            controltype(controllevel) = 5
            controlid(controllevel) = uniquenumber
            If n >= 2 Then
                e$ = fixoperationorder(getelements$(ca$, 2, n))
                If Error_Happened Then GoTo errmes
                l$ = SCase$("While") + sp + tlayout$
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                e$ = evaluate(e$, typ)
                If Error_Happened Then GoTo errmes
                If (typ And ISREFERENCE) Then e$ = refer$(e$, typ, 0)
                If Error_Happened Then GoTo errmes
                If stringprocessinghappened Then e$ = cleanupstringprocessingcall$ + e$ + ")"
                If (typ And ISSTRING) Then a$ = "WHILE ERROR! Cannot accept a STRING type.": GoTo errmes
                Print #12, "while((" + e$ + ")||new_error){"
            Else
                a$ = "WHILE ERROR! Expected expression after WHILE.": GoTo errmes
            End If

            GoTo finishedline
        End If
    End If

    If n = 1 Then
        If firstelement$ = "WEND" Then

            If controltype(controllevel) <> 5 Then a$ = "WEND without WHILE": GoTo errmes
            Print #12, "ww_continue_" + str2$(controlid(controllevel)) + ":;"
            Print #12, "}"
            Print #12, "ww_exit_" + str2$(controlid(controllevel)) + ":;"
            controllevel = controllevel - 1
            l$ = SCase$("Wend")
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishednonexec '***no error causing code, event checking done by WHILE***
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "DO" Then
            If NoChecks = 0 Then Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1

            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            controllevel = controllevel + 1
            controlref(controllevel) = linenumber
            l$ = SCase$("Do")
            If n >= 2 Then
                whileuntil = 0
                If secondelement$ = "WHILE" Then whileuntil = 1: l$ = l$ + sp + SCase$("While")
                If secondelement$ = "UNTIL" Then whileuntil = 2: l$ = l$ + sp + SCase$("Until")
                If whileuntil = 0 Then a$ = "DO ERROR! Expected WHILE or UNTIL after DO.": GoTo errmes
                If whileuntil > 0 And n = 2 Then a$ = "Condition expected after WHILE/UNTIL": GoTo errmes
                e$ = fixoperationorder(getelements$(ca$, 3, n))
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp + tlayout$
                e$ = evaluate(e$, typ)
                If Error_Happened Then GoTo errmes
                If (typ And ISREFERENCE) Then e$ = refer$(e$, typ, 0)
                If Error_Happened Then GoTo errmes
                If stringprocessinghappened Then e$ = cleanupstringprocessingcall$ + e$ + ")"
                If (typ And ISSTRING) Then a$ = "DO ERROR! Cannot accept a STRING type.": GoTo errmes
                If whileuntil = 1 Then Print #12, "while((" + e$ + ")||new_error){" Else Print #12, "while((!(" + e$ + "))||new_error){"
                controltype(controllevel) = 4
            Else
                controltype(controllevel) = 3
                Print #12, "do{"
            End If
            controlid(controllevel) = uniquenumber
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "LOOP" Then
            l$ = SCase$("Loop")
            If controltype(controllevel) <> 3 And controltype(controllevel) <> 4 Then a$ = "PROGRAM FLOW ERROR!": GoTo errmes
            If n >= 2 Then
                If NoChecks = 0 Then Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1
                If controltype(controllevel) = 4 Then a$ = "PROGRAM FLOW ERROR!": GoTo errmes
                whileuntil = 0
                If secondelement$ = "WHILE" Then whileuntil = 1: l$ = l$ + sp + SCase$("While")
                If secondelement$ = "UNTIL" Then whileuntil = 2: l$ = l$ + sp + SCase$("Until")
                If whileuntil = 0 Then a$ = "LOOP ERROR! Expected WHILE or UNTIL after LOOP.": GoTo errmes
                If whileuntil > 0 And n = 2 Then a$ = "Condition expected after WHILE/UNTIL": GoTo errmes
                e$ = fixoperationorder(getelements$(ca$, 3, n))
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp + tlayout$
                e$ = evaluate(e$, typ)
                If Error_Happened Then GoTo errmes
                If (typ And ISREFERENCE) Then e$ = refer$(e$, typ, 0)
                If Error_Happened Then GoTo errmes
                If stringprocessinghappened Then e$ = cleanupstringprocessingcall$ + e$ + ")"
                If (typ And ISSTRING) Then a$ = "LOOP ERROR! Cannot accept a STRING type.": GoTo errmes
                Print #12, "dl_continue_" + str2$(controlid(controllevel)) + ":;"
                If whileuntil = 1 Then Print #12, "}while((" + e$ + ")&&(!new_error));" Else Print #12, "}while((!(" + e$ + "))&&(!new_error));"
            Else
                Print #12, "dl_continue_" + str2$(controlid(controllevel)) + ":;"

                If controltype(controllevel) = 4 Then
                    Print #12, "}"
                Else
                    Print #12, "}while(1);" 'infinite loop!
                End If
            End If
            Print #12, "dl_exit_" + str2$(controlid(controllevel)) + ":;"
            controllevel = controllevel - 1
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            If n = 1 Then GoTo finishednonexec '***no error causing code, event checking done by DO***
            GoTo finishedline
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "FOR" Then
            If NoChecks = 0 Then Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1

            l$ = SCase$("For")

            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            controllevel = controllevel + 1
            controlref(controllevel) = linenumber
            controltype(controllevel) = 2
            controlid(controllevel) = uniquenumber

            v$ = ""
            startvalue$ = ""
            p3$ = "1": stepused = 0
            p2$ = ""
            mode = 0
            E = 0
            For i = 2 To n
                e$ = getelement$(a$, i)
                If e$ = "=" Then
                    If mode <> 0 Then E = 1: Exit For
                    mode = 1
                    v$ = getelements$(ca$, 2, i - 1)
                    equpos = i
                End If
                If e$ = "TO" Then
                    If mode <> 1 Then E = 1: Exit For
                    mode = 2
                    startvalue$ = getelements$(ca$, equpos + 1, i - 1)
                    topos = i
                End If
                If e$ = "STEP" Then
                    If mode <> 2 Then E = 1: Exit For
                    mode = 3
                    stepused = 1
                    p2$ = getelements$(ca$, topos + 1, i - 1)
                    p3$ = getelements$(ca$, i + 1, n)
                    Exit For
                End If
            Next
            If mode < 2 Then E = 1
            If p2$ = "" Then p2$ = getelements$(ca$, topos + 1, n)
            If Len(v$) = 0 Or Len(startvalue$) = 0 Or Len(p2$) = 0 Then E = 1
            If E <> 0 And mode < 3 Then a$ = "Expected FOR name = start TO end": GoTo errmes
            If E Then a$ = "Expected FOR name = start TO end STEP increment": GoTo errmes

            e$ = fixoperationorder(v$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + sp + tlayout$
            e$ = evaluate(e$, typ)
            If Error_Happened Then GoTo errmes
            If (typ And ISREFERENCE) Then
                getid Val(e$)
                If Error_Happened Then GoTo errmes
                If (id.t And ISPOINTER) Then
                    If (id.t And ISSTRING) = 0 Then
                        If (id.t And ISOFFSETINBITS) = 0 Then
                            If (id.t And ISARRAY) = 0 Then
                                GoTo fornextfoundvar
                            End If
                        End If
                    End If
                End If
            End If
            a$ = "Unsupported variable used in FOR statement": GoTo errmes
            fornextfoundvar:
            controlvalue(controllevel) = currentid
            v$ = e$

            'find C++ datatype to match variable
            'markup to cater for greater range/accuracy
            ctype$ = ""
            ctyp = typ - ISPOINTER
            bits = typ And 511
            If (typ And ISFLOAT) Then
                If bits = 32 Then ctype$ = "double": ctyp = 64& + ISFLOAT
                If bits = 64 Then ctype$ = "long double": ctyp = 256& + ISFLOAT
                If bits = 256 Then ctype$ = "long double": ctyp = 256& + ISFLOAT
            Else
                If bits = 8 Then ctype$ = "int16": ctyp = 16&
                If bits = 16 Then ctype$ = "int32": ctyp = 32&
                If bits = 32 Then ctype$ = "int64": ctyp = 64&
                If bits = 64 Then ctype$ = "int64": ctyp = 64&
            End If
            If ctype$ = "" Then a$ = "Unsupported variable used in FOR statement": GoTo errmes
            u$ = str2(uniquenumber)

            If subfunc = "" Then
                Print #13, "static " + ctype$ + " fornext_value" + u$ + ";"
                Print #13, "static " + ctype$ + " fornext_finalvalue" + u$ + ";"
                Print #13, "static " + ctype$ + " fornext_step" + u$ + ";"
                Print #13, "static uint8 fornext_step_negative" + u$ + ";"
            Else
                Print #13, ctype$ + " fornext_value" + u$ + ";"
                Print #13, ctype$ + " fornext_finalvalue" + u$ + ";"
                Print #13, ctype$ + " fornext_step" + u$ + ";"
                Print #13, "uint8 fornext_step_negative" + u$ + ";"
            End If

            'calculate start
            e$ = fixoperationorder$(startvalue$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + sp + "=" + sp + tlayout$
            e$ = evaluatetotyp$(e$, ctyp)
            If Error_Happened Then GoTo errmes
            Print #12, "fornext_value" + u$ + "=" + e$ + ";"

            'final
            e$ = fixoperationorder$(p2$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + sp + SCase$("To") + sp + tlayout$
            e$ = evaluatetotyp(e$, ctyp)
            If Error_Happened Then GoTo errmes
            Print #12, "fornext_finalvalue" + u$ + "=" + e$ + ";"

            'step
            e$ = fixoperationorder$(p3$)
            If Error_Happened Then GoTo errmes
            If stepused = 1 Then l$ = l$ + sp + SCase$("Step") + sp + tlayout$
            e$ = evaluatetotyp(e$, ctyp)
            If Error_Happened Then GoTo errmes

            Print #12, "fornext_step" + u$ + "=" + e$ + ";"
            Print #12, "if (fornext_step" + u$ + "<0) fornext_step_negative" + u$ + "=1; else fornext_step_negative" + u$ + "=0;"

            Print #12, "if (new_error) goto fornext_error" + u$ + ";"
            Print #12, "goto fornext_entrylabel" + u$ + ";"
            Print #12, "while(1){"
            typbak = typ
            Print #12, "fornext_value" + u$ + "=fornext_step" + u$ + "+(" + refer$(v$, typ, 0) + ");"
            If Error_Happened Then GoTo errmes
            typ = typbak
            Print #12, "fornext_entrylabel" + u$ + ":"
            setrefer v$, typ, "fornext_value" + u$, 1
            If Error_Happened Then GoTo errmes
            Print #12, "if (fornext_step_negative" + u$ + "){"
            Print #12, "if (fornext_value" + u$ + "<fornext_finalvalue" + u$ + ") break;"
            Print #12, "}else{"
            Print #12, "if (fornext_value" + u$ + ">fornext_finalvalue" + u$ + ") break;"
            Print #12, "}"
            Print #12, "fornext_error" + u$ + ":;"

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$

            GoTo finishedline
        End If
    End If

    If n = 1 Then
        If firstelement$ = "ELSE" Then

            'Routine to add error checking for ELSE so we'll no longer be able to do things like the following:
            'IF x = 1 THEN
            '    SELECT CASE s
            '        CASE 1
            '    END SELECT ELSE y = 2
            'END IF
            'Notice the ELSE with the SELECT CASE?  Before this patch, commands like those were considered valid QB64 code.
            temp$ = UCase$(LTrim$(RTrim$(wholeline)))
            'IF NoIDEMode THEN
            Do While InStr(temp$, Chr$(9))
                Asc(temp$, InStr(temp$, Chr$(9))) = 32
            Loop
            'END IF
            goodelse = 0 'a check to see if it's a good else
            If Left$(temp$, 2) = "IF" Then goodelse = -1: GoTo skipelsecheck 'If we have an IF, the else is probably good
            If Left$(temp$, 4) = "ELSE" Then goodelse = -1: GoTo skipelsecheck 'If it's an else by itself,then we'll call it good too at this point and let the rest of the syntax checking check for us
            Do
                spacelocation = InStr(temp$, " ")
                If spacelocation Then temp$ = Left$(temp$, spacelocation - 1) + Mid$(temp$, spacelocation + 1)
            Loop Until spacelocation = 0
            If InStr(temp$, ":ELSE") Or InStr(temp$, ":IF") Then goodelse = -1: GoTo skipelsecheck 'I personally don't like the idea of a :ELSE statement, but this checks for that and validates it as well.  YUCK!  (I suppose this might be useful if there's a label where the ELSE is, like thisline: ELSE
            count = 0
            Do
                count = count + 1
                Select Case Mid$(temp$, count, 1)
                    Case Is = "1", "2", "3", "4", "5", "6", "7", "8", "9", "0", ":"
                    Case Else: Exit Do
                End Select
            Loop Until count >= Len(temp$)
            If Mid$(temp$, count, 4) = "ELSE" Or Mid$(temp$, count, 2) = "IF" Then goodelse = -1 'We only had numbers before our else
            If Not goodelse Then a$ = "Invalid Syntax for ELSE": GoTo errmes
            skipelsecheck:
            'End of ELSE Error checking
            For i = controllevel To 1 Step -1
                t = controltype(i)
                If t = 1 Then
                    If controlstate(controllevel) = 2 Then a$ = "IF-THEN already contains an ELSE statement": GoTo errmes
                    Print #12, "}else{"
                    controlstate(controllevel) = 2
                    If lineelseused = 0 Then lhscontrollevel = lhscontrollevel - 1
                    l$ = SCase$("Else")
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishednonexec '***no error causing code, event checking done by IF***
                End If
            Next
            a$ = "ELSE without IF": GoTo errmes
        End If
    End If

    If n >= 3 Then
        If firstelement$ = "ELSEIF" Then
            If NoChecks = 0 Then
                Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1
            End If
            For i = controllevel To 1 Step -1
                t = controltype(i)
                If t = 1 Then
                    If controlstate(controllevel) = 2 Then a$ = "ELSEIF invalid after ELSE": GoTo errmes
                    controlstate(controllevel) = 1
                    controlvalue(controllevel) = controlvalue(controllevel) + 1
                    e$ = getelement$(a$, n)
                    If e$ <> "THEN" Then a$ = "Expected ELSEIF expression THEN": GoTo errmes
                    Print #12, "}else{"
                    e$ = fixoperationorder$(getelements$(ca$, 2, n - 1))
                    If Error_Happened Then GoTo errmes
                    l$ = SCase$("ElseIf") + sp + tlayout$ + sp + SCase$("Then")
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    e$ = evaluate(e$, typ)
                    If Error_Happened Then GoTo errmes
                    If (typ And ISREFERENCE) Then e$ = refer$(e$, typ, 0)
                    If Error_Happened Then GoTo errmes
                    If typ And ISSTRING Then
                        a$ = "Expected ELSEIF LEN(stringexpression) THEN": GoTo errmes
                    End If
                    If stringprocessinghappened Then
                        Print #12, "if (" + cleanupstringprocessingcall$ + e$ + ")){"
                    Else
                        Print #12, "if (" + e$ + "){"
                    End If
                    lhscontrollevel = lhscontrollevel - 1
                    GoTo finishedline
                End If
            Next
            a$ = "ELSEIF without IF": GoTo errmes
        End If
    End If

    If n >= 3 Then
        If firstelement$ = "IF" Then
            If NoChecks = 0 Then
                Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1
            End If

            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            e$ = getelement(a$, n)
            iftype = 0
            If e$ = "THEN" Then iftype = 1
            If e$ = "GOTO" Then iftype = 2
            If iftype = 0 Then a$ = "Expected IF expression THEN/GOTO": GoTo errmes

            controllevel = controllevel + 1
            controlref(controllevel) = linenumber
            controltype(controllevel) = 1
            controlvalue(controllevel) = 0 'number of extra closing } required at END IF
            controlstate(controllevel) = 0

            e$ = fixoperationorder$(getelements(ca$, 2, n - 1))
            If Error_Happened Then GoTo errmes
            l$ = SCase$("If") + sp + tlayout$
            e$ = evaluate(e$, typ)
            If Error_Happened Then GoTo errmes
            If (typ And ISREFERENCE) Then e$ = refer$(e$, typ, 0)
            If Error_Happened Then GoTo errmes

            If typ And ISSTRING Then
                a$ = "Expected IF LEN(stringexpression) THEN": GoTo errmes
            End If

            If stringprocessinghappened Then
                Print #12, "if ((" + cleanupstringprocessingcall$ + e$ + "))||new_error){"
            Else
                Print #12, "if ((" + e$ + ")||new_error){"
            End If

            If iftype = 1 Then l$ = l$ + sp + SCase$("Then") 'note: 'GOTO' will be added when iftype=2
            layoutdone = 1: If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$

            If iftype = 2 Then 'IF ... GOTO
                GoTo finishedline
            End If

            THENGOTO = 1 'possible: IF a=1 THEN 10
            GoTo finishedline2
        End If
    End If

    'ENDIF
    If n = 1 And getelement(a$, 1) = "ENDIF" Then
        If controltype(controllevel) <> 1 Then a$ = "END IF without IF": GoTo errmes
        layoutdone = 1
        If impliedendif = 0 Then
            l$ = SCase$("End If")
            If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
        End If

        Print #12, "}"
        For i = 1 To controlvalue(controllevel)
            Print #12, "}"
        Next
        controllevel = controllevel - 1
        GoTo finishednonexec '***no error causing code, event checking done by IF***
    End If

    'END IF
    If n = 2 Then
        If getelement(a$, 1) = "END" And getelement(a$, 2) = "IF" Then


            If controltype(controllevel) <> 1 Then a$ = "END IF without IF": GoTo errmes
            layoutdone = 1
            If impliedendif = 0 Then
                l$ = SCase$("End" + sp + "If")
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
            End If

            Print #12, "}"
            For i = 1 To controlvalue(controllevel)
                Print #12, "}"
            Next
            controllevel = controllevel - 1
            GoTo finishednonexec '***no error causing code, event checking done by IF***
        End If
    End If

    'SELECT CASE
    If n >= 1 Then
        If firstelement$ = "SELECT" Then
            If NoChecks = 0 Then
                Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1
            End If

            'prevents code from being placed before 'CASE condition' in a SELECT CASE block
            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                a$ = "Expected CASE expression": GoTo errmes
            End If

            SelectCaseCounter = SelectCaseCounter + 1
            If UBound(EveryCaseSet) <= SelectCaseCounter Then ReDim _Preserve EveryCaseSet(SelectCaseCounter)
            If UBound(SelectCaseHasCaseBlock) <= SelectCaseCounter Then ReDim _Preserve SelectCaseHasCaseBlock(SelectCaseCounter)
            SelectCaseHasCaseBlock(SelectCaseCounter) = 0
            If secondelement$ = "EVERYCASE" Then
                EveryCaseSet(SelectCaseCounter) = -1
                If n = 2 Then a$ = "Expected SELECT CASE expression": GoTo errmes
                e$ = fixoperationorder(getelements$(ca$, 3, n))
                If Error_Happened Then GoTo errmes
                l$ = SCase$("Select EveryCase ") + tlayout$
            Else
                EveryCaseSet(SelectCaseCounter) = 0
                If n = 1 Or secondelement$ <> "CASE" Then a$ = "Expected CASE or EVERYCASE": GoTo errmes
                If n = 2 Then a$ = "Expected SELECT CASE expression": GoTo errmes
                e$ = fixoperationorder(getelements$(ca$, 3, n))
                If Error_Happened Then GoTo errmes
                l$ = SCase$("Select Case ") + tlayout$
            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            e$ = evaluate(e$, typ)
            If Error_Happened Then GoTo errmes
            u = uniquenumber

            controllevel = controllevel + 1
            controlvalue(controllevel) = 0 'id

            t$ = ""
            If (typ And ISSTRING) Then
                t = 0
                If (typ And ISUDT) = 0 And (typ And ISARRAY) = 0 And (typ And ISREFERENCE) <> 0 Then
                    controlvalue(controllevel) = Val(e$)
                Else
                    If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                    If Error_Happened Then GoTo errmes
                    Print #13, "static qbs *sc_" + str2$(u) + "=qbs_new(0,0);"
                    Print #12, "qbs_set(sc_" + str2$(u) + "," + e$ + ");"
                    If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"
                End If

            Else

                If (typ And ISFLOAT) Then

                    If (typ And 511) > 64 Then t = 3: t$ = "long double"
                    If (typ And 511) = 32 Then t = 4: t$ = "float"
                    If (typ And 511) = 64 Then t = 5: t$ = "double"
                    If (typ And ISUDT) = 0 And (typ And ISARRAY) = 0 And (typ And ISREFERENCE) <> 0 Then
                        controlvalue(controllevel) = Val(e$)
                    Else
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then GoTo errmes

                        Print #13, "static " + t$ + " sc_" + str2$(u) + ";"
                        Print #12, "sc_" + str2$(u) + "=" + e$ + ";"
                        If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"
                    End If

                Else

                    'non-float
                    t = 1: t$ = "int64"
                    If (typ And ISUNSIGNED) Then
                        If (typ And 511) <= 32 Then t = 7: t$ = "uint32"
                        If (typ And 511) > 32 Then t = 2: t$ = "uint64"
                    Else
                        If (typ And 511) <= 32 Then t = 6: t$ = "int32"
                        If (typ And 511) > 32 Then t = 1: t$ = "int64"
                    End If
                    If (typ And ISUDT) = 0 And (typ And ISARRAY) = 0 And (typ And ISREFERENCE) <> 0 Then
                        controlvalue(controllevel) = Val(e$)
                    Else
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then GoTo errmes
                        Print #13, "static " + t$ + " sc_" + str2$(u) + ";"
                        Print #12, "sc_" + str2$(u) + "=" + e$ + ";"
                        If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"
                    End If

                End If
            End If

            controlref(controllevel) = linenumber
            controltype(controllevel) = 10 + t
            controlid(controllevel) = u
            If EveryCaseSet(SelectCaseCounter) Then Print #13, "int32 sc_" + str2$(controlid(controllevel)) + "_var;"
            If EveryCaseSet(SelectCaseCounter) Then Print #12, "sc_" + str2$(controlid(controllevel)) + "_var=0;"
            GoTo finishedline
        End If
    End If

    'END SELECT
    If n = 2 Then
        If firstelement$ = "END" And secondelement$ = "SELECT" Then
            'complete current case if necessary
            '18=CASE (awaiting END SELECT/CASE/CASE ELSE)
            '19=CASE ELSE (awaiting END SELECT)
            If controltype(controllevel) = 18 Then
                everycasenewcase = everycasenewcase + 1
                Print #12, "sc_ec_" + str2$(everycasenewcase) + "_end:;"
                controllevel = controllevel - 1
                If EveryCaseSet(SelectCaseCounter) = 0 Then Print #12, "goto sc_" + str2$(controlid(controllevel)) + "_end;"
                Print #12, "}"
            End If
            If controltype(controllevel) = 19 Then
                controllevel = controllevel - 1
                If EveryCaseSet(SelectCaseCounter) Then Print #12, "} /* End of SELECT EVERYCASE ELSE */"
            End If

            Print #12, "sc_" + str2$(controlid(controllevel)) + "_end:;"
            If controltype(controllevel) < 10 Or controltype(controllevel) > 17 Then a$ = "END SELECT without SELECT CASE": GoTo errmes

            If SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
                'warn user of empty SELECT CASE block
                If Not IgnoreWarnings Then
                    addWarning linenumber, inclevel, inclinenumber(inclevel), incname$(inclevel), "empty SELECT CASE block", ""
                End If
            End If

            controllevel = controllevel - 1
            SelectCaseCounter = SelectCaseCounter - 1
            l$ = SCase$("End" + sp + "Select")
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishednonexec '***no error causing code, event checking done by SELECT CASE***
        End If
    End If

    'prevents code from being placed before 'CASE condition' in a SELECT CASE block
    If n >= 1 And firstelement$ <> "CASE" And SelectCaseCounter > 0 And SelectCaseHasCaseBlock(SelectCaseCounter) = 0 Then
        a$ = "Expected CASE expression": GoTo errmes
    End If

    'CASE
    If n >= 1 Then
        If firstelement$ = "CASE" Then

            l$ = SCase$("Case")
            'complete current case if necessary
            '18=CASE (awaiting END SELECT/CASE/CASE ELSE)
            '19=CASE ELSE (awaiting END SELECT)
            If controltype(controllevel) = 19 Then a$ = "Expected END SELECT": GoTo errmes
            If controltype(controllevel) = 18 Then
                lhscontrollevel = lhscontrollevel - 1
                controllevel = controllevel - 1
                everycasenewcase = everycasenewcase + 1
                Print #12, "sc_ec_" + str2$(everycasenewcase) + "_end:;"
                If EveryCaseSet(SelectCaseCounter) = 0 Then
                    Print #12, "goto sc_" + str2$(controlid(controllevel)) + "_end;"
                Else
                    Print #12, "sc_" + str2$(controlid(controllevel)) + "_var=-1;"
                End If
                Print #12, "}"
                'following line fixes problem related to RESUME after error
                'statementn = statementn + 1
                'if nochecks=0 then PRINT #12, "S_" + str2$(statementn) + ":;"
            End If

            If controltype(controllevel) <> 6 And (controltype(controllevel) < 10 Or controltype(controllevel) > 17) Then a$ = "CASE without SELECT CASE": GoTo errmes
            If n = 1 Then a$ = "Expected CASE expression": GoTo errmes
            SelectCaseHasCaseBlock(SelectCaseCounter) = -1

            'upgrade:
            '#1: variables can be referred to directly by storing an id in 'controlref'
            '    (but not if part of an array etc.)
            'DIM controlvalue(1000) AS LONG
            '#2: more types will be available
            '    +SINGLE
            '    +DOUBLE
            '    -LONG DOUBLE
            '    +INT32
            '    +UINT32
            '14=SELECT CASE float ...
            '15=SELECT CASE double
            '16=SELECT CASE int32
            '17=SELECT CASE uint32

            '10=SELECT CASE qbs (awaiting END SELECT/CASE)
            '11=SELECT CASE int64 (awaiting END SELECT/CASE)
            '12=SELECT CASE uint64 (awaiting END SELECT/CASE)
            '13=SELECT CASE LONG double (awaiting END SELECT/CASE/CASE ELSE)
            '14=SELECT CASE float ...
            '15=SELECT CASE double
            '16=SELECT CASE int32
            '17=SELECT CASE uint32

            '    bits = targettyp AND 511
            '                                IF bits <= 16 THEN e$ = "qbr_float_to_long(" + e$ + ")"
            '                                IF bits > 16 AND bits < 32 THEN e$ = "qbr_double_to_long(" + e$ + ")"
            '                                IF bits >= 32 THEN e$ = "qbr(" + e$ + ")"

            t = controltype(controllevel) - 10
            'get required type cast, and float options
            flt = 0
            If t = 0 Then tc$ = ""
            If t = 1 Then tc$ = ""
            If t = 2 Then tc$ = ""
            If t = 3 Then tc$ = "": flt = 1
            If t = 4 Then tc$ = "(float)": flt = 1
            If t = 5 Then tc$ = "(double)": flt = 1
            If t = 6 Then tc$ = ""
            If t = 7 Then tc$ = ""

            n$ = "sc_" + str2$(controlid(controllevel))
            cv = controlvalue(controllevel)
            If cv Then
                n$ = refer$(str2$(cv), 0, 0)
                If Error_Happened Then GoTo errmes
            End If

            'CASE ELSE
            If n = 2 Then
                If getelement$(a$, 2) = "C-EL" Then
                    If EveryCaseSet(SelectCaseCounter) Then Print #12, "if (sc_" + str2$(controlid(controllevel)) + "_var==0) {"
                    controllevel = controllevel + 1: controltype(controllevel) = 19
                    controlref(controllevel) = controlref(controllevel - 1)
                    l$ = l$ + sp + SCase$("Else")
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishednonexec '***no error causing code, event checking done by SELECT CASE***
                End If
            End If

            If NoChecks = 0 Then
                Print #12, "S_" + str2$(statementn) + ":;": dynscope = 1
            End If

            f12$ = ""

            nexp = 0
            B = 0
            e$ = ""
            For i = 2 To n
                e2$ = getelement$(ca$, i)
                If e2$ = "(" Then B = B + 1
                If e2$ = ")" Then B = B - 1
                If i = n Then e$ = e$ + sp + e2$
                If i = n Or (e2$ = "," And B = 0) Then
                    If nexp <> 0 Then l$ = l$ + sp2 + ",": f12$ = f12$ + "||"
                    If e$ = "" Then a$ = "Expected expression": GoTo errmes
                    e$ = Right$(e$, Len(e$) - 1)

                    'TYPE 1? ... TO ...
                    n2 = numelements(e$)
                    b2 = 0
                    el$ = "": er$ = ""
                    usedto = 0
                    For i2 = 1 To n2
                        e3$ = getelement$(e$, i2)
                        If e3$ = "(" Then b2 = b2 + 1
                        If e3$ = ")" Then b2 = b2 - 1
                        If b2 = 0 And UCase$(e3$) = "TO" Then
                            usedto = 1
                        Else
                            If usedto = 0 Then el$ = el$ + sp + e3$ Else er$ = er$ + sp + e3$
                        End If
                    Next
                    If usedto = 1 Then
                        If el$ = "" Or er$ = "" Then a$ = "Expected expression TO expression": GoTo errmes
                        el$ = Right$(el$, Len(el$) - 1): er$ = Right$(er$, Len(er$) - 1)
                        'evaluate each side
                        For i2 = 1 To 2
                            If i2 = 1 Then e$ = el$ Else e$ = er$
                            e$ = fixoperationorder(e$)
                            If Error_Happened Then GoTo errmes
                            If i2 = 1 Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp + SCase$("To") + sp + tlayout$
                            e$ = evaluate(e$, typ)
                            If Error_Happened Then GoTo errmes
                            If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                            If Error_Happened Then GoTo errmes
                            If t = 0 Then
                                If (typ And ISSTRING) = 0 Then a$ = "Expected string expression": GoTo errmes
                                If i2 = 1 Then f12$ = f12$ + "(qbs_greaterorequal(" + n$ + "," + e$ + ")&&qbs_lessorequal(" + n$ + ","
                                If i2 = 2 Then f12$ = f12$ + e$ + "))"
                            Else
                                If (typ And ISSTRING) Then a$ = "Expected numeric expression": GoTo errmes
                                'round to integer?
                                If (typ And ISFLOAT) Then
                                    If t = 1 Then e$ = "qbr(" + e$ + ")"
                                    If t = 2 Then e$ = "qbr_longdouble_to_uint64(" + e$ + ")"
                                    If t = 6 Or t = 7 Then e$ = "qbr_double_to_long(" + e$ + ")"
                                End If
                                'cast result?
                                If Len(tc$) Then e$ = tc$ + "(" + e$ + ")"
                                If i2 = 1 Then f12$ = f12$ + "((" + n$ + ">=(" + e$ + "))&&(" + n$ + "<=("
                                If i2 = 2 Then f12$ = f12$ + e$ + ")))"
                            End If
                        Next
                        GoTo addedexp
                    End If

                    '10=SELECT CASE qbs (awaiting END SELECT/CASE)
                    '11=SELECT CASE int64 (awaiting END SELECT/CASE)
                    '12=SELECT CASE uint64 (awaiting END SELECT/CASE)
                    '13=SELECT CASE LONG double (awaiting END SELECT/CASE/CASE ELSE)
                    '14=SELECT CASE float ...
                    '15=SELECT CASE double
                    '16=SELECT CASE int32
                    '17=SELECT CASE uint32

                    '    bits = targettyp AND 511
                    '                                IF bits <= 16 THEN e$ = "qbr_float_to_long(" + e$ + ")"
                    '                                IF bits > 16 AND bits < 32 THEN e$ = "qbr_double_to_long(" + e$ + ")"
                    '                                IF bits >= 32 THEN e$ = "qbr(" + e$ + ")"

                    o$ = "==" 'used by type 3

                    'TYPE 2?
                    x$ = getelement$(e$, 1)
                    If isoperator(x$) Then 'non-standard usage correction
                        If x$ = "=" Or x$ = "<>" Or x$ = ">" Or x$ = "<" Or x$ = ">=" Or x$ = "<=" Then
                            e$ = "IS" + sp + e$
                            x$ = "IS"
                        End If
                    End If
                    If UCase$(x$) = "IS" Then
                        n2 = numelements(e$)
                        If n2 < 3 Then a$ = "Expected IS =,<>,>,<,>=,<= expression": GoTo errmes
                        o$ = getelement$(e$, 2)
                        o2$ = o$
                        o = 0
                        If o$ = "=" Then o$ = "==": o = 1
                        If o$ = "<>" Then o$ = "!=": o = 1
                        If o$ = ">" Then o = 1
                        If o$ = "<" Then o = 1
                        If o$ = ">=" Then o = 1
                        If o$ = "<=" Then o = 1
                        If o <> 1 Then a$ = "Expected IS =,<>,>,<,>=,<= expression": GoTo errmes
                        l$ = l$ + sp + SCase$("Is") + sp + o2$
                        e$ = getelements$(e$, 3, n2)
                        'fall through to type 3 using modified e$ & o$
                    End If

                    'TYPE 3? simple expression
                    e$ = fixoperationorder(e$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$
                    e$ = evaluate(e$, typ)
                    If Error_Happened Then GoTo errmes
                    If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                    If Error_Happened Then GoTo errmes
                    If t = 0 Then
                        'string comparison
                        If (typ And ISSTRING) = 0 Then a$ = "Expected string expression": GoTo errmes
                        If o$ = "==" Then o$ = "qbs_equal"
                        If o$ = "!=" Then o$ = "qbs_notequal"
                        If o$ = ">" Then o$ = "qbs_greaterthan"
                        If o$ = "<" Then o$ = "qbs_lessthan"
                        If o$ = ">=" Then o$ = "qbs_greaterorequal"
                        If o$ = "<=" Then o$ = "qbs_lessorequal"
                        f12$ = f12$ + o$ + "(" + n$ + "," + e$ + ")"
                    Else
                        'numeric
                        If (typ And ISSTRING) Then a$ = "Expected numeric expression": GoTo errmes
                        'round to integer?
                        If (typ And ISFLOAT) Then
                            If t = 1 Then e$ = "qbr(" + e$ + ")"
                            If t = 2 Then e$ = "qbr_longdouble_to_uint64(" + e$ + ")"
                            If t = 6 Or t = 7 Then e$ = "qbr_double_to_long(" + e$ + ")"
                        End If
                        'cast result?
                        If Len(tc$) Then e$ = tc$ + "(" + e$ + ")"
                        f12$ = f12$ + "(" + n$ + o$ + "(" + e$ + "))"
                    End If

                    addedexp:
                    e$ = ""
                    nexp = nexp + 1
                Else
                    e$ = e$ + sp + e2$
                End If
            Next

            If stringprocessinghappened Then
                Print #12, "if ((" + cleanupstringprocessingcall$ + f12$ + "))||new_error){"
            Else
                Print #12, "if ((" + f12$ + ")||new_error){"
            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            controllevel = controllevel + 1
            controlref(controllevel) = controlref(controllevel - 1)
            controltype(controllevel) = 18
            GoTo finishedline
        End If
    End If

    'static scope commands:

    If NoChecks = 0 Then
        Print #12, "do{"
    End If

    If n > 1 Then
        If firstelement$ = "PALETTE" Then
            If secondelement$ = "USING" Then
                l$ = SCase$("Palette" + sp + "Using" + sp)
                If n < 3 Then a$ = "Expected PALETTE USING array-name": GoTo errmes
                'check array
                e$ = getelement$(ca$, 3)
                If FindArray(e$) Then
                    If Error_Happened Then GoTo errmes
                    z = 1
                    t = id.arraytype
                    If (t And 511) <> 16 And (t And 511) <> 32 Then z = 0
                    If t And ISFLOAT Then z = 0
                    If t And ISOFFSETINBITS Then z = 0
                    If t And ISSTRING Then z = 0
                    If t And ISUDT Then z = 0
                    If t And ISUNSIGNED Then z = 0
                    If z = 0 Then a$ = "Array must be of type INTEGER or LONG": GoTo errmes
                    bits = t And 511
                    GoTo pu_gotarray
                End If
                If Error_Happened Then GoTo errmes
                a$ = "Expected PALETTE USING array-name": GoTo errmes
                pu_gotarray:
                'add () if index not specified
                If n = 3 Then
                    e$ = e$ + sp + "(" + sp + ")"
                Else
                    If n = 4 Or getelement$(a$, 4) <> "(" Or getelement$(a$, n) <> ")" Then a$ = "Expected PALETTE USING array-name(...)": GoTo errmes
                    e$ = e$ + sp + getelements$(ca$, 4, n)
                End If
                e$ = fixoperationorder$(e$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + tlayout$
                e$ = evaluatetotyp(e$, -2)
                If Error_Happened Then GoTo errmes
                Print #12, "sub_paletteusing(" + e$ + "," + str2(bits) + ");"
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If 'using
        End If 'palette
    End If 'n>1

    If firstelement$ = "KEY" Then
        If n = 1 Then a$ = "Expected KEY ...": GoTo errmes
        l$ = SCase$("KEY") + sp
        If secondelement$ = "OFF" Then
            If n > 2 Then a$ = "Expected KEY OFF only": GoTo errmes
            l$ = l$ + SCase$("Off"): layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "key_off();"
            GoTo finishedline
        End If
        If secondelement$ = "ON" Then
            If n > 2 Then a$ = "Expected KEY ON only": GoTo errmes
            l$ = l$ + SCase$("On"): layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "key_on();"
            GoTo finishedline
        End If
        If secondelement$ = "LIST" Then
            If n > 2 Then a$ = "Expected KEY LIST only": GoTo errmes
            l$ = l$ + SCase$("List"): layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "key_list();"
            GoTo finishedline
        End If
        'search for comma to indicate assignment
        B = 0: e$ = ""
        For i = 2 To n
            e2$ = getelement(ca$, i)
            If e2$ = "(" Then B = B + 1
            If e2$ = ")" Then B = B - 1
            If e2$ = "," And B = 0 Then
                i = i + 1: GoTo key_assignment
            End If
            If Len(e$) Then e$ = e$ + sp + e2$ Else e$ = e2$
        Next
        'assume KEY(x) ON/OFF/STOP and handle as a sub
        GoTo key_fallthrough
        key_assignment:
        'KEY x, "string"
        'index
        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + tlayout$ + sp2 + "," + sp
        e$ = evaluatetotyp(e$, 32&)
        If Error_Happened Then GoTo errmes
        Print #12, "key_assign(" + e$ + ",";
        'string
        e$ = getelements$(ca$, i, n)
        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + tlayout$
        e$ = evaluatetotyp(e$, ISSTRING)
        If Error_Happened Then GoTo errmes
        Print #12, e$ + ");"
        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        GoTo finishedline
    End If 'KEY
    key_fallthrough:

    If firstelement$ = "FIELD" Then

        'get filenumber
        B = 0: e$ = ""
        For i = 2 To n
            e2$ = getelement(ca$, i)
            If e2$ = "(" Then B = B + 1
            If e2$ = ")" Then B = B - 1
            If e2$ = "," And B = 0 Then
                i = i + 1: GoTo fieldgotfn
            End If
            If Len(e$) Then e$ = e$ + sp + e2$ Else e$ = e2$
        Next
        GoTo fielderror
        fieldgotfn:
        If e$ = "#" Or Len(e$) = 0 Then GoTo fielderror
        If Left$(e$, 2) = "#" + sp Then e$ = Right$(e$, Len(e$) - 2): l$ = SCase$("Field") + sp + "#" + sp2 Else l$ = SCase$("Field") + sp
        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + tlayout$ + sp2 + "," + sp
        e$ = evaluatetotyp(e$, 32&)
        If Error_Happened Then GoTo errmes
        Print #12, "field_new(" + e$ + ");"

        fieldnext:

        'get fieldwidth
        If i > n Then GoTo fielderror
        B = 0: e$ = ""
        For i = i To n
            e2$ = getelement(ca$, i)
            If e2$ = "(" Then B = B + 1
            If e2$ = ")" Then B = B - 1
            If UCase$(e2$) = "AS" And B = 0 Then
                i = i + 1: GoTo fieldgotfw
            End If
            If Len(e$) Then e$ = e$ + sp + e2$ Else e$ = e2$
        Next
        GoTo fielderror
        fieldgotfw:
        If Len(e$) = 0 Then GoTo fielderror
        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + tlayout$ + sp + SCase$("As") + sp
        sizee$ = evaluatetotyp(e$, 32&)
        If Error_Happened Then GoTo errmes

        'get variable name
        If i > n Then GoTo fielderror
        B = 0: e$ = ""
        For i = i To n
            e2$ = getelement(ca$, i)
            If e2$ = "(" Then B = B + 1
            If e2$ = ")" Then B = B - 1
            If (i = n Or e2$ = ",") And B = 0 Then
                If e2$ = "," Then i = i - 1
                If i = n Then
                    If Len(e$) Then e$ = e$ + sp + e2$ Else e$ = e2$
                End If
                GoTo fieldgotfname
            End If
            If Len(e$) Then e$ = e$ + sp + e2$ Else e$ = e2$
        Next
        GoTo fielderror
        fieldgotfname:
        If Len(e$) = 0 Then GoTo fielderror
        'evaluate it to check it is a STRING
        e$ = fixoperationorder(e$)
        If Error_Happened Then GoTo errmes
        l$ = l$ + tlayout$
        e$ = evaluate(e$, typ)
        If Error_Happened Then GoTo errmes
        If (typ And ISSTRING) = 0 Then GoTo fielderror
        If typ And ISFIXEDLENGTH Then a$ = "Fixed length strings cannot be used in a FIELD statement": GoTo errmes
        If (typ And ISREFERENCE) = 0 Then GoTo fielderror
        e$ = refer(e$, typ, 0)
        If Error_Happened Then GoTo errmes
        Print #12, "field_add(" + e$ + "," + sizee$ + ");"

        If i < n Then
            i = i + 1
            e$ = getelement(a$, i)
            If e$ <> "," Then a$ = "Expected ,": GoTo errmes
            l$ = l$ + sp2 + "," + sp
            i = i + 1
            GoTo fieldnext
        End If

        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        GoTo finishedline

        fielderror: a$ = "Expected FIELD #filenumber, characters AS variable$, ...": GoTo errmes
    End If

    '1=IF (awaiting END IF)
    '2=FOR (awaiting NEXT)
    '3=DO (awaiting LOOP [UNTIL|WHILE param])
    '4=DO WHILE/UNTIL (awaiting LOOP)
    '5=WHILE (awaiting WEND)

    If n = 2 Then
        If firstelement$ = "EXIT" Then

            l$ = SCase$("Exit") + sp

            If secondelement$ = "DO" Then
                'scan backwards until previous control level reached
                l$ = l$ + SCase$("Do")
                For i = controllevel To 1 Step -1
                    t = controltype(i)
                    If t = 3 Or t = 4 Then
                        Print #12, "goto dl_exit_" + str2$(controlid(i)) + ";"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    End If
                Next
                a$ = "EXIT DO without DO": GoTo errmes
            End If

            If secondelement$ = "FOR" Then
                'scan backwards until previous control level reached
                l$ = l$ + SCase$("For")
                For i = controllevel To 1 Step -1
                    t = controltype(i)
                    If t = 2 Then
                        Print #12, "goto fornext_exit_" + str2$(controlid(i)) + ";"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    End If
                Next
                a$ = "EXIT FOR without FOR": GoTo errmes
            End If

            If secondelement$ = "WHILE" Then
                'scan backwards until previous control level reached
                l$ = l$ + SCase$("While")
                For i = controllevel To 1 Step -1
                    t = controltype(i)
                    If t = 5 Then
                        Print #12, "goto ww_exit_" + str2$(controlid(i)) + ";"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    End If
                Next
                a$ = "EXIT WHILE without WHILE": GoTo errmes
            End If

            If secondelement$ = "SELECT" Then
                'scan backwards until previous control level reached
                l$ = l$ + SCase$("Select")
                For i = controllevel To 1 Step -1
                    t = controltype(i)
                    If t = 18 Or t = 19 Then 'CASE/CASE ELSE
                        Print #12, "goto sc_" + str2$(controlid(i - 1)) + "_end;"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    End If
                Next
                a$ = "EXIT SELECT without SELECT": GoTo errmes
            End If

            If secondelement$ = "CASE" Then
                'scan backwards until previous control level reached
                l$ = l$ + SCase$("Case")
                For i = controllevel To 1 Step -1
                    t = controltype(i)
                    If t = 18 Then 'CASE
                        Print #12, "goto sc_ec_" + str2$(everycasenewcase + 1) + "_end;"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    ElseIf t = 19 Then 'CASE ELSE
                        Print #12, "goto sc_" + str2$(controlid(i - 1)) + "_end;"
                        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                        GoTo finishedline
                    End If
                Next
                a$ = "EXIT CASE without CASE": GoTo errmes
            End If

        End If
    End If

    If n >= 2 Then
        If firstelement$ = "ON" And secondelement$ = "STRIG" Then
            DEPENDENCY(DEPENDENCY_DEVICEINPUT) = 1
            i = 3
            If i > n Then a$ = "Expected (": GoTo errmes
            a2$ = getelement$(ca$, i): i = i + 1
            If a2$ <> "(" Then a$ = "Expected (": GoTo errmes
            l$ = SCase$("On" + sp + "Strig" + sp2 + "(")
            If i > n Then a$ = "Expected ...": GoTo errmes
            B = 0
            x = 0
            e2$ = ""
            e3$ = ""
            For i = i To n
                e$ = getelement$(ca$, i)
                a = Asc(e$)
                If a = 40 Then B = B + 1
                If a = 41 Then B = B - 1
                If B = -1 Then GoTo onstriggotarg
                If a = 44 And B = 0 Then
                    x = x + 1
                    If x > 1 Then a$ = "Expected )": GoTo errmes
                    If e2$ = "" Then a$ = "Expected ... ,": GoTo errmes
                    e3$ = e2$
                    e2$ = ""
                Else
                    If Len(e2$) Then e2$ = e2$ + sp + e$ Else e2$ = e$
                End If
            Next
            a$ = "Expected )": GoTo errmes
            onstriggotarg:
            If e2$ = "" Then a$ = "Expected ... )": GoTo errmes
            Print #12, "onstrig_setup(";

            'sort scanned results
            If Len(e3$) Then
                optI$ = e3$
                optController$ = e2$
                optPassed$ = "1"
            Else
                optI$ = e2$
                optController$ = "0"
                optPassed$ = "0"
            End If

            'i
            e$ = fixoperationorder$(optI$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + tlayout$
            e$ = evaluatetotyp(e$, 32&): If Error_Happened Then GoTo errmes
            Print #12, e$ + ",";

            'controller , passed
            If optPassed$ = "1" Then
                e$ = fixoperationorder$(optController$): If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$
                e$ = evaluatetotyp(e$, 32&): If Error_Happened Then GoTo errmes
            Else
                e$ = optController$
            End If
            Print #12, e$ + "," + optPassed$ + ",";

            l$ = l$ + sp2 + ")" + sp 'close brackets

            i = i + 1
            If i > n Then a$ = "Expected GOSUB/sub-name": GoTo errmes
            a2$ = getelement$(a$, i): i = i + 1
            onstrigid = onstrigid + 1
            Print #12, str2$(onstrigid) + ",";

            If a2$ = "GOSUB" Then
                If i > n Then a$ = "Expected linenumber/label": GoTo errmes
                a2$ = getelement$(ca$, i): i = i + 1

                Print #12, "0);"

                If validlabel(a2$) = 0 Then a$ = "Invalid label": GoTo errmes

                v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
                x = 1
                labchk60z:
                If v Then
                    s = Labels(r).Scope
                    If s = 0 Or s = -1 Then 'main scope?
                        If s = -1 Then Labels(r).Scope = 0 'acquire scope
                        x = 0 'already defined
                        tlayout$ = RTrim$(Labels(r).cn)
                        Labels(r).Scope_Restriction = subfuncn
                        Labels(r).Error_Line = linenumber
                    Else
                        If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk60z
                    End If
                End If
                If x Then
                    'does not exist
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd a2$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = 0
                    Labels(r).Error_Line = linenumber
                    Labels(r).Scope_Restriction = subfuncn
                End If 'x
                l$ = l$ + SCase$("GoSub") + sp + tlayout$

                Print #30, "if(strig_event_id==" + str2$(onstrigid) + ")goto LABEL_" + a2$ + ";"

                Print #29, "case " + str2$(onstrigid) + ":"
                Print #29, "strig_event_occurred++;"
                Print #29, "strig_event_id=" + str2$(onstrigid) + ";"
                Print #29, "strig_event_occurred++;"
                Print #29, "return_point[next_return_point++]=0;"
                Print #29, "if (next_return_point>=return_points) more_return_points();"
                Print #29, "QBMAIN(NULL);"
                Print #29, "break;"

                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline

            Else

                'establish whether sub a2$ exists using try
                x = 0
                try = findid(a2$)
                If Error_Happened Then GoTo errmes
                Do While try
                    If id.subfunc = 2 Then x = 1: Exit Do
                    If try = 2 Then findanotherid = 1: try = findid(a2$) Else try = 0
                    If Error_Happened Then GoTo errmes
                Loop
                If x = 0 Then a$ = "Expected GOSUB/sub": GoTo errmes

                l$ = l$ + RTrim$(id.cn)

                Print #29, "case " + str2$(onstrigid) + ":"
                Print #29, RTrim$(id.callname) + "(";

                If id.args > 1 Then a$ = "SUB requires more than one argument": GoTo errmes

                If i > n Then

                    If id.args = 1 Then a$ = "Expected argument after SUB": GoTo errmes
                    Print #12, "0);"
                    Print #29, ");"

                Else

                    If id.args = 0 Then a$ = "SUB has no arguments": GoTo errmes

                    t = CVL(id.arg)
                    B = t And 511
                    If B = 0 Or (t And ISARRAY) <> 0 Or (t And ISFLOAT) <> 0 Or (t And ISSTRING) <> 0 Or (t And ISOFFSETINBITS) <> 0 Then a$ = "Only SUB arguments of integer-type allowed": GoTo errmes
                    If B = 8 Then ct$ = "int8"
                    If B = 16 Then ct$ = "int16"
                    If B = 32 Then ct$ = "int32"
                    If B = 64 Then ct$ = "int64"
                    If t And ISOFFSET Then ct$ = "ptrszint"
                    If t And ISUNSIGNED Then ct$ = "u" + ct$
                    Print #29, "(" + ct$ + "*)&i64);"

                    e$ = getelements$(ca$, i, n)
                    e$ = fixoperationorder$(e$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$
                    e$ = evaluatetotyp(e$, INTEGER64TYPE - ISPOINTER)
                    If Error_Happened Then GoTo errmes
                    Print #12, e$ + ");"

                End If

                Print #29, "break;"
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline
            End If

        End If
    End If

    If n >= 2 Then
        If firstelement$ = "ON" And secondelement$ = "TIMER" Then
            i = 3
            If i > n Then a$ = "Expected (": GoTo errmes
            a2$ = getelement$(ca$, i): i = i + 1
            If a2$ <> "(" Then a$ = "Expected (": GoTo errmes
            l$ = SCase$("On" + sp + "Timer" + sp2 + "(")
            If i > n Then a$ = "Expected ...": GoTo errmes
            B = 0
            x = 0
            e2$ = ""
            e3$ = ""
            For i = i To n
                e$ = getelement$(ca$, i)
                a = Asc(e$)
                If a = 40 Then B = B + 1
                If a = 41 Then B = B - 1
                If B = -1 Then GoTo ontimgotarg
                If a = 44 And B = 0 Then
                    x = x + 1
                    If x > 1 Then a$ = "Expected )": GoTo errmes
                    If e2$ = "" Then a$ = "Expected ... ,": GoTo errmes
                    e3$ = e2$
                    e2$ = ""
                Else
                    If Len(e2$) Then e2$ = e2$ + sp + e$ Else e2$ = e$
                End If
            Next
            a$ = "Expected )": GoTo errmes
            ontimgotarg:
            If e2$ = "" Then a$ = "Expected ... )": GoTo errmes
            Print #12, "ontimer_setup(";
            'i
            If Len(e3$) Then
                e$ = fixoperationorder$(e3$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + tlayout$ + "," + sp
                e$ = evaluatetotyp(e$, 32&)
                If Error_Happened Then GoTo errmes
                Print #12, e$ + ",";
            Else
                Print #12, "0,";
                l$ = l$ + sp2
            End If
            'sec
            e$ = fixoperationorder$(e2$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + tlayout$ + sp2 + ")" + sp
            e$ = evaluatetotyp(e$, DOUBLETYPE - ISPOINTER)
            If Error_Happened Then GoTo errmes
            Print #12, e$ + ",";
            i = i + 1
            If i > n Then a$ = "Expected GOSUB/sub-name": GoTo errmes
            a2$ = getelement$(a$, i): i = i + 1
            ontimerid = ontimerid + 1
            Print #12, str2$(ontimerid) + ",";

            If a2$ = "GOSUB" Then
                If i > n Then a$ = "Expected linenumber/label": GoTo errmes
                a2$ = getelement$(ca$, i): i = i + 1

                Print #12, "0);"

                If validlabel(a2$) = 0 Then a$ = "Invalid label": GoTo errmes

                v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
                x = 1
                labchk60:
                If v Then
                    s = Labels(r).Scope
                    If s = 0 Or s = -1 Then 'main scope?
                        If s = -1 Then Labels(r).Scope = 0 'acquire scope
                        x = 0 'already defined
                        tlayout$ = RTrim$(Labels(r).cn)
                        Labels(r).Scope_Restriction = subfuncn
                        Labels(r).Error_Line = linenumber
                    Else
                        If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk60
                    End If
                End If
                If x Then
                    'does not exist
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd a2$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = 0
                    Labels(r).Error_Line = linenumber
                    Labels(r).Scope_Restriction = subfuncn
                End If 'x
                l$ = l$ + SCase$("GoSub") + sp + tlayout$

                Print #25, "if(timer_event_id==" + str2$(ontimerid) + ")goto LABEL_" + a2$ + ";"

                Print #24, "case " + str2$(ontimerid) + ":"
                Print #24, "timer_event_occurred++;"
                Print #24, "timer_event_id=" + str2$(ontimerid) + ";"
                Print #24, "timer_event_occurred++;"
                Print #24, "return_point[next_return_point++]=0;"
                Print #24, "if (next_return_point>=return_points) more_return_points();"
                Print #24, "QBMAIN(NULL);"
                Print #24, "break;"

                'call validlabel (to validate the label) [see goto]
                'increment ontimerid
                'use ontimerid to generate the jumper routine
                'etc.

                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline
            Else

                'establish whether sub a2$ exists using try
                x = 0
                try = findid(a2$)
                If Error_Happened Then GoTo errmes
                Do While try
                    If id.subfunc = 2 Then x = 1: Exit Do
                    If try = 2 Then findanotherid = 1: try = findid(a2$) Else try = 0
                    If Error_Happened Then GoTo errmes
                Loop
                If x = 0 Then a$ = "Expected GOSUB/sub": GoTo errmes

                l$ = l$ + RTrim$(id.cn)

                Print #24, "case " + str2$(ontimerid) + ":"
                Print #24, RTrim$(id.callname) + "(";

                If id.args > 1 Then a$ = "SUB requires more than one argument": GoTo errmes

                If i > n Then

                    If id.args = 1 Then a$ = "Expected argument after SUB": GoTo errmes
                    Print #12, "0);"
                    Print #24, ");"

                Else

                    If id.args = 0 Then a$ = "SUB has no arguments": GoTo errmes

                    t = CVL(id.arg)
                    B = t And 511
                    If B = 0 Or (t And ISARRAY) <> 0 Or (t And ISFLOAT) <> 0 Or (t And ISSTRING) <> 0 Or (t And ISOFFSETINBITS) <> 0 Then a$ = "Only SUB arguments of integer-type allowed": GoTo errmes
                    If B = 8 Then ct$ = "int8"
                    If B = 16 Then ct$ = "int16"
                    If B = 32 Then ct$ = "int32"
                    If B = 64 Then ct$ = "int64"
                    If t And ISOFFSET Then ct$ = "ptrszint"
                    If t And ISUNSIGNED Then ct$ = "u" + ct$
                    Print #24, "(" + ct$ + "*)&i64);"

                    e$ = getelements$(ca$, i, n)
                    e$ = fixoperationorder$(e$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$
                    e$ = evaluatetotyp(e$, INTEGER64TYPE - ISPOINTER)
                    If Error_Happened Then GoTo errmes
                    Print #12, e$ + ");"

                End If

                Print #24, "break;"
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline
            End If

        End If
    End If

    If n >= 2 Then
        If firstelement$ = "ON" And secondelement$ = "KEY" Then
            i = 3
            If i > n Then a$ = "Expected (": GoTo errmes
            a2$ = getelement$(ca$, i): i = i + 1
            If a2$ <> "(" Then a$ = "Expected (": GoTo errmes
            l$ = SCase$("On" + sp + "Key" + sp2 + "(")
            If i > n Then a$ = "Expected ...": GoTo errmes
            B = 0
            x = 0
            e2$ = ""
            For i = i To n
                e$ = getelement$(ca$, i)
                a = Asc(e$)

                If a = 40 Then B = B + 1
                If a = 41 Then B = B - 1
                If B = -1 Then Exit For
                If Len(e2$) Then e2$ = e2$ + sp + e$ Else e2$ = e$
            Next
            If i = n + 1 Then a$ = "Expected )": GoTo errmes
            If e2$ = "" Then a$ = "Expected ... )": GoTo errmes

            e$ = fixoperationorder$(e2$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + tlayout$ + sp2 + ")" + sp
            e$ = evaluatetotyp(e$, DOUBLETYPE - ISPOINTER)
            If Error_Happened Then GoTo errmes
            Print #12, "onkey_setup(" + e$ + ",";

            i = i + 1
            If i > n Then a$ = "Expected GOSUB/sub-name": GoTo errmes
            a2$ = getelement$(a$, i): i = i + 1
            onkeyid = onkeyid + 1
            Print #12, str2$(onkeyid) + ",";

            If a2$ = "GOSUB" Then
                If i > n Then a$ = "Expected linenumber/label": GoTo errmes
                a2$ = getelement$(ca$, i): i = i + 1

                Print #12, "0);"

                If validlabel(a2$) = 0 Then a$ = "Invalid label": GoTo errmes

                v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
                x = 1
                labchk61:
                If v Then
                    s = Labels(r).Scope
                    If s = 0 Or s = -1 Then 'main scope?
                        If s = -1 Then Labels(r).Scope = 0 'acquire scope
                        x = 0 'already defined
                        tlayout$ = RTrim$(Labels(r).cn)
                        Labels(r).Scope_Restriction = subfuncn
                        Labels(r).Error_Line = linenumber
                    Else
                        If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk61
                    End If
                End If
                If x Then
                    'does not exist
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd a2$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = 0
                    Labels(r).Error_Line = linenumber
                    Labels(r).Scope_Restriction = subfuncn
                End If 'x
                l$ = l$ + SCase$("GoSub") + sp + tlayout$

                Print #28, "if(key_event_id==" + str2$(onkeyid) + ")goto LABEL_" + a2$ + ";"

                Print #27, "case " + str2$(onkeyid) + ":"
                Print #27, "key_event_occurred++;"
                Print #27, "key_event_id=" + str2$(onkeyid) + ";"
                Print #27, "key_event_occurred++;"
                Print #27, "return_point[next_return_point++]=0;"
                Print #27, "if (next_return_point>=return_points) more_return_points();"
                Print #27, "QBMAIN(NULL);"
                Print #27, "break;"

                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline
            Else

                'establish whether sub a2$ exists using try
                x = 0
                try = findid(a2$)
                If Error_Happened Then GoTo errmes
                Do While try
                    If id.subfunc = 2 Then x = 1: Exit Do
                    If try = 2 Then findanotherid = 1: try = findid(a2$) Else try = 0
                    If Error_Happened Then GoTo errmes
                Loop
                If x = 0 Then a$ = "Expected GOSUB/sub": GoTo errmes

                l$ = l$ + RTrim$(id.cn)

                Print #27, "case " + str2$(onkeyid) + ":"
                Print #27, RTrim$(id.callname) + "(";

                If id.args > 1 Then a$ = "SUB requires more than one argument": GoTo errmes

                If i > n Then

                    If id.args = 1 Then a$ = "Expected argument after SUB": GoTo errmes
                    Print #12, "0);"
                    Print #27, ");"

                Else

                    If id.args = 0 Then a$ = "SUB has no arguments": GoTo errmes

                    t = CVL(id.arg)
                    B = t And 511
                    If B = 0 Or (t And ISARRAY) <> 0 Or (t And ISFLOAT) <> 0 Or (t And ISSTRING) <> 0 Or (t And ISOFFSETINBITS) <> 0 Then a$ = "Only SUB arguments of integer-type allowed": GoTo errmes
                    If B = 8 Then ct$ = "int8"
                    If B = 16 Then ct$ = "int16"
                    If B = 32 Then ct$ = "int32"
                    If B = 64 Then ct$ = "int64"
                    If t And ISOFFSET Then ct$ = "ptrszint"
                    If t And ISUNSIGNED Then ct$ = "u" + ct$
                    Print #27, "(" + ct$ + "*)&i64);"

                    e$ = getelements$(ca$, i, n)
                    e$ = fixoperationorder$(e$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$
                    e$ = evaluatetotyp(e$, INTEGER64TYPE - ISPOINTER)
                    If Error_Happened Then GoTo errmes
                    Print #12, e$ + ");"

                End If

                Print #27, "break;"
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                layoutdone = 1
                GoTo finishedline
            End If

        End If
    End If

    'SHARED (SUB)
    If n >= 1 Then
        If firstelement$ = "SHARED" Then
            If n = 1 Then a$ = "Expected SHARED ...": GoTo errmes
            i = 2
            If subfuncn = 0 Then a$ = "SHARED must be used within a SUB/FUNCTION": GoTo errmes



            l$ = SCase$("Shared")
            subfuncshr:

            'get variable name
            n$ = getelement$(ca$, i): i = i + 1

            If n$ = "" Then a$ = "Expected SHARED variable-name or SHARED AS type variable-list": GoTo errmes

            If UCase$(n$) <> "AS" Then
                'traditional dim syntax for SHARED
                newSharedSyntax = 0
                s$ = removesymbol(n$)
                If Error_Happened Then GoTo errmes
                l2$ = s$ 'either symbol or nothing

                'array?
                a = 0
                If getelement$(a$, i) = "(" Then
                    If getelement$(a$, i + 1) <> ")" Then a$ = "Expected ()": GoTo errmes
                    i = i + 2
                    a = 1
                    l2$ = l2$ + sp2 + "(" + sp2 + ")"
                End If

                method = 1

                'specific type?
                t$ = ""
                ts$ = ""
                t3$ = ""
                If getelement$(a$, i) = "AS" Then
                    l2$ = l2$ + sp + SCase$("As")
                    getshrtyp:
                    i = i + 1
                    t2$ = getelement$(a$, i)
                    If t2$ <> "," And t2$ <> "" Then
                        If t$ = "" Then t$ = t2$ Else t$ = t$ + " " + t2$
                        If t3$ = "" Then t3$ = t2$ Else t3$ = t3$ + sp + t2$
                        GoTo getshrtyp
                    End If
                    If t$ = "" Then a$ = "Expected AS type": GoTo errmes

                    t = typname2typ(t$)
                    If Error_Happened Then GoTo errmes
                    If t And ISINCONVENTIONALMEMORY Then t = t - ISINCONVENTIONALMEMORY
                    If t And ISPOINTER Then t = t - ISPOINTER
                    If t And ISREFERENCE Then t = t - ISREFERENCE
                    tsize = typname2typsize
                    method = 0
                    If (t And ISUDT) = 0 Then
                        ts$ = type2symbol$(t$)
                        l2$ = l2$ + sp + SCase2$(t3$)
                    Else
                        t3$ = RTrim$(udtxcname(t And 511))
                        l2$ = l2$ + sp + t3$
                    End If
                    If Error_Happened Then GoTo errmes

                End If 'as

                If Len(s$) <> 0 And Len(t$) <> 0 Then a$ = "Expected symbol or AS type after variable name": GoTo errmes

                'no symbol of type specified, apply default
                If s$ = "" And t$ = "" Then
                    If Left$(n$, 1) = "_" Then v = 27 Else v = Asc(UCase$(n$)) - 64
                    s$ = defineextaz(v)
                End If

                NormalSharedBlock:
                'switch to main module
                oldsubfunc$ = subfunc$
                subfunc$ = ""
                defdatahandle = 18
                Close #13: Open tmpdir$ + "maindata.txt" For Append As #13
                Close #19: Open tmpdir$ + "mainfree.txt" For Append As #19

                'use 'try' to locate the variable (if it already exists)
                n2$ = n$ + s$ + ts$ 'note: either ts$ or s$ will exist unless it is a UDT
                try = findid(n2$)
                If Error_Happened Then GoTo errmes
                Do While try
                    If a Then
                        'an array

                        If id.arraytype Then
                            If Len(t$) = 0 Then GoTo shrfound
                            t2 = id.arraytype: t2size = id.tsize
                            If t2 And ISINCONVENTIONALMEMORY Then t2 = t2 - ISINCONVENTIONALMEMORY
                            If t2 And ISPOINTER Then t2 = t2 - ISPOINTER
                            If t2 And ISREFERENCE Then t2 = t2 - ISREFERENCE
                            If t = t2 And tsize = t2size Then GoTo shrfound
                        End If

                    Else
                        'not an array

                        If id.t Then
                            If Len(t$) = 0 Then GoTo shrfound
                            t2 = id.t: t2size = id.tsize
                            If t2 And ISINCONVENTIONALMEMORY Then t2 = t2 - ISINCONVENTIONALMEMORY
                            If t2 And ISPOINTER Then t2 = t2 - ISPOINTER
                            If t2 And ISREFERENCE Then t2 = t2 - ISREFERENCE

                            If t = t2 And tsize = t2size Then GoTo shrfound
                        End If

                    End If

                    If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
                    If Error_Happened Then GoTo errmes
                Loop
                'unknown variable
                If a Then a$ = "Array '" + n$ + "' not defined": GoTo errmes
                'create variable
                If Len(s$) Then typ$ = s$ Else typ$ = t$
                If optionexplicit Then a$ = "Variable '" + n$ + "' (" + symbol2fulltypename$(typ$) + ") not defined": GoTo errmes
                bypassNextVariable = -1
                retval = dim2(n$, typ$, method, "")
                If Error_Happened Then GoTo errmes
                'note: variable created!

                shrfound:
                If newSharedSyntax = 0 Then
                    l$ = l$ + sp + RTrim$(id.cn) + l2$
                Else
                    If sharedAsLayoutAdded = 0 Then
                        sharedAsLayoutAdded = -1
                        l$ = l$ + l2$ + sp$ + RTrim$(id.cn) + l3$
                    Else
                        l$ = l$ + sp$ + RTrim$(id.cn) + l3$
                    End If
                End If

                ids(currentid).share = ids(currentid).share Or 2 'set as temporarily shared

                'method must apply to the current sub/function regardless of how the variable was defined in 'main'
                lmay = Len(RTrim$(id.mayhave)): lmust = Len(RTrim$(id.musthave))
                If lmay <> 0 Or lmust <> 0 Then
                    If (method = 1 And lmust = 0) Or (method = 0 And lmay = 0) Then
                        revertmaymusthaven = revertmaymusthaven + 1
                        revertmaymusthave(revertmaymusthaven) = currentid
                        Swap ids(currentid).musthave, ids(currentid).mayhave
                    End If
                End If

                'switch back to sub/func
                subfunc$ = oldsubfunc$
                defdatahandle = 13
                Close #13: Open tmpdir$ + "data" + str2$(subfuncn) + ".txt" For Append As #13
                Close #19: Open tmpdir$ + "free" + str2$(subfuncn) + ".txt" For Append As #19

                If newSharedSyntax Then Return

                If getelement$(a$, i) = "," Then i = i + 1: l$ = l$ + sp2 + ",": GoTo subfuncshr
                If getelement$(a$, i) <> "" Then a$ = "Expected ,": GoTo errmes

                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            Else
                'new dim syntax for SHARED!
                i = i - 1 'relocate back to "AS"

                'estabilish the data type:
                t$ = ""
                ts$ = ""
                t3$ = ""
                n$ = ""
                previousElement$ = ""
                l2$ = sp + SCase$("As")
                sharedAsLayoutAdded = 0
                getshrtyp2:
                i = i + 1
                t2$ = getelement$(a$, i)
                If t2$ <> "," And t2$ <> "(" And t2$ <> "" Then
                    'get first variable name
                    n$ = getelement$(ca$, i)

                    If Len(previousElement$) Then
                        If t$ = "" Then t$ = previousElement$ Else t$ = t$ + " " + previousElement$
                        If t3$ = "" Then t3$ = previousElement$ Else t3$ = t3$ + sp + previousElement$
                    End If
                    previousElement$ = t2$
                    GoTo getshrtyp2
                End If
                If t$ = "" Then a$ = "Expected SHARED AS type variable-list or SHARED variable-name AS type": GoTo errmes

                t = typname2typ(t$)
                If Error_Happened Then GoTo errmes
                If t And ISINCONVENTIONALMEMORY Then t = t - ISINCONVENTIONALMEMORY
                If t And ISPOINTER Then t = t - ISPOINTER
                If t And ISREFERENCE Then t = t - ISREFERENCE
                tsize = typname2typsize
                method = 0
                If (t And ISUDT) = 0 Then
                    ts$ = type2symbol$(t$)
                    l2$ = l2$ + sp + SCase2$(t3$)
                Else
                    t3$ = RTrim$(udtxcname(t And 511))
                    l2$ = l2$ + sp + t3$
                End If
                If Error_Happened Then GoTo errmes

                subfuncshr2:
                s$ = removesymbol(n$)
                If Error_Happened Then GoTo errmes
                If s$ <> "" Then
                    a$ = "Cannot use type symbol with SHARED AS type variable-list (" + s$ + ")"
                    GoTo errmes
                End If

                'array?
                a = 0
                l3$ = ""
                If getelement$(a$, i) = "(" Then
                    If getelement$(a$, i + 1) <> ")" Then a$ = "Expected ()": GoTo errmes
                    i = i + 2
                    a = 1
                    l3$ = sp2 + "(" + sp2 + ")"
                End If

                newSharedSyntax = -1
                GoSub NormalSharedBlock
                newSharedSyntax = 0

                If getelement$(a$, i) = "," Then
                    i = i + 1
                    l$ = l$ + sp2 + ","

                    'get next variable name
                    n$ = getelement$(ca$, i): i = i + 1
                    GoTo subfuncshr2
                End If
                If getelement$(a$, i) <> "" Then a$ = "Expected ,": GoTo errmes

                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
        End If
    End If

    'EXIT SUB/FUNCTION
    If n = 2 Then
        If firstelement$ = "EXIT" Then
            sf = 0
            If secondelement$ = "FUNCTION" Then sf = 1
            If secondelement$ = "SUB" Then sf = 2
            If sf Then

                If Len(subfunc) = 0 Then a$ = "EXIT " + secondelement$ + " must be used within a " + secondelement$: GoTo errmes

                Print #12, "goto exit_subfunc;"
                If Left$(subfunc, 4) = "SUB_" Then secondelement$ = SCase$("Sub") Else secondelement$ = SCase$("Function")
                l$ = SCase$("Exit") + sp + secondelement$
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
        End If
    End If

    '_ECHO checking
    If firstelement$ = "_ECHO" Then
        If Console = 0 Then
            a$ = qb64prefix$ + "ECHO requires $CONSOLE or $CONSOLE:ONLY to be set first": GoTo errmes
        End If
    End If

    'ASC statement (fully inline)
    If n >= 1 Then
        If firstelement$ = "ASC" Then
            If getelement$(a$, 2) <> "(" Then a$ = "Expected ( after ASC": GoTo errmes

            'calculate 3 parts
            useposition = 0
            part = 1
            i = 3
            a3$ = ""
            stringvariable$ = ""
            position$ = ""
            B = 0
            Do

                If i > n Then 'got part 3
                    If part <> 3 Or Len(a3$) = 0 Then a$ = "Expected ASC ( ... , ... ) = ...": GoTo errmes
                    expression$ = a3$
                    Exit Do
                End If

                a2$ = getelement$(ca$, i)
                If a2$ = "(" Then B = B + 1
                If a2$ = ")" Then B = B - 1

                If B = -1 Then

                    If part = 1 Then 'eg. ASC(a$)=65
                        If getelement$(a$, i + 1) <> "=" Then a$ = "Expected =": GoTo errmes
                        stringvariable$ = a3$
                        position$ = "1"
                        part = 3: a3$ = "": i = i + 1: GoTo ascgotpart
                    End If

                    If part = 2 Then 'eg. ASC(a$,i)=65
                        If getelement$(a$, i + 1) <> "=" Then a$ = "Expected =": GoTo errmes
                        useposition = 1
                        position$ = a3$
                        part = 3: a3$ = "": i = i + 1: GoTo ascgotpart
                    End If

                    'fall through, already in part 3

                End If

                If a2$ = "," And B = 0 Then
                    If part = 1 Then stringvariable$ = a3$: part = 2: a3$ = "": GoTo ascgotpart
                End If

                If Len(a3$) Then a3$ = a3$ + sp + a2$ Else a3$ = a2$
                ascgotpart:
                i = i + 1
            Loop
            If Len(stringvariable$) = 0 Or Len(position$) = 0 Then a$ = "Expected ASC ( ... , ... ) = ...": GoTo errmes

            'validate stringvariable$
            stringvariable$ = fixoperationorder$(stringvariable$)
            If Error_Happened Then GoTo errmes
            l$ = SCase$("Asc") + sp2 + "(" + sp2 + tlayout$

            e$ = evaluate(stringvariable$, sourcetyp)
            If Error_Happened Then GoTo errmes
            If (sourcetyp And ISREFERENCE) = 0 Or (sourcetyp And ISSTRING) = 0 Then a$ = "Expected ASC ( string-variable , ...": GoTo errmes
            stringvariable$ = evaluatetotyp(stringvariable$, ISSTRING)
            If Error_Happened Then GoTo errmes

            If position$ = "1" Then
                If useposition Then l$ = l$ + sp2 + "," + sp + "1" + sp2 + ")" + sp + "=" Else l$ = l$ + sp2 + ")" + sp + "="

                Print #12, "tqbs=" + stringvariable$ + "; if (!new_error){"
                e$ = fixoperationorder$(expression$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp + tlayout$
                e$ = evaluatetotyp(e$, 32&)
                If Error_Happened Then GoTo errmes
                Print #12, "tmp_long=" + e$ + "; if (!new_error){"
                Print #12, "if (tqbs->len){tqbs->chr[0]=tmp_long;}else{error(5);}"
                Print #12, "}}"

            Else

                Print #12, "tqbs=" + stringvariable$ + "; if (!new_error){"
                e$ = fixoperationorder$(position$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$ + sp2 + ")" + sp + "="
                e$ = evaluatetotyp(e$, 32&)
                If Error_Happened Then GoTo errmes
                Print #12, "tmp_fileno=" + e$ + "; if (!new_error){"
                e$ = fixoperationorder$(expression$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp + tlayout$
                e$ = evaluatetotyp(e$, 32&)
                If Error_Happened Then GoTo errmes
                Print #12, "tmp_long=" + e$ + "; if (!new_error){"
                Print #12, "if ((tmp_fileno>0)&&(tmp_fileno<=tqbs->len)){tqbs->chr[tmp_fileno-1]=tmp_long;}else{error(5);}"
                Print #12, "}}}"

            End If
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    'MID$ statement
    If n >= 1 Then
        If firstelement$ = "MID$" Then
            If getelement$(a$, 2) <> "(" Then a$ = "Expected ( after MID$": GoTo errmes
            'calculate 4 parts
            length$ = ""
            part = 1
            i = 3
            a3$ = ""
            stringvariable$ = ""
            start$ = ""
            B = 0
            Do
                If i > n Then
                    If part <> 4 Or a3$ = "" Then a$ = "Expected MID$(...)=...": GoTo errmes
                    stringexpression$ = a3$
                    Exit Do
                End If
                a2$ = getelement$(ca$, i)
                If a2$ = "(" Then B = B + 1
                If a2$ = ")" Then B = B - 1
                If B = -1 Then
                    If part = 2 Then
                        If getelement$(a$, i + 1) <> "=" Then a$ = "Expected = after )": GoTo errmes
                        start$ = a3$: part = 4: a3$ = "": i = i + 1: GoTo midgotpart
                    End If
                    If part = 3 Then
                        If getelement$(a$, i + 1) <> "=" Then a$ = "Expected = after )": GoTo errmes
                        If a3$ = "" Then a$ = "Omit , before ) if omitting length in MID$ statement": GoTo errmes
                        length$ = a3$: part = 4: a3$ = "": i = i + 1: GoTo midgotpart
                    End If
                End If
                If a2$ = "," And B = 0 Then
                    If part = 1 Then stringvariable$ = a3$: part = 2: a3$ = "": GoTo midgotpart
                    If part = 2 Then start$ = a3$: part = 3: a3$ = "": GoTo midgotpart
                End If
                If Len(a3$) Then a3$ = a3$ + sp + a2$ Else a3$ = a2$
                midgotpart:
                i = i + 1
            Loop
            If stringvariable$ = "" Then a$ = "Syntax error - first parameter must be a string variable/array-element": GoTo errmes
            If start$ = "" Then a$ = "Syntax error - second parameter not optional": GoTo errmes
            'check if it is a valid source string
            stringvariable$ = fixoperationorder$(stringvariable$)
            If Error_Happened Then GoTo errmes
            l$ = SCase$("Mid$") + sp2 + "(" + sp2 + tlayout$
            e$ = evaluate(stringvariable$, sourcetyp)
            If Error_Happened Then GoTo errmes
            If (sourcetyp And ISREFERENCE) = 0 Or (sourcetyp And ISSTRING) = 0 Then a$ = "MID$ expects a string variable/array-element as its first argument": GoTo errmes
            stringvariable$ = evaluatetotyp(stringvariable$, ISSTRING)
            If Error_Happened Then GoTo errmes

            start$ = fixoperationorder$(start$)
            If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            start$ = evaluatetotyp((start$), 32&)

            stringexpression$ = fixoperationorder$(stringexpression$)
            If Error_Happened Then GoTo errmes
            l2$ = tlayout$
            stringexpression$ = evaluatetotyp(stringexpression$, ISSTRING)
            If Error_Happened Then GoTo errmes

            If Len(length$) Then
                length$ = fixoperationorder$(length$)
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$
                length$ = evaluatetotyp(length$, 32&)
                If Error_Happened Then GoTo errmes
                Print #12, "sub_mid(" + stringvariable$ + "," + start$ + "," + length$ + "," + stringexpression$ + ",1);"
            Else
                Print #12, "sub_mid(" + stringvariable$ + "," + start$ + ",0," + stringexpression$ + ",0);"
            End If

            l$ = l$ + sp2 + ")" + sp + "=" + sp + l2$
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    If n >= 2 Then
        If firstelement$ = "ERASE" Then
            i = 2
            l$ = SCase$("Erase")
            erasenextarray:
            var$ = getelement$(ca$, i)
            x$ = var$: ls$ = removesymbol(x$)
            If Error_Happened Then GoTo errmes

            If FindArray(var$) Then
                If Error_Happened Then GoTo errmes
                l$ = l$ + sp + RTrim$(id.cn) + ls$
                'erase the array
                clearerase:
                n$ = RTrim$(id.callname)
                bytesperelement$ = str2((id.arraytype And 511) \ 8)
                If id.arraytype And ISSTRING Then bytesperelement$ = str2(id.tsize)
                If id.arraytype And ISOFFSETINBITS Then bytesperelement$ = str2((id.arraytype And 511)) + "/8+1"
                If id.arraytype And ISUDT Then
                    bytesperelement$ = str2(udtxsize(id.arraytype And 511) \ 8)
                End If
                Print #12, "if (" + n$ + "[2]&1){" 'array is defined
                Print #12, "if (" + n$ + "[2]&2){" 'array is static
                If (id.arraytype And ISSTRING) <> 0 And (id.arraytype And ISFIXEDLENGTH) = 0 Then
                    Print #12, "tmp_long=";
                    For i2 = 1 To Abs(id.arrayelements)
                        If i2 <> 1 Then Print #12, "*";
                        Print #12, n$ + "[" + str2(i2 * 4 - 4 + 5) + "]";
                    Next
                    Print #12, ";"
                    Print #12, "while(tmp_long--){"
                    Print #12, "((qbs*)(((uint64*)(" + n$ + "[0]))[tmp_long]))->len=0;"
                    Print #12, "}"
                Else
                    'numeric
                    'clear array
                    Print #12, "memset((void*)(" + n$ + "[0]),0,";
                    For i2 = 1 To Abs(id.arrayelements)
                        If i2 <> 1 Then Print #12, "*";
                        Print #12, n$ + "[" + str2(i2 * 4 - 4 + 5) + "]";
                    Next
                    Print #12, "*" + bytesperelement$ + ");"
                End If
                Print #12, "}else{" 'array is dynamic
                '1. free memory & any allocated strings
                If (id.arraytype And ISSTRING) <> 0 And (id.arraytype And ISFIXEDLENGTH) = 0 Then
                    'free strings
                    Print #12, "tmp_long=";
                    For i2 = 1 To Abs(id.arrayelements)
                        If i2 <> 1 Then Print #12, "*";
                        Print #12, n$ + "[" + str2(i2 * 4 - 4 + 5) + "]";
                    Next
                    Print #12, ";"
                    Print #12, "while(tmp_long--){"
                    Print #12, "qbs_free((qbs*)(((uint64*)(" + n$ + "[0]))[tmp_long]));"
                    Print #12, "}"
                    'free memory
                    Print #12, "free((void*)(" + n$ + "[0]));"
                Else
                    'free memory
                    Print #12, "if (" + n$ + "[2]&4){" 'cmem array
                    Print #12, "cmem_dynamic_free((uint8*)(" + n$ + "[0]));"
                    Print #12, "}else{" 'non-cmem array
                    Print #12, "free((void*)(" + n$ + "[0]));"
                    Print #12, "}"
                End If
                '2. set array (and its elements) as undefined
                Print #12, n$ + "[2]^=1;" 'remove defined flag, keeping other flags (such as cmem)
                'set dimensions as undefined
                For i2 = 1 To Abs(id.arrayelements)
                    B = i2 * 4
                    Print #12, n$ + "[" + str2(B) + "]=2147483647;" 'base
                    Print #12, n$ + "[" + str2(B + 1) + "]=0;" 'num. index
                    Print #12, n$ + "[" + str2(B + 2) + "]=0;" 'multiplier
                Next
                If (id.arraytype And ISSTRING) <> 0 And (id.arraytype And ISFIXEDLENGTH) = 0 Then
                    Print #12, n$ + "[0]=(ptrszint)&nothingstring;"
                Else
                    Print #12, n$ + "[0]=(ptrszint)nothingvalue;"
                End If
                Print #12, "}" 'static/dynamic
                Print #12, "}" 'array is defined
                If clearerasereturn = 1 Then clearerasereturn = 0: GoTo clearerasereturned
                GoTo erasedarray
            End If
            If Error_Happened Then GoTo errmes
            a$ = "Undefined array passed to ERASE": GoTo errmes

            erasedarray:
            If i < n Then
                i = i + 1: n$ = getelement$(a$, i): If n$ <> "," Then a$ = "Expected ,": GoTo errmes
                l$ = l$ + sp2 + ","
                i = i + 1: If i > n Then a$ = "Expected , ...": GoTo errmes
                GoTo erasenextarray
            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    'DIM/REDIM/STATIC
    If n >= 2 Then
        dimoption = 0: redimoption = 0: commonoption = 0
        If firstelement$ = "DIM" Then l$ = SCase$("Dim"): dimoption = 1
        If firstelement$ = "REDIM" Then
            l$ = SCase$("ReDim")
            dimoption = 2: redimoption = 1
            If secondelement$ = "_PRESERVE" Then
                redimoption = 2
                If secondelement$ = "_PRESERVE" Then
                    l$ = l$ + sp + SCase$("_Preserve")
                Else
                    l$ = l$ + sp + SCase$("Preserve")
                End If
                If n = 2 Then a$ = "Expected REDIM " + qb64prefix$ + "PRESERVE ...": GoTo errmes
            End If
        End If
        If firstelement$ = "STATIC" Then l$ = SCase$("Static"): dimoption = 3
        If firstelement$ = "COMMON" Then l$ = SCase$("Common"): dimoption = 1: commonoption = 1
        If dimoption Then

            If dimoption = 3 And subfuncn = 0 Then a$ = "STATIC must be used within a SUB/FUNCTION": GoTo errmes
            If commonoption = 1 And subfuncn <> 0 Then a$ = "COMMON cannot be used within a SUB/FUNCTION": GoTo errmes

            i = 2
            If redimoption = 2 Then i = 3

            If dimoption <> 3 Then 'shared cannot be static
                a2$ = getelement(a$, i)
                If a2$ = "SHARED" Then
                    If subfuncn <> 0 Then a$ = "DIM/REDIM SHARED invalid within a SUB/FUNCTION": GoTo errmes
                    dimshared = 1
                    i = i + 1
                    l$ = l$ + sp + SCase$("Shared")
                End If
            End If

            If dimoption = 3 Then dimstatic = 1: AllowLocalName = 1

            'look for new dim syntax: DIM AS variabletype var1, var2, etc....
            e$ = getelement$(a$, i)
            If e$ <> "AS" Then
                'no "AS", so this is the traditional dim syntax
                dimnext:
                newDimSyntax = 0
                notype = 0
                listarray = 0

                'old chain code
                'chaincommonarray=0

                varname$ = getelement(ca$, i): i = i + 1
                If varname$ = "" Then a$ = "Expected " + firstelement$ + " variable-name or " + firstelement$ + " AS type variable-list": GoTo errmes

                'get the next element
                If i >= n + 1 Then e$ = "" Else e$ = getelement(a$, i): i = i + 1

                'check if next element is a ( to create an array
                elements$ = ""

                If e$ = "(" Then
                    B = 1
                    For i = i To n
                        e$ = getelement(ca$, i)
                        If e$ = "(" Then B = B + 1
                        If e$ = ")" Then B = B - 1
                        If B = 0 Then Exit For
                        If Len(elements$) Then elements$ = elements$ + sp + e$ Else elements$ = e$
                    Next
                    If B <> 0 Then a$ = "Expected )": GoTo errmes
                    i = i + 1 'set i to point to the next element

                    If commonoption Then elements$ = "?"

                    'arrayname() means list array to it will automatically be static when it is formally dimensioned later
                    'note: listed arrays are always created in dynamic memory, but their contents are not erased
                    '      this differs from static arrays from SUB...STATIC and the unique QB64 method -> STATIC arrayname(100)
                    If dimoption = 3 Then 'STATIC used
                        If Len(elements$) = 0 Then 'nothing between brackets
                            listarray = 1 'add to static list
                        End If
                    End If

                    'last element was ")"
                    'get next element
                    If i >= n + 1 Then e$ = "" Else e$ = getelement(a$, i): i = i + 1
                End If 'e$="("
                d$ = e$

                dimmethod = 0

                appendname$ = "" 'the symbol to append to name returned by dim2
                appendtype$ = "" 'eg. sp+AS+spINTEGER
                dim2typepassback$ = ""

                'does varname have an appended symbol?
                s$ = removesymbol$(varname$)
                If Error_Happened Then GoTo errmes
                If validname(varname$) = 0 Then a$ = "Invalid variable name": GoTo errmes

                If s$ <> "" Then
                    typ$ = s$
                    dimmethod = 1
                    appendname$ = typ$
                    GoTo dimgottyp
                End If

                If d$ = "AS" Then
                    appendtype$ = sp + SCase$("As")
                    typ$ = ""
                    For i = i To n
                        d$ = getelement(a$, i)
                        If d$ = "," Then i = i + 1: Exit For
                        typ$ = typ$ + d$ + " "
                        appendtype$ = appendtype$ + sp + d$
                        d$ = ""
                    Next
                    appendtype$ = SCase2$(appendtype$) 'capitalise default types (udt override this later if necessary)
                    typ$ = RTrim$(typ$)
                    GoTo dimgottyp
                End If

                'auto-define type based on name
                notype = 1
                If Left$(varname$, 1) = "_" Then v = 27 Else v = Asc(UCase$(varname$)) - 64
                typ$ = defineaz(v)
                dimmethod = 1
                GoTo dimgottyp

                dimgottyp:
                If d$ <> "" And d$ <> "," Then a$ = "DIM: Expected ,": GoTo errmes

                'In QBASIC, if no type info is given it can refer to an expeicit/formally defined array
                If notype <> 0 And dimoption <> 3 And dimoption <> 1 Then 'not DIM or STATIC which only create new content
                    If Len(elements$) Then 'an array
                        If FindArray(varname$) Then
                            If Len(RTrim$(id.mayhave)) Then 'explict/formally defined
                                typ$ = id2fulltypename$ 'adopt type
                                dimmethod = 0 'set as formally defined
                            End If
                        End If
                    End If
                End If

                NormalDimBlock:
                If dimoption = 3 And Len(elements$) Then 'eg. STATIC a(100)
                    'does a conflicting array exist? (use findarray) if so again this should lead to duplicate definition
                    typ2$ = symbol2fulltypename$(typ$)
                    t = typname2typ(typ2$): ts = typname2typsize
                    'try name without any extension
                    If FindArray(varname$) Then 'name without any symbol
                        If id.insubfuncn = subfuncn Then 'global cannot conflict with static
                            If Len(RTrim$(id.musthave)) Then
                                'if types match then fail
                                If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                    If ts = id.tsize Then
                                        a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                    End If
                                End If
                            Else
                                If dimmethod = 0 Then
                                    a$ = "Name already in use (" + varname$ + ")": GoTo errmes 'explicit over explicit
                                Else
                                    'if types match then fail
                                    If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                        If ts = id.tsize Then
                                            a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                        End If
                                    End If
                                End If
                            End If
                        End If
                    End If
                    'add extension (if possible)
                    If (t And ISUDT) = 0 Then
                        s2$ = type2symbol$(typ2$)
                        If Error_Happened Then GoTo errmes
                        If FindArray(varname$ + s2$) Then
                            If id.insubfuncn = subfuncn Then 'global cannot conflict with static
                                If Len(RTrim$(id.musthave)) Then
                                    'if types match then fail
                                    If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                        If ts = id.tsize Then
                                            a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes
                                        End If
                                    End If
                                Else
                                    If dimmethod = 0 Then
                                        a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes 'explicit over explicit
                                    Else
                                        'if types match then fail
                                        If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                            If ts = id.tsize Then
                                                a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes
                                            End If
                                        End If
                                    End If
                                End If
                            End If
                        End If
                    End If 'not a UDT
                End If

                If listarray Then 'eg. STATIC a()
                    'note: list is cleared by END SUB/FUNCTION

                    'is a conflicting array already listed? if so this should cause a duplicate definition error
                    'check for conflict within list:
                    xi = 1
                    For x = 1 To staticarraylistn
                        varname2$ = getelement$(staticarraylist, xi): xi = xi + 1
                        typ2$ = getelement$(staticarraylist, xi): xi = xi + 1
                        dimmethod2 = Val(getelement$(staticarraylist, xi)): xi = xi + 1
                        'check if they are similar
                        If UCase$(varname$) = UCase$(varname2$) Then
                            If dimmethod2 = 1 Then
                                'old using symbol
                                If symbol2fulltypename$(typ$) = typ2$ Then a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                            Else
                                'old using AS
                                If dimmethod = 0 Then
                                    a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                Else
                                    If symbol2fulltypename$(typ$) = typ2$ Then a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                End If
                            End If
                        End If
                    Next

                    'does a conflicting array exist? (use findarray) if so again this should lead to duplicate definition
                    typ2$ = symbol2fulltypename$(typ$)
                    t = typname2typ(typ2$): ts = typname2typsize
                    'try name without any extension
                    If FindArray(varname$) Then 'name without any symbol
                        If id.insubfuncn = subfuncn Then 'global cannot conflict with static
                            If Len(RTrim$(id.musthave)) Then
                                'if types match then fail
                                If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                    If ts = id.tsize Then
                                        a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                    End If
                                End If
                            Else
                                If dimmethod = 0 Then
                                    a$ = "Name already in use (" + varname$ + ")": GoTo errmes 'explicit over explicit
                                Else
                                    'if types match then fail
                                    If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                        If ts = id.tsize Then
                                            a$ = "Name already in use (" + varname$ + ")": GoTo errmes
                                        End If
                                    End If
                                End If
                            End If
                        End If
                    End If
                    'add extension (if possible)
                    If (t And ISUDT) = 0 Then
                        s2$ = type2symbol$(typ2$)
                        If Error_Happened Then GoTo errmes
                        If FindArray(varname$ + s2$) Then
                            If id.insubfuncn = subfuncn Then 'global cannot conflict with static
                                If Len(RTrim$(id.musthave)) Then
                                    'if types match then fail
                                    If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                        If ts = id.tsize Then
                                            a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes
                                        End If
                                    End If
                                Else
                                    If dimmethod = 0 Then
                                        a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes 'explicit over explicit
                                    Else
                                        'if types match then fail
                                        If (id.arraytype And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) = (t And (ISFLOAT + ISUDT + 511 + ISUNSIGNED + ISSTRING + ISFIXEDLENGTH)) Then
                                            If ts = id.tsize Then
                                                a$ = "Name already in use (" + varname$ + s2$ + ")": GoTo errmes
                                            End If
                                        End If
                                    End If
                                End If
                            End If
                        End If
                    End If 'not a UDT

                    'note: static list arrays cannot be created until they are formally [or informally] (RE)DIM'd later
                    If Len(staticarraylist) Then staticarraylist = staticarraylist + sp
                    staticarraylist = staticarraylist + varname$ + sp + symbol2fulltypename$(typ$) + sp + str2(dimmethod)
                    If Error_Happened Then GoTo errmes
                    staticarraylistn = staticarraylistn + 1
                    l$ = l$ + sp + varname$ + appendname$ + sp2 + "(" + sp2 + ")" + appendtype$
                    'note: none of the following code is run, dim2 call is also skipped

                Else

                    olddimstatic = dimstatic

                    'check if varname is on the static list
                    If Len(elements$) Then 'it's an array
                        If subfuncn Then 'it's in a sub/function
                            xi = 1
                            For x = 1 To staticarraylistn
                                varname2$ = getelement$(staticarraylist, xi): xi = xi + 1
                                typ2$ = getelement$(staticarraylist, xi): xi = xi + 1
                                dimmethod2 = Val(getelement$(staticarraylist, xi)): xi = xi + 1
                                'check if they are similar
                                If UCase$(varname$) = UCase$(varname2$) Then
                                    If symbol2fulltypename$(typ$) = typ2$ Then
                                        If Error_Happened Then GoTo errmes
                                        If dimmethod = dimmethod2 Then
                                            'match found!
                                            varname$ = varname2$
                                            dimstatic = 3
                                            If dimoption = 3 Then a$ = "Array already listed as STATIC": GoTo errmes
                                        End If
                                    End If 'typ
                                End If 'varname
                            Next
                        End If
                    End If

                    'COMMON exception
                    'note: COMMON alone does not imply SHARED
                    '      if either(or both) COMMON & later DIM have SHARED, variable becomes shared
                    If commonoption Then
                        If Len(elements$) Then

                            'add array to list
                            If Len(commonarraylist) Then commonarraylist = commonarraylist + sp
                            'note: dimmethod distinguishes between a%(...) vs a(...) AS INTEGER
                            commonarraylist = commonarraylist + varname$ + sp + symbol2fulltypename$(typ$) + sp + str2(dimmethod) + sp + str2(dimshared)
                            If Error_Happened Then GoTo errmes
                            commonarraylistn = commonarraylistn + 1
                            If Error_Happened Then GoTo errmes

                            x = 0

                            v$ = varname$
                            If dimmethod = 1 Then v$ = v$ + typ$
                            try = findid(v$)
                            If Error_Happened Then GoTo errmes
                            Do While try
                                If id.arraytype Then

                                    t = typname2typ(typ$)
                                    If Error_Happened Then GoTo errmes
                                    s = typname2typsize
                                    match = 1
                                    'note: dimmethod 2 is already matched
                                    If dimmethod = 0 Then
                                        t2 = id.arraytype
                                        s2 = id.tsize
                                        If (t And ISFLOAT) <> (t2 And ISFLOAT) Then match = 0
                                        If (t And ISUNSIGNED) <> (t2 And ISUNSIGNED) Then match = 0
                                        If (t And ISSTRING) <> (t2 And ISSTRING) Then match = 0
                                        If (t And ISFIXEDLENGTH) <> (t2 And ISFIXEDLENGTH) Then match = 0
                                        If (t And ISOFFSETINBITS) <> (t2 And ISOFFSETINBITS) Then match = 0
                                        If (t And ISUDT) <> (t2 And ISUDT) Then match = 0
                                        If (t And 511) <> (t2 And 511) Then match = 0
                                        If s <> s2 Then match = 0
                                        'check for implicit/explicit declaration match
                                        oldmethod = 0: If Len(RTrim$(id.musthave)) Then oldmethod = 1
                                        If oldmethod <> dimmethod Then match = 0
                                    End If

                                    If match Then
                                        x = currentid
                                        If dimshared Then ids(x).share = 1 'share if necessary
                                        tlayout$ = RTrim$(id.cn) + sp + "(" + sp2 + ")"

                                        If dimmethod = 0 Then
                                            If t And ISUDT Then
                                                dim2typepassback$ = RTrim$(udtxcname(t And 511))
                                            Else
                                                dim2typepassback$ = typ$
                                                Do While InStr(dim2typepassback$, " ")
                                                    Asc(dim2typepassback$, InStr(dim2typepassback$, " ")) = Asc(sp)
                                                Loop
                                                dim2typepassback$ = SCase2$(dim2typepassback$)
                                            End If
                                        End If 'method 0

                                        Exit Do
                                    End If 'match

                                End If 'arraytype
                                If try = 2 Then findanotherid = 1: try = findid(v$) Else try = 0
                                If Error_Happened Then GoTo errmes
                            Loop

                            If x = 0 Then x = idn + 1

                            'note: the following code only adds include directives, everything else is defered
                            Open tmpdir$ + "chain.txt" For Append As #22
                            'include directive
                            Print #22, "#include " + Chr$(34) + "chain" + str2$(x) + ".txt" + Chr$(34)
                            Close #22
                            'create/clear include file
                            Open tmpdir$ + "chain" + str2$(x) + ".txt" For Output As #22: Close #22

                            Open tmpdir$ + "inpchain.txt" For Append As #22
                            'include directive
                            Print #22, "#include " + Chr$(34) + "inpchain" + str2$(x) + ".txt" + Chr$(34)
                            Close #22
                            'create/clear include file
                            Open tmpdir$ + "inpchain" + str2$(x) + ".txt" For Output As #22: Close #22

                            'note: elements$="?"
                            If x <> idn + 1 Then GoTo skipdim 'array already exists
                            GoTo dimcommonarray

                        End If
                    End If

                    'is varname on common list?
                    '******
                    If Len(elements$) Then 'it's an array
                        If subfuncn = 0 Then 'not in a sub/function

                            xi = 1
                            For x = 1 To commonarraylistn
                                varname2$ = getelement$(commonarraylist, xi): xi = xi + 1
                                typ2$ = getelement$(commonarraylist, xi): xi = xi + 1
                                dimmethod2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1
                                dimshared2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1
                                'check if they are similar
                                If varname$ = varname2$ Then
                                    If symbol2fulltypename$(typ$) = typ2$ Then
                                        If Error_Happened Then GoTo errmes
                                        If dimmethod = dimmethod2 Then

                                            'match found!
                                            'enforce shared status (if necessary)
                                            If dimshared2 Then dimshared = dimshared Or 2 'temp force SHARED

                                            'old chain code
                                            'chaincommonarray=x

                                        End If 'method
                                    End If 'typ
                                End If 'varname
                            Next
                        End If
                    End If

                    dimcommonarray:
                    retval = dim2(varname$, typ$, dimmethod, elements$)
                    If Error_Happened Then GoTo errmes
                    skipdim:
                    If dimshared >= 2 Then dimshared = dimshared - 2

                    'non-array COMMON variable
                    If commonoption <> 0 And Len(elements$) = 0 Then

                        'CHAIN.TXT (save)

                        use_global_byte_elements = 1

                        'switch output from main.txt to chain.txt
                        Close #12
                        Open tmpdir$ + "chain.txt" For Append As #12
                        l2$ = tlayout$

                        Print #12, "int32val=1;" 'simple variable
                        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

                        t = id.t
                        bits = t And 511
                        If t And ISUDT Then bits = udtxsize(t And 511)
                        If t And ISSTRING Then
                            If t And ISFIXEDLENGTH Then
                                bits = id.tsize * 8
                            Else
                                Print #12, "int64val=__STRING_" + RTrim$(id.n) + "->len*8;"
                                bits = 0
                            End If
                        End If

                        If bits Then
                            Print #12, "int64val=" + str2$(bits) + ";" 'size in bits
                        End If
                        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"

                        'put the variable
                        e$ = RTrim$(id.n)

                        If (t And ISUDT) = 0 Then
                            If t And ISFIXEDLENGTH Then
                                e$ = e$ + "$" + str2$(id.tsize)
                            Else
                                e$ = e$ + typevalue2symbol$(t)
                                If Error_Happened Then GoTo errmes
                            End If
                        End If
                        e$ = evaluatetotyp(fixoperationorder$(e$), -4)
                        If Error_Happened Then GoTo errmes

                        Print #12, "sub_put(FF,NULL," + e$ + ",0);"

                        tlayout$ = l2$
                        'revert output to main.txt
                        Close #12
                        Open tmpdir$ + "main.txt" For Append As #12


                        'INPCHAIN.TXT (load)

                        'switch output from main.txt to chain.txt
                        Close #12
                        Open tmpdir$ + "inpchain.txt" For Append As #12
                        l2$ = tlayout$


                        Print #12, "if (int32val==1){"
                        'get the size in bits
                        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
                        '***assume correct size***

                        e$ = RTrim$(id.n)
                        t = id.t
                        If (t And ISUDT) = 0 Then
                            If t And ISFIXEDLENGTH Then
                                e$ = e$ + "$" + str2$(id.tsize)
                            Else
                                e$ = e$ + typevalue2symbol$(t)
                                If Error_Happened Then GoTo errmes
                            End If
                        End If

                        If t And ISSTRING Then
                            If (t And ISFIXEDLENGTH) = 0 Then
                                Print #12, "tqbs=qbs_new(int64val>>3,1);"
                                Print #12, "qbs_set(__STRING_" + RTrim$(id.n) + ",tqbs);"
                                'now that the string is the correct size, the following GET command will work correctly...
                            End If
                        End If

                        e$ = evaluatetotyp(fixoperationorder$(e$), -4)
                        If Error_Happened Then GoTo errmes
                        Print #12, "sub_get(FF,NULL," + e$ + ",0);"

                        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);" 'get next command
                        Print #12, "}"

                        tlayout$ = l2$
                        'revert output to main.txt
                        Close #12
                        Open tmpdir$ + "main.txt" For Append As #12

                        use_global_byte_elements = 0

                    End If

                    commonarraylisted:

                    If Len(appendtype$) > 0 And newDimSyntax = -1 Then
                        If Len(dim2typepassback$) Then appendtype$ = sp + SCase$("As") + sp + dim2typepassback$
                        If newDimSyntaxTypePassBack = 0 Then
                            newDimSyntaxTypePassBack = -1
                            l$ = l$ + appendtype$
                        End If
                    End If

                    n2 = numelements(tlayout$)
                    l$ = l$ + sp + getelement$(tlayout$, 1) + appendname$
                    If n2 > 1 Then
                        l$ = l$ + sp2 + getelements$(tlayout$, 2, n2)
                    End If

                    If Len(appendtype$) > 0 And newDimSyntax = 0 Then
                        If Len(dim2typepassback$) Then appendtype$ = sp + SCase$("As") + sp + dim2typepassback$
                        l$ = l$ + appendtype$
                    End If

                    'modify first element name to include symbol

                    dimstatic = olddimstatic

                End If 'listarray=0

                If newDimSyntax Then Return

                If d$ = "," Then l$ = l$ + sp2 + ",": GoTo dimnext

                dimoption = 0
                dimshared = 0
                redimoption = 0
                If dimstatic = 1 Then dimstatic = 0
                AllowLocalName = 0

                layoutdone = 1
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$

                GoTo finishedline
            Else
                'yes, this is the new dim syntax.
                i = i + 1 'skip "AS"
                newDimSyntaxTypePassBack = 0

                'estabilish the data type:
                appendname$ = ""
                appendtype$ = sp + SCase$("As")
                typ$ = ""
                varname$ = ""
                previousElement$ = ""
                For i = i To n
                    d$ = getelement(a$, i)
                    If d$ = "," Or d$ = "(" Then Exit For
                    varname$ = getelement(ca$, i)
                    If Len(previousElement$) Then
                        typ$ = typ$ + previousElement$ + " "
                        appendtype$ = appendtype$ + sp + previousElement$
                    End If
                    previousElement$ = d$
                    d$ = ""
                Next
                appendtype$ = SCase2$(appendtype$) 'capitalise default types (udt override this later if necessary)
                typ$ = RTrim$(typ$)

                dimnext2:
                notype = 0
                listarray = 0

                If typ$ = "" Or varname$ = "" Then a$ = "Expected " + firstelement$ + " AS type variable-list or " + firstelement$ + " variable-name AS type": GoTo errmes

                'get the next element
                If i >= n + 1 Then e$ = "" Else e$ = getelement(a$, i): i = i + 1

                'check if next element is a ( to create an array
                elements$ = ""

                If e$ = "(" Then
                    B = 1
                    For i = i To n
                        e$ = getelement(ca$, i)
                        If e$ = "(" Then B = B + 1
                        If e$ = ")" Then B = B - 1
                        If B = 0 Then Exit For
                        If Len(elements$) Then elements$ = elements$ + sp + e$ Else elements$ = e$
                    Next
                    If B <> 0 Then a$ = "Expected )": GoTo errmes
                    i = i + 1 'set i to point to the next element

                    If commonoption Then elements$ = "?"

                    'arrayname() means list array to it will automatically be static when it is formally dimensioned later
                    'note: listed arrays are always created in dynamic memory, but their contents are not erased
                    '      this differs from static arrays from SUB...STATIC and the unique QB64 method -> STATIC arrayname(100)
                    If dimoption = 3 Then 'STATIC used
                        If Len(elements$) = 0 Then 'nothing between brackets
                            listarray = 1 'add to static list
                        End If
                    End If

                    'last element was ")"
                    'get next element
                    If i >= n + 1 Then e$ = "" Else e$ = getelement(a$, i): i = i + 1
                End If 'e$="("
                d$ = e$

                dimmethod = 0

                dim2typepassback$ = ""

                'does varname have an appended symbol?
                s$ = removesymbol$(varname$)
                If Error_Happened Then GoTo errmes
                If validname(varname$) = 0 Then a$ = "Invalid variable name": GoTo errmes

                If s$ <> "" Then
                    a$ = "Cannot use type symbol with " + firstelement$ + " AS type variable-list (" + s$ + ")"
                    GoTo errmes
                End If

                If d$ <> "" And d$ <> "," Then a$ = "DIM: Expected ,": GoTo errmes

                newDimSyntax = -1
                GoSub NormalDimBlock
                newDimSyntax = 0

                If d$ = "," Then
                    l$ = l$ + sp2 + ","
                    varname$ = getelement(ca$, i): i = i + 1
                    GoTo dimnext2
                End If

                dimoption = 0
                dimshared = 0
                redimoption = 0
                If dimstatic = 1 Then dimstatic = 0
                AllowLocalName = 0

                layoutdone = 1
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$

                GoTo finishedline
            End If
        End If
    End If

    'THEN [GOTO] linenumber?
    If THENGOTO = 1 Then
        If n = 1 Then
            l$ = ""
            a = Asc(Left$(firstelement$, 1))
            If a = 46 Or (a >= 48 And a <= 57) Then a2$ = ca$: GoTo THENGOTO
        End If
    End If

    'goto
    If n = 2 Then
        If getelement$(a$, 1) = "GOTO" Then
            l$ = SCase$("GoTo")
            a2$ = getelement$(ca$, 2)
            THENGOTO:
            If validlabel(a2$) = 0 Then a$ = "Invalid label!": GoTo errmes

            v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
            x = 1
            labchk2:
            If v Then
                s = Labels(r).Scope
                If s = subfuncn Or s = -1 Then 'same scope?
                    If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                    x = 0 'already defined
                    tlayout$ = RTrim$(Labels(r).cn)
                Else
                    If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk2
                End If
            End If
            If x Then
                'does not exist
                nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                Labels(nLabels) = Empty_Label
                HashAdd a2$, HASHFLAG_LABEL, nLabels
                r = nLabels
                Labels(r).State = 0
                Labels(r).cn = tlayout$
                Labels(r).Scope = subfuncn
                Labels(r).Error_Line = linenumber
            End If 'x

            If Len(l$) Then l$ = l$ + sp + tlayout$ Else l$ = tlayout$
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "goto LABEL_" + a2$ + ";"
            GoTo finishedline
        End If
    End If

    If n = 1 Then
        If firstelement$ = "_CONTINUE" Then
            If firstelement$ = "_CONTINUE" Then l$ = SCase$("_Continue") Else l$ = SCase$("Continue")
            'scan backwards until previous control level reached
            For i = controllevel To 1 Step -1
                t = controltype(i)
                If t = 2 Then 'for...next
                    Print #12, "goto fornext_continue_" + str2$(controlid(i)) + ";"
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                ElseIf t = 3 Or t = 4 Then 'do...loop
                    Print #12, "goto dl_continue_" + str2$(controlid(i)) + ";"
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                ElseIf t = 5 Then 'while...wend
                    Print #12, "goto ww_continue_" + str2$(controlid(i)) + ";"
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                End If
            Next
            a$ = qb64prefix$ + "CONTINUE outside DO..LOOP/FOR..NEXT/WHILE..WEND block": GoTo errmes
        End If
    End If

    If firstelement$ = "CHAIN" Then
    End If

    If firstelement$ = "RUN" Then 'RUN
        l$ = SCase$("Run")
        If n = 1 Then
            'no parameters
            Print #12, "sub_run_init();" 'note: called first to free up screen-locked image handles
            Print #12, "sub_clear(NULL,NULL,NULL,NULL);" 'use functionality of CLEAR
            If Len(subfunc$) Then
                Print #12, "QBMAIN(NULL);"
            Else
                Print #12, "goto S_0;"
            End If
        Else
            'parameter passed
            e$ = getelements$(ca$, 2, n)
            e$ = fixoperationorder$(e$)
            If Error_Happened Then GoTo errmes
            l2$ = tlayout$
            ignore$ = evaluate(e$, typ)
            If Error_Happened Then GoTo errmes
            If n = 2 And ((typ And ISSTRING) = 0) Then
                'assume it's a label or line number
                lbl$ = getelement$(ca$, 2)
                If validlabel(lbl$) = 0 Then a$ = "Invalid label!": GoTo errmes 'invalid label

                v = HashFind(lbl$, HASHFLAG_LABEL, ignore, r)
                x = 1
                labchk501:
                If v Then
                    s = Labels(r).Scope
                    If s = 0 Or s = -1 Then 'main scope?
                        If s = -1 Then Labels(r).Scope = 0 'acquire scope
                        x = 0 'already defined
                        tlayout$ = RTrim$(Labels(r).cn)
                        Labels(r).Scope_Restriction = subfuncn
                        Labels(r).Error_Line = linenumber
                    Else
                        If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk501
                    End If
                End If
                If x Then
                    'does not exist
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd lbl$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = 0
                    Labels(r).Error_Line = linenumber
                    Labels(r).Scope_Restriction = subfuncn
                End If 'x

                l$ = l$ + sp + tlayout$
                Print #12, "sub_run_init();" 'note: called first to free up screen-locked image handles
                Print #12, "sub_clear(NULL,NULL,NULL,NULL);" 'use functionality of CLEAR
                If Len(subfunc$) Then
                    Print #21, "if (run_from_line==" + str2(nextrunlineindex) + "){run_from_line=0;goto LABEL_" + lbl$ + ";}"
                    Print #12, "run_from_line=" + str2(nextrunlineindex) + ";"
                    nextrunlineindex = nextrunlineindex + 1
                    Print #12, "QBMAIN(NULL);"
                Else
                    Print #12, "goto LABEL_" + lbl$ + ";"
                End If
            Else
                'assume it's a string containing a filename to execute
                e$ = evaluatetotyp(e$, ISSTRING)
                If Error_Happened Then GoTo errmes
                Print #12, "sub_run(" + e$ + ");"
                l$ = l$ + sp + l2$
            End If 'isstring
        End If 'n=1
        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        GoTo finishedline
    End If 'run

    If firstelement$ = "END" Then
        l$ = SCase$("End")
        If n > 1 Then
            e$ = getelements$(ca$, 2, n)
            e$ = fixoperationorder$(e$): If Error_Happened Then GoTo errmes
            l2$ = tlayout$
            e$ = evaluatetotyp(e$, ISINTEGER64): If Error_Happened Then GoTo errmes
            inclinenump$ = ""
            If inclinenumber(inclevel) Then
                inclinenump$ = "," + str2$(inclinenumber(inclevel))
                thisincname$ = getfilepath$(incname$(inclevel))
                thisincname$ = Mid$(incname$(inclevel), Len(thisincname$) + 1)
                inclinenump$ = inclinenump$ + "," + Chr$(34) + thisincname$ + Chr$(34)
            End If
            temp$ = ""
            Print #12, "if(qbevent){" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");}" 'non-resumable error check (cannot exit without handling errors)
            Print #12, "exit_code=" + e$ + ";"
            l$ = l$ + sp + l2$
        End If
        xend
        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        GoTo finishedline
    End If

    If firstelement$ = "SYSTEM" Then
        l$ = SCase$("System")
        If n > 1 Then
            e$ = getelements$(ca$, 2, n)
            e$ = fixoperationorder$(e$): If Error_Happened Then GoTo errmes
            l2$ = tlayout$
            e$ = evaluatetotyp(e$, ISINTEGER64): If Error_Happened Then GoTo errmes
            inclinenump$ = ""
            If inclinenumber(inclevel) Then
                inclinenump$ = "," + str2$(inclinenumber(inclevel))
                thisincname$ = getfilepath$(incname$(inclevel))
                thisincname$ = Mid$(incname$(inclevel), Len(thisincname$) + 1)
                inclinenump$ = inclinenump$ + "," + Chr$(34) + thisincname$ + Chr$(34)
            End If
            temp$ = ""
            Print #12, "if(qbevent){" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");}" 'non-resumable error check (cannot exit without handling errors)
            Print #12, "exit_code=" + e$ + ";"
            l$ = l$ + sp + l2$
        End If

        Print #12, "if (sub_gl_called) error(271);"
        Print #12, "close_program=1;"
        Print #12, "end();"
        layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
        GoTo finishedline
    End If

    If n >= 1 Then
        If firstelement$ = "STOP" Then
            l$ = SCase$("Stop")
            If n > 1 Then
                e$ = getelements$(ca$, 2, n)
                e$ = fixoperationorder$(e$)
                If Error_Happened Then GoTo errmes
                l$ = SCase$("Stop") + sp + tlayout$
                e$ = evaluatetotyp(e$, 64)
                If Error_Happened Then GoTo errmes
                'note: this value is currently ignored but evaluated for checking reasons
            End If
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "close_program=1;"
            Print #12, "end();"
            GoTo finishedline
        End If
    End If

    If n = 2 Then
        If firstelement$ = "GOSUB" Then
            xgosub ca$
            If Error_Happened Then GoTo errmes
            'note: layout implemented in xgosub
            GoTo finishedline
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "RETURN" Then
            If n = 1 Then
                Print #12, "#include " + Chr$(34) + "ret" + str2$(subfuncn) + ".txt" + Chr$(34)
                l$ = SCase$("Return")
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            Else
                'label/linenumber follows
                If subfuncn <> 0 Then a$ = "RETURN linelabel/linenumber invalid within a SUB/FUNCTION": GoTo errmes
                If n > 2 Then a$ = "Expected linelabel/linenumber after RETURN": GoTo errmes
                Print #12, "if (!next_return_point) error(3);" 'check return point available
                Print #12, "next_return_point--;" 'destroy return point
                a2$ = getelement$(ca$, 2)
                If validlabel(a2$) = 0 Then a$ = "Invalid label!": GoTo errmes

                v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
                x = 1
                labchk505:
                If v Then
                    s = Labels(r).Scope
                    If s = subfuncn Or s = -1 Then 'same scope?
                        If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                        x = 0 'already defined
                        tlayout$ = RTrim$(Labels(r).cn)
                    Else
                        If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk505
                    End If
                End If
                If x Then
                    'does not exist
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd a2$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = subfuncn
                    Labels(r).Error_Line = linenumber
                End If 'x

                Print #12, "goto LABEL_" + a2$ + ";"
                l$ = SCase$("Return") + sp + tlayout$
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "RESUME" Then
            l$ = SCase$("Resume")
            If n = 1 Then
                resumeprev:


                Print #12, "if (!error_handling){error(20);}else{error_retry=1; qbevent=1; error_handling=0; error_err=0; return;}"

                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
            If n > 2 Then a$ = "Too many parameters": GoTo errmes
            s$ = getelement$(ca$, 2)
            If UCase$(s$) = "NEXT" Then
                Print #12, "if (!error_handling){error(20);}else{error_handling=0; error_err=0; return;}"

                l$ = l$ + sp + SCase$("Next")
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
            If s$ = "0" Then l$ = l$ + sp + "0": GoTo resumeprev
            If validlabel(s$) = 0 Then a$ = "Invalid label passed to RESUME": GoTo errmes

            v = HashFind(s$, HASHFLAG_LABEL, ignore, r)
            x = 1
            labchk506:
            If v Then
                s = Labels(r).Scope
                If s = subfuncn Or s = -1 Then 'same scope?
                    If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                    x = 0 'already defined
                    tlayout$ = RTrim$(Labels(r).cn)
                Else
                    If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk506
                End If
            End If
            If x Then
                'does not exist
                nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                Labels(nLabels) = Empty_Label
                HashAdd s$, HASHFLAG_LABEL, nLabels
                r = nLabels
                Labels(r).State = 0
                Labels(r).cn = tlayout$
                Labels(r).Scope = subfuncn
                Labels(r).Error_Line = linenumber
            End If 'x

            l$ = l$ + sp + tlayout$
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            Print #12, "if (!error_handling){error(20);}else{error_handling=0; error_err=0; goto LABEL_" + s$ + ";}"
            GoTo finishedline
        End If
    End If

    If n = 4 Then
        If getelements(a$, 1, 3) = "ON" + sp + "ERROR" + sp + "GOTO" Then
            l$ = SCase$("On" + sp + "Error" + sp + "GoTo")
            lbl$ = getelement$(ca$, 4)
            If lbl$ = "0" Then
                Print #12, "error_goto_line=0;"
                l$ = l$ + sp + "0"
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If
            If validlabel(lbl$) = 0 Then a$ = "Invalid label": GoTo errmes

            v = HashFind(lbl$, HASHFLAG_LABEL, ignore, r)
            x = 1
            labchk6:
            If v Then
                s = Labels(r).Scope
                If s = 0 Or s = -1 Then 'main scope?
                    If s = -1 Then Labels(r).Scope = 0 'acquire scope
                    x = 0 'already defined
                    tlayout$ = RTrim$(Labels(r).cn)
                    Labels(r).Scope_Restriction = subfuncn
                    Labels(r).Error_Line = linenumber
                Else
                    If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk6
                End If
            End If
            If x Then
                'does not exist
                nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                Labels(nLabels) = Empty_Label
                HashAdd lbl$, HASHFLAG_LABEL, nLabels
                r = nLabels
                Labels(r).State = 0
                Labels(r).cn = tlayout$
                Labels(r).Scope = 0
                Labels(r).Error_Line = linenumber
                Labels(r).Scope_Restriction = subfuncn
            End If 'x


            l$ = l$ + sp + tlayout$
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            errorlabels = errorlabels + 1
            Print #12, "error_goto_line=" + str2(errorlabels) + ";"
            Print #14, "if (error_goto_line==" + str2(errorlabels) + "){error_handling=1; goto LABEL_" + lbl$ + ";}"
            GoTo finishedline
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "RESTORE" Then
            l$ = SCase$("Restore")
            If n = 1 Then
                Print #12, "data_offset=0;"
            Else
                If n > 2 Then a$ = "Syntax error - too many parameters (expected RESTORE label/line number)": GoTo errmes
                lbl$ = getelement$(ca$, 2)
                If validlabel(lbl$) = 0 Then a$ = "Invalid label": GoTo errmes

                'rule: a RESTORE label has no scope, therefore, only one instance of that label may exist
                'how: enforced by a post check for duplicates
                v = HashFind(lbl$, HASHFLAG_LABEL, ignore, r)
                x = 1
                If v Then 'already defined
                    x = 0
                    tlayout$ = RTrim$(Labels(r).cn)
                    Labels(r).Data_Referenced = 1 'make sure the data referenced flag is set
                    If Labels(r).Error_Line = 0 Then Labels(r).Error_Line = linenumber
                End If
                If x Then
                    nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                    Labels(nLabels) = Empty_Label
                    HashAdd lbl$, HASHFLAG_LABEL, nLabels
                    r = nLabels
                    Labels(r).State = 0
                    Labels(r).cn = tlayout$
                    Labels(r).Scope = -1 'modifyable scope
                    Labels(r).Error_Line = linenumber
                    Labels(r).Data_Referenced = 1
                End If 'x

                l$ = l$ + sp + tlayout$
                Print #12, "data_offset=data_at_LABEL_" + lbl$ + ";"
            End If
            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    'ON ... GOTO/GOSUB
    If n >= 1 Then
        If firstelement$ = "ON" Then
            xongotogosub a$, ca$, n
            If Error_Happened Then GoTo errmes
            GoTo finishedline
        End If
    End If

    '(_MEM) _MEMPUT _MEMGET
    If n >= 1 Then
        If firstelement$ = "_MEMGET" Then
            'get expressions
            e$ = ""
            B = 0
            ne = 0
            For i2 = 2 To n
                e2$ = getelement$(ca$, i2)
                If e2$ = "(" Then B = B + 1
                If e2$ = ")" Then B = B - 1
                If e2$ = "," And B = 0 Then
                    ne = ne + 1
                    If ne = 1 Then blk$ = e$: e$ = ""
                    If ne = 2 Then offs$ = e$: e$ = ""
                    If ne = 3 Then a$ = "Syntax error - too many parameters (Expected " + qb64prefix$ + "MEMGET mem-reference, offset, variable)": GoTo errmes
                Else
                    If Len(e$) = 0 Then e$ = e2$ Else e$ = e$ + sp + e2$
                End If
            Next
            var$ = e$
            If e$ = "" Or ne <> 2 Then a$ = "Expected " + qb64prefix$ + "MEMGET mem-reference, offset, variable": GoTo errmes

            If firstelement$ = "_MEMGET" Then l$ = SCase$("_MemGet") + sp Else l$ = SCase$("MemGet") + sp

            e$ = fixoperationorder$(blk$): If Error_Happened Then GoTo errmes
            l$ = l$ + tlayout$

            test$ = evaluate(e$, typ): If Error_Happened Then GoTo errmes
            If (typ And ISUDT) = 0 Or (typ And 511) <> 1 Then a$ = "Expected " + qb64prefix$ + "MEM type": GoTo errmes
            blkoffs$ = evaluatetotyp(e$, -6)

            '            IF typ AND ISREFERENCE THEN e$ = refer(e$, typ, 0)


            'PRINT #12, blkoffs$ '???

            e$ = fixoperationorder$(offs$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            e$ = evaluatetotyp(e$, OFFSETTYPE - ISPOINTER): If Error_Happened Then GoTo errmes
            offs$ = e$
            'PRINT #12, e$ '???

            e$ = fixoperationorder$(var$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            varsize$ = evaluatetotyp(e$, -5): If Error_Happened Then GoTo errmes
            varoffs$ = evaluatetotyp(e$, -6): If Error_Happened Then GoTo errmes


            'PRINT #12, varoffs$ '???
            'PRINT #12, varsize$ '???

            'what do we do next
            'need to know offset of variable and its size

            'known sizes will be handled by designated command casts, otherwise use memmove
            s = 0
            If varsize$ = "1" Then s = 1: st$ = "int8"
            If varsize$ = "2" Then s = 2: st$ = "int16"
            If varsize$ = "4" Then s = 4: st$ = "int32"
            If varsize$ = "8" Then s = 8: st$ = "int64"

            If NoChecks Then
                'fast version:
                If s Then
                    Print #12, "*(" + st$ + "*)" + varoffs$ + "=*(" + st$ + "*)(" + offs$ + ");"
                Else
                    Print #12, "memmove(" + varoffs$ + ",(void*)" + offs$ + "," + varsize$ + ");"
                End If
            Else
                'safe version:
                Print #12, "tmp_long=" + offs$ + ";"
                'is mem block init?
                Print #12, "if ( ((mem_block*)(" + blkoffs$ + "))->lock_offset ){"
                'are region and id valid?
                Print #12, "if ("
                Print #12, "tmp_long < ((mem_block*)(" + blkoffs$ + "))->offset  ||"
                Print #12, "(tmp_long+(" + varsize$ + ")) > ( ((mem_block*)(" + blkoffs$ + "))->offset + ((mem_block*)(" + blkoffs$ + "))->size)  ||"
                Print #12, "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id  ){"
                'diagnose error
                Print #12, "if (" + "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id" + ") error(308); else error(300);"
                Print #12, "}else{"
                If s Then
                    Print #12, "*(" + st$ + "*)" + varoffs$ + "=*(" + st$ + "*)tmp_long;"
                Else
                    Print #12, "memmove(" + varoffs$ + ",(void*)tmp_long," + varsize$ + ");"
                End If
                Print #12, "}"
                Print #12, "}else error(309);"
            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline
        End If
    End If

    If n >= 1 Then
        If firstelement$ = "_MEMPUT" Then
            'get expressions
            typ$ = ""
            e$ = ""
            B = 0
            ne = 0
            For i2 = 2 To n
                e2$ = getelement$(ca$, i2)
                If e2$ = "(" Then B = B + 1
                If e2$ = ")" Then B = B - 1
                If (e2$ = "," Or UCase$(e2$) = "AS") And B = 0 Then
                    ne = ne + 1
                    If ne = 1 Then blk$ = e$: e$ = ""
                    If ne = 2 Then offs$ = e$: e$ = ""
                    If ne = 3 Then var$ = e$: e$ = ""
                    If (UCase$(e2$) = "AS" And ne <> 3) Or (ne = 3 And UCase$(e2$) <> "AS") Or ne = 4 Then a$ = "Expected _MEMPUT mem-reference,offset,variable|value[AS type]": GoTo errmes
                Else
                    If Len(e$) = 0 Then e$ = e2$ Else e$ = e$ + sp + e2$
                End If
            Next
            If ne < 2 Or e$ = "" Then a$ = "Expected " + qb64prefix$ + "MEMPUT mem-reference, offset, variable|value[AS type]": GoTo errmes
            If ne = 2 Then var$ = e$ Else typ$ = UCase$(e$)

            If firstelement$ = "_MEMPUT" Then l$ = SCase$("_MemPut") + sp Else l$ = SCase$("MemPut") + sp

            e$ = fixoperationorder$(blk$): If Error_Happened Then GoTo errmes
            l$ = l$ + tlayout$

            test$ = evaluate(e$, typ): If Error_Happened Then GoTo errmes
            If (typ And ISUDT) = 0 Or (typ And 511) <> 1 Then a$ = "Expected " + qb64prefix$ + "MEM type": GoTo errmes
            blkoffs$ = evaluatetotyp(e$, -6)

            e$ = fixoperationorder$(offs$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            e$ = evaluatetotyp(e$, OFFSETTYPE - ISPOINTER): If Error_Happened Then GoTo errmes
            offs$ = e$

            If ne = 2 Then
                e$ = fixoperationorder$(var$): If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$

                test$ = evaluate(e$, t): If Error_Happened Then GoTo errmes
                If (t And ISREFERENCE) = 0 And (t And ISSTRING) Then
                    Print #12, "g_tmp_str=" + test$ + ";"
                    varsize$ = "g_tmp_str->len"
                    varoffs$ = "g_tmp_str->chr"
                Else
                    varsize$ = evaluatetotyp(e$, -5): If Error_Happened Then GoTo errmes
                    varoffs$ = evaluatetotyp(e$, -6): If Error_Happened Then GoTo errmes
                End If

                'known sizes will be handled by designated command casts, otherwise use memmove
                s = 0
                If varsize$ = "1" Then s = 1: st$ = "int8"
                If varsize$ = "2" Then s = 2: st$ = "int16"
                If varsize$ = "4" Then s = 4: st$ = "int32"
                If varsize$ = "8" Then s = 8: st$ = "int64"

                If NoChecks Then
                    'fast version:
                    If s Then
                        Print #12, "*(" + st$ + "*)(" + offs$ + ")=*(" + st$ + "*)" + varoffs$ + ";"
                    Else
                        Print #12, "memmove((void*)" + offs$ + "," + varoffs$ + "," + varsize$ + ");"
                    End If
                Else
                    'safe version:
                    Print #12, "tmp_long=" + offs$ + ";"
                    'is mem block init?
                    Print #12, "if ( ((mem_block*)(" + blkoffs$ + "))->lock_offset ){"
                    'are region and id valid?
                    Print #12, "if ("
                    Print #12, "tmp_long < ((mem_block*)(" + blkoffs$ + "))->offset  ||"
                    Print #12, "(tmp_long+(" + varsize$ + ")) > ( ((mem_block*)(" + blkoffs$ + "))->offset + ((mem_block*)(" + blkoffs$ + "))->size)  ||"
                    Print #12, "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id  ){"
                    'diagnose error
                    Print #12, "if (" + "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id" + ") error(308); else error(300);"
                    Print #12, "}else{"
                    If s Then
                        Print #12, "*(" + st$ + "*)tmp_long=*(" + st$ + "*)" + varoffs$ + ";"
                    Else
                        Print #12, "memmove((void*)tmp_long," + varoffs$ + "," + varsize$ + ");"
                    End If
                    Print #12, "}"
                    Print #12, "}else error(309);"
                End If

            Else

                '... AS type method
                'FUNCTION typname2typ& (t2$)
                'typname2typsize = 0 'the default
                t = typname2typ(typ$)
                If t = 0 Then a$ = "Invalid type": GoTo errmes
                If (t And ISOFFSETINBITS) <> 0 Or (t And ISUDT) <> 0 Or (t And ISSTRING) Then a$ = qb64prefix$ + "MEMPUT requires numeric type": GoTo errmes
                If (t And ISPOINTER) Then t = t - ISPOINTER
                'attempt conversion...
                e$ = fixoperationorder$(var$): If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$ + sp + SCase$("As") + sp + typ$
                e$ = evaluatetotyp(e$, t): If Error_Happened Then GoTo errmes
                st$ = typ2ctyp$(t, "")
                varsize$ = str2((t And 511) \ 8)
                If NoChecks Then
                    'fast version:
                    Print #12, "*(" + st$ + "*)(" + offs$ + ")=" + e$ + ";"
                Else
                    'safe version:
                    Print #12, "tmp_long=" + offs$ + ";"
                    'is mem block init?
                    Print #12, "if ( ((mem_block*)(" + blkoffs$ + "))->lock_offset ){"
                    'are region and id valid?
                    Print #12, "if ("
                    Print #12, "tmp_long < ((mem_block*)(" + blkoffs$ + "))->offset  ||"
                    Print #12, "(tmp_long+(" + varsize$ + ")) > ( ((mem_block*)(" + blkoffs$ + "))->offset + ((mem_block*)(" + blkoffs$ + "))->size)  ||"
                    Print #12, "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id  ){"
                    'diagnose error
                    Print #12, "if (" + "((mem_lock*)((mem_block*)(" + blkoffs$ + "))->lock_offset)->id != ((mem_block*)(" + blkoffs$ + "))->lock_id" + ") error(308); else error(300);"
                    Print #12, "}else{"
                    Print #12, "*(" + st$ + "*)tmp_long=" + e$ + ";"
                    Print #12, "}"
                    Print #12, "}else error(309);"
                End If

            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline

        End If
    End If

    If n >= 1 Then
        If firstelement$ = "_MEMFILL" Then
            'get expressions
            typ$ = ""
            e$ = ""
            B = 0
            ne = 0
            For i2 = 2 To n
                e2$ = getelement$(ca$, i2)
                If e2$ = "(" Then B = B + 1
                If e2$ = ")" Then B = B - 1
                If (e2$ = "," Or UCase$(e2$) = "AS") And B = 0 Then
                    ne = ne + 1
                    If ne = 1 Then blk$ = e$: e$ = ""
                    If ne = 2 Then offs$ = e$: e$ = ""
                    If ne = 3 Then bytes$ = e$: e$ = ""
                    If ne = 4 Then var$ = e$: e$ = ""
                    If (UCase$(e2$) = "AS" And ne <> 4) Or (ne = 4 And UCase$(e2$) <> "AS") Or ne = 5 Then a$ = "Expected _MEMFILL mem-reference,offset,bytes,variable|value[AS type]": GoTo errmes
                Else
                    If Len(e$) = 0 Then e$ = e2$ Else e$ = e$ + sp + e2$
                End If
            Next
            If ne < 3 Or e$ = "" Then a$ = "Expected " + qb64prefix$ + "MEMFILL mem-reference, offset, bytes, variable|value[AS type]": GoTo errmes
            If ne = 3 Then var$ = e$ Else typ$ = UCase$(e$)

            If firstelement$ = "_MEMFILL" Then l$ = SCase$("_MemFill") + sp Else l$ = SCase$("MemFill") + sp

            e$ = fixoperationorder$(blk$): If Error_Happened Then GoTo errmes
            l$ = l$ + tlayout$

            test$ = evaluate(e$, typ): If Error_Happened Then GoTo errmes
            If (typ And ISUDT) = 0 Or (typ And 511) <> 1 Then a$ = "Expected " + qb64prefix$ + "MEM type": GoTo errmes
            blkoffs$ = evaluatetotyp(e$, -6)

            e$ = fixoperationorder$(offs$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            e$ = evaluatetotyp(e$, OFFSETTYPE - ISPOINTER): If Error_Happened Then GoTo errmes
            offs$ = e$

            e$ = fixoperationorder$(bytes$): If Error_Happened Then GoTo errmes
            l$ = l$ + sp2 + "," + sp + tlayout$
            e$ = evaluatetotyp(e$, OFFSETTYPE - ISPOINTER): If Error_Happened Then GoTo errmes
            bytes$ = e$

            If ne = 3 Then 'no AS
                e$ = fixoperationorder$(var$): If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$
                test$ = evaluate(e$, t)
                If (t And ISREFERENCE) = 0 And (t And ISSTRING) Then
                    Print #12, "tmp_long=(ptrszint)" + test$ + ";"
                    varsize$ = "((qbs*)tmp_long)->len"
                    varoffs$ = "((qbs*)tmp_long)->chr"
                Else
                    varsize$ = evaluatetotyp(e$, -5): If Error_Happened Then GoTo errmes
                    varoffs$ = evaluatetotyp(e$, -6): If Error_Happened Then GoTo errmes
                End If

                If NoChecks Then
                    Print #12, "sub__memfill_nochecks(" + offs$ + "," + bytes$ + ",(ptrszint)" + varoffs$ + "," + varsize$ + ");"
                Else
                    Print #12, "sub__memfill((mem_block*)" + blkoffs$ + "," + offs$ + "," + bytes$ + ",(ptrszint)" + varoffs$ + "," + varsize$ + ");"
                End If

            Else

                '... AS type method
                t = typname2typ(typ$)
                If t = 0 Then a$ = "Invalid type": GoTo errmes
                If (t And ISOFFSETINBITS) <> 0 Or (t And ISUDT) <> 0 Or (t And ISSTRING) Then a$ = qb64prefix$ + "MEMFILL requires numeric type": GoTo errmes
                If (t And ISPOINTER) Then t = t - ISPOINTER
                'attempt conversion...
                e$ = fixoperationorder$(var$): If Error_Happened Then GoTo errmes
                l$ = l$ + sp2 + "," + sp + tlayout$ + sp + SCase$("As") + sp + typ$
                e$ = evaluatetotyp(e$, t): If Error_Happened Then GoTo errmes

                c$ = "sub__memfill_"
                If NoChecks Then c$ = "sub__memfill_nochecks_"
                If t And ISOFFSET Then
                    c$ = c$ + "OFFSET"
                Else
                    If t And ISFLOAT Then
                        If (t And 511) = 32 Then c$ = c$ + "SINGLE"
                        If (t And 511) = 64 Then c$ = c$ + "DOUBLE"
                        If (t And 511) = 256 Then c$ = c$ + "FLOAT" 'padded variable
                    Else
                        c$ = c$ + str2((t And 511) \ 8)
                    End If
                End If
                c$ = c$ + "("
                If NoChecks = 0 Then c$ = c$ + "(mem_block*)" + blkoffs$ + ","
                Print #12, c$ + offs$ + "," + bytes$ + "," + e$ + ");"
            End If

            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            GoTo finishedline

        End If
    End If

    'note: ABSOLUTE cannot be used without CALL
    cispecial = 0
    If n > 1 Then
        If firstelement$ = "INTERRUPT" Or firstelement$ = "INTERRUPTX" Then
            a$ = "CALL" + sp + firstelement$ + sp + "(" + sp + getelements$(a$, 2, n) + sp + ")"
            ca$ = "CALL" + sp + firstelement$ + sp + "(" + sp + getelements$(ca$, 2, n) + sp + ")"
            n = n + 3
            firstelement$ = "CALL"
            cispecial = 1
            'fall through
        End If
    End If

    usecall = 0
    If firstelement$ = "CALL" Then
        usecall = 1
        If n = 1 Then a$ = "Expected CALL sub-name [(...)]": GoTo errmes
        cn$ = getelement$(ca$, 2): n$ = UCase$(cn$)

        If n > 2 Then

            If n <= 4 Then a$ = "Expected CALL sub-name (...)": GoTo errmes
            If getelement$(a$, 3) <> "(" Or getelement$(a$, n) <> ")" Then a$ = "Expected CALL sub-name (...)": GoTo errmes
            a$ = n$ + sp + getelements$(a$, 4, n - 1)
            ca$ = cn$ + sp + getelements$(ca$, 4, n - 1)


            If n$ = "INTERRUPT" Or n$ = "INTERRUPTX" Then 'assume CALL INTERRUPT[X] request
                'print "CI: call interrupt command reached":sleep 1
                If n$ = "INTERRUPT" Then Print #12, "call_interrupt("; Else Print #12, "call_interruptx(";
                argn = 0
                n = numelements(a$)
                B = 0
                e$ = ""
                For i = 2 To n
                    e2$ = getelement$(ca$, i)
                    If e2$ = "(" Then B = B + 1
                    If e2$ = ")" Then B = B - 1
                    If (e2$ = "," And B = 0) Or i = n Then
                        If i = n Then
                            If e$ = "" Then e$ = e2$ Else e$ = e$ + sp + e2$
                        End If
                        argn = argn + 1
                        If argn = 1 Then 'interrupt number
                            e$ = fixoperationorder$(e$)
                            If Error_Happened Then GoTo errmes
                            l$ = SCase$("Call") + sp + n$ + sp2 + "(" + sp2 + tlayout$
                            If cispecial = 1 Then l$ = n$ + sp + tlayout$
                            e$ = evaluatetotyp(e$, 64&)
                            If Error_Happened Then GoTo errmes
                            'print "CI: evaluated interrupt number as ["+e$+"]":sleep 1
                            Print #12, e$;
                        End If
                        If argn = 2 Or argn = 3 Then 'inregs, outregs
                            e$ = fixoperationorder$(e$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + sp2 + "," + sp + tlayout$
                            e2$ = e$
                            e$ = evaluatetotyp(e$, -2) 'offset+size
                            If Error_Happened Then GoTo errmes
                            'print "CI: evaluated in/out regs ["+e2$+"] as ["+e$+"]":sleep 1
                            Print #12, "," + e$;
                        End If
                        e$ = ""
                    Else
                        If e$ = "" Then e$ = e2$ Else e$ = e$ + sp + e2$
                    End If
                Next
                If argn <> 3 Then a$ = "Expected CALL INTERRUPT (interrupt-no, inregs, outregs)": GoTo errmes
                Print #12, ");"
                If cispecial = 0 Then l$ = l$ + sp2 + ")"
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                'print "CI: done":sleep 1
                GoTo finishedline
            End If 'call interrupt

            'call to CALL ABSOLUTE beyond reasonable doubt
            If n$ = "ABSOLUTE" Then
                l$ = SCase$("Call" + sp + "Absolute" + sp2 + "(" + sp2)
                argn = 0
                n = numelements(a$)
                B = 0
                e$ = ""
                For i = 2 To n
                    e2$ = getelement$(ca$, i)
                    If e2$ = "(" Then B = B + 1
                    If e2$ = ")" Then B = B - 1
                    If (e2$ = "," And B = 0) Or i = n Then
                        If i < n Then
                            If e$ = "" Then a$ = "Expected expression before , or )": GoTo errmes
                            '1. variable or value?
                            e$ = fixoperationorder$(e$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + tlayout$ + sp2 + "," + sp
                            ignore$ = evaluate(e$, typ)
                            If Error_Happened Then GoTo errmes

                            If (typ And ISPOINTER) <> 0 And (typ And ISREFERENCE) <> 0 Then

                                'assume standard variable
                                'assume not string/array/udt/etc
                                e$ = "VARPTR" + sp + "(" + sp + e$ + sp + ")"
                                e$ = evaluatetotyp(e$, UINTEGERTYPE - ISPOINTER)
                                If Error_Happened Then GoTo errmes

                            Else

                                'assume not string
                                'single, double or integer64?
                                If typ And ISFLOAT Then
                                    If (typ And 511) = 32 Then
                                        e$ = evaluatetotyp(e$, SINGLETYPE - ISPOINTER)
                                        If Error_Happened Then GoTo errmes
                                        v$ = "pass" + str2$(uniquenumber)
                                        Print #defdatahandle, "float *" + v$ + "=NULL;"
                                        Print #13, "if(" + v$ + "==NULL){"
                                        Print #13, "cmem_sp-=4;"
                                        Print #13, v$ + "=(float*)(dblock+cmem_sp);"
                                        Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                                        Print #13, "}"
                                        e$ = "(uint16)(((uint8*)&(*" + v$ + "=" + e$ + "))-((uint8*)dblock))"
                                    Else
                                        e$ = evaluatetotyp(e$, DOUBLETYPE - ISPOINTER)
                                        If Error_Happened Then GoTo errmes
                                        v$ = "pass" + str2$(uniquenumber)
                                        Print #defdatahandle, "double *" + v$ + "=NULL;"
                                        Print #13, "if(" + v$ + "==NULL){"
                                        Print #13, "cmem_sp-=8;"
                                        Print #13, v$ + "=(double*)(dblock+cmem_sp);"
                                        Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                                        Print #13, "}"
                                        e$ = "(uint16)(((uint8*)&(*" + v$ + "=" + e$ + "))-((uint8*)dblock))"
                                    End If
                                Else
                                    e$ = evaluatetotyp(e$, INTEGER64TYPE - ISPOINTER)
                                    If Error_Happened Then GoTo errmes
                                    v$ = "pass" + str2$(uniquenumber)
                                    Print #defdatahandle, "int64 *" + v$ + "=NULL;"
                                    Print #13, "if(" + v$ + "==NULL){"
                                    Print #13, "cmem_sp-=8;"
                                    Print #13, v$ + "=(int64*)(dblock+cmem_sp);"
                                    Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                                    Print #13, "}"
                                    e$ = "(uint16)(((uint8*)&(*" + v$ + "=" + e$ + "))-((uint8*)dblock))"
                                End If

                            End If

                            Print #12, "call_absolute_offsets[" + str2$(argn) + "]=" + e$ + ";"
                        Else
                            If e$ = "" Then e$ = e2$ Else e$ = e$ + sp + e2$
                            e$ = fixoperationorder(e$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + tlayout$ + sp2 + ")"
                            e$ = evaluatetotyp(e$, UINTEGERTYPE - ISPOINTER)
                            If Error_Happened Then GoTo errmes
                            Print #12, "call_absolute(" + str2$(argn) + "," + e$ + ");"
                        End If
                        argn = argn + 1
                        e$ = ""
                    Else
                        If e$ = "" Then e$ = e2$ Else e$ = e$ + sp + e2$
                    End If
                Next
                layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                GoTo finishedline
            End If

        Else 'n>2

            a$ = n$
            ca$ = cn$
            usecall = 2

        End If 'n>2

        n = numelements(a$)
        firstelement$ = getelement$(a$, 1)

        'valid SUB name
        validsub = 0
        findidsecondarg = "": If n >= 2 Then findidsecondarg = getelement$(a$, 2)
        try = findid(firstelement$)
        If Error_Happened Then GoTo errmes
        Do While try
            If id.subfunc = 2 Then validsub = 1: Exit Do
            If try = 2 Then
                findidsecondarg = "": If n >= 2 Then findidsecondarg = getelement$(a$, 2)
                findanotherid = 1
                try = findid(firstelement$)
                If Error_Happened Then GoTo errmes
            Else
                try = 0
            End If
        Loop
        If validsub = 0 Then a$ = "Expected CALL sub-name [(...)]": GoTo errmes
    End If

    'sub?
    If n >= 1 Then

        If firstelement$ = "?" Then firstelement$ = "PRINT"

        findidsecondarg = "": If n >= 2 Then findidsecondarg = getelement$(a$, 2)
        try = findid(firstelement$)
        If Error_Happened Then GoTo errmes
        Do While try
            If id.subfunc = 2 Then

                'check symbol
                s$ = removesymbol$(firstelement$ + "")
                If Error_Happened Then GoTo errmes
                If Asc(id.musthave) = 36 Then '="$"
                    If s$ <> "$" Then GoTo notsubcall 'missing musthave "$"
                Else
                    If Len(s$) Then GoTo notsubcall 'unrequired symbol added
                End If
                'check for variable assignment
                If n > 1 Then
                    If Asc(id.specialformat) <> 61 Then '<>"="
                        If Asc(getelement$(a$, 2)) = 61 Then GoTo notsubcall 'assignment, not sub call
                    End If
                End If
                'check for array assignment
                If n > 2 Then
                    If firstelement$ <> "PRINT" And firstelement$ <> "LPRINT" Then
                        If getelement$(a$, 2) = "(" Then
                            B = 1
                            For i = 3 To n
                                e$ = getelement$(a$, i)
                                If e$ = "(" Then B = B + 1
                                If e$ = ")" Then
                                    B = B - 1
                                    If B = 0 Then
                                        If i = n Then Exit For
                                        If getelement$(a$, i + 1) = "=" Then GoTo notsubcall
                                    End If
                                End If
                            Next
                        End If
                    End If
                End If

                'generate error on driect _GL call
                If firstelement$ = "_GL" Then
                    a$ = "Cannot call SUB _GL directly": GoTo errmes
                End If

                If firstelement$ = "OPEN" Then
                    'gwbasic or qbasic version?
                    B = 0
                    For x = 2 To n
                        a2$ = getelement$(a$, x)
                        If a2$ = "(" Then B = B + 1
                        If a2$ = ")" Then B = B - 1
                        If a2$ = "FOR" Or a2$ = "AS" Then Exit For 'qb style open verified
                        If B = 0 And a2$ = "," Then 'the gwbasic version includes a comma after the first string expression
                            findanotherid = 1
                            try = findid(firstelement$) 'id of sub_open_gwbasic
                            If Error_Happened Then GoTo errmes
                            Exit For
                        End If
                    Next
                End If

                'IF findid(firstelement$) THEN
                'IF id.subfunc = 2 THEN

                If firstelement$ = "CLOSE" Or firstelement$ = "RESET" Then
                    If firstelement$ = "RESET" Then
                        If n > 1 Then a$ = "Syntax error - RESET takes no parameters": GoTo errmes
                        l$ = SCase$("Reset")
                    Else
                        l$ = SCase$("Close")
                    End If

                    If n = 1 Then
                        Print #12, "sub_close(NULL,0);" 'closes all files
                    Else
                        l$ = l$ + sp
                        B = 0
                        s = 0
                        a3$ = ""
                        For x = 2 To n
                            a2$ = getelement$(ca$, x)
                            If a2$ = "(" Then B = B + 1
                            If a2$ = ")" Then B = B - 1
                            If a2$ = "#" And B = 0 Then
                                If s = 0 Then s = 1 Else a$ = "Unexpected #": GoTo errmes
                                l$ = l$ + "#" + sp2
                                GoTo closenexta
                            End If

                            If a2$ = "," And B = 0 Then
                                If s = 2 Then
                                    e$ = fixoperationorder$(a3$)
                                    If Error_Happened Then GoTo errmes
                                    l$ = l$ + tlayout$ + sp2 + "," + sp
                                    e$ = evaluatetotyp(e$, 64&)
                                    If Error_Happened Then GoTo errmes
                                    Print #12, "sub_close(" + e$ + ",1);"
                                    a3$ = ""
                                    s = 0
                                    GoTo closenexta
                                Else
                                    a$ = "Expected expression before ,": GoTo errmes
                                End If
                            End If

                            s = 2
                            If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$

                            closenexta:
                        Next

                        If s = 2 Then
                            e$ = fixoperationorder$(a3$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + tlayout$
                            e$ = evaluatetotyp(e$, 64&)
                            If Error_Happened Then GoTo errmes
                            Print #12, "sub_close(" + e$ + ",1);"
                        Else
                            l$ = Left$(l$, Len(l$) - 1)
                        End If

                    End If
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                End If 'close

                'data, restore, read
                If firstelement$ = "READ" Then 'file input
                    xread ca$, n
                    If Error_Happened Then GoTo errmes
                    'note: layout done in xread sub
                    GoTo finishedline
                End If 'read

                lineinput = 0
                If n >= 2 Then
                    If firstelement$ = "LINE" And secondelement$ = "INPUT" Then
                        lineinput = 1
                        a$ = Right$(a$, Len(a$) - 5): ca$ = Right$(ca$, Len(ca$) - 5): n = n - 1 'remove "LINE"
                        firstelement$ = "INPUT"
                    End If
                End If

                If firstelement$ = "INPUT" Then 'file input
                    If n > 1 Then
                        If getelement$(a$, 2) = "#" Then
                            l$ = SCase$("Input") + sp + "#": If lineinput Then l$ = SCase$("Line") + sp + l$

                            u$ = str2$(uniquenumber)
                            'which file?
                            If n = 2 Then a$ = "Expected # ... , ...": GoTo errmes
                            a3$ = ""
                            B = 0
                            For i = 3 To n
                                a2$ = getelement$(ca$, i)
                                If a2$ = "(" Then B = B + 1
                                If a2$ = ")" Then B = B - 1
                                If a2$ = "," And B = 0 Then
                                    If a3$ = "" Then a$ = "Expected # ... , ...": GoTo errmes
                                    GoTo inputgotfn
                                End If
                                If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
                            Next
                            inputgotfn:
                            e$ = fixoperationorder$(a3$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + sp2 + tlayout$
                            e$ = evaluatetotyp(e$, 64&)
                            If Error_Happened Then GoTo errmes
                            Print #12, "tmp_fileno=" + e$ + ";"
                            Print #12, "if (new_error) goto skip" + u$ + ";"
                            i = i + 1
                            If i > n Then a$ = "Expected , ...": GoTo errmes
                            a3$ = ""
                            B = 0
                            For i = i To n
                                a2$ = getelement$(ca$, i)
                                If a2$ = "(" Then B = B + 1
                                If a2$ = ")" Then B = B - 1
                                If i = n Then
                                    If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
                                    a2$ = ",": B = 0
                                End If
                                If a2$ = "," And B = 0 Then
                                    If a3$ = "" Then a$ = "Expected , ...": GoTo errmes
                                    e$ = fixoperationorder$(a3$)
                                    If Error_Happened Then GoTo errmes
                                    l$ = l$ + sp2 + "," + sp + tlayout$
                                    e$ = evaluate(e$, t)
                                    If Error_Happened Then GoTo errmes
                                    If (t And ISREFERENCE) = 0 Then a$ = "Expected variable-name": GoTo errmes
                                    If (t And ISSTRING) Then
                                        e$ = refer(e$, t, 0)
                                        If Error_Happened Then GoTo errmes
                                        If lineinput Then
                                            Print #12, "sub_file_line_input_string(tmp_fileno," + e$ + ");"
                                            Print #12, "if (new_error) goto skip" + u$ + ";"
                                        Else
                                            Print #12, "sub_file_input_string(tmp_fileno," + e$ + ");"
                                            Print #12, "if (new_error) goto skip" + u$ + ";"
                                        End If
                                        stringprocessinghappened = 1
                                    Else
                                        If lineinput Then a$ = "Expected string-variable": GoTo errmes

                                        'numeric variable
                                        If (t And ISFLOAT) <> 0 Or (t And 511) <> 64 Then
                                            If (t And ISOFFSETINBITS) Then
                                                setrefer e$, t, "((int64)func_file_input_float(tmp_fileno," + str2(t) + "))", 1
                                                If Error_Happened Then GoTo errmes
                                            Else
                                                setrefer e$, t, "func_file_input_float(tmp_fileno," + str2(t) + ")", 1
                                                If Error_Happened Then GoTo errmes
                                            End If
                                        Else
                                            If t And ISUNSIGNED Then
                                                setrefer e$, t, "func_file_input_uint64(tmp_fileno)", 1
                                                If Error_Happened Then GoTo errmes
                                            Else
                                                setrefer e$, t, "func_file_input_int64(tmp_fileno)", 1
                                                If Error_Happened Then GoTo errmes
                                            End If
                                        End If

                                        Print #12, "if (new_error) goto skip" + u$ + ";"

                                    End If
                                    If i = n Then Exit For
                                    If lineinput Then a$ = "Too many variables": GoTo errmes
                                    a3$ = "": a2$ = ""
                                End If
                                If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
                            Next
                            Print #12, "skip" + u$ + ":"
                            If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"
                            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                            GoTo finishedline
                        End If
                    End If
                End If 'input#

                If firstelement$ = "INPUT" Then
                    l$ = SCase$("Input"): If lineinput Then l$ = SCase$("Line") + sp + l$
                    commaneeded = 0
                    i = 2

                    newline = 1: If getelement$(a$, i) = ";" Then newline = 0: i = i + 1: l$ = l$ + sp + ";"

                    a2$ = getelement$(ca$, i)
                    If Left$(a2$, 1) = Chr$(34) Then
                        e$ = fixoperationorder$(a2$): l$ = l$ + sp + tlayout$
                        If Error_Happened Then GoTo errmes
                        Print #12, "qbs_print(qbs_new_txt_len(" + a2$ + "),0);"
                        i = i + 1
                        'MUST be followed by a ; or ,
                        a2$ = getelement$(ca$, i)
                        i = i + 1
                        l$ = l$ + sp2 + a2$
                        If a2$ = ";" Then
                            If lineinput Then GoTo finishedpromptstring
                            Print #12, "qbs_print(qbs_new_txt(" + Chr$(34) + "? " + Chr$(34) + "),0);"
                            GoTo finishedpromptstring
                        End If
                        If a2$ = "," Then
                            GoTo finishedpromptstring
                        End If
                        a$ = "Syntax error - Reference: INPUT [;] " + Chr$(34) + "[Question or statement text]" + Chr$(34) + "{,|;} variable[, ...] or INPUT ; variable[, ...]": GoTo errmes
                    End If
                    'there was no promptstring, so print a ?
                    If lineinput = 0 Then Print #12, "qbs_print(qbs_new_txt(" + Chr$(34) + "? " + Chr$(34) + "),0);"
                    finishedpromptstring:
                    numvar = 0
                    For i = i To n
                        If commaneeded = 1 Then
                            a2$ = getelement$(ca$, i)
                            If a2$ <> "," Then a$ = "Syntax error - comma expected": GoTo errmes
                        Else

                            B = 0
                            e$ = ""
                            For i2 = i To n
                                e2$ = getelement$(ca$, i2)
                                If e2$ = "(" Then B = B + 1
                                If e2$ = ")" Then B = B - 1
                                If e2$ = "," And B = 0 Then i2 = i2 - 1: Exit For
                                e$ = e$ + sp + e2$
                            Next
                            i = i2: If i > n Then i = n
                            If e$ = "" Then a$ = "Expected variable": GoTo errmes
                            e$ = Right$(e$, Len(e$) - 1)
                            e$ = fixoperationorder$(e$)
                            If Error_Happened Then GoTo errmes
                            l$ = l$ + sp + tlayout$: If i <> n Then l$ = l$ + sp2 + ","
                            e$ = evaluate(e$, t)
                            If Error_Happened Then GoTo errmes
                            If (t And ISREFERENCE) = 0 Then a$ = "Expected variable": GoTo errmes

                            If (t And ISSTRING) Then
                                e$ = refer(e$, t, 0)
                                If Error_Happened Then GoTo errmes
                                numvar = numvar + 1
                                If lineinput Then
                                    Print #12, "qbs_input_variabletypes[" + str2(numvar) + "]=ISSTRING+512;"
                                Else
                                    Print #12, "qbs_input_variabletypes[" + str2(numvar) + "]=ISSTRING;"
                                End If
                                Print #12, "qbs_input_variableoffsets[" + str2(numvar) + "]=" + e$ + ";"
                                GoTo gotinputvar
                            End If

                            If lineinput Then a$ = "Expected string variable": GoTo errmes
                            If (t And ISARRAY) Then
                                If (t And ISOFFSETINBITS) Then
                                    a$ = "INPUT cannot handle BIT array elements": GoTo errmes
                                End If
                            End If
                            e$ = "&(" + refer(e$, t, 0) + ")"
                            If Error_Happened Then GoTo errmes

                            'remove assumed/unnecessary flags
                            If (t And ISPOINTER) Then t = t - ISPOINTER
                            If (t And ISINCONVENTIONALMEMORY) Then t = t - ISINCONVENTIONALMEMORY
                            If (t And ISREFERENCE) Then t = t - ISREFERENCE

                            'IF (t AND ISOFFSETINBITS) THEN
                            'numvar = numvar + 1
                            'consider storing the bit offset in unused bits of t
                            'PRINT #12, "qbs_input_variabletypes[" + str2(numvar) + "]=" + str2(t) + ";"
                            'PRINT #12, "qbs_input_variableoffsets[" + str2(numvar) + "]=" + refer(ref$, typ, 1) + ";"
                            'GOTO gotinputvar
                            'END IF

                            'assume it is a regular variable
                            numvar = numvar + 1
                            Print #12, "qbs_input_variabletypes[" + str2(numvar) + "]=" + str2$(t) + ";"
                            Print #12, "qbs_input_variableoffsets[" + str2(numvar) + "]=" + e$ + ";"
                            GoTo gotinputvar

                        End If
                        gotinputvar:
                        commaneeded = commaneeded + 1: If commaneeded = 2 Then commaneeded = 0
                    Next
                    If numvar = 0 Then a$ = "Syntax error - Reference: INPUT [;] " + Chr$(34) + "[Question or statement text]" + Chr$(34) + "{,|;} variable[, ...] or INPUT ; variable[, ...]": GoTo errmes
                    If lineinput = 1 And numvar > 1 Then a$ = "Too many variables": GoTo errmes
                    Print #12, "qbs_input(" + str2(numvar) + "," + str2$(newline) + ");"
                    Print #12, "if (stop_program) end();"
                    Print #12, cleanupstringprocessingcall$ + "0);"
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                End If

                If firstelement$ = "WRITE" Then 'file write
                    If n > 1 Then
                        If getelement$(a$, 2) = "#" Then
                            xfilewrite ca$, n
                            If Error_Happened Then GoTo errmes
                            GoTo finishedline
                        End If '#
                    End If 'n>1
                End If '"write"

                If firstelement$ = "WRITE" Then 'write
                    xwrite ca$, n
                    If Error_Happened Then GoTo errmes
                    GoTo finishedline
                End If '"write"

                If firstelement$ = "PRINT" Then 'file print
                    If n > 1 Then
                        If getelement$(a$, 2) = "#" Then
                            xfileprint a$, ca$, n
                            If Error_Happened Then GoTo errmes
                            l$ = tlayout$
                            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                            GoTo finishedline
                        End If '#
                    End If 'n>1
                End If '"print"

                If firstelement$ = "PRINT" Or firstelement$ = "LPRINT" Then
                    If secondelement$ <> "USING" Then 'check to see if we need to auto-add semicolons
                        elementon = 2
                        redosemi:
                        For i = elementon To n - 1
                            nextchar$ = getelement$(a$, i + 1)
                            If nextchar$ <> ";" And nextchar$ <> "," And nextchar$ <> "+" And nextchar$ <> ")" Then
                                temp1$ = getelement$(a$, i)
                                beginpoint = InStr(beginpoint, temp1$, Chr$(34))
                                endpoint = InStr(beginpoint + 1, temp1$, Chr$(34) + ",")
                                If beginpoint <> 0 And endpoint <> 0 Then 'if we have both positions
                                    'Quote without semicolon check (like PRINT "abc"123)
                                    textlength = endpoint - beginpoint - 1
                                    textvalue$ = Mid$(temp1$, endpoint + 2, Len(LTrim$(Str$(textlength))))
                                    If Val(textvalue$) = textlength Then
                                        insertelements a$, i, ";"
                                        insertelements ca$, i, ";"
                                        n = n + 1
                                        elementon = i + 2 'just a easy way to reduce redundant calls to the routine
                                        GoTo redosemi
                                    End If
                                End If
                                If temp1$ <> "USING" Then
                                    If Left$(LTrim$(nextchar$), 1) = Chr$(34) Then
                                        If temp1$ <> ";" And temp1$ <> "," And temp1$ <> "+" And temp1$ <> "(" Then
                                            insertelements a$, i, ";"
                                            insertelements ca$, i, ";"
                                            n = n + 1
                                            elementon = i + 2 'just a easy way to reduce redundant calls to the routine
                                            GoTo redosemi
                                        End If
                                    End If
                                End If
                            End If
                        Next
                    End If

                    xprint a$, ca$, n
                    If Error_Happened Then GoTo errmes
                    l$ = tlayout$
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    GoTo finishedline
                End If

                If firstelement$ = "CLEAR" Then
                    If subfunc$ <> "" Then a$ = "CLEAR cannot be used inside a SUB/FUNCTION": GoTo errmes
                End If

                'LSET/RSET
                If firstelement$ = "LSET" Or firstelement$ = "RSET" Then
                    If n = 1 Then a$ = "Expected " + firstelement$ + " ...": GoTo errmes
                    If firstelement$ = "LSET" Then l$ = SCase$("LSet") Else l$ = SCase$("RSet")
                    dest$ = ""
                    source$ = ""
                    part = 1
                    i = 2
                    a3$ = ""
                    B = 0
                    Do
                        If i > n Then
                            If part <> 2 Or a3$ = "" Then a$ = "Expected LSET/RSET stringvariable=string": GoTo errmes
                            source$ = a3$
                            Exit Do
                        End If
                        a2$ = getelement$(ca$, i)
                        If a2$ = "(" Then B = B + 1
                        If a2$ = ")" Then B = B - 1
                        If a2$ = "=" And B = 0 Then
                            If part = 1 Then dest$ = a3$: part = 2: a3$ = "": GoTo lrsetgotpart
                        End If
                        If Len(a3$) Then a3$ = a3$ + sp + a2$ Else a3$ = a2$
                        lrsetgotpart:
                        i = i + 1
                    Loop
                    If dest$ = "" Then a$ = "Expected LSET/RSET stringvariable=string": GoTo errmes
                    'check if it is a valid source string
                    f$ = fixoperationorder$(dest$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$ + sp + "="
                    e$ = evaluate(f$, sourcetyp)
                    If Error_Happened Then GoTo errmes
                    If (sourcetyp And ISREFERENCE) = 0 Or (sourcetyp And ISSTRING) = 0 Then a$ = "LSET/RSET expects a string variable/array-element as its first argument": GoTo errmes
                    dest$ = evaluatetotyp(f$, ISSTRING)
                    If Error_Happened Then GoTo errmes
                    source$ = fixoperationorder$(source$)
                    If Error_Happened Then GoTo errmes
                    l$ = l$ + sp + tlayout$
                    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                    source$ = evaluatetotyp(source$, ISSTRING)
                    If Error_Happened Then GoTo errmes
                    If firstelement$ = "LSET" Then
                        Print #12, "sub_lset(" + dest$ + "," + source$ + ");"
                    Else
                        Print #12, "sub_rset(" + dest$ + "," + source$ + ");"
                    End If
                    GoTo finishedline
                End If

                'SWAP
                If firstelement$ = "SWAP" Then
                    If n < 4 Then a$ = "Expected SWAP ... , ...": GoTo errmes
                    B = 0
                    ele = 1
                    e1$ = ""
                    e2$ = ""
                    For i = 2 To n
                        e$ = getelement$(ca$, i)
                        If e$ = "(" Then B = B + 1
                        If e$ = ")" Then B = B - 1
                        If e$ = "," And B = 0 Then
                            If ele = 2 Then a$ = "Expected SWAP ... , ...": GoTo errmes
                            ele = 2
                        Else
                            If ele = 1 Then e1$ = e1$ + sp + e$ Else e2$ = e2$ + sp + e$
                        End If
                    Next
                    If e2$ = "" Then a$ = "Expected SWAP ... , ...": GoTo errmes
                    e1$ = Right$(e1$, Len(e1$) - 1): e2$ = Right$(e2$, Len(e2$) - 1)

                    e1$ = fixoperationorder(e1$)
                    If Error_Happened Then GoTo errmes
                    e1l$ = tlayout$
                    e2$ = fixoperationorder(e2$)
                    If Error_Happened Then GoTo errmes
                    e2l$ = tlayout$
                    e1$ = evaluate(e1$, e1typ): e2$ = evaluate(e2$, e2typ)
                    If Error_Happened Then GoTo errmes
                    If (e1typ And ISREFERENCE) = 0 Or (e2typ And ISREFERENCE) = 0 Then a$ = "Expected variable": GoTo errmes

                    layoutdone = 1
                    l$ = SCase$("Swap") + sp + e1l$ + sp2 + "," + sp + e2l$
                    If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$

                    'swap strings?
                    If (e1typ And ISSTRING) Then
                        If (e2typ And ISSTRING) = 0 Then a$ = "Type mismatch": GoTo errmes
                        e1$ = refer(e1$, e1typ, 0): e2$ = refer(e2$, e2typ, 0)
                        If Error_Happened Then GoTo errmes
                        Print #12, "swap_string(" + e1$ + "," + e2$ + ");"
                        GoTo finishedline
                    End If

                    'swap UDT?
                    'note: entire UDTs, unlike thier elements cannot be swapped like standard variables
                    '      as UDT sizes may vary, and to avoid a malloc operation, QB64 should allocate a buffer
                    '      in global.txt for the purpose of swapping each UDT type

                    If e1typ And ISUDT Then
                        a$ = e1$
                        'retrieve ID
                        i = InStr(a$, sp3)
                        If i Then
                            idnumber = Val(Left$(a$, i - 1)): a$ = Right$(a$, Len(a$) - i)
                            getid idnumber
                            If Error_Happened Then GoTo errmes
                            u = Val(a$)
                            i = InStr(a$, sp3): a$ = Right$(a$, Len(a$) - i): E = Val(a$)
                            i = InStr(a$, sp3): o$ = Right$(a$, Len(a$) - i)
                            n$ = "UDT_" + RTrim$(id.n): If id.t = 0 Then n$ = "ARRAY_" + n$ + "[0]"
                            If E = 0 Then 'not an element of UDT u
                                lhsscope$ = scope$
                                e$ = e2$: t2 = e2typ
                                If (t2 And ISUDT) = 0 Then a$ = "Expected SWAP with similar user defined type": GoTo errmes
                                idnumber2 = Val(e$)
                                getid idnumber2
                                If Error_Happened Then GoTo errmes
                                n2$ = "UDT_" + RTrim$(id.n): If id.t = 0 Then n2$ = "ARRAY_" + n2$ + "[0]"
                                i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i): u2 = Val(e$)
                                i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i): e2 = Val(e$)

                                i = InStr(e$, sp3): o2$ = Right$(e$, Len(e$) - i)
                                'WARNING: u2 may need minor modifications based on e to see if they are the same
                                If u <> u2 Or e2 <> 0 Then a$ = "Expected SWAP with similar user defined type": GoTo errmes
                                dst$ = "(((char*)" + lhsscope$ + n$ + ")+(" + o$ + "))"
                                src$ = "(((char*)" + scope$ + n2$ + ")+(" + o2$ + "))"
                                B = udtxsize(u) \ 8
                                siz$ = str2$(B)
                                If B = 1 Then Print #12, "swap_8(" + src$ + "," + dst$ + ");"
                                If B = 2 Then Print #12, "swap_16(" + src$ + "," + dst$ + ");"
                                If B = 4 Then Print #12, "swap_32(" + src$ + "," + dst$ + ");"
                                If B = 8 Then Print #12, "swap_64(" + src$ + "," + dst$ + ");"
                                If B <> 1 And B <> 2 And B <> 4 And B <> 8 Then Print #12, "swap_block(" + src$ + "," + dst$ + "," + siz$ + ");"
                                GoTo finishedline
                            End If 'e=0
                        End If 'i
                    End If 'isudt

                    'cull irrelavent flags to make comparison possible
                    e1typc = e1typ
                    If e1typc And ISPOINTER Then e1typc = e1typc - ISPOINTER
                    If e1typc And ISINCONVENTIONALMEMORY Then e1typc = e1typc - ISINCONVENTIONALMEMORY
                    If e1typc And ISARRAY Then e1typc = e1typc - ISARRAY
                    If e1typc And ISUNSIGNED Then e1typc = e1typc - ISUNSIGNED
                    If e1typc And ISUDT Then e1typc = e1typc - ISUDT
                    e2typc = e2typ
                    If e2typc And ISPOINTER Then e2typc = e2typc - ISPOINTER
                    If e2typc And ISINCONVENTIONALMEMORY Then e2typc = e2typc - ISINCONVENTIONALMEMORY
                    If e2typc And ISARRAY Then e2typc = e2typc - ISARRAY
                    If e2typc And ISUNSIGNED Then e2typc = e2typc - ISUNSIGNED
                    If e2typc And ISUDT Then e2typc = e2typc - ISUDT
                    If e1typc <> e2typc Then a$ = "Type mismatch": GoTo errmes
                    t = e1typ
                    If t And ISOFFSETINBITS Then a$ = "Cannot SWAP bit-length variables": GoTo errmes
                    B = t And 511
                    t$ = str2$(B): If B > 64 Then t$ = "longdouble"
                    Print #12, "swap_" + t$ + "(&" + refer(e1$, e1typ, 0) + ",&" + refer(e2$, e2typ, 0) + ");"
                    If Error_Happened Then GoTo errmes
                    GoTo finishedline
                End If

                If firstelement$ = "OPTION" Then
                    If optionexplicit = 0 Then e$ = " or OPTION " + qb64prefix$ + "EXPLICIT" Else e$ = ""
                    If optionexplicitarray = 0 Then e$ = e$ + " or OPTION " + qb64prefix$ + "EXPLICITARRAY"
                    If n = 1 Then a$ = "Expected OPTION BASE" + e$: GoTo errmes
                    e$ = getelement$(a$, 2)
                    Select Case e$
                        Case "BASE"
                            l$ = getelement$(a$, 3)
                            If l$ <> "0" And l$ <> "1" Then a$ = "Expected OPTION BASE 0 or 1": GoTo errmes
                            If l$ = "1" Then optionbase = 1 Else optionbase = 0
                            l$ = SCase$("Option" + sp + "Base") + sp + l$
                            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                            GoTo finishedline
                        Case "EXPLICIT", "_EXPLICIT"
                            If e$ = "EXPLICIT" And qb64prefix$ = "_" Then
                                If optionexplicit = 0 Then e$ = " or OPTION " + qb64prefix$ + "EXPLICIT" Else e$ = ""
                                If optionexplicitarray = 0 Then e$ = e$ + " or OPTION " + qb64prefix$ + "EXPLICITARRAY"
                                a$ = "Expected OPTION BASE" + e$: GoTo errmes
                            End If

                            opex_desiredState = -1
                            If optionexplicit = 0 Then
                                If opex_recompileAttempts = 0 Then
                                    opex_recompileAttempts = opex_recompileAttempts + 1
                                    GoTo do_recompile
                                End If
                            End If

                            l$ = SCase$("Option") + sp
                            If e$ = "EXPLICIT" Then l$ = l$ + SCase$("Explicit") Else l$ = l$ + SCase$("_Explicit")
                            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                            GoTo finishedline
                        Case "EXPLICITARRAY", "_EXPLICITARRAY"
                            If e$ = "EXPLICITARRAY" And qb64prefix$ = "_" Then
                                If optionexplicit = 0 Then e$ = " or OPTION " + qb64prefix$ + "EXPLICIT" Else e$ = ""
                                If optionexplicitarray = 0 Then e$ = e$ + " or OPTION " + qb64prefix$ + "EXPLICITARRAY"
                                a$ = "Expected OPTION BASE" + e$: GoTo errmes
                            End If

                            opexarray_desiredState = -1
                            If optionexplicitarray = 0 Then
                                If opexarray_recompileAttempts = 0 Then
                                    opexarray_recompileAttempts = opexarray_recompileAttempts + 1
                                    GoTo do_recompile
                                End If
                            End If

                            l$ = SCase$("Option") + sp
                            If e$ = "EXPLICITARRAY" Then l$ = l$ + SCase$("ExplicitArray") Else l$ = l$ + SCase$("_ExplicitArray")
                            layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
                            GoTo finishedline
                        Case Else
                            If optionexplicit = 0 Then e$ = " or OPTION " + qb64prefix$ + "EXPLICIT" Else e$ = ""
                            If optionexplicitarray = 0 Then e$ = e$ + " or OPTION " + qb64prefix$ + "EXPLICITARRAY"
                            a$ = "Expected OPTION BASE" + e$: GoTo errmes
                    End Select
                End If

                'any other "unique" subs can be processed above

                id2 = id

                targetid = currentid

                If RTrim$(id2.callname) = "sub_stub" Then a$ = "Command not implemented": GoTo errmes

                If n > 1 Then
                    If id2.args = 0 Then a$ = "SUB does not require any arguments": GoTo errmes
                End If

                SetDependency id2.Dependency

                seperateargs_error = 0
                passedneeded = seperateargs(getelements(a$, 2, n), getelements(ca$, 2, n), passed&)
                If seperateargs_error Then a$ = seperateargs_error_message: GoTo errmes

                'backup args to local string array space before calling evaluate
                For i = 1 To OptMax: separgs2(i) = "": Next 'save space!
                For i = 1 To OptMax + 1: separgslayout2(i) = "": Next
                For i = 1 To id2.args: separgs2(i) = separgs(i): Next
                For i = 1 To id2.args + 1: separgslayout2(i) = separgslayout(i): Next

                'note: seperateargs finds the arguments to pass and sets passed& as necessary
                '      FIXOPERTIONORDER is not called on these args yet
                '      what we need it to do is build a second array of layout info at the same time
                '   ref:DIM SHARED separgslayout(100) AS STRING
                '   the above array stores what layout info (if any) goes BEFORE the arg in question
                '       it has one extra index which is the arg after

                If usecall Then
                    If id.internal_subfunc Then
                        If usecall = 1 Then l$ = SCase$("Call") + sp + SCase$(RTrim$(id.cn)) + RTrim$(id.musthave) + sp2 + "(" + sp2
                        If usecall = 2 Then l$ = SCase$("Call") + sp + SCase$(RTrim$(id.cn)) + RTrim$(id.musthave) + sp 'sp at end for easy parsing
                    Else
                        If usecall = 1 Then l$ = SCase$("Call") + sp + RTrim$(id.cn) + RTrim$(id.musthave) + sp2 + "(" + sp2
                        If usecall = 2 Then l$ = SCase$("Call") + sp + RTrim$(id.cn) + RTrim$(id.musthave) + sp 'sp at end for easy parsing
                    End If
                Else
                    If id.internal_subfunc Then
                        l$ = SCase$(RTrim$(id.cn)) + RTrim$(id.musthave) + sp
                    Else
                        l$ = RTrim$(id.cn) + RTrim$(id.musthave) + sp
                    End If
                End If

                subcall$ = RTrim$(id.callname) + "("
                addedlayout = 0

                fieldcall = 0
                'GET/PUT field exception
                If RTrim$(id2.callname) = "sub_get" Or RTrim$(id2.callname) = "sub_put" Then
                    If passed And 2 Then
                        'regular GET/PUT call with variable provided
                        passed = passed - 2 'for complience with existing methods, remove 'passed' flag for the passing of a variable
                    Else
                        'FIELD GET/PUT call with variable omited
                        If RTrim$(id2.callname) = "sub_get" Then
                            fieldcall = 1
                            subcall$ = "field_get("
                        Else
                            fieldcall = 2
                            subcall$ = "field_put("
                        End If
                    End If
                End If 'field exception

                If RTrim$(id2.callname) = "sub_timer" Or RTrim$(id2.callname) = "sub_key" Then 'spacing exception
                    If usecall = 0 Then
                        l$ = Left$(l$, Len(l$) - 1) + sp2
                    End If
                End If

                For i = 1 To id2.args
                    targettyp = CVL(Mid$(id2.arg, -3 + i * 4, 4))
                    nele = Asc(Mid$(id2.nele, i, 1))
                    nelereq = Asc(Mid$(id2.nelereq, i, 1))

                    addlayout = 1 'omits option values in layout (eg. BINARY="2")
                    convertspacing = 0 'if an 'equation' is next, it will be preceeded by a space
                    x$ = separgslayout2$(i)
                    Do While Len(x$)
                        x = Asc(x$)
                        If x Then
                            convertspacing = 0
                            x2$ = Mid$(x$, 2, x)
                            x$ = Right$(x$, Len(x$) - x - 1)

                            s = 0
                            an = 0
                            x3$ = Right$(l$, 1)
                            If x3$ = sp Then s = 1
                            If x3$ = sp2 Then
                                s = 2
                                If alphanumeric(Asc(Right$(l$, 2))) Then an = 1
                            Else
                                If alphanumeric(Asc(x3$)) Then an = 1
                            End If
                            s1 = s

                            If alphanumeric(Asc(x2$)) Then convertspacing = 1

                            If (an = 1 Or addedlayout = 1) And alphanumeric(Asc(x2$)) <> 0 Then
                                s = 1 'force space
                                x2$ = x2$ + sp2
                                GoTo customlaychar
                            End If

                            If x2$ = "=" Then
                                s = 1
                                x2$ = x2$ + sp
                                GoTo customlaychar
                            End If

                            If x2$ = "#" Then
                                s = 1
                                x2$ = x2$ + sp2
                                GoTo customlaychar
                            End If

                            If x2$ = "," Then x2$ = x2$ + sp: GoTo customlaychar


                            If x$ = Chr$(0) Then 'substitution
                                If x2$ = "STEP" Then x2$ = x2$ + sp2: GoTo customlaychar
                                x2$ = x2$ + sp: GoTo customlaychar
                            End If

                            'default solution sp2+?+sp2
                            x2$ = x2$ + sp2

                            customlaychar:
                            If s = 0 Then s = 2
                            If s <> s1 Then
                                If s1 Then l$ = Left$(l$, Len(l$) - 1)
                                If s = 1 Then l$ = l$ + sp
                                If s = 2 Then l$ = l$ + sp2
                            End If

                            If (RTrim$(id2.callname) = "sub_timer" Or RTrim$(id2.callname) = "sub_key") And i = id2.args Then 'spacing exception
                                If x2$ <> ")" + sp2 Then
                                    l$ = Left$(l$, Len(l$) - 1) + sp
                                End If
                            End If

                            l$ = l$ + x2$
                        Else
                            addlayout = 0
                            x$ = Right$(x$, Len(x$) - 1)
                        End If
                        addedlayout = 0
                    Loop

                    '---better sub syntax checking begins here---

                    If targettyp = -3 Then
                        If separgs2(i) = "N-LL" Then a$ = "Expected array name": GoTo errmes
                        'names of numeric arrays have ( ) automatically appended (nothing else)
                        e$ = separgs2(i)

                        If InStr(e$, sp) = 0 Then 'one element only
                            try_string$ = e$
                            try = findid(try_string$)
                            If Error_Happened Then GoTo errmes
                            Do
                                If try Then
                                    If id.arraytype Then
                                        If (id.arraytype And ISSTRING) = 0 Then
                                            e$ = e$ + sp + "(" + sp + ")"
                                            Exit Do
                                        End If
                                    End If
                                    '---
                                    If try = 2 Then findanotherid = 1: try = findid(try_string$) Else try = 0
                                    If Error_Happened Then GoTo errmes
                                End If 'if try
                                If try = 0 Then 'add symbol?
                                    If Len(removesymbol$(try_string$)) = 0 Then
                                        If Error_Happened Then GoTo errmes
                                        a = Asc(try_string$)
                                        If a >= 97 And a <= 122 Then a = a - 32
                                        If a = 95 Then a = 91
                                        a = a - 64
                                        If Len(defineextaz(a)) Then try_string$ = try_string$ + defineextaz(a): try = findid(try_string$)
                                        If Error_Happened Then GoTo errmes
                                    End If
                                End If 'try=0
                            Loop Until try = 0
                        End If 'one element only

                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then GoTo errmes
                        If convertspacing = 1 And addlayout = 1 Then l$ = Left$(l$, Len(l$) - 1) + sp
                        If addlayout Then l$ = l$ + tlayout$: addedlayout = 1
                        e$ = evaluatetotyp(e$, -2)
                        If Error_Happened Then GoTo errmes
                        GoTo sete
                    End If '-3

                    If targettyp = -2 Then
                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then GoTo errmes
                        If convertspacing = 1 And addlayout = 1 Then l$ = Left$(l$, Len(l$) - 1) + sp
                        If addlayout Then l$ = l$ + tlayout$: addedlayout = 1
                        e$ = evaluatetotyp(e$, -2)
                        If Error_Happened Then GoTo errmes
                        GoTo sete
                    End If '-2

                    If targettyp = -4 Then

                        If fieldcall Then
                            i = id2.args + 1
                            Exit For
                        End If

                        If separgs2(i) = "N-LL" Then a$ = "Expected variable name/array element": GoTo errmes
                        e$ = fixoperationorder$(separgs2(i))
                        If Error_Happened Then GoTo errmes
                        If convertspacing = 1 And addlayout = 1 Then l$ = Left$(l$, Len(l$) - 1) + sp
                        If addlayout Then l$ = l$ + tlayout$: addedlayout = 1

                        'GET/PUT RANDOM-ACCESS override
                        If firstelement$ = "GET" Or firstelement$ = "PUT" Then
                            e2$ = e$ 'backup
                            e$ = evaluate(e$, sourcetyp)
                            If Error_Happened Then GoTo errmes
                            If (sourcetyp And ISSTRING) Then
                                If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                                    'replace name of sub to call
                                    subcall$ = Right$(subcall$, Len(subcall$) - 7) 'delete original name
                                    'note: GET2 & PUT2 take differing input, following code is correct
                                    If firstelement$ = "GET" Then
                                        subcall$ = "sub_get2" + subcall$
                                        e$ = refer(e$, sourcetyp, 0) 'pass a qbs pointer instead
                                        If Error_Happened Then GoTo errmes
                                        GoTo sete
                                    Else
                                        subcall$ = "sub_put2" + subcall$
                                        'no goto sete required, fall through
                                    End If
                                End If
                            End If
                            e$ = e2$ 'restore
                        End If 'override

                        e$ = evaluatetotyp(e$, -4)
                        If Error_Happened Then GoTo errmes
                        GoTo sete
                    End If '-4

                    If separgs2(i) = "N-LL" Then
                        e$ = "NULL"
                    Else

                        e2$ = fixoperationorder$(separgs2(i))
                        If Error_Happened Then GoTo errmes
                        If convertspacing = 1 And addlayout = 1 Then l$ = Left$(l$, Len(l$) - 1) + sp
                        If addlayout Then l$ = l$ + tlayout$: addedlayout = 1

                        e$ = evaluate(e2$, sourcetyp)
                        If Error_Happened Then GoTo errmes

                        If sourcetyp And ISOFFSET Then
                            If (targettyp And ISOFFSET) = 0 Then
                                If id2.internal_subfunc = 0 Then a$ = "Cannot convert _OFFSET type to other types": GoTo errmes
                            End If
                        End If

                        If RTrim$(id2.callname) = "sub_paint" Then
                            If i = 3 Then
                                If (sourcetyp And ISSTRING) Then
                                    targettyp = ISSTRING
                                End If
                            End If
                        End If

                        If Left$(separgs2(i), 2) = "(" + sp Then dereference = 1 Else dereference = 0

                        'pass by reference
                        If (targettyp And ISPOINTER) Then
                            If dereference = 0 Then 'check deferencing wasn't used

                                'note: array pointer
                                If (targettyp And ISARRAY) Then
                                    If (sourcetyp And ISREFERENCE) = 0 Then a$ = "Expected arrayname()": GoTo errmes
                                    If (sourcetyp And ISARRAY) = 0 Then a$ = "Expected arrayname()": GoTo errmes

                                    'check arrays are of same type
                                    targettyp2 = targettyp: sourcetyp2 = sourcetyp
                                    targettyp2 = targettyp2 And (511 + ISOFFSETINBITS + ISUDT + ISSTRING + ISFIXEDLENGTH + ISFLOAT)
                                    sourcetyp2 = sourcetyp2 And (511 + ISOFFSETINBITS + ISUDT + ISSTRING + ISFIXEDLENGTH + ISFLOAT)
                                    If sourcetyp2 <> targettyp2 Then a$ = "Incorrect array type passed to sub": GoTo errmes

                                    'check arrayname was followed by '()'
                                    If targettyp And ISUDT Then
                                        'get UDT info
                                        udtrefid = Val(e$)
                                        getid udtrefid
                                        If Error_Happened Then GoTo errmes
                                        udtrefi = InStr(e$, sp3) 'end of id
                                        udtrefi2 = InStr(udtrefi + 1, e$, sp3) 'end of u
                                        udtrefu = Val(Mid$(e$, udtrefi + 1, udtrefi2 - udtrefi - 1))
                                        udtrefi3 = InStr(udtrefi2 + 1, e$, sp3) 'skip e
                                        udtrefe = Val(Mid$(e$, udtrefi2 + 1, udtrefi3 - udtrefi2 - 1))
                                        o$ = Right$(e$, Len(e$) - udtrefi3)
                                        'note: most of the UDT info above is not required
                                        If Left$(o$, 4) <> "(0)*" Then a$ = "Expected arrayname()": GoTo errmes
                                    Else
                                        If Right$(e$, 2) <> sp3 + "0" Then a$ = "Expected arrayname()": GoTo errmes
                                    End If

                                    idnum = Val(Left$(e$, InStr(e$, sp3) - 1))
                                    getid idnum
                                    If Error_Happened Then GoTo errmes

                                    If targettyp And ISFIXEDLENGTH Then
                                        targettypsize = CVL(Mid$(id2.argsize, i * 4 - 4 + 1, 4))
                                        If id.tsize <> targettypsize Then a$ = "Incorrect array type passed to sub": GoTo errmes
                                    End If

                                    If Mid$(sfcmemargs(targetid), i, 1) = Chr$(1) Then 'cmem required?
                                        If cmemlist(idnum) = 0 Then
                                            cmemlist(idnum) = 1
                                            recompile = 1
                                        End If
                                    End If

                                    If id.linkid = 0 Then
                                        'if id.linkid is 0, it means the number of array elements is definietly
                                        'known of the array being passed, this is not some "fake"/unknown array.
                                        'using the numer of array elements of a fake array would be dangerous!

                                        If nelereq = 0 Then
                                            'only continue if the number of array elements required is unknown
                                            'and it needs to be set

                                            If id.arrayelements > 0 Then '2009

                                                nelereq = id.arrayelements
                                                Mid$(id2.nelereq, i, 1) = Chr$(nelereq)

                                            End If

                                            'print rtrim$(id2.n)+">nelereq=";nelereq

                                            ids(targetid) = id2
                                        Else
                                            'the number of array elements required is known AND
                                            'the number of elements in the array to be passed is known

                                            If id.arrayelements <> nelereq Then a$ = "Passing arrays with a differing number of elements to a SUB/FUNCTION is not supported": GoTo errmes
                                        End If
                                    End If

                                    e$ = refer(e$, sourcetyp, 1)
                                    If Error_Happened Then GoTo errmes
                                    GoTo sete

                                End If 'target is an array

                                'note: not an array...
                                'target is not an array

                                If (targettyp And ISSTRING) = 0 Then
                                    If (sourcetyp And ISREFERENCE) Then
                                        idnum = Val(Left$(e$, InStr(e$, sp3) - 1)) 'id# of sourcetyp

                                        targettyp2 = targettyp: sourcetyp2 = sourcetyp

                                        'get info about source/target
                                        arr = 0: If (sourcetyp2 And ISARRAY) Then arr = 1
                                        passudtelement = 0: If (targettyp2 And ISUDT) = 0 And (sourcetyp2 And ISUDT) <> 0 Then passudtelement = 1: sourcetyp2 = sourcetyp2 - ISUDT

                                        'remove flags irrelevant for comparison... ISPOINTER,ISREFERENCE,ISINCONVENTIONALMEMORY,ISARRAY
                                        targettyp2 = targettyp2 And (511 + ISOFFSETINBITS + ISUDT + ISFLOAT + ISSTRING)
                                        sourcetyp2 = sourcetyp2 And (511 + ISOFFSETINBITS + ISUDT + ISFLOAT + ISSTRING)

                                        'compare types
                                        If sourcetyp2 = targettyp2 Then

                                            If sourcetyp And ISUDT Then
                                                'udt/udt array

                                                'get info
                                                udtrefid = Val(e$)
                                                getid udtrefid
                                                If Error_Happened Then GoTo errmes
                                                udtrefi = InStr(e$, sp3) 'end of id
                                                udtrefi2 = InStr(udtrefi + 1, e$, sp3) 'end of u
                                                udtrefu = Val(Mid$(e$, udtrefi + 1, udtrefi2 - udtrefi - 1))
                                                udtrefi3 = InStr(udtrefi2 + 1, e$, sp3) 'skip e
                                                udtrefe = Val(Mid$(e$, udtrefi2 + 1, udtrefi3 - udtrefi2 - 1))
                                                o$ = Right$(e$, Len(e$) - udtrefi3)
                                                'note: most of the UDT info above is not required

                                                If arr Then
                                                    n$ = scope$ + "ARRAY_UDT_" + RTrim$(id.n) + "[0]"
                                                Else
                                                    n$ = scope$ + "UDT_" + RTrim$(id.n)
                                                End If

                                                e$ = "(void*)( ((char*)(" + n$ + ")) + (" + o$ + ") )"

                                                'convert void* to target type*
                                                If passudtelement Then e$ = "(" + typ2ctyp$(targettyp2 + (targettyp And ISUNSIGNED), "") + "*)" + e$
                                                If Error_Happened Then GoTo errmes

                                            Else
                                                'not a udt
                                                If arr Then
                                                    If (sourcetyp2 And ISOFFSETINBITS) Then a$ = "Cannot pass BIT array offsets": GoTo errmes
                                                    e$ = "(&(" + refer(e$, sourcetyp, 0) + "))"
                                                    If Error_Happened Then GoTo errmes
                                                Else
                                                    e$ = refer(e$, sourcetyp, 1)
                                                    If Error_Happened Then GoTo errmes
                                                End If

                                                'note: signed/unsigned mismatch requires casting
                                                If (sourcetyp And ISUNSIGNED) <> (targettyp And ISUNSIGNED) Then
                                                    e$ = "(" + typ2ctyp$(targettyp2 + (targettyp And ISUNSIGNED), "") + "*)" + e$
                                                    If Error_Happened Then GoTo errmes
                                                End If

                                            End If 'udt?

                                            If Mid$(sfcmemargs(targetid), i, 1) = Chr$(1) Then 'cmem required?
                                                If cmemlist(idnum) = 0 Then
                                                    cmemlist(idnum) = 1
                                                    recompile = 1
                                                End If
                                            End If

                                            GoTo sete
                                        End If 'similar
                                    End If 'reference
                                Else 'not a string
                                    'its a string
                                    If (sourcetyp And ISREFERENCE) Then
                                        idnum = Val(Left$(e$, InStr(e$, sp3) - 1)) 'id# of sourcetyp
                                        If Mid$(sfcmemargs(targetid), i, 1) = Chr$(1) Then 'cmem required?
                                            If cmemlist(idnum) = 0 Then
                                                cmemlist(idnum) = 1
                                                recompile = 1
                                            End If
                                        End If
                                    End If 'reference
                                End If 'its a string

                            End If 'dereference check
                        End If 'target is a pointer

                        'note: Target is not a pointer...

                        'String-numeric mismatch?
                        If targettyp And ISSTRING Then
                            If (sourcetyp And ISSTRING) = 0 Then
                                nth = i
                                If ids(targetid).args = 1 Then a$ = "String required for sub": GoTo errmes
                                a$ = str_nth$(nth) + " sub argument requires a string": GoTo errmes
                            End If
                        End If
                        If (targettyp And ISSTRING) = 0 Then
                            If sourcetyp And ISSTRING Then
                                nth = i
                                If ids(targetid).args = 1 Then a$ = "Number required for sub": GoTo errmes
                                a$ = str_nth$(nth) + " sub argument requires a number": GoTo errmes
                            End If
                        End If

                        'change to "non-pointer" value
                        If (sourcetyp And ISREFERENCE) Then
                            e$ = refer(e$, sourcetyp, 0)
                            If Error_Happened Then GoTo errmes
                        End If

                        If explicitreference = 0 Then
                            If targettyp And ISUDT Then
                                nth = i
                                x$ = "'" + RTrim$(udtxcname(targettyp And 511)) + "'"
                                If ids(targetid).args = 1 Then a$ = "TYPE " + x$ + " required for sub": GoTo errmes
                                a$ = str_nth$(nth) + " sub argument requires TYPE " + x$: GoTo errmes
                            End If
                        Else
                            If sourcetyp And ISUDT Then a$ = "Number required for sub": GoTo errmes
                        End If

                        'round to integer if required
                        If (sourcetyp And ISFLOAT) Then
                            If (targettyp And ISFLOAT) = 0 Then
                                '**32 rounding fix
                                bits = targettyp And 511
                                If bits <= 16 Then e$ = "qbr_float_to_long(" + e$ + ")"
                                If bits > 16 And bits < 32 Then e$ = "qbr_double_to_long(" + e$ + ")"
                                If bits >= 32 Then e$ = "qbr(" + e$ + ")"
                            End If
                        End If

                        If (targettyp And ISPOINTER) Then 'pointer required
                            If (targettyp And ISSTRING) Then GoTo sete 'no changes required
                            t$ = typ2ctyp$(targettyp, "")
                            If Error_Happened Then GoTo errmes
                            v$ = "pass" + str2$(uniquenumber)
                            'assume numeric type
                            If Mid$(sfcmemargs(targetid), i, 1) = Chr$(1) Then 'cmem required?
                                bytesreq = ((targettyp And 511) + 7) \ 8
                                Print #defdatahandle, t$ + " *" + v$ + "=NULL;"
                                Print #13, "if(" + v$ + "==NULL){"
                                Print #13, "cmem_sp-=" + str2(bytesreq) + ";"
                                Print #13, v$ + "=(" + t$ + "*)(dblock+cmem_sp);"
                                Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                                Print #13, "}"
                                e$ = "&(*" + v$ + "=" + e$ + ")"
                            Else
                                Print #13, t$ + " " + v$ + ";"
                                e$ = "&(" + v$ + "=" + e$ + ")"
                            End If
                            GoTo sete
                        End If

                    End If 'not "NULL"

                    sete:

                    If RTrim$(id2.callname) = "sub_paint" Then
                        If i = 3 Then
                            If (sourcetyp And ISSTRING) Then
                                e$ = "(qbs*)" + e$
                            Else
                                e$ = "(uint32)" + e$
                            End If
                        End If
                    End If

                    If id2.ccall Then
                        'if a forced cast from a returned ccall function is in e$, remove it
                        If Left$(e$, 3) = "(  " Then
                            e$ = removecast$(e$)
                        End If

                        If targettyp And ISSTRING Then
                            e$ = "(char*)(" + e$ + ")->chr"
                        End If

                        If LTrim$(RTrim$(e$)) = "0" Then e$ = "NULL"
                    End If

                    If i <> 1 Then subcall$ = subcall$ + ","
                    subcall$ = subcall$ + e$
                Next

                'note: i=id.args+1
                x$ = separgslayout2$(i)
                Do While Len(x$)
                    x = Asc(x$)
                    If x Then
                        x2$ = Mid$(x$, 2, x)
                        x$ = Right$(x$, Len(x$) - x - 1)

                        s = 0
                        an = 0
                        x3$ = Right$(l$, 1)
                        If x3$ = sp Then s = 1
                        If x3$ = sp2 Then
                            s = 2
                            If alphanumeric(Asc(Right$(l$, 2))) Then an = 1
                            'if asc(right$(l$,2))=34 then an=1
                        Else
                            If alphanumeric(Asc(x3$)) Then an = 1
                            'if asc(x3$)=34 then an=1
                        End If
                        s1 = s

                        If (an = 1 Or addedlayout = 1) And alphanumeric(Asc(x2$)) <> 0 Then
                            s = 1 'force space
                            x2$ = x2$ + sp2
                            GoTo customlaychar2
                        End If

                        If x2$ = "=" Then
                            s = 1
                            x2$ = x2$ + sp
                            GoTo customlaychar2
                        End If

                        If x2$ = "#" Then
                            s = 1
                            x2$ = x2$ + sp2
                            GoTo customlaychar2
                        End If

                        If x2$ = "," Then x2$ = x2$ + sp: GoTo customlaychar2

                        If x$ = Chr$(0) Then 'substitution
                            If x2$ = "STEP" Then x2$ = SCase$("Step") + sp2: GoTo customlaychar2
                            x2$ = x2$ + sp: GoTo customlaychar2
                        End If

                        'default solution sp2+?+sp2
                        x2$ = x2$ + sp2
                        customlaychar2:
                        If s = 0 Then s = 2
                        If s <> s1 Then
                            If s1 Then l$ = Left$(l$, Len(l$) - 1)
                            If s = 1 Then l$ = l$ + sp
                            If s = 2 Then l$ = l$ + sp2
                        End If
                        l$ = l$ + x2$

                    Else
                        addlayout = 0
                        x$ = Right$(x$, Len(x$) - 1)
                    End If
                    addedlayout = 0
                Loop

                If passedneeded Then
                    subcall$ = subcall$ + "," + str2$(passed&)
                End If
                subcall$ = subcall$ + ");"

                Print #12, subcall$

                subcall$ = ""
                If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"

                layoutdone = 1
                x$ = Right$(l$, 1): If x$ = sp Or x$ = sp2 Then l$ = Left$(l$, Len(l$) - 1)
                If usecall = 1 Then l$ = l$ + sp2 + ")"
                If Len(layout$) = 0 Then layout$ = l$ Else layout$ = layout$ + sp + l$
                GoTo finishedline
            End If

            If try = 2 Then
                findidsecondarg = "": If n >= 2 Then findidsecondarg = getelement$(a$, 2)
                findanotherid = 1
                try = findid(firstelement$)
                If Error_Happened Then GoTo errmes
            Else
                try = 0
            End If
        Loop

    End If

    notsubcall:

    If n >= 1 Then
        If firstelement$ = "LET" Then
            If n = 1 Then a$ = "Syntax error - Reference: LET variable = expression (tip: LET is entirely optional)": GoTo errmes
            ca$ = Right$(ca$, Len(ca$) - 4)
            n = n - 1
            l$ = SCase$("Let")
            If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
            'note: layoutdone=1 will be set later
            GoTo letused
        End If
    End If

    'LET ???=???
    If n >= 3 Then
        If InStr(a$, sp + "=" + sp) Then
            letused:
            assign ca$, n
            If Error_Happened Then GoTo errmes
            layoutdone = 1
            If Len(layout$) = 0 Then layout$ = tlayout$ Else layout$ = layout$ + sp + tlayout$
            GoTo finishedline
        End If
    End If '>=3
    If Right$(a$, 2) = sp + "=" Then a$ = "Expected ... = expression": GoTo errmes

    'Syntax error
    a$ = "Syntax error": GoTo errmes

    finishedline:
    THENGOTO = 0
    finishedline2:

    If inputfunctioncalled Then
        inputfunctioncalled = 0
    End If

    If arrayprocessinghappened = 1 Then arrayprocessinghappened = 0

    inclinenump$ = ""
    If inclinenumber(inclevel) Then
        inclinenump$ = "," + str2$(inclinenumber(inclevel))
        thisincname$ = getfilepath$(incname$(inclevel))
        thisincname$ = Mid$(incname$(inclevel), Len(thisincname$) + 1)
        inclinenump$ = inclinenump$ + "," + Chr$(34) + thisincname$ + Chr$(34)
    End If
    If NoChecks = 0 Then
        temp$ = ""
        If dynscope Then
            dynscope = 0
            Print #12, "if(qbevent){" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");if(r)goto S_" + str2$(statementn) + ";}"
        Else
            Print #12, "if(!qbevent)break;" + temp$ + "evnt(" + str2$(linenumber) + inclinenump$ + ");}while(r);"
        End If
    End If

    finishednonexec:

    firstLine = 0

    If layoutdone = 0 Then layoutok = 0 'invalidate layout if not handled

    If continuelinefrom = 0 Then 'note: manager #2 requires this condition

        'Include Manager #2 '***
        If Len(addmetainclude$) Then

            If inclevel = 0 Then
                'backup line formatting
                layoutcomment_backup$ = layoutcomment$
                layoutok_backup = layoutok
                layout_backup$ = layout$
            End If

            a$ = addmetainclude$: addmetainclude$ = "" 'read/clear message

            If inclevel = 0 Then
                includingFromRoot = 0
                forceIncludingFile = 0
                forceInclude:
                If forceIncludeFromRoot$ <> "" Then
                    a$ = forceIncludeFromRoot$
                    forceIncludeFromRoot$ = ""
                    forceIncludingFile = 1
                    includingFromRoot = 1
                End If
            End If

            If inclevel = 100 Then a$ = "Too many indwelling INCLUDE files": GoTo errmes
            '1. Verify file exists (location is either (a)relative to source file or (b)absolute)
            fh = 99 + inclevel + 1

            firstTryMethod = 1
            If includingFromRoot <> 0 And inclevel = 0 Then firstTryMethod = 2
            For try = firstTryMethod To 2 'if including file from root, do not attempt including from relative location
                If try = 1 Then
                    If inclevel = 0 Then
                        If idemode Then p$ = idepath$ + pathsep$ Else p$ = getfilepath$(sourcefile$)
                    Else
                        p$ = getfilepath$(incname(inclevel))
                    End If
                    f$ = p$ + a$
                End If
                If try = 2 Then f$ = a$
                If _FileExists(f$) Then
                    qberrorhappened = -2 '***
                    Open f$ For Binary As #fh
                    qberrorhappened2: '***
                    If qberrorhappened = -2 Then Exit For '***
                End If
                qberrorhappened = 0
            Next
            If qberrorhappened <> -2 Then qberrorhappened = 0: a$ = "File " + a$ + " not found": GoTo errmes
            inclevel = inclevel + 1: incname$(inclevel) = f$: inclinenumber(inclevel) = 0
        End If 'fall through to next section...
        '--------------------
        Do While inclevel
            fh = 99 + inclevel
            '2. Feed next line
            If EOF(fh) = 0 Then
                Line Input #fh, x$
                a3$ = x$
                continuelinefrom = 0
                inclinenumber(inclevel) = inclinenumber(inclevel) + 1
                'create extended error string 'incerror$'
                errorLineInInclude = inclinenumber(inclevel)
                e$ = " in line " + str2(inclinenumber(inclevel)) + " of " + incname$(inclevel) + " included"
                If inclevel > 1 Then
                    e$ = e$ + " (through "
                    For x = 1 To inclevel - 1 Step 1
                        e$ = e$ + incname$(x)
                        If x < inclevel - 1 Then 'a sep is req
                            If x = inclevel - 2 Then
                                e$ = e$ + " then "
                            Else
                                e$ = e$ + ", "
                            End If
                        End If
                    Next
                    e$ = e$ + ")"
                End If
                incerror$ = e$
                linenumber = linenumber - 1 'lower official linenumber to counter later increment
                If idemode Then sendc$ = Chr$(10) + a3$: GoTo sendcommand 'passback
                GoTo includeline
            End If
            '3. Close & return control
            Close #fh
            inclevel = inclevel - 1
            If inclevel = 0 Then
                If forceIncludingFile = 1 Then
                    forceIncludingFile = 0
                    GoTo forceIncludeCompleted
                End If
                'restore line formatting
                layoutok = layoutok_backup
                layout$ = layout_backup$
                layoutcomment$ = layoutcomment_backup$
            End If
        Loop 'fall through to next section...
        '(end manager)

    End If 'continuelinefrom=0

    If idemode Then
        If continuelinefrom <> 0 Then GoTo ide4 'continue processing other commands on line

        If Len(layoutcomment$) Then
            If Len(layout$) Then layout$ = layout$ + sp + layoutcomment$ Else layout$ = layoutcomment$
        End If

        If layoutok = 0 Then
            layout$ = layoutoriginal$
        Else

            'reverse '046' changes present in autolayout
            'replace fix046$ with .
            i = InStr(layout$, fix046$)
            Do While i
                layout$ = Left$(layout$, i - 1) + "." + Right$(layout$, Len(layout$) - (i + Len(fix046$) - 1))
                i = InStr(layout$, fix046$)
            Loop

        End If
        x = lhscontrollevel: If controllevel < lhscontrollevel Then x = controllevel
        If definingtype = 2 Then x = x + 1
        If definingtype > 0 Then definingtype = 2
        If declaringlibrary = 2 Then x = x + 1
        If declaringlibrary > 0 Then declaringlibrary = 2
        layout$ = Space$(x) + layout$
        If linecontinuation Then layout$ = ""

        GoTo ideret4 'return control to IDE
    End If

    'layout is not currently used by the compiler (as appose to the IDE), if it was it would be used here
    skipide4:
Loop

'add final line
If lastLineReturn = 0 Then
    lastLineReturn = 1
    lastLine = 1
    wholeline$ = ""
    GoTo mainpassLastLine
End If

ide5:
linenumber = 0

If closedmain = 0 Then closemain

If definingtype Then linenumber = definingtypeerror: a$ = "TYPE without END TYPE": GoTo errmes

'check for open controls (copy #1)
If controllevel Then
    a$ = "Unidentified open control block"
    Select Case controltype(controllevel)
        Case 1: a$ = "IF without END IF"
        Case 2: a$ = "FOR without NEXT"
        Case 3, 4: a$ = "DO without LOOP"
        Case 5: a$ = "WHILE without WEND"
        Case 6: a$ = "$IF without $END IF"
        Case 10 To 19: a$ = "SELECT CASE without END SELECT"
        Case 32: a$ = "SUB/FUNCTION without END SUB/FUNCTION"
    End Select
    linenumber = controlref(controllevel)
    GoTo errmes
End If

If ideindentsubs = 0 Then
    If Len(subfunc) Then a$ = "SUB/FUNCTION without END SUB/FUNCTION": GoTo errmes
End If

'close the error handler (cannot be put in 'closemain' because subs/functions can also add error jumps to this file)
Print #14, "exit(99);" 'in theory this line should never be run!
Print #14, "}" 'close error jump handler

'create CLEAR method "CLEAR"
Close #12 'close code handle
Open tmpdir$ + "clear.txt" For Output As #12 'direct code to clear.txt

For i = 1 To idn

    If ids(i).staticscope Then 'static scope?
        subfunc = RTrim$(ids(i).insubfunc) 'set static scope
        GoTo clearstaticscope
    End If

    a = Asc(ids(i).insubfunc)
    If a = 0 Or a = 32 Then 'global scope?
        subfunc = "" 'set global scope
        clearstaticscope:

        If ids(i).arraytype Then 'an array
            getid i
            If Error_Happened Then GoTo errmes
            If id.arrayelements = -1 Then GoTo clearerasereturned 'cannot erase non-existant array
            clearerasereturn = 1: GoTo clearerase
        End If 'array

        If ids(i).t Then 'non-array variable
            getid i
            If Error_Happened Then GoTo errmes
            bytes$ = variablesize$(-1)
            If Error_Happened Then GoTo errmes
            'create a reference
            typ = id.t + ISREFERENCE
            If typ And ISUDT Then
                e$ = str2(i) + sp3 + str2(typ And 511) + sp3 + "0" + sp3 + "0"
            Else
                e$ = str2(i)
            End If
            e$ = refer$(e$, typ, 1)
            If Error_Happened Then GoTo errmes
            If typ And ISSTRING Then
                If typ And ISFIXEDLENGTH Then
                    Print #12, "memset((void*)(" + e$ + "->chr),0," + bytes$ + ");"
                    GoTo cleared
                End If
            End If
            If typ And ISUDT Then
                If udtxvariable(typ And 511) Then
                    'this next procedure resets values of UDT variables with variable-length strings
                    clear_udt_with_varstrings e$, typ And 511, 12, 0
                Else
                    Print #12, "memset((void*)" + e$ + ",0," + bytes$ + ");"
                End If
            End If
            GoTo cleared
        End If 'non-array variable

    End If 'scope

    cleared:
    clearerasereturned:
Next
Close #12

'Set cmem flags for subs/functions requiring data passed in cmem
For i = 1 To idn
    If cmemlist(i) Then 'must be in cmem
        getid i
        If Error_Happened Then GoTo errmes

        If id.sfid Then 'it is an argument of a sub/function

            i2 = id.sfid
            x = id.sfarg

            'check if cmem flag is set, if not then set it & force recompile
            If Mid$(sfcmemargs(i2), x, 1) <> Chr$(1) Then
                Mid$(sfcmemargs(i2), x, 1) = Chr$(1)
                recompile = 1
            End If
        End If
    End If
Next i

unresolved = 0
For i = 1 To idn
    getid i
    If Error_Happened Then GoTo errmes
    If id.subfunc Then
        For i2 = 1 To id.args
            t = CVL(Mid$(id.arg, i2 * 4 - 3, 4))
            If t > 0 Then
                If (t And ISPOINTER) Then
                    If (t And ISARRAY) Then
                        nele = Asc(Mid$(id.nele, i2, 1))
                        nelereq = Asc(Mid$(id.nelereq, i2, 1))
                        If nele <> nelereq Then
                            unresolved = unresolved + 1
                            sflistn = sflistn + 1
                            sfidlist(sflistn) = i
                            sfarglist(sflistn) = i2
                            sfelelist(sflistn) = nelereq '0 means still unknown
                        End If
                    End If
                End If
            End If
        Next
    End If
Next

'is recompilation required to resolve this?
If unresolved > 0 Then
    If lastunresolved = -1 Then
        'first pass
        recompile = 1
    Else
        'not first pass
        If unresolved < lastunresolved Then
            recompile = 1
        End If
    End If
End If 'unresolved
lastunresolved = unresolved

xi = 1
For x = 1 To commonarraylistn
    varname$ = getelement$(commonarraylist, xi): xi = xi + 1
    typ$ = getelement$(commonarraylist, xi): xi = xi + 1
    dimmethod2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1
    dimshared2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1
    'find the array ID (try method)
    t = typname2typ(typ$)
    If Error_Happened Then GoTo errmes
    If (t And ISUDT) = 0 Then varname$ = varname$ + type2symbol$(typ$)
    If Error_Happened Then GoTo errmes

    try = findid(varname$)
    If Error_Happened Then GoTo errmes
    Do While try
        If id.arraytype Then GoTo foundcommonarray2
        If try = 2 Then findanotherid = 1: try = findid(varname$) Else try = 0
        If Error_Happened Then GoTo errmes
    Loop
    foundcommonarray2:

    If id.arrayelements = -1 Then
        If arrayelementslist(currentid) <> 0 Then recompile = 1
    End If
Next

If recompile Then
    do_recompile:
    recompile = 0
    If idemode Then iderecompile = 1
    For closeall = 1 To 255: Close closeall: Next
    Open tmpdir$ + "temp.bin" For Output Lock Write As #26 'relock
    GoTo recompile
End If

For r = 1 To nLabels

    If Labels(r).Scope_Restriction Then
        a$ = RTrim$(Labels(r).cn)
        ignore = validlabel(a$)
        v = HashFind(a$, HASHFLAG_LABEL, ignore, r2)
        addlabchk7:
        If v Then
            If Labels(r2).Scope = Labels(r).Scope_Restriction Then
                linenumber = Labels(r).Error_Line: a$ = "Common label within a SUB/FUNCTION": GoTo errmes
            End If
            If v = 2 Then v = HashFindCont(ignore, r2): GoTo addlabchk7
        End If 'v
    End If 'restriction

    'check for undefined labels
    If Labels(r).State = 0 Then

        If InStr(PossibleSubNameLabels$, sp + UCase$(RTrim$(Labels(r).cn)) + sp) Then
            If InStr(SubNameLabels$, sp + UCase$(RTrim$(Labels(r).cn)) + sp) = 0 Then 'not already added
                SubNameLabels$ = SubNameLabels$ + UCase$(RTrim$(Labels(r).cn)) + sp
                GoTo do_recompile
            End If
        End If

        linenumber = Labels(r).Error_Line: a$ = "Label '" + RTrim$(Labels(r).cn) + "' not defined": GoTo errmes
    End If

    If Labels(r).Data_Referenced Then

        'check for ambiguous RESTORE reference
        x = 0
        a$ = RTrim$(Labels(r).cn)
        ignore = validlabel(a$)
        v = HashFind(a$, HASHFLAG_LABEL, ignore, r2)
        addlabchk4:
        If v Then
            x = x + 1
            If v = 2 Then v = HashFindCont(ignore, r2): GoTo addlabchk4
        End If 'v
        If x <> 1 Then linenumber = Labels(r).Error_Line: a$ = "Ambiguous DATA label": GoTo errmes

        'add global data offset variable
        Print #18, "ptrszint data_at_LABEL_" + a$ + "=" + str2(Labels(r).Data_Offset) + ";"

    End If 'data referenced

Next

'create include files for COMMON arrays

Close #12

'return to 'main'
subfunc$ = ""
defdatahandle = 18
Close #13: Open tmpdir$ + "maindata.txt" For Append As #13
Close #19: Open tmpdir$ + "mainfree.txt" For Append As #19

If Console Then
    Print #18, "int32 console=1;"
Else
    Print #18, "int32 console=0;"
End If

If ScreenHide Then
    Print #18, "int32 screen_hide_startup=1;"
Else
    Print #18, "int32 screen_hide_startup=0;"
End If

If Asserts Then
    Print #18, "int32 asserts=1;"
Else
    Print #18, "int32 asserts=0;"
End If

Print #18, "int32 vwatch=0;"

fh = FreeFile
Open tmpdir$ + "dyninfo.txt" For Append As #fh
If Resize Then
    Print #fh, "ScreenResize=1;"
End If
If Resize_Scale Then
    Print #fh, "ScreenResizeScale=" + str2(Resize_Scale) + ";"
End If
Close #fh

'DATA_finalize
Print #18, "ptrszint data_size=" + str2(DataOffset) + ";"
If DataOffset = 0 Then
    Print #18, "uint8 *data=(uint8*)calloc(1,1);"
Else
    If inline_DATA = 0 Then
        x$ = Chr$(0): Put #16, , x$
        Print #18, "extern " + Chr$(34) + "C" + Chr$(34) + "{"
        Print #18, "extern char *_binary____temp" + tempfolderindexstr2$ + "_data_bin_start;"
        Print #18, "}"
        Print #18, "uint8 *data=(uint8*)&_binary____temp" + tempfolderindexstr2$ + "_data_bin_start;"
    Else
        'inline data
        Close #16
        ff = FreeFile
        Open tmpdir$ + "data.bin" For Binary As #ff
        x$ = Space$(LOF(ff))
        Get #ff, , x$
        Close #ff
        x2$ = "uint8 inline_data[]={"
        For i = 1 To Len(x$)
            x2$ = x2$ + inlinedatastr$(Asc(x$, i))
        Next
        x2$ = x2$ + "0};"
        Print #18, x2$
        Print #18, "uint8 *data=&inline_data[0];"
        x$ = "": x2$ = ""
    End If
End If

use_global_byte_elements = 1
ncommontmp = 0
xi = 1
For x = 1 To commonarraylistn
    varname$ = getelement$(commonarraylist, xi): xi = xi + 1
    typ$ = getelement$(commonarraylist, xi): xi = xi + 1
    dimmethod2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1
    dimshared2 = Val(getelement$(commonarraylist, xi)): xi = xi + 1

    'find the array ID (try method)
    purevarname$ = varname$
    t = typname2typ(typ$)
    If Error_Happened Then GoTo errmes
    If (t And ISUDT) = 0 Then varname$ = varname$ + type2symbol$(typ$)
    If Error_Happened Then GoTo errmes
    try = findid(varname$)
    If Error_Happened Then GoTo errmes
    Do While try
        If id.arraytype Then GoTo foundcommonarray
        If try = 2 Then findanotherid = 1: try = findid(varname$) Else try = 0
        If Error_Happened Then GoTo errmes
    Loop
    a$ = "COMMON array unlocatable": GoTo errmes 'should never happen
    foundcommonarray:

    i = currentid
    arraytype = id.arraytype
    arrayelements = id.arrayelements
    e$ = RTrim$(id.n)
    If (t And ISUDT) = 0 Then e$ = e$ + typevalue2symbol$(t)
    If Error_Happened Then GoTo errmes
    n$ = e$
    n2$ = RTrim$(id.callname)
    tsize = id.tsize

    'select command
    command = 3 'fixed length elements
    If t And ISSTRING Then
        If (t And ISFIXEDLENGTH) = 0 Then
            command = 4 'var-len elements
        End If
    End If

    'if...
    'i) array elements are still undefined (ie. arrayelements=-1) pass the input content along
    '   if any existed or an array-placeholder
    'ii) if the array's elements were defined, any input content would have been loaded so the
    '    array (in whatever state it currently is) should be passed. If it is currently erased
    '    then it should be passed as a placeholder

    If arrayelements = -1 Then

        'load array (copies the array, if any, into a buffer for later)

        Open tmpdir$ + "inpchain" + str2$(i) + ".txt" For Output As #12
        Print #12, "if (int32val==2){" 'array place-holder
        'create buffer to store array as-is in global.txt
        x$ = str2$(uniquenumber)
        x1$ = "chainarraybuf" + x$
        x2$ = "chainarraybufsiz" + x$
        Print #18, "static uint8 *" + x1$ + "=(uint8*)malloc(1);"
        Print #18, "static int64 " + x2$ + "=0;"
        'read next command
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        If command = 3 Then Print #12, "if (int32val==3){" 'fixed-length-element array
        If command = 4 Then Print #12, "if (int32val==4){" 'var-length-element array
        Print #12, x2$ + "+=4; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int32*)(" + x1$ + "+" + x2$ + "-4)=int32val;"

        If command = 3 Then
            'read size in bits of one element, convert it to bytes
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
            Print #12, x2$ + "+=8; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int64*)(" + x1$ + "+" + x2$ + "-8)=int64val;"
            Print #12, "bytes=int64val>>3;"
        End If 'com=3

        If command = 4 Then Print #12, "bytes=1;" 'bytes used to calculate number of elements

        'read number of dimensions
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"
        Print #12, x2$ + "+=4; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int32*)(" + x1$ + "+" + x2$ + "-4)=int32val;"

        'read size of dimensions & calculate the size of the array in bytes
        Print #12, "while(int32val--){"
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);" 'lbound
        Print #12, x2$ + "+=8; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int64*)(" + x1$ + "+" + x2$ + "-8)=int64val;"
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val2,8," + NewByteElement$ + "),0);" 'ubound
        Print #12, x2$ + "+=8; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int64*)(" + x1$ + "+" + x2$ + "-8)=int64val2;"
        Print #12, "bytes*=(int64val2-int64val+1);"
        Print #12, "}"

        If command = 3 Then
            'read the array data
            Print #12, x2$ + "+=bytes; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + ");"
            Print #12, "sub_get(FF,NULL,byte_element((uint64)(" + x1$ + "+" + x2$ + "-bytes),bytes," + NewByteElement$ + "),0);"
        End If 'com=3

        If command = 4 Then
            Print #12, "bytei=0;"
            Print #12, "while(bytei<bytes){"
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);" 'get size
            Print #12, x2$ + "+=8; " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + "); *(int64*)(" + x1$ + "+" + x2$ + "-8)=int64val;"
            Print #12, x2$ + "+=(int64val>>3); " + x1$ + "=(uint8*)realloc(" + x1$ + "," + x2$ + ");"
            Print #12, "sub_get(FF,NULL,byte_element((uint64)(" + x1$ + "+" + x2$ + "-(int64val>>3)),(int64val>>3)," + NewByteElement$ + "),0);"
            Print #12, "bytei++;"
            Print #12, "}"
        End If

        'get next command
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"
        Print #12, "}" 'command=3 or 4

        Print #12, "}" 'array place-holder
        Close #12

        'save array (saves the buffered data, if any, for later)

        Open tmpdir$ + "chain" + str2$(i) + ".txt" For Output As #12
        Print #12, "int32val=2;" 'placeholder
        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        Print #12, "sub_put(FF,NULL,byte_element((uint64)" + x1$ + "," + x2$ + "," + NewByteElement$ + "),0);"
        Close #12

    Else
        'note: arrayelements<>-1

        'load array

        Open tmpdir$ + "inpchain" + str2$(i) + ".txt" For Output As #12

        Print #12, "if (int32val==2){" 'array place-holder
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        If command = 3 Then Print #12, "if (int32val==3){" 'fixed-length-element array
        If command = 4 Then Print #12, "if (int32val==4){" 'var-length-element array

        If command = 3 Then
            'get size in bits
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
            '***assume correct***
        End If

        'get number of elements
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"
        '***assume correct***

        e$ = ""
        If command = 4 Then Print #12, "bytes=1;" 'bytes counts the number of total elements
        For x2 = 1 To arrayelements
            'create 'secret' variables to assist in passing common arrays
            If x2 > ncommontmp Then
                ncommontmp = ncommontmp + 1
                retval = dim2("___RESERVED_COMMON_LBOUND" + str2$(ncommontmp), "_INTEGER64", 0, "")
                If Error_Happened Then GoTo errmes
                retval = dim2("___RESERVED_COMMON_UBOUND" + str2$(ncommontmp), "_INTEGER64", 0, "")
                If Error_Happened Then GoTo errmes
            End If
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
            Print #12, "*__INTEGER64____RESERVED_COMMON_LBOUND" + str2$(x2) + "=int64val;"
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val2,8," + NewByteElement$ + "),0);"
            Print #12, "*__INTEGER64____RESERVED_COMMON_UBOUND" + str2$(x2) + "=int64val2;"
            If command = 4 Then Print #12, "bytes*=(int64val2-int64val+1);"
            If x2 > 1 Then e$ = e$ + sp + "," + sp
            e$ = e$ + "___RESERVED_COMMON_LBOUND" + str2$(x2) + sp + "TO" + sp + "___RESERVED_COMMON_UBOUND" + str2$(x2)
        Next

        If Error_Happened Then GoTo errmes
        'Note: purevarname$ is simply varname$ without the type symbol after it
        redimoption = 1
        retval = dim2(purevarname$, typ$, 0, e$)
        If Error_Happened Then GoTo errmes
        redimoption = 0

        If Error_Happened Then GoTo errmes

        If command = 3 Then
            'use get to load in the array data
            varname$ = varname$ + sp + "(" + sp + ")"
            e$ = evaluatetotyp(fixoperationorder$(varname$), -4)
            If Error_Happened Then GoTo errmes
            Print #12, "sub_get(FF,NULL," + e$ + ",0);"
        End If

        If command = 4 Then
            Print #12, "bytei=0;"
            Print #12, "while(bytei<bytes){"
            Print #12, "sub_get(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);" 'get size
            Print #12, "tqbs=((qbs*)(((uint64*)(" + n2$ + "[0]))[bytei]));" 'get element
            Print #12, "qbs_set(tqbs,qbs_new(int64val>>3,1));" 'change string size
            Print #12, "sub_get(FF,NULL,byte_element((uint64)tqbs->chr,int64val>>3," + NewByteElement$ + "),0);" 'get size
            Print #12, "bytei++;"
            Print #12, "}"
        End If

        'get next command
        Print #12, "sub_get(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"
        Print #12, "}"
        Print #12, "}"
        Close #12

        'save array

        Open tmpdir$ + "chain" + str2$(i) + ".txt" For Output As #12

        Print #12, "int32val=2;" 'placeholder
        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        Print #12, "if (" + n2$ + "[2]&1){" 'don't add unless defined

        If command = 3 Then Print #12, "int32val=3;"
        If command = 4 Then Print #12, "int32val=4;"
        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        If command = 3 Then
            'size of each element in bits
            bits = t And 511
            If t And ISUDT Then bits = udtxsize(t And 511)
            If t And ISSTRING Then bits = tsize * 8
            Print #12, "int64val=" + str2$(bits) + ";" 'size in bits
            Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
        End If 'com=3

        Print #12, "int32val=" + str2$(arrayelements) + ";" 'number of dimensions
        Print #12, "sub_put(FF,NULL,byte_element((uint64)&int32val,4," + NewByteElement$ + "),0);"

        If command = 3 Then

            For x2 = 1 To arrayelements
                'simulate calls to lbound/ubound
                e$ = "LBOUND" + sp + "(" + sp + n$ + sp + "," + sp + str2$(x2) + sp + ")"
                e$ = evaluatetotyp(fixoperationorder$(e$), 64)
                If Error_Happened Then GoTo errmes
                Print #12, "int64val=" + e$ + ";"
                Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
                e$ = "UBOUND" + sp + "(" + sp + n$ + sp + "," + sp + str2$(x2) + sp + ")"
                e$ = evaluatetotyp(fixoperationorder$(e$), 64)
                If Error_Happened Then GoTo errmes
                Print #12, "int64val=" + e$ + ";"
                Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
            Next

            'array data
            e$ = evaluatetotyp(fixoperationorder$(n$ + sp + "(" + sp + ")"), -4)
            If Error_Happened Then GoTo errmes
            Print #12, "sub_put(FF,NULL," + e$ + ",0);"

        End If 'com=3

        If command = 4 Then

            'store LBOUND/UBOUND values and calculate number of total elements/strings
            Print #12, "bytes=1;" 'note: bytes is actually the total number of elements
            For x2 = 1 To arrayelements
                e$ = "LBOUND" + sp + "(" + sp + n$ + sp + "," + sp + str2$(x2) + sp + ")"
                e$ = evaluatetotyp(fixoperationorder$(e$), 64)
                If Error_Happened Then GoTo errmes
                Print #12, "int64val=" + e$ + ";"
                Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);"
                e$ = "UBOUND" + sp + "(" + sp + n$ + sp + "," + sp + str2$(x2) + sp + ")"
                e$ = evaluatetotyp(fixoperationorder$(e$), 64)
                If Error_Happened Then GoTo errmes
                Print #12, "int64val2=" + e$ + ";"
                Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val2,8," + NewByteElement$ + "),0);"
                Print #12, "bytes*=(int64val2-int64val+1);"
            Next

            Print #12, "bytei=0;"
            Print #12, "while(bytei<bytes){"
            Print #12, "tqbs=((qbs*)(((uint64*)(" + n2$ + "[0]))[bytei]));" 'get element
            Print #12, "int64val=tqbs->len; int64val<<=3;"
            Print #12, "sub_put(FF,NULL,byte_element((uint64)&int64val,8," + NewByteElement$ + "),0);" 'size of element
            Print #12, "sub_put(FF,NULL,byte_element((uint64)tqbs->chr,tqbs->len," + NewByteElement$ + "),0);" 'element data
            Print #12, "bytei++;"
            Print #12, "}"

        End If 'com=4

        Print #12, "}" 'don't add unless defined

        Close #12

    End If 'id.arrayelements=-1
Next
use_global_byte_elements = 0

For closeall = 1 To 255: Close closeall: Next
Open tmpdir$ + "temp.bin" For Output Lock Write As #26 'relock
compilelog$ = tmpdir$ + "compilelog.txt"
Open compilelog$ For Output As #1: Close #1 'Clear log

If idemode = 0 And Not QuietMode Then
    If ConsoleMode Then
        Print "[" + String$(maxprogresswidth, ".") + "] 100%"
    Else
        Locate , 1
        Print String$(maxprogresswidth, 219) + " 100%"
    End If
End If

If Not IgnoreWarnings Then
    totalUnusedVariables = 0
    For i = 1 To totalVariablesCreated
        If usedVariableList(i).used = 0 Then
            totalUnusedVariables = totalUnusedVariables + 1
        End If
    Next

    If totalUnusedVariables > 0 Then
        maxVarNameLen = 0
        For i = 1 To totalVariablesCreated
            If usedVariableList(i).used = 0 Then
                If Len(usedVariableList(i).name) > maxVarNameLen Then maxVarNameLen = Len(usedVariableList(i).name)
            End If
        Next

        header$ = "unused variable" 's (" + LTRIM$(STR$(totalUnusedVariables)) + ")"
        For i = 1 To totalVariablesCreated
            If usedVariableList(i).used = 0 Then
                addWarning usedVariableList(i).linenumber, usedVariableList(i).includeLevel, usedVariableList(i).includedLine, usedVariableList(i).includedFile, header$, usedVariableList(i).name + Space$((maxVarNameLen + 1) - Len(usedVariableList(i).name)) + "  " + usedVariableList(i).varType
            End If
        Next
    End If
End If

If idemode Then GoTo ideret5
ide6:

If idemode = 0 And No_C_Compile_Mode = 0 Then
    If Not QuietMode Then
        Print
        Print "Compiling C++ code into executable..."
    End If
    If Len(outputfile_cmd$) Then
        'resolve relative path for output file
        path.out$ = getfilepath$(outputfile_cmd$)
        f$ = Mid$(outputfile_cmd$, Len(path.out$) + 1)
        file$ = RemoveFileExtension$(f$)
        If Len(path.out$) Then
            If _DirExists(path.out$) = 0 Then
                Print
                Print "Can't create output executable - path not found: " + path.out$
                If ConsoleMode Then System 1
                End 1
            End If
            currentdir$ = _CWD$
            ChDir path.out$
            path.out$ = _CWD$
            ChDir currentdir$
            If Right$(path.out$, 1) <> pathsep$ Then path.out$ = path.out$ + pathsep$
            path.exe$ = path.out$
            SaveExeWithSource = -1 'Override the global setting if an output file was specified
        End If
    End If
    t.path.exe$ = path.exe$
    If path.exe$ = "../../" Or path.exe$ = "..\..\" Then path.exe$ = ""
    If _FileExists(path.exe$ + file$ + extension$) Then
        E = 0
        On Error GoTo qberror_test
        Kill path.exe$ + file$ + extension$
        On Error GoTo qberror
        If E = 1 Then
            a$ = "CANNOT CREATE " + Chr$(34) + file$ + extension$ + Chr$(34) + " BECAUSE THE FILE IS ALREADY IN USE!": GoTo errmes
        End If
    End If
    path.exe$ = t.path.exe$
End If

'Update dependencies

o$ = LCase$(os$)
defines$ = "": defines_header$ = " -D "
ver$ = Version$ 'eg. "0.123"
x = InStr(ver$, "."): If x Then Asc(ver$, x) = 95 'change "." to "_"
libs$ = ""

If DEPENDENCY(DEPENDENCY_GL) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_GL"
End If

If DEPENDENCY(DEPENDENCY_SCREENIMAGE) Then
    DEPENDENCY(DEPENDENCY_IMAGE_CODEC) = 1
End If

If DEPENDENCY(DEPENDENCY_IMAGE_CODEC) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_IMAGE_CODEC"
End If

If DEPENDENCY(DEPENDENCY_CONSOLE_ONLY) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_CONSOLE_ONLY"
End If

If DEPENDENCY(DEPENDENCY_SOCKETS) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_SOCKETS"
Else
    defines$ = defines$ + defines_header$ + "DEPENDENCY_NO_SOCKETS"
End If

If DEPENDENCY(DEPENDENCY_PRINTER) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_PRINTER"
Else
    defines$ = defines$ + defines_header$ + "DEPENDENCY_NO_PRINTER"
End If

If DEPENDENCY(DEPENDENCY_ICON) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_ICON"
Else
    defines$ = defines$ + defines_header$ + "DEPENDENCY_NO_ICON"
End If

If DEPENDENCY(DEPENDENCY_SCREENIMAGE) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_SCREENIMAGE"
Else
    defines$ = defines$ + defines_header$ + "DEPENDENCY_NO_SCREENIMAGE"
End If

If DEPENDENCY(DEPENDENCY_LOADFONT) Then
    d$ = "internal\c\parts\video\font\ttf\"
    'rebuild?
    If _FileExists(d$ + "os\" + o$ + "\src.o") = 0 Then
        Build d$ + "os\" + o$
    End If
    defines$ = defines$ + defines_header$ + "DEPENDENCY_LOADFONT"
    libs$ = libs$ + " " + "parts\video\font\ttf\os\" + o$ + "\src.o"
End If

localpath$ = "internal\c\"

If DEPENDENCY(DEPENDENCY_DEVICEINPUT) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_DEVICEINPUT"
    libname$ = "input\game_controller"
    libpath$ = "parts\" + libname$ + "\os\" + o$
    libfile$ = libpath$ + "\src.a"
    If _FileExists(localpath$ + libfile$) = 0 Then Build localpath$ + libpath$ 'rebuild?
    libs$ = libs$ + " " + libfile$
End If

If DEPENDENCY(DEPENDENCY_AUDIO_DECODE) Then DEPENDENCY(DEPENDENCY_AUDIO_CONVERSION) = 1
If DEPENDENCY(DEPENDENCY_AUDIO_CONVERSION) Then DEPENDENCY(DEPENDENCY_AUDIO_OUT) = 1
If DEPENDENCY(DEPENDENCY_AUDIO_DECODE) Then DEPENDENCY(DEPENDENCY_AUDIO_OUT) = 1

If DEPENDENCY(DEPENDENCY_AUDIO_CONVERSION) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_AUDIO_CONVERSION"

    d1$ = "parts\audio\conversion"
    d2$ = d1$ + "\os\" + o$
    d3$ = "internal\c\" + d2$
    If _FileExists(d3$ + "\src.a") = 0 Then 'rebuild?
        Build d3$
    End If
    libs$ = libs$ + " " + d2$ + "\src.a"
End If

If DEPENDENCY(DEPENDENCY_AUDIO_DECODE) Then
    'General decoder
    defines$ = defines$ + defines_header$ + "DEPENDENCY_AUDIO_DECODE"
    'MINI_MP3 decoder
    d1$ = "parts\audio\decode\mp3_mini"
    d2$ = d1$ + "\os\" + o$
    d3$ = "internal\c\" + d2$
    If _FileExists(d3$ + "\src.a") = 0 Then 'rebuild?
        Build d3$
    End If
    libs$ = libs$ + " " + d2$ + "\src.a"
    'OGG decoder
    d1$ = "parts\audio\decode\ogg"
    d2$ = d1$ + "\os\" + o$
    d3$ = "internal\c\" + d2$
    If _FileExists(d3$ + "\src.o") = 0 Then 'rebuild?
        Build d3$
    End If
    libs$ = libs$ + " " + d2$ + "\src.o"
    'WAV decoder
    '(no action required)
End If

If DEPENDENCY(DEPENDENCY_AUDIO_OUT) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_AUDIO_OUT"
    d1$ = "parts\audio\out"
    d2$ = d1$ + "\os\" + o$
    d3$ = "internal\c\" + d2$
    If _FileExists(d3$ + "\src.a") = 0 Then 'rebuild?
        Build d3$
    End If
    libs$ = libs$ + " " + d2$ + "\src.a"
End If

If DEPENDENCY(DEPENDENCY_ZLIB) Then
    defines$ = defines$ + defines_header$ + "DEPENDENCY_ZLIB"
    libs$ = libs$ + " -l:libz.a"
End If

'finalize libs$ and defines$ strings
If Len(libs$) Then libs$ = libs$ + " "
PATH_SLASH_CORRECT libs$
If Len(defines$) Then defines$ = defines$ + " "

'Build core?
d1$ = "parts\core"
d2$ = d1$ + "\os\" + o$
d3$ = "internal\c\" + d2$
If _FileExists(d3$ + "\src.a") = 0 Then 'rebuild?
    Build d3$
End If

'Build libqb?
depstr$ = ver$ + "_"
For i = 1 To DEPENDENCY_LAST
    If DEPENDENCY(i) Then depstr$ = depstr$ + "1" Else depstr$ = depstr$ + "0"
Next
libqb$ = " libqb\os\" + o$ + "\libqb_" + depstr$ + ".o "
PATH_SLASH_CORRECT libqb$
If _FileExists("internal\c\" + LTrim$(RTrim$(libqb$))) = 0 Then
    ChDir "internal\c"
    Shell _Hide GDB_Fix("g++ -c -s -w -Wall libqb.cpp -D FREEGLUT_STATIC " + defines$ + " -o libqb/os/" + o$ + "/libqb_" + depstr$ + ".o") + " 2>> ../../" + compilelog$
    ChDir "..\.."
End If

'link-time only defines
If DEPENDENCY(DEPENDENCY_AUDIO_OUT) Then
End If

For x = 1 To ResolveStaticFunctions
    If Len(ResolveStaticFunction_File(x)) Then

        n = 0
        Shell _Hide "nm " + Chr$(34) + ResolveStaticFunction_File(x) + Chr$(34) + " --demangle -g >./internal/temp/nm_output.txt 2>./internal/temp/nm_error.txt"

        fh = FreeFile
        s$ = " " + ResolveStaticFunction_Name(x) + "("
        Open "internal\temp\nm_output.txt" For Binary As #fh
        Do Until EOF(fh)
            Line Input #fh, a$
            If Len(a$) Then
                'search for SPACE+functionname+LEFTBRACKET
                x1 = InStr(a$, s$)
                If x1 Then
                    If ResolveStaticFunction_Method(x) = 1 Then
                        x1 = x1 + 1
                        x2 = InStr(x1, a$, ")")
                        fh2 = FreeFile
                        Open tmpdir$ + "global.txt" For Append As #fh2
                        Print #fh2, "extern void " + Mid$(a$, x1, x2 - x1 + 1) + ";"
                        Close #fh2
                    End If
                    n = n + 1
                End If 'x1
            End If '<>""
        Loop
        Close #fh
        If n > 1 Then a$ = "Unable to resolve multiple instances of sub/function '" + ResolveStaticFunction_Name(x) + "' in '" + ResolveStaticFunction_File(x) + "'": GoTo errmes

        If n = 0 Then 'attempt to locate simple function name without brackets
            fh = FreeFile
            s$ = " " + ResolveStaticFunction_Name(x): s2$ = s$
            Open "internal\temp\nm_output.txt" For Binary As #fh
            Do Until EOF(fh)
                Line Input #fh, a$
                If Len(a$) Then
                    'search for SPACE+functionname
                    x1 = InStr(a$, s$)
                    If Right$(a$, Len(s$)) = s$ Then
                        fh2 = FreeFile
                        If ResolveStaticFunction_Method(x) = 1 Then
                            Open tmpdir$ + "global.txt" For Append As #fh2
                            Print #fh2, "extern " + Chr$(34) + "C" + Chr$(34) + "{"
                            Print #fh2, "extern void " + s2$ + "(void);"
                            Print #fh2, "}"
                        Else
                            Open tmpdir$ + "externtype" + str2(x) + ".txt" For Output As #fh2
                            Print #fh2, "extern " + Chr$(34) + "C" + Chr$(34) + " "
                        End If
                        Close #fh2
                        n = n + 1
                        Exit Do
                    End If 'x1
                End If '<>""
            Loop
            Close #fh
        End If

        If n = 0 Then 'a C++ dynamic object library?
            Shell _Hide "nm " + Chr$(34) + ResolveStaticFunction_File(x) + Chr$(34) + " -D --demangle -g >./internal/temp/nm_output_dynamic.txt 2>./internal/temp/nm_error.txt"
            fh = FreeFile
            s$ = " " + ResolveStaticFunction_Name(x) + "("
            Open "internal\temp\nm_output_dynamic.txt" For Binary As #fh
            Do Until EOF(fh)
                Line Input #fh, a$
                If Len(a$) Then
                    'search for SPACE+functionname+LEFTBRACKET
                    x1 = InStr(a$, s$)
                    If x1 Then
                        If ResolveStaticFunction_Method(x) = 1 Then
                            x1 = x1 + 1
                            x2 = InStr(x1, a$, ")")
                            fh2 = FreeFile
                            Open tmpdir$ + "global.txt" For Append As #fh2
                            Print #fh2, "extern void " + Mid$(a$, x1, x2 - x1 + 1) + ";"
                            Close #fh2
                        End If
                        n = n + 1
                    End If 'x1
                End If '<>""
            Loop
            Close #fh
            If n > 1 Then a$ = "Unable to resolve multiple instances of sub/function '" + ResolveStaticFunction_Name(x) + "' in '" + ResolveStaticFunction_File(x) + "'": GoTo errmes
        End If

        If n = 0 Then 'a C dynamic object library?
            fh = FreeFile
            s$ = " " + ResolveStaticFunction_Name(x)
            Open "internal\temp\nm_output_dynamic.txt" For Binary As #fh
            Do Until EOF(fh)
                Line Input #fh, a$
                If Len(a$) Then
                    'search for SPACE+functionname
                    x1 = InStr(a$, s$)
                    If Right$(a$, Len(s$)) = s$ Then
                        fh2 = FreeFile
                        If ResolveStaticFunction_Method(x) = 1 Then
                            Open tmpdir$ + "global.txt" For Append As #fh2
                            Print #fh2, "extern " + Chr$(34) + "C" + Chr$(34) + "{"
                            Print #fh2, "extern void " + s$ + "(void);"
                            Print #fh2, "}"
                        Else
                            Open tmpdir$ + "externtype" + str2(x) + ".txt" For Output As #fh2
                            Print #fh2, "extern " + Chr$(34) + "C" + Chr$(34) + " "
                        End If
                        Close #fh2
                        n = n + 1
                        Exit Do
                    End If 'x1
                End If '<>""
            Loop
            Close #fh
        End If
    End If
Next

If inline_DATA = 0 Then
    If DataOffset Then
        b$ = "64"
        Open ".\internal\c\makedat_lnx" + b$ + ".txt" For Binary As #150: Line Input #150, a$: Close #150
        a$ = a$ + " " + tmpdir2$ + "data.bin " + tmpdir2$ + "data.o"
        ChDir ".\internal\c"
        Shell _Hide a$ + " 2>> ../../" + compilelog$
        ChDir "..\.."
    End If
End If

If DEPENDENCY(DEPENDENCY_CONSOLE_ONLY) Then
    Open "./internal/c/makeline_lnx_nogui.txt" For Input As #150
Else
    Open "./internal/c/makeline_lnx.txt" For Input As #150
End If

Line Input #150, a$: a$ = GDB_Fix(a$)
Close #150
'change qbx.cpp to qbx999.cpp?
x = InStr(a$, "qbx.cpp"): If x <> 0 And tempfolderindex <> 1 Then a$ = Left$(a$, x - 1) + "qbx" + str2$(tempfolderindex) + ".cpp" + Right$(a$, Len(a$) - (x + 6))

If inline_DATA = 0 Then
    'add data.o?
    If DataOffset Then
        x = InStr(a$, "-lrt")
        If x Then
            a$ = Left$(a$, x - 1) + " " + tmpdir2$ + "data.o " + Right$(a$, Len(a$) - x + 1)
        End If
    End If
End If

'add custom libraries
If Len(mylib$) Then
    x = InStr(a$, ".cpp ")
    If x Then
        x = x + 5
        a$ = Left$(a$, x - 1) + " " + mylibopt$ + " " + mylib$ + " " + Right$(a$, Len(a$) - x + 1)
    End If
End If

'add dependent libraries
If Len(libs$) Then
    x = InStr(a$, ".cpp ")
    If x Then
        x = x + 5
        a$ = Left$(a$, x - 1) + libs$ + Right$(a$, Len(a$) - x + 1)
    End If
End If

'add dependency defines
If Len(defines$) Then
    x = InStr(a$, ".cpp ")
    If x Then
        x = x + 5
        a$ = Left$(a$, x - 1) + defines$ + Right$(a$, Len(a$) - x + 1)
    End If
End If

'add libqb
x = InStr(a$, ".cpp ")
If x Then
    x = x + 5
    a$ = Left$(a$, x - 1) + libqb$ + Right$(a$, Len(a$) - x + 1)
End If

a$ = a$ + QuotedFilename$(path.exe$ + file$ + extension$)

ffh = FreeFile
Open tmpdir$ + "recompile_lnx.sh" For Output As #ffh
Print #ffh, "#!/bin/sh" + Chr$(10);
Print #ffh, "Pause()" + Chr$(10);
Print #ffh, "{" + Chr$(10);
Print #ffh, "OLDCONFIG=`stty -g`" + Chr$(10);
Print #ffh, "stty -icanon -echo min 1 time 0" + Chr$(10);
Print #ffh, "dd count=1 2>/dev/null" + Chr$(10);
Print #ffh, "stty $OLDCONFIG" + Chr$(10);
Print #ffh, "}" + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "Recompiling..." + CHR_QUOTE + Chr$(10);
Print #ffh, "cd ../c" + Chr$(10);
Print #ffh, a$ + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "Press ENTER to exit..." + CHR_QUOTE + Chr$(10);
Print #ffh, "Pause" + Chr$(10);
Close ffh
Shell _Hide "chmod +x " + tmpdir$ + "recompile_lnx.sh"

ffh = FreeFile
Open tmpdir$ + "debug_lnx.sh" For Output As #ffh
Print #ffh, "#!/bin/sh" + Chr$(10);
Print #ffh, "Pause()" + Chr$(10);
Print #ffh, "{" + Chr$(10);
Print #ffh, "OLDCONFIG=`stty -g`" + Chr$(10);
Print #ffh, "stty -icanon -echo min 1 time 0" + Chr$(10);
Print #ffh, "dd count=1 2>/dev/null" + Chr$(10);
Print #ffh, "stty $OLDCONFIG" + Chr$(10);
Print #ffh, "}" + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "C++ Debugging: " + file$ + extension$ + " using GDB" + CHR_QUOTE + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "Debugger commands:" + CHR_QUOTE + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "After the debugger launches type 'run' to start your program" + CHR_QUOTE + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "After your program crashes type 'list' to find where the problem is and fix/report it" + CHR_QUOTE + Chr$(10);
Print #ffh, "echo " + CHR_QUOTE + "(the GDB debugger has many other useful commands, this advice is for beginners)" + CHR_QUOTE + Chr$(10);
Print #ffh, "gdb " + Chr$(34) + path.exe$ + file$ + extension$ + Chr$(34) + Chr$(10);
Print #ffh, "Pause" + Chr$(10);
Close ffh
Shell _Hide "chmod +x " + tmpdir$ + "debug_lnx.sh"

If No_C_Compile_Mode = 0 Then
    ChDir "./internal/c"
    Shell _Hide a$ + " 2>> ../../" + compilelog$
    ChDir "../.."
    If idemode Then
        'Restore fg/bg colors
        dummy = DarkenFGBG(0)
    End If
End If

If No_C_Compile_Mode Then compfailed = 0: GoTo No_C_Compile
If path.exe$ = "../../" Or path.exe$ = "..\..\" Then path.exe$ = ""
If _FileExists(path.exe$ + file$ + extension$) Then
    compfailed = 0
    lastBinaryGenerated$ = path.exe$ + file$ + extension$
Else
    compfailed = 1 'detect compilation failure
End If

If compfailed Then
    If idemode Then
        idemessage$ = "C++ Compilation failed " + Chr$(0) + "(Check " + _Trim$(compilelog$) + ")"
        GoTo ideerror
    End If
    If compfailed Then
        Print "ERROR: C++ compilation failed."
        Print "Check " + compilelog$ + " for details."
    End If
Else
    If idemode = 0 And Not QuietMode Then Print "Output: "; lastBinaryGenerated$
End If

Skip_Build:

If idemode Then GoTo ideret6

No_C_Compile:

If (compfailed <> 0 Or warningsissued <> 0) And ConsoleMode = 0 Then End 1
If compfailed <> 0 Then System 1
System 0

qberror_test:
E = 1
Resume Next

qberror:

If ideerror Then 'error happened inside the IDE
    fh = FreeFile
    Open "internal\temp\ideerror.txt" For Append As #fh
    Print #fh, Date$; Time$; "--------------------"
    Print #fh, Err
    Print #fh, _ErrorMessage$
    Print #fh, _ErrorLine
    Print #fh, _InclErrorLine
    Print #fh, _InclErrorFile$
    Close #fh
    sendc$ = Chr$(255) 'a runtime error has occurred
    Resume sendcommand 'allow IDE to handle error recovery
End If

qberrorhappenedvalue = qberrorhappened
qberrorhappened = 1

If idemode And qberrorhappenedvalue >= 0 Then
    'real qb error occurred
    ideerrorline = linenumber
    idemessage$ = "Compiler error (check for syntax errors) (" + _ErrorMessage$ + ":"
    If Err Then idemessage$ = idemessage$ + str2$(Err) + "-"
    If _ErrorLine Then idemessage$ = idemessage$ + str2$(_ErrorLine)
    If _InclErrorLine Then idemessage$ = idemessage$ + "-" + _InclErrorFile$ + "-" + str2$(_InclErrorLine)
    idemessage$ = idemessage$ + ")"
    If inclevel > 0 Then idemessage$ = idemessage$ + incerror$
    Resume ideerror
End If

If qberrorhappenedvalue >= 0 Then
    a$ = "UNEXPECTED INTERNAL COMPILER ERROR!": GoTo errmes 'internal comiler error
End If

qberrorcode = Err
qberrorline = Erl
If qberrorhappenedvalue = -1 Then Resume qberrorhappened1
If qberrorhappenedvalue = -2 Then Resume qberrorhappened2
If qberrorhappenedvalue = -3 Then Resume qberrorhappened3
End

errmes: 'set a$ to message
If Error_Happened Then a$ = Error_Message: Error_Happened = 0
layout$ = "": layoutok = 0 'invalidate layout

If forceIncludingFile Then 'If we're to the point where we're adding the automatic QB64 includes, we don't need to report the $INCLUDE information
    If InStr(a$, "END SUB/FUNCTION before") Then a$ = "SUB without END SUB" 'Just a simple rewrite of the error message to be less confusing for SUB/FUNCTIONs
Else 'We want to let the user know which module the error occurred in
    If inclevel > 0 Then a$ = a$ + incerror$
End If

If idemode Then
    ideerrorline = linenumber
    idemessage$ = a$
    GoTo ideerror 'infinitely preferable to RESUME
End If
'non-ide mode output
Print
If Not MonochromeLoggingMode Then
    Color 9
End If
Print a$
If Not MonochromeLoggingMode Then Color 7
For i = 1 To Len(linefragment)
    If Mid$(linefragment, i, 1) = sp$ Then Mid$(linefragment, i, 1) = " "
Next
For i = 1 To Len(wholeline)
    If Mid$(wholeline, i, 1) = sp$ Then Mid$(wholeline, i, 1) = " "
Next
Print "Caused by (or after):" + linefragment
If Not MonochromeLoggingMode Then Color 8
Print "LINE ";
If Not MonochromeLoggingMode Then Color 15
Print str2(linenumber) + ":";
If Not MonochromeLoggingMode Then Color 7
Print wholeline

If ConsoleMode Then System 1
End 1

Function ParseCMDLineArgs$ ()
    'Recall that COMMAND$ is a concatenation of argv[] elements, so we don't have
    'to worry about more than one space between things (unless they used quotes,
    'in which case they're simply asking for trouble).
    For i = 1 To _CommandCount
        token$ = Command$(i)
        If LCase$(token$) = "/?" Or LCase$(token$) = "--help" Or LCase$(token$) = "/help" Then token$ = "-?"
        Select Case LCase$(Left$(token$, 2))
            Case "-?" 'Command-line help
                _Dest _Console
                If qb64versionprinted = 0 Then qb64versionprinted = -1: Print "QB64 Compiler V" + Version$
                Print
                Print "Usage: qb64 [switches] <file>"
                Print
                Print "Options:"
                Print "  <file>                  Source file to load" '                                '80 columns
                Print "  -c                      Compile instead of edit"
                Print "  -o <output file>        Write output executable to <output file>"
                Print "  -x                      Compile instead of edit and output the result to the"
                Print "                             console"
                Print "  -w                      Show warnings"
                Print "  -q                      Quiet mode (does not inhibit warnings or errors)"
                Print "  -m                      Do not colorize compiler output (monochrome mode)"
                Print "  -e                      Enable OPTION _EXPLICIT, making variable declaration"
                Print "                             mandatory (per-compilation; doesn't affect the"
                Print "                             source file or global settings)"
                Print "  -s[:switch=true/false]  View/edit compiler settings"
                Print "  -l:<line number>        Start the IDE at the specified line number"
                Print "  -p                      Purge all pre-compiled content first"
                Print "  -z                      Generate C code without compiling to executable"
                Print
                System
            Case "-c" 'Compile instead of edit
                NoIDEMode = 1
                cmdlineswitch = -1
            Case "-o" 'Specify an output file
                If Len(Command$(i + 1)) > 0 Then outputfile_cmd$ = Command$(i + 1): i = i + 1
                cmdlineswitch = -1
            Case "-x" 'Use the console
                ConsoleMode = 1
                NoIDEMode = 1 'Implies -c
                cmdlineswitch = -1
            Case "-w" 'Show warnings
                ShowWarnings = -1
                cmdlineswitch = -1
            Case "-q" 'Quiet mode
                QuietMode = -1
                cmdlineswitch = -1
            Case "-m" 'Monochrome mode
                MonochromeLoggingMode = -1
                cmdlineswitch = -1
            Case "-e" 'Option Explicit
                optionexplicit_cmd = -1
                cmdlineswitch = -1
            Case "-s" 'Settings
                settingsMode = -1
                _Dest _Console
                If qb64versionprinted = 0 Then qb64versionprinted = -1: Print "QB64 Compiler V" + Version$
                Select Case LCase$(Mid$(token$, 3))
                    Case ""
                        Print "debuginfo     = ";
                        If idedebuginfo Then Print "true" Else Print "false"
                        Print "exewithsource = ";
                        If SaveExeWithSource Then Print "true" Else Print "false"
                        System
                    Case ":exewithsource"
                        Print "exewithsource = ";
                        If SaveExeWithSource Then Print "true" Else Print "false"
                        System
                    Case ":exewithsource=true"
                        WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "True"
                        Print "exewithsource = true"
                        SaveExeWithSource = -1
                    Case ":exewithsource=false"
                        WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "False"
                        Print "exewithsource = false"
                        SaveExeWithSource = 0
                    Case ":debuginfo"
                        Print "debuginfo = ";
                        If idedebuginfo Then Print "true" Else Print "false"
                        System
                    Case ":debuginfo=true"
                        Print "debuginfo = true"
                        WriteConfigSetting generalSettingsSection$, "DebugInfo", "True" + DebugInfoIniWarning$
                        idedebuginfo = 1
                        Include_GDB_Debugging_Info = idedebuginfo
                        ChDir "./internal/c"
                        Shell _Hide "./purge_all_precompiled_content_lnx.sh"
                        ChDir "../.."
                    Case ":debuginfo=false"
                        Print "debuginfo = false"
                        WriteConfigSetting generalSettingsSection$, "DebugInfo", "False" + DebugInfoIniWarning$
                        idedebuginfo = 0
                        Include_GDB_Debugging_Info = idedebuginfo
                        ChDir "./internal/c"
                        Shell _Hide "./purge_all_precompiled_content_lnx.sh"
                        ChDir "../.."
                    Case Else
                        Print "Invalid settings switch: "; token$
                        Print
                        Print "Valid switches:"
                        Print "    -s:debuginfo=true/false     (Embed C++ debug info into .EXE)"
                        Print "    -s:exewithsource=true/false (Save .EXE in the source folder)"
                        System 1
                End Select
                _Dest 0
            Case "-l" 'goto line (ide mode only); -l:<line number>
                If Mid$(token$, 3, 1) = ":" Then ideStartAtLine = Val(Mid$(token$, 4))
                cmdlineswitch = -1
            Case "-p" 'Purge
                ChDir "./internal/c"
                Shell _Hide "./purge_all_precompiled_content_lnx.sh"
                ChDir "../.."
                cmdlineswitch = -1
            Case "-z" 'Not compiling C code
                No_C_Compile_Mode = 1
                ConsoleMode = 1 'Implies -x
                NoIDEMode = 1 'Implies -c
                cmdlineswitch = -1
            Case Else 'Something we don't recognise, assume it's a filename
                If PassedFileName$ = "" Then PassedFileName$ = token$
        End Select
    Next i

    If Len(PassedFileName$) Then
        ParseCMDLineArgs$ = PassedFileName$
    Else
        If cmdlineswitch = 0 And settingsMode = -1 Then System
    End If
End Function

Function Type2MemTypeValue (t1)
    t = 0
    If t1 And ISARRAY Then t = t + 65536
    If t1 And ISUDT Then
        If (t1 And 511) = 1 Then
            t = t + 4096 '_MEM type
        Else
            t = t + 32768
        End If
    Else
        If t1 And ISSTRING Then
            t = t + 512 'string
        Else
            If t1 And ISFLOAT Then
                t = t + 256 'float
            Else
                t = t + 128 'integer
                If t1 And ISUNSIGNED Then t = t + 1024
                If t1 And ISOFFSET Then t = t + 8192 'offset type
            End If
            t1s = (t1 And 511) \ 8
            If t1s = 1 Then t = t + t1s
            If t1s = 2 Then t = t + t1s
            If t1s = 4 Then t = t + t1s
            If t1s = 8 Then t = t + t1s
            If t1s = 16 Then t = t + t1s
            If t1s = 32 Then t = t + t1s
            If t1s = 64 Then t = t + t1s
        End If
    End If
    Type2MemTypeValue = t
End Function

Function FileHasExtension (f$)
    For i = Len(f$) To 1 Step -1
        a = Asc(f$, i)
        If a = 47 Or a = 92 Then Exit For
        If a = 46 Then FileHasExtension = -1: Exit Function
    Next
End Function

Function RemoveFileExtension$ (f$) 'returns f$ without extension
    For i = Len(f$) To 1 Step -1
        a = Asc(f$, i)
        If a = 47 Or a = 92 Then Exit For
        If a = 46 Then RemoveFileExtension$ = Left$(f$, i - 1): Exit Function
    Next
    RemoveFileExtension$ = f$
End Function

'udt is non-zero if this is an array of udt's, to allow examining each udt element
Function allocarray (n2$, elements$, elementsize, udt)
    dimsharedlast = dimshared: dimshared = 0

    If autoarray = 1 Then autoarray = 0: autoary = 1 'clear global value & set local value

    f12$ = ""

    'changelog:
    'added 4 to [2] to indicate cmem array where appropriate

    e$ = elements$: n$ = n2$
    If elementsize = -2147483647 Then stringarray = 1: elementsize = 8

    If Asc(e$) = 63 Then '?
        l$ = "(" + sp2 + ")"
        undefined = -1
        nume = 1
        If Len(e$) = 1 Then GoTo undefinedarray
        undefined = 1
        nume = Val(Right$(e$, Len(e$) - 1))
        GoTo undefinedarray
    End If

    'work out how many elements there are (critical to later calculations)
    nume = 1
    n = numelements(e$)
    For i = 1 To n
        e2$ = getelement(e$, i)
        If e2$ = "(" Then b = b + 1
        If b = 0 And e2$ = "," Then nume = nume + 1
        If e2$ = ")" Then b = b - 1
    Next

    descstatic = 0
    If arraydesc Then
        If id.arrayelements <> nume Then

            If id.arrayelements = -1 Then 'unknown
                If arrayelementslist(currentid) <> 0 And nume <> arrayelementslist(currentid) Then Give_Error "Cannot change the number of elements an array has!": Exit Function
                If nume = 1 Then id.arrayelements = 1: ids(currentid).arrayelements = 1 'lucky guess!
                arrayelementslist(currentid) = nume
            Else
                Give_Error "Cannot change the number of elements an array has!": Exit Function
            End If

        End If
        If id.staticarray Then descstatic = 1
    End If

    l$ = "(" + sp2

    cr$ = Chr$(13) + Chr$(10)
    sd$ = ""
    constdimensions = 1
    ei = 4 + nume * 4 - 4
    cure = 1
    e3$ = "": e3base$ = ""
    For i = 1 To n
        e2$ = getelement(e$, i)
        If e2$ = "(" Then b = b + 1
        If (e2$ = "," And b = 0) Or i = n Then
            If i = n Then e3$ = e3$ + sp + e2$
            e3$ = Right$(e3$, Len(e3$) - 1)
            If e3base$ <> "" Then e3base$ = Right$(e3base$, Len(e3base$) - 1)
            'set the base

            basegiven = 1
            If e3base$ = "" Then e3base$ = str2$(optionbase + 0): basegiven = 0
            constequation = 1

            e3base$ = fixoperationorder$(e3base$)
            If Error_Happened Then Exit Function
            If basegiven Then l$ = l$ + tlayout$ + sp + SCase$("To") + sp
            e3base$ = evaluatetotyp$(e3base$, 64&)
            If Error_Happened Then Exit Function

            If constequation = 0 Then constdimensions = 0
            sd$ = sd$ + n$ + "[" + str2(ei) + "]=" + e3base$ + ";" + cr$
            'set the number of indexes
            constequation = 1

            e3$ = fixoperationorder$(e3$)
            If Error_Happened Then Exit Function
            l$ = l$ + tlayout$ + sp2
            If i = n Then l$ = l$ + ")" Else l$ = l$ + "," + sp
            e3$ = evaluatetotyp$(e3$, 64&)
            If Error_Happened Then Exit Function

            If constequation = 0 Then constdimensions = 0
            ei = ei + 1
            sd$ = sd$ + n$ + "[" + str2(ei) + "]=(" + e3$ + ")-" + n$ + "[" + str2(ei - 1) + "]+1;" + cr$
            ei = ei + 1
            'calc muliplier
            If cure = 1 Then
                'set only for the purpose of the calculating correct multipliers
                sd$ = sd$ + n$ + "[" + str2(ei) + "]=1;" + cr$
            Else
                sd$ = sd$ + n$ + "[" + str2(ei) + "]=" + n$ + "[" + str2(ei + 4) + "]*" + n$ + "[" + str2(ei + 3) + "];" + cr$
            End If
            ei = ei + 1
            ei = ei + 1 'skip reserved
            ei = ei - 8
            cure = cure + 1
            e3$ = "": e3base$ = ""
            GoTo aanexte
        End If
        If e2$ = ")" Then b = b - 1
        If UCase$(e2$) = "TO" And b = 0 Then
            e3base$ = e3$
            e3$ = ""
        Else
            e3$ = e3$ + sp + e2$
        End If
        aanexte:
    Next
    sd$ = Left$(sd$, Len(sd$) - 2)

    undefinedarray:

    'calc cmem
    cmem = 0
    If arraydesc = 0 Then
        If cmemlist(idn + 1) Then cmem = 1
    Else
        If cmemlist(arraydesc) Then cmem = 1
    End If

    staticarray = constdimensions
    If subfuncn <> 0 And dimstatic = 0 Then staticarray = 0 'arrays in SUBS/FUNCTIONS are DYNAMIC
    If dimstatic = 3 Then staticarray = 0 'STATIC arrayname() listed arrays keep thier values but are dynamic in memory
    If DynamicMode Then staticarray = 0
    If redimoption Then staticarray = 0
    If dimoption = 3 Then staticarray = 0 'STATIC a(100) arrays are still dynamic

    If arraydesc Then
        If staticarray = 1 Then
            If descstatic Then Give_Error "Cannot redefine a static array!": Exit Function
            staticarray = 0
        End If
    End If

    bytesperelement$ = str2(elementsize)
    If elementsize < 0 Then
        elementsize = -elementsize
        bytesperelement$ = str2(elementsize) + "/8+1"
    End If

    'Begin creation of array descriptor (if array has not been defined yet)
    If arraydesc = 0 Then
        Print #defdatahandle, "ptrszint *" + n$ + "=NULL;"
        Print #13, "if (!" + n$ + "){"
        Print #13, n$ + "=(ptrszint*)mem_static_malloc(" + str2(4 * nume + 4 + 1) + "*ptrsz);" '+1 is for the lock
        'create _MEM lock
        Print #13, "new_mem_lock();"
        Print #13, "mem_lock_tmp->type=4;"
        Print #13, "((ptrszint*)" + n$ + ")[" + str2(4 * nume + 4 + 1 - 1) + "]=(ptrszint)mem_lock_tmp;"
    End If

    'generate sizestr$ & elesizestr$ (both are used in various places in following code)
    sizestr$ = ""
    For i = 1 To nume
        If i <> 1 Then sizestr$ = sizestr$ + "*"
        sizestr$ = sizestr$ + n$ + "[" + str2(i * 4 - 4 + 5) + "]"
    Next
    elesizestr$ = sizestr$ 'elements in entire array
    sizestr$ = sizestr$ + "*" + bytesperelement$ 'bytes in entire array

    '------------------STATIC ARRAY CREATION--------------------------------
    If staticarray Then
        'STATIC memory
        Print #13, sd$ 'setup new array dimension ranges
        'Example of sd$ for DIM a(10):
        '__ARRAY_SINGLE_A[4]= 0 ;
        '__ARRAY_SINGLE_A[5]=( 10 )-__ARRAY_SINGLE_A[4]+1;
        '__ARRAY_SINGLE_A[6]=1;
        If cmem And stringarray = 0 Then
            'Note: A string array's pointers are always stored in 64bit memory
            '(static)CONVENTINAL memory
            Print #13, n$ + "[0]=(ptrszint)cmem_static_pointer;"
            'alloc mem & check if static memory boundry has oversteped dynamic memory boundry
            Print #13, "if ((cmem_static_pointer+=((" + sizestr$ + ")+15)&-16)>cmem_dynamic_base) error(257);"
            '64K check
            Print #13, "if ((" + sizestr$ + ")>65536) error(257);"
            'clear array
            Print #13, "memset((void*)(" + n$ + "[0]),0," + sizestr$ + ");"
            'set flags
            Print #13, n$ + "[2]=1+2+4;" 'init+static+cmem
        Else
            '64BIT MEMORY
            Print #13, n$ + "[0]=(ptrszint)mem_static_malloc(" + sizestr$ + ");"
            If stringarray Then
                'Init string pointers in the array
                Print #13, "tmp_long=" + elesizestr$ + ";"
                Print #13, "while(tmp_long--){"
                If cmem Then
                    Print #13, "((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new_cmem(0,0);"
                Else
                    Print #13, "((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new(0,0);"
                End If
                Print #13, "}"
            Else
                'clear array
                Print #13, "memset((void*)(" + n$ + "[0]),0," + sizestr$ + ");"
            End If
            Print #13, n$ + "[2]=1+2;" 'init+static
        End If

        If udt > 0 And udtxvariable(udt) Then
            Print #13, "tmp_long=" + elesizestr$ + ";"
            Print #13, "while(tmp_long--){"
            initialise_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
            Print #13, acc$
            Print #13, "}"
        End If

        'Close static array desc
        Print #13, "}"
        allocarray = nume + 65536
    End If
    '------------------END OF STATIC ARRAY CREATION-------------------------

    '------------------DYNAMIC ARRAY CREATION-------------------------------
    If staticarray = 0 Then

        If undefined = 0 Then

            'Generate error if array is static
            f12$ = f12$ + CRLF + "if (" + n$ + "[2]&2){" 'static array
            f12$ = f12$ + CRLF + "error(10);" 'cannot redefine a static array!
            f12$ = f12$ + CRLF + "}else{"
            'Note: Array is either undefined or dynamically defined at this point

            'REDIM (not DIM) must be used to redefine an array
            If redimoption = 0 Then
                f12$ = f12$ + CRLF + "if (" + n$ + "[2]&1){" 'array is defined
                f12$ = f12$ + CRLF + "if (!error_occurred) error(10);" 'cannot redefine an array without using REDIM!
                f12$ = f12$ + CRLF + "}else{"
            Else
                '--------ERASE EXISTING ARRAY IF NECESSARY--------

                'IMPORTANT: If array is not going to be preserved, it should be cleared before
                '           creating the new array for memory considerations

                'refresh lock ID (_MEM)
                f12$ = f12$ + CRLF + "((mem_lock*)((ptrszint*)" + n$ + ")[" + str2(4 * nume + 4 + 1 - 1) + "])->id=(++mem_lock_id);"

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "static int32 preserved_elements;" 'must be put here for scope considerations
                End If

                'If array is defined, it must be destroyed first
                f12$ = f12$ + CRLF + "if (" + n$ + "[2]&1){" 'array is defined

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "preserved_elements=" + elesizestr$ + ";"
                    GoTo skiperase
                End If

                'Note: pointers to strings must be freed before array can be freed
                If stringarray Then
                    f12$ = f12$ + CRLF + "tmp_long=" + elesizestr$ + ";"
                    f12$ = f12$ + CRLF + "while(tmp_long--) qbs_free((qbs*)((uint64*)(" + n$ + "[0]))[tmp_long]);"
                End If
                'As must any variable length strings in UDT's
                If udt > 0 And udtxvariable(udt) Then
                    f12$ = f12$ + CRLF + "tmp_long=" + elesizestr$ + ";"
                    f12$ = f12$ + CRLF + "while(tmp_long--) {"
                    free_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
                    f12$ = f12$ + acc$ + "}"
                End If

                'Free array's memory
                If stringarray Then
                    'Note: String arrays are never in cmem
                    f12$ = f12$ + CRLF + "free((void*)(" + n$ + "[0]));"
                Else
                    'Note: Array may be in cmem!
                    f12$ = f12$ + CRLF + "if (" + n$ + "[2]&4){" 'array is in cmem
                    f12$ = f12$ + CRLF + "cmem_dynamic_free((uint8*)(" + n$ + "[0]));"
                    f12$ = f12$ + CRLF + "}else{" 'not in cmem
                    f12$ = f12$ + CRLF + "free((void*)(" + n$ + "[0]));"
                    f12$ = f12$ + CRLF + "}"
                End If

                skiperase:

                f12$ = f12$ + CRLF + "}" 'array was defined
                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "else preserved_elements=0;" 'if array wasn't defined, no elements are preserved
                End If

                '--------ERASED ARRAY AS NECESSARY--------
            End If 'redim specified

            '--------CREATE ARRAY & CLEAN-UP CODE--------
            'Overwrite existing array dimension sizes/ranges
            f12$ = f12$ + CRLF + sd$
            If stringarray Or ((udt > 0) And udtxvariable(udt)) Then

                'Note: String and variable-length udt arrays are always created in 64bit memory

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "if (preserved_elements){"

                    f12$ = f12$ + CRLF + "static ptrszint tmp_long2;"

                    'free any qbs strings which will be lost in the realloc
                    f12$ = f12$ + CRLF + "tmp_long2=" + elesizestr$ + ";"
                    f12$ = f12$ + CRLF + "if (tmp_long2<preserved_elements){"
                    f12$ = f12$ + CRLF + "for(tmp_long=tmp_long2;tmp_long<preserved_elements;tmp_long++) {"
                    If stringarray Then
                        f12$ = f12$ + CRLF + "qbs_free((qbs*)((uint64*)(" + n$ + "[0]))[tmp_long]);"
                    Else
                        acc$ = ""
                        free_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
                        f12$ = f12$ + acc$
                    End If
                    f12$ = f12$ + CRLF + "}}"
                    'reallocate the array
                    f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)realloc((void*)(" + n$ + "[0]),tmp_long2*" + bytesperelement$ + ");"
                    f12$ = f12$ + CRLF + "if (!" + n$ + "[0]) error(257);" 'not enough memory
                    f12$ = f12$ + CRLF + "if (preserved_elements<tmp_long2){"
                    f12$ = f12$ + CRLF + "for(tmp_long=preserved_elements;tmp_long<tmp_long2;tmp_long++){"
                    If stringarray Then
                        f12$ = f12$ + CRLF + "if (" + n$ + "[2]&4){" 'array is in cmem
                        f12$ = f12$ + CRLF + "((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new_cmem(0,0);"
                        f12$ = f12$ + CRLF + "}else{" 'not in cmem
                        f12$ = f12$ + CRLF + "((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new(0,0);"
                        f12$ = f12$ + CRLF + "}" 'not in cmem
                    Else
                        acc$ = ""
                        initialise_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
                        f12$ = f12$ + acc$
                    End If
                    f12$ = f12$ + CRLF + "}"
                    f12$ = f12$ + CRLF + "}"

                    f12$ = f12$ + CRLF + "}else{"
                End If

                '1. Create array
                f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)malloc(" + sizestr$ + ");"
                f12$ = f12$ + CRLF + "if (!" + n$ + "[0]) error(257);" 'not enough memory
                f12$ = f12$ + CRLF + n$ + "[2]|=1;" 'ADD initialized flag
                f12$ = f12$ + CRLF + "tmp_long=" + elesizestr$ + ";"


                'init individual strings
                If stringarray Then
                    f12$ = f12$ + CRLF + "if (" + n$ + "[2]&4){" 'array is in cmem
                    f12$ = f12$ + CRLF + "while(tmp_long--) ((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new_cmem(0,0);"
                    f12$ = f12$ + CRLF + "}else{" 'not in cmem
                    f12$ = f12$ + CRLF + "while(tmp_long--) ((uint64*)(" + n$ + "[0]))[tmp_long]=(uint64)qbs_new(0,0);"
                    f12$ = f12$ + CRLF + "}" 'not in cmem
                Else 'initialise udt's
                    f12$ = f12$ + CRLF + "while(tmp_long--){"
                    acc$ = ""
                    initialise_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
                    f12$ = f12$ + acc$ + "}"
                End If

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "}"
                End If

                '2. Generate "clean up" code (called when EXITING A SUB/FUNCTION)
                If arraydesc = 0 Then 'only add for first declaration of the array
                    Print #19, "if (" + n$ + "[2]&1){" 'initialized?
                    Print #19, "tmp_long=" + elesizestr$ + ";"
                    If udt > 0 And udtxvariable(udt) Then
                        Print #19, "while(tmp_long--) {"
                        acc$ = ""
                        free_array_udt_varstrings n$, udt, 0, bytesperelement$, acc$
                        Print #19, acc$ + "}"
                    Else
                        Print #19, "while(tmp_long--) qbs_free((qbs*)((uint64*)(" + n$ + "[0]))[tmp_long]);"
                    End If
                    Print #19, "free((void*)(" + n$ + "[0]));"
                    Print #19, "}"
                    'free lock (_MEM)
                    Print #19, "free_mem_lock( (mem_lock*)((ptrszint*)" + n$ + ")[" + str2(4 * nume + 4 + 1 - 1) + "] );"
                End If

            Else 'not string/var-udt array

                '1. Create array
                f12$ = f12$ + CRLF + "if (" + n$ + "[2]&4){" 'array will be in cmem

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "if (preserved_elements){"

                    'reallocation method
                    'backup data
                    f12$ = f12$ + CRLF + "memcpy(redim_preserve_cmem_buffer,(void*)(" + n$ + "[0]),preserved_elements*" + bytesperelement$ + ");"
                    'free old array
                    f12$ = f12$ + CRLF + "cmem_dynamic_free((uint8*)(" + n$ + "[0]));"
                    f12$ = f12$ + CRLF + "tmp_long=" + elesizestr$ + ";"
                    f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)cmem_dynamic_malloc(tmp_long*" + bytesperelement$ + ");"
                    f12$ = f12$ + CRLF + "memcpy((void*)(" + n$ + "[0]),redim_preserve_cmem_buffer,preserved_elements*" + bytesperelement$ + ");"
                    f12$ = f12$ + CRLF + "if (preserved_elements<tmp_long) ZeroMemory(((uint8*)(" + n$ + "[0]))+preserved_elements*" + bytesperelement$ + ",(tmp_long*" + bytesperelement$ + ")-(preserved_elements*" + bytesperelement$ + "));"

                    f12$ = f12$ + CRLF + "}else{"
                End If

                'standard cmem method
                f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)cmem_dynamic_malloc(" + sizestr$ + ");"
                'clear array
                f12$ = f12$ + CRLF + "memset((void*)(" + n$ + "[0]),0," + sizestr$ + ");"

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "}"
                End If

                f12$ = f12$ + CRLF + "}else{" 'not in cmem

                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "if (preserved_elements){"
                    'reallocation method
                    f12$ = f12$ + CRLF + "tmp_long=" + elesizestr$ + ";"
                    f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)realloc((void*)(" + n$ + "[0]),tmp_long*" + bytesperelement$ + ");"
                    f12$ = f12$ + CRLF + "if (!" + n$ + "[0]) error(257);" 'not enough memory
                    f12$ = f12$ + CRLF + "if (preserved_elements<tmp_long) ZeroMemory(((uint8*)(" + n$ + "[0]))+preserved_elements*" + bytesperelement$ + ",(tmp_long*" + bytesperelement$ + ")-(preserved_elements*" + bytesperelement$ + "));"

                    f12$ = f12$ + CRLF + "}else{"
                End If
                'standard allocation method
                f12$ = f12$ + CRLF + n$ + "[0]=(ptrszint)calloc(" + sizestr$ + ",1);"
                f12$ = f12$ + CRLF + "if (!" + n$ + "[0]) error(257);" 'not enough memory
                If redimoption = 2 Then
                    f12$ = f12$ + CRLF + "}"
                End If

                f12$ = f12$ + CRLF + "}" 'not in cmem
                f12$ = f12$ + CRLF + n$ + "[2]|=1;" 'ADD initialized flag

                '2. Generate "clean up" code (called when EXITING A SUB/FUNCTION)
                If arraydesc = 0 Then 'only add for first declaration of the array
                    Print #19, "if (" + n$ + "[2]&1){" 'initialized?
                    Print #19, "if (" + n$ + "[2]&4){" 'array is in cmem
                    Print #19, "cmem_dynamic_free((uint8*)(" + n$ + "[0]));"
                    Print #19, "}else{"
                    Print #19, "free((void*)(" + n$ + "[0]));"
                    Print #19, "}" 'cmem
                    Print #19, "}" 'init
                    'free lock (_MEM)
                    Print #19, "free_mem_lock( (mem_lock*)((ptrszint*)" + n$ + ")[" + str2(4 * nume + 4 + 1 - 1) + "] );"
                End If
            End If 'not string array

        End If 'undefined=0

        '----FINISH ARRAY DESCRIPTOR IF DEFINING FOR THE FIRST TIME----
        If arraydesc = 0 Then
            'Note: Array is init as undefined (& possibly a cmem flag)
            If cmem Then Print #13, n$ + "[2]=4;" Else Print #13, n$ + "[2]=0;"
            'set dimensions as undefined
            For i = 1 To nume
                b = i * 4
                Print #13, n$ + "[" + str2(b) + "]=2147483647;" 'base
                Print #13, n$ + "[" + str2(b + 1) + "]=0;" 'num. index
                Print #13, n$ + "[" + str2(b + 2) + "]=0;" 'multiplier
            Next
            If stringarray Then
                'set array's data offset to the offset of the offset to nothingstring
                Print #13, n$ + "[0]=(ptrszint)&nothingstring;"
            Else
                'set array's data offset to "nothing"
                Print #13, n$ + "[0]=(ptrszint)nothingvalue;"
            End If
            Print #13, "}" 'close array descriptor
        End If 'arraydesc = 0

        If undefined = 0 Then

            If redimoption = 0 Then f12$ = f12$ + CRLF + "}" 'if REDIM not specified the above is conditional
            f12$ = f12$ + CRLF + "}" 'not static

        End If 'undefined=0

        allocarray = nume
        If undefined = -1 Then allocarray = -1

    End If

    If autoary = 0 Then
        If dimoption = 3 Then 'STATIC a(100) puts creation code in main
            Print #13, f12$
        Else
            Print #12, f12$
        End If
    End If

    '[8] offset of data
    '[8] reserved (could be used to store a bit offset)
    '(the following repeats depending on the number of elements)
    '[4] base-offset
    '[4] number of indexes
    '[4] multiplier (the last multiplier doesn't actually exist)
    '[4] reserved

    dimshared = dimsharedlast

    tlayout$ = l$
End Function

Function arrayreference$ (indexes$, typ)
    arrayprocessinghappened = 1
    '*returns an array reference: idnumber | index$
    '*does not take into consideration the type of the array

    '*expects array id to be passed in the global id structure

    idnumber$ = str2(currentid)

    Dim id2 As idstruct

    id2 = id

    a$ = indexes$
    typ = id2.arraytype + ISARRAY + ISREFERENCE
    n$ = RTrim$(id2.callname)

    If a$ = "" Then 'no indexes passed eg. a()
        r$ = "0"
        GoTo gotarrayindex
    End If

    n = numelements(a$)

    'find number of elements supplied
    elements = 1
    b = 0
    For i = 1 To n
        a = Asc(getelement(a$, i))
        If a = 40 Then b = b + 1
        If a = 41 Then b = b - 1
        If a = 44 And b = 0 Then elements = elements + 1
    Next

    If id2.arrayelements = -1 Then
        If arrayelementslist(currentid) <> 0 And elements <> arrayelementslist(currentid) Then Give_Error "Cannot change the number of elements an array has!": Exit Function
        If elements = 1 Then id2.arrayelements = 1: ids(currentid).arrayelements = 1 'lucky guess
        arrayelementslist(currentid) = elements
    Else
        If elements <> id2.arrayelements Then Give_Error "Cannot change the number of elements an array has!": Exit Function
    End If

    curarg = 1
    firsti = 1
    For i = 1 To n
        l$ = getelement(a$, i)
        If l$ = "(" Then b = b + 1
        If l$ = ")" Then b = b - 1
        If (l$ = "," And b = 0) Or (i = n) Then
            If i = n Then
                If l$ = "," Then Give_Error "Array index missing": Exit Function
                e$ = evaluatetotyp(getelements$(a$, firsti, i), 64&)
                If Error_Happened Then Exit Function
            Else
                e$ = evaluatetotyp(getelements$(a$, firsti, i - 1), 64&)
                If Error_Happened Then Exit Function
            End If
            If e$ = "" Then Give_Error "Array index missing": Exit Function
            argi = (elements - curarg) * 4 + 4
            If curarg = 1 Then
                If NoChecks = 0 Then
                    r$ = r$ + "array_check((" + e$ + ")-" + n$ + "[" + str2(argi) + "]," + n$ + "[" + str2(argi + 1) + "])+"
                Else
                    r$ = r$ + "(" + e$ + ")-" + n$ + "[" + str2(argi) + "]+"
                End If

            Else
                If NoChecks = 0 Then
                    r$ = r$ + "array_check((" + e$ + ")-" + n$ + "[" + str2(argi) + "]," + n$ + "[" + str2(argi + 1) + "])*" + n$ + "[" + str2(argi + 2) + "]+"
                Else
                    r$ = r$ + "((" + e$ + ")-" + n$ + "[" + str2(argi) + "])*" + n$ + "[" + str2(argi + 2) + "]+"
                End If
            End If
            firsti = i + 1
            curarg = curarg + 1
        End If
    Next
    r$ = Left$(r$, Len(r$) - 1) 'remove trailing +
    gotarrayindex:

    r$ = idnumber$ + sp3 + r$
    arrayreference$ = r$
    'PRINT "arrayreference returning:" + r$
End Function

Sub assign (a$, n)
    For i = 1 To n
        c = Asc(getelement$(a$, i))
        If c = 40 Then b = b + 1 '(
        If c = 41 Then b = b - 1 ')
        If c = 61 And b = 0 Then '=
            If i = 1 Then Give_Error "Expected ... =": Exit Sub
            If i = n Then Give_Error "Expected = ...": Exit Sub

            a2$ = fixoperationorder(getelements$(a$, 1, i - 1))
            If Error_Happened Then Exit Sub
            l$ = tlayout$ + sp + "=" + sp

            'note: evaluating a2$ will fail if it is setting a function's return value without this check (as the function, not the return-variable) will be found by evaluate)
            If i = 2 Then 'lhs has only 1 element
                try = findid(a2$)
                If Error_Happened Then Exit Sub
                Do While try
                    If id.t Then
                        If subfuncn = id.insubfuncn Then 'avoid global before local
                            If (id.t And ISUDT) = 0 Then
                                makeidrefer a2$, typ
                                GoTo assignsimplevariable
                            End If
                        End If
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(a2$) Else try = 0
                    If Error_Happened Then Exit Sub
                Loop
            End If

            a2$ = evaluate$(a2$, typ): If Error_Happened Then Exit Sub
            assignsimplevariable:
            If (typ And ISREFERENCE) = 0 Then Give_Error "Expected variable =": Exit Sub
            setrefer a2$, typ, getelements$(a$, i + 1, n), 0
            If Error_Happened Then Exit Sub
            tlayout$ = l$ + tlayout$

            Exit Sub

        End If '=,b=0
    Next
    Give_Error "Expected =": Exit Sub
End Sub

Sub clearid
    id = cleariddata
End Sub

Sub closemain
    xend
    Print #12, "return;"
    Print #12, "}"
    Print #15, "}" 'end case
    Print #15, "}"
    Print #15, "error(3);" 'no valid return possible
    closedmain = 1
End Sub

Function countelements (a$)
    n = numelements(a$)
    c = 1
    For i = 1 To n
        e$ = getelement$(a$, i)
        If e$ = "(" Then b = b + 1
        If e$ = ")" Then b = b - 1
        If b < 0 Then Give_Error "Unexpected ) encountered": Exit Function
        If e$ = "," And b = 0 Then c = c + 1
    Next
    countelements = c
End Function

Function dim2 (varname$, typ2$, method, elements$)
    'notes: (DO NOT REMOVE THESE IMPORTANT USAGE NOTES)
    '
    '(shared)dimsfarray: Creates an ID only (no C++ code)
    '                    Adds an index/'link' to the sub/function's argument
    '                        ID.sfid=glinkid
    '                        ID.sfarg=glinkarg
    '                    Sets arrayelements=-1 'unknown' (if elements$="?") otherwise val(elements$)
    '                    ***Does not refer to arrayelementslist()***
    '
    '(argument)method: 0 being created by a DIM name AS type
    '                  1 being created by a DIM name+symbol
    '                  or automatically without the use of DIM
    '
    'elements$="?": (see also dimsfarray for that special case)
    '               Checks arrayelementslist() and;
    '               if unknown(=0), creates an ID only
    '               if known, creates a DYNAMIC array's C++ initialization code so it can be used later
    '
    typ$ = typ2$
    dim2 = 1 'success

    cvarname$ = varname$
    l$ = cvarname$
    varname$ = UCase$(varname$)

    If dimsfarray = 1 Then f = 0 Else f = 1

    If dimstatic <> 0 And dimshared = 0 Then
        'name will have include the sub/func name in its scope
        'variable/array will be created in main on startup
        defdatahandle = 18 'change from 13 to 18(global.txt)
        Close #13: Open tmpdir$ + "maindata.txt" For Append As #13
        Close #19: Open tmpdir$ + "mainfree.txt" For Append As #19
    End If

    scope2$ = module$ + "_" + subfunc$ + "_"
    'Note: when REDIMing a SHARED array in dynamic memory scope2$ must be modified

    If Len(typ$) = 0 Then Give_Error "DIM2: No type specified!": Exit Function

    'UDT
    'is it a udt?
    For i = 1 To lasttype
        If typ$ = RTrim$(udtxname(i)) Then
            dim2typepassback$ = RTrim$(udtxcname(i))
            If typ$ = "MEM" And RTrim$(udtxname(i)) = "_MEM" Then
                dim2typepassback$ = Mid$(RTrim$(udtxcname(i)), 2)
            End If

            n$ = "UDT_" + varname$

            'array of UDTs
            If elements$ <> "" Then
                arraydesc = 0
                If f = 1 Then
                    try = findid(varname$)
                    If Error_Happened Then Exit Function
                    Do While try
                        If (id.arraytype) Then
                            l$ = RTrim$(id.cn)
                            arraydesc = currentid: scope2$ = scope$
                            Exit Do
                        End If
                        If try = 2 Then findanotherid = 1: try = findid(varname$) Else try = 0
                        If Error_Happened Then Exit Function
                    Loop
                End If
                n$ = scope2$ + "ARRAY_" + n$
                bits = udtxsize(i)
                If udtxbytealign(i) Then
                    If bits Mod 8 Then bits = bits + 8 - (bits Mod 8)
                End If

                If f = 1 Then

                    If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                        E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                    End If
                    nume = allocarray(n$, elements$, -bits, i)
                    If Error_Happened Then Exit Function
                    l$ = l$ + sp + tlayout$
                    If arraydesc Then GoTo dim2exitfunc
                    clearid

                Else
                    clearid
                    If elements$ = "?" Then
                        nume = -1
                        id.linkid = glinkid
                        id.linkarg = glinkarg
                    Else
                        nume = Val(elements$)
                    End If
                End If

                id.arraytype = UDTTYPE + i
                If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
                id.n = cvarname$

                If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

                id.arrayelements = nume
                id.callname = n$
                regid
                If Error_Happened Then Exit Function
                GoTo dim2exitfunc
            End If

            'not an array of UDTs
            bits = udtxsize(i): bytes = bits \ 8
            If bits Mod 8 Then
                bytes = bytes + 1
            End If
            n$ = scope2$ + n$
            If f Then Print #defdatahandle, "void *" + n$ + "=NULL;"
            clearid
            id.n = cvarname$
            id.t = UDTTYPE + i
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f Then
                    Print #13, "if(" + n$ + "==NULL){"
                    Print #13, "cmem_sp-=" + str2(bytes) + ";"
                    Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                    Print #13, n$ + "=(void*)(dblock+cmem_sp);"
                    Print #13, "memset(" + n$ + ",0," + str2(bytes) + ");"
                    Print #13, "}"
                End If
            Else
                If f Then
                    Print #13, "if(" + n$ + "==NULL){"
                    Print #13, n$ + "=(void*)mem_static_malloc(" + str2$(bytes) + ");"
                    Print #13, "memset(" + n$ + ",0," + str2(bytes) + ");"
                    If udtxvariable(i) Then
                        initialise_udt_varstrings n$, i, 13, 0
                        free_udt_varstrings n$, i, 19, 0
                    End If
                    Print #13, "}"
                End If
            End If
            id.callname = n$
            regid
            If Error_Happened Then Exit Function
            GoTo dim2exitfunc
        End If
    Next i
    'it isn't a udt

    typ$ = symbol2fulltypename$(typ$)
    If Error_Happened Then Exit Function

    'check if _UNSIGNED was specified
    unsgn = 0
    If Left$(typ$, 10) = "_UNSIGNED " Then
        unsgn = 1
        typ$ = Mid$(typ$, InStr(typ$, Chr$(32)) + 1)
        If Len(typ$) = 0 Then Give_Error "Expected more type information after " + qb64prefix$ + "UNSIGNED!": Exit Function
    End If

    n$ = "" 'n$ is assumed to be "" after branching into the code for each type

    If Left$(typ$, 6) = "STRING" Then

        If Len(typ$) > 6 Then
            If Left$(typ$, 9) <> "STRING * " Then Give_Error "Expected STRING * number/constant": Exit Function

            c$ = Right$(typ$, Len(typ$) - 9)

            'constant check 2011
            hashfound = 0
            hashname$ = c$
            hashchkflags = HASHFLAG_CONSTANT
            hashres = HashFindRev(hashname$, hashchkflags, hashresflags, hashresref)
            Do While hashres
                If constsubfunc(hashresref) = subfuncn Or constsubfunc(hashresref) = 0 Then
                    If constdefined(hashresref) Then
                        hashfound = 1
                        Exit Do
                    End If
                End If
                If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
            Loop
            If hashfound Then
                i2 = hashresref
                t = consttype(i2)
                If t And ISSTRING Then Give_Error "Expected STRING * numeric-constant": Exit Function
                'convert value to general formats
                If t And ISFLOAT Then
                    v## = constfloat(i2)
                    v&& = v##
                    v~&& = v&&
                Else
                    If t And ISUNSIGNED Then
                        v~&& = constuinteger(i2)
                        v&& = v~&&
                        v## = v&&
                    Else
                        v&& = constinteger(i2)
                        v## = v&&
                        v~&& = v&&
                    End If
                End If
                If v&& < 1 Or v&& > 9999999999 Then Give_Error "STRING * out-of-range constant": Exit Function
                bytes = v&&
                dim2typepassback$ = SCase$("String * ") + constcname(i2)
                GoTo constantlenstr
            End If

            If isuinteger(c$) = 0 Then Give_Error "Number/Constant expected after *": Exit Function
            If Len(c$) > 10 Then Give_Error "Too many characters in number after *": Exit Function
            bytes = Val(c$)
            If bytes = 0 Then Give_Error "Cannot create a fixed string of length 0": Exit Function
            constantlenstr:
            n$ = "STRING" + str2(bytes) + "_" + varname$

            'array of fixed length strings
            If elements$ <> "" Then
                arraydesc = 0
                If f = 1 Then
                    try = findid(varname$ + "$")
                    If Error_Happened Then Exit Function
                    Do While try
                        If (id.arraytype) Then
                            l$ = RTrim$(id.cn)
                            arraydesc = currentid: scope2$ = scope$
                            Exit Do
                        End If
                        If try = 2 Then findanotherid = 1: try = findid(varname$ + "$") Else try = 0
                        If Error_Happened Then Exit Function
                    Loop
                End If
                n$ = scope2$ + "ARRAY_" + n$

                If f = 1 Then

                    If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                        E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                    End If
                    nume = allocarray(n$, elements$, bytes, 0)
                    If Error_Happened Then Exit Function
                    l$ = l$ + sp + tlayout$
                    If arraydesc Then GoTo dim2exitfunc
                    clearid

                Else
                    clearid
                    If elements$ = "?" Then
                        nume = -1
                        id.linkid = glinkid
                        id.linkarg = glinkarg
                    Else
                        nume = Val(elements$)
                    End If
                End If

                id.arraytype = STRINGTYPE + ISFIXEDLENGTH
                If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
                id.n = cvarname$
                If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

                id.arrayelements = nume
                id.callname = n$
                id.tsize = bytes
                If method = 0 Then
                    id.mayhave = "$" + str2(bytes)
                End If
                If method = 1 Then
                    id.musthave = "$" + str2(bytes)
                End If
                regid
                If Error_Happened Then Exit Function
                GoTo dim2exitfunc
            End If

            'standard fixed length string
            n$ = scope2$ + n$
            If f Then Print #defdatahandle, "qbs *" + n$ + "=NULL;"
            If f Then Print #19, "qbs_free(" + n$ + ");" 'so descriptor can be freed
            clearid
            id.n = cvarname$
            id.t = STRINGTYPE + ISFIXEDLENGTH
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f Then Print #13, "if(" + n$ + "==NULL){"
                If f Then Print #13, "cmem_sp-=" + str2(bytes) + ";"
                If f Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                If f Then Print #13, n$ + "=qbs_new_fixed((uint8*)(dblock+cmem_sp)," + str2(bytes) + ",0);"
                If f Then Print #13, "memset(" + n$ + "->chr,0," + str2(bytes) + ");"
                If f Then Print #13, "}"
            Else
                If f Then Print #13, "if(" + n$ + "==NULL){"
                o$ = "(uint8*)mem_static_malloc(" + str2$(bytes) + ")"
                If f Then Print #13, n$ + "=qbs_new_fixed(" + o$ + "," + str2$(bytes) + ",0);"
                If f Then Print #13, "memset(" + n$ + "->chr,0," + str2$(bytes) + ");"
                If f Then Print #13, "}"
            End If
            id.tsize = bytes
            If method = 0 Then
                id.mayhave = "$" + str2(bytes)
            End If
            If method = 1 Then
                id.musthave = "$" + str2(bytes)
            End If
            id.callname = n$
            regid
            If Error_Happened Then Exit Function
            GoTo dim2exitfunc
        End If

        'variable length string processing
        n$ = "STRING_" + varname$

        'array of variable length strings
        If elements$ <> "" Then
            arraydesc = 0
            If f = 1 Then
                try = findid(varname$ + "$")
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(varname$ + "$") Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, -2147483647, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.n = cvarname$
            id.arraytype = STRINGTYPE
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
            If method = 0 Then
                id.mayhave = "$"
            End If
            If method = 1 Then
                id.musthave = "$"
            End If
            regid
            If Error_Happened Then Exit Function
            GoTo dim2exitfunc
        End If

        'standard variable length string
        n$ = scope2$ + n$
        clearid
        id.n = cvarname$
        id.t = STRINGTYPE
        If cmemlist(idn + 1) Then
            If f Then Print #defdatahandle, "qbs *" + n$ + "=NULL;"
            If f Then Print #13, "if (!" + n$ + ")" + n$ + "=qbs_new_cmem(0,0);"
            id.t = id.t + ISINCONVENTIONALMEMORY
        Else
            If f Then Print #defdatahandle, "qbs *" + n$ + "=NULL;"
            If f Then Print #13, "if (!" + n$ + ")" + n$ + "=qbs_new(0,0);"
        End If
        If f Then Print #19, "qbs_free(" + n$ + ");"
        If method = 0 Then
            id.mayhave = "$"
        End If
        If method = 1 Then
            id.musthave = "$"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If Left$(typ$, 4) = "_BIT" Then
        If (Left$(typ$, 4) = "_BIT" And Len(typ$) > 4) Or (Left$(typ$, 3) = "BIT" And Len(typ$) > 3) Then
            If Left$(typ$, 7) <> "_BIT * " And Left$(typ$, 6) <> "BIT * " Then Give_Error "Expected " + qb64prefix$ + "BIT * number": Exit Function
            c$ = Mid$(typ$, InStr(typ$, " * ") + 3)
            If isuinteger(c$) = 0 Then Give_Error "Number expected after *": Exit Function
            If Len(c$) > 2 Then Give_Error "Cannot create a bit variable of size > 64 bits": Exit Function
            bits = Val(c$)
            If bits = 0 Then Give_Error "Cannot create a bit variable of size 0 bits": Exit Function
            If bits > 64 Then Give_Error "Cannot create a bit variable of size > 64 bits": Exit Function
        Else
            bits = 1
        End If
        If bits <= 32 Then ct$ = "int32" Else ct$ = "int64"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "BIT" + str2(bits) + "_" + varname$

        'array of bit-length variables
        If elements$ <> "" Then
            If bits > 63 Then Give_Error "Cannot create a bit array of size > 63 bits": Exit Function
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "`" + str2(bits)
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, -bits, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.n = cvarname$
            id.arraytype = BITTYPE - 1 + bits
            If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
            If method = 0 Then
                If unsgn Then id.mayhave = "~`" + str2(bits) Else id.mayhave = "`" + str2(bits)
            End If
            If method = 1 Then
                If unsgn Then id.musthave = "~`" + str2(bits) Else id.musthave = "`" + str2(bits)
            End If
            regid
            If Error_Happened Then Exit Function
            GoTo dim2exitfunc
        End If
        'standard bit-length variable
        n$ = scope2$ + n$
        Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
        Print #13, "if(" + n$ + "==NULL){"
        Print #13, "cmem_sp-=4;"
        Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
        Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
        Print #13, "*" + n$ + "=0;"
        Print #13, "}"
        clearid
        id.n = cvarname$
        id.t = BITTYPE - 1 + bits + ISINCONVENTIONALMEMORY: If unsgn Then id.t = id.t + ISUNSIGNED
        If method = 0 Then
            If unsgn Then id.mayhave = "~`" + str2(bits) Else id.mayhave = "`" + str2(bits)
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~`" + str2(bits) Else id.musthave = "`" + str2(bits)
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "_BYTE" Then
        ct$ = "int8"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "BYTE_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "%%"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop

            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 1, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = BYTETYPE: If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = BYTETYPE: If unsgn Then id.t = id.t + ISUNSIGNED
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=1;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(1);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            If unsgn Then id.mayhave = "~%%" Else id.mayhave = "%%"
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~%%" Else id.musthave = "%%"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "INTEGER" Then
        ct$ = "int16"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "INTEGER_" + varname$

        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "%"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 2, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = INTEGERTYPE: If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = INTEGERTYPE: If unsgn Then id.t = id.t + ISUNSIGNED
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=2;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(2);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            If unsgn Then id.mayhave = "~%" Else id.mayhave = "%"
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~%" Else id.musthave = "%"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "_OFFSET" Then
        ct$ = "ptrszint"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "OFFSET_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "%&"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, OS_BITS \ 8, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = OFFSETTYPE: If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = OFFSETTYPE: If unsgn Then id.t = id.t + ISUNSIGNED
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=" + str2(OS_BITS \ 8) + ";"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(" + str2(OS_BITS \ 8) + ");"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            If unsgn Then id.mayhave = "~%&" Else id.mayhave = "%&"
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~%&" Else id.musthave = "%&"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "LONG" Then
        ct$ = "int32"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "LONG_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "&"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 4, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = LONGTYPE: If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = LONGTYPE: If unsgn Then id.t = id.t + ISUNSIGNED
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=4;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(4);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            If unsgn Then id.mayhave = "~&" Else id.mayhave = "&"
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~&" Else id.musthave = "&"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "_INTEGER64" Then
        ct$ = "int64"
        If unsgn Then n$ = "U": ct$ = "u" + ct$
        n$ = n$ + "INTEGER64_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$: If unsgn Then cmps$ = cmps$ + "~"
            cmps$ = cmps$ + "&&"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 8, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = INTEGER64TYPE: If unsgn Then id.arraytype = id.arraytype + ISUNSIGNED
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = INTEGER64TYPE: If unsgn Then id.t = id.t + ISUNSIGNED
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=8;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(8);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            If unsgn Then id.mayhave = "~&&" Else id.mayhave = "&&"
        End If
        If method = 1 Then
            If unsgn Then id.musthave = "~&&" Else id.musthave = "&&"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If unsgn = 1 Then Give_Error "Type cannot be unsigned": Exit Function

    If typ$ = "SINGLE" Then
        ct$ = "float"
        n$ = n$ + "SINGLE_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$ + "!"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 4, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = SINGLETYPE
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = SINGLETYPE
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=4;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(4);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            id.mayhave = "!"
        End If
        If method = 1 Then
            id.musthave = "!"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "DOUBLE" Then
        ct$ = "double"
        n$ = n$ + "DOUBLE_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$ + "#"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then

                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 8, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid

            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = DOUBLETYPE
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = DOUBLETYPE
            If f = 1 Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f = 1 Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f = 1 Then Print #13, "cmem_sp-=8;"
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f = 1 Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f = 1 Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(8);"
            End If
            If f = 1 Then Print #13, "*" + n$ + "=0;"
            If f = 1 Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            id.mayhave = "#"
        End If
        If method = 1 Then
            id.musthave = "#"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    If typ$ = "_FLOAT" Then
        ct$ = "long double"
        n$ = n$ + "FLOAT_" + varname$
        If elements$ <> "" Then
            arraydesc = 0
            cmps$ = varname$ + "##"
            If f = 1 Then
                try = findid(cmps$)
                If Error_Happened Then Exit Function
                Do While try
                    If (id.arraytype) Then
                        l$ = RTrim$(id.cn)
                        arraydesc = currentid: scope2$ = scope$
                        Exit Do
                    End If
                    If try = 2 Then findanotherid = 1: try = findid(cmps$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            End If
            n$ = scope2$ + "ARRAY_" + n$

            If f = 1 Then
                If Len(elements$) = 1 And Asc(elements$) = 63 Then '"?"
                    E = arrayelementslist(idn + 1): If E Then elements$ = elements$ + str2$(E) 'eg. "?3" for a 3 dimensional array
                End If
                nume = allocarray(n$, elements$, 32, 0)
                If Error_Happened Then Exit Function
                l$ = l$ + sp + tlayout$
                If arraydesc Then GoTo dim2exitfunc
                clearid
            Else
                clearid
                If elements$ = "?" Then
                    nume = -1
                    id.linkid = glinkid
                    id.linkarg = glinkarg
                Else
                    nume = Val(elements$)
                End If
            End If

            id.arraytype = FLOATTYPE
            If cmemlist(idn + 1) Then id.arraytype = id.arraytype + ISINCONVENTIONALMEMORY
            If nume > 65536 Then nume = nume - 65536: id.staticarray = 1

            id.arrayelements = nume
            id.callname = n$
        Else
            n$ = scope2$ + n$
            clearid
            id.t = FLOATTYPE
            If f Then Print #defdatahandle, ct$ + " *" + n$ + "=NULL;"
            If f Then Print #13, "if(" + n$ + "==NULL){"
            If cmemlist(idn + 1) Then
                id.t = id.t + ISINCONVENTIONALMEMORY
                If f Then Print #13, "cmem_sp-=32;"
                If f Then Print #13, n$ + "=(" + ct$ + "*)(dblock+cmem_sp);"
                If f Then Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
            Else
                If f Then Print #13, n$ + "=(" + ct$ + "*)mem_static_malloc(32);"
            End If
            If f Then Print #13, "*" + n$ + "=0;"
            If f Then Print #13, "}"
        End If
        id.n = cvarname$
        If method = 0 Then
            id.mayhave = "##"
        End If
        If method = 1 Then
            id.musthave = "##"
        End If
        id.callname = n$
        regid
        If Error_Happened Then Exit Function
        GoTo dim2exitfunc
    End If

    Give_Error "Unknown type": Exit Function
    dim2exitfunc:

    bypassNextVariable = 0

    If dimsfarray Then
        ids(idn).sfid = glinkid
        ids(idn).sfarg = glinkarg
    End If

    'restore STATIC state
    If dimstatic <> 0 And dimshared = 0 Then
        defdatahandle = 13
        Close #13: Open tmpdir$ + "data" + str2$(subfuncn) + ".txt" For Append As #13
        Close #19: Open tmpdir$ + "free" + str2$(subfuncn) + ".txt" For Append As #19
    End If

    tlayout$ = l$

End Function

Function udtreference$ (o$, a$, typ As Long)
    'UDT REFERENCE FORMAT
    'idno|udtno|udtelementno|byteoffset
    '     ^udt of the element, not of the id

    obak$ = o$

    'PRINT "called udtreference!"

    r$ = str2$(currentid) + sp3

    o = 0 'the fixed/known part of the offset

    incmem = 0
    If id.t Then
        u = id.t And 511
        If id.t And ISINCONVENTIONALMEMORY Then incmem = 1
    Else
        u = id.arraytype And 511
        If id.arraytype And ISINCONVENTIONALMEMORY Then incmem = 1
    End If
    E = 0

    n = numelements(a$)
    If n = 0 Then GoTo fulludt

    i = 1
    udtfindelenext:
    If getelement$(a$, i) <> "." Then Give_Error "Expected .": Exit Function
    i = i + 1
    n$ = getelement$(a$, i)
    nsym$ = removesymbol(n$): If Len(nsym$) Then ntyp = typname2typ(nsym$): ntypsize = typname2typsize
    If Error_Happened Then Exit Function

    If n$ = "" Then Give_Error "Expected .elementname": Exit Function
    udtfindele:
    If E = 0 Then E = udtxnext(u) Else E = udtenext(E)
    If E = 0 Then Give_Error "Element not defined": Exit Function
    n2$ = RTrim$(udtename(E))
    If udtebytealign(E) Then
        If o Mod 8 Then o = o + (8 - (o Mod 8))
    End If

    If n$ <> n2$ Then
        'increment fixed offset
        o = o + udtesize(E)
        GoTo udtfindele
    End If

    'check symbol after element's name (if given) is correct
    If Len(nsym$) Then

        If udtetype(E) And ISUDT Then Give_Error "Invalid symbol after user defined type": Exit Function
        If ntyp <> udtetype(E) Or ntypsize <> udtetypesize(E) Then
            If nsym$ = "$" And ((udtetype(E) And ISFIXEDLENGTH) <> 0) Then GoTo correctsymbol
            Give_Error "Incorrect symbol after element name": Exit Function
        End If
    End If
    correctsymbol:

    'Move into another UDT structure?
    If i <> n Then
        If (udtetype(E) And ISUDT) = 0 Then Give_Error "Expected user defined type": Exit Function
        u = udtetype(E) And 511
        E = 0
        i = i + 1
        GoTo udtfindelenext
    End If

    'Change e reference to u | 0 reference?
    If udtetype(E) And ISUDT Then
        u = udtetype(E) And 511
        E = 0
    End If

    fulludt:

    r$ = r$ + str2$(u) + sp3 + str2$(E) + sp3

    If o Mod 8 Then Give_Error "QB64 cannot handle bit offsets within user defined types": Exit Function
    o = o \ 8

    If o$ <> "" Then
        If o <> 0 Then 'dont add an unnecessary 0
            o$ = o$ + "+" + str2$(o)
        End If
    Else
        o$ = str2$(o)
    End If

    r$ = r$ + o$

    udtreference$ = r$
    typ = udtetype(E) + ISUDT + ISREFERENCE

    'full udt override:
    If E = 0 Then
        typ = u + ISUDT + ISREFERENCE
    End If

    If obak$ <> "" Then typ = typ + ISARRAY
    If incmem Then typ = typ + ISINCONVENTIONALMEMORY

    'print "UDTREF:"+r$+","+str2$(typ)

End Function

Function evaluate$ (a2$, typ As Long)
    Dim block(1000) As String
    Dim evaledblock(1000) As Integer
    Dim blocktype(1000) As Long
    'typ IS A RETURN VALUE
    '''DIM cli(15) AS INTEGER
    a$ = a2$
    typ = -1

    If a2$ = "" Then Give_Error "Syntax error": Exit Function

    blockn = 0
    n = numelements(a$)
    b = 0 'bracketting level
    For i = 1 To n
        reevaluate:

        l$ = getelement(a$, i)

        If i <> n Then nextl$ = getelement(a$, i + 1) Else nextl$ = ""

        '''getclass cl$, i, cli()

        If b = 0 Then 'don't evaluate anything within brackets
            l2$ = l$ 'pure version of l$
            For try_method = 1 To 4
                l$ = l2$
                If try_method = 2 Or try_method = 4 Then
                    If Error_Happened Then Exit Function
                    dtyp$ = removesymbol(l$): If Error_Happened Then dtyp$ = "": Error_Happened = 0
                    If Len(dtyp$) = 0 Then
                        If isoperator(l$) = 0 Then
                            If isvalidvariable(l$) Then
                                If Left$(l$, 1) = "_" Then v = 27 Else v = Asc(UCase$(l$)) - 64
                                l$ = l$ + defineextaz(v)
                            End If
                        End If
                    Else
                        l$ = l2$
                    End If
                End If
                try = findid(l$)
                If Error_Happened Then Exit Function
                Do While try
                    'is l$ an array?
                    If nextl$ = "(" Then
                        If id.arraytype Then
                            If (subfuncn = id.insubfuncn And try_method <= 2) Or try_method >= 3 Then
                                arrayid = currentid
                                constequation = 0
                                i2 = i + 2
                                b2 = 0
                                evalnextele3:
                                l2$ = getelement(a$, i2)
                                If l2$ = "(" Then b2 = b2 + 1
                                If l2$ = ")" Then
                                    b2 = b2 - 1
                                    If b2 = -1 Then
                                        c$ = arrayreference(getelements$(a$, i + 2, i2 - 1), typ2)
                                        If Error_Happened Then Exit Function
                                        i = i2

                                        'UDT
                                        If typ2 And ISUDT Then
                                            'print "arrayref returned:"+c$
                                            getid arrayid
                                            If Error_Happened Then Exit Function
                                            o$ = Right$(c$, Len(c$) - InStr(c$, sp3))
                                            'change o$ to a byte offset if necessary
                                            u = typ2 And 511
                                            s = udtxsize(u)
                                            If udtxbytealign(u) Then
                                                If s Mod 8 Then s = s + (8 - (s Mod 8)) 'round up to nearest byte
                                                s = s \ 8
                                            End If
                                            o$ = "(" + o$ + ")*" + str2$(s)
                                            'print "calling evaludt with o$:"+o$
                                            GoTo evaludt
                                        End If

                                        GoTo evalednextele3
                                    End If
                                End If
                                i2 = i2 + 1
                                GoTo evalnextele3
                                evalednextele3:
                                blockn = blockn + 1
                                block(blockn) = c$
                                evaledblock(blockn) = 2
                                blocktype(blockn) = typ2
                                If (typ2 And ISSTRING) Then stringprocessinghappened = 1
                                GoTo evaled
                            End If
                        End If

                    Else
                        'not followed by "("

                        'is l$ a simple variable?
                        If id.t <> 0 And (id.t And ISUDT) = 0 Then
                            If (subfuncn = id.insubfuncn And try_method <= 2) Or try_method >= 3 Then
                                constequation = 0
                                blockn = blockn + 1
                                makeidrefer block(blockn), blocktype(blockn)
                                If (blocktype(blockn) And ISSTRING) Then stringprocessinghappened = 1
                                evaledblock(blockn) = 2
                                GoTo evaled
                            End If
                        End If

                        'is l$ a UDT?
                        If id.t And ISUDT Then
                            If (subfuncn = id.insubfuncn And try_method <= 2) Or try_method >= 3 Then
                                constequation = 0
                                o$ = ""
                                evaludt:
                                b2 = 0
                                i3 = i + 1
                                For i2 = i3 To n
                                    e2$ = getelement(a$, i2)
                                    If e2$ = "(" Then b2 = b2 + 1
                                    If b2 = 0 Then
                                        If e2$ = ")" Or isoperator(e2$) Then
                                            i4 = i2 - 1
                                            GoTo gotudt
                                        End If
                                    End If
                                    If e2$ = ")" Then b2 = b2 - 1
                                Next
                                i4 = n
                                gotudt:
                                If i4 < i3 Then e$ = "" Else e$ = getelements$(a$, i3, i4)
                                'PRINT "UDTREFERENCE:";l$; e$
                                e$ = udtreference(o$, e$, typ2)
                                If Error_Happened Then Exit Function
                                i = i4
                                blockn = blockn + 1
                                block(blockn) = e$
                                evaledblock(blockn) = 2
                                blocktype(blockn) = typ2
                                'is the following next necessary?
                                'IF (typ2 AND ISSTRING) THEN stringprocessinghappened = 1
                                GoTo evaled
                            End If
                        End If

                    End If '"(" or no "("

                    'is l$ a function?
                    If id.subfunc = 1 Then
                        constequation = 0
                        If getelement(a$, i + 1) = "(" Then
                            i2 = i + 2
                            b2 = 0
                            args = 1
                            evalnextele:
                            l2$ = getelement(a$, i2)
                            If l2$ = "(" Then b2 = b2 + 1
                            If l2$ = ")" Then
                                b2 = b2 - 1
                                If b2 = -1 Then
                                    If i2 = i + 2 Then Give_Error "Expected (...)": Exit Function
                                    c$ = evaluatefunc(getelements$(a$, i + 2, i2 - 1), args, typ2)
                                    If Error_Happened Then Exit Function
                                    i = i2
                                    GoTo evalednextele
                                End If
                            End If
                            If l2$ = "," And b2 = 0 Then args = args + 1
                            i2 = i2 + 1
                            GoTo evalnextele
                        Else
                            'no brackets
                            c$ = evaluatefunc("", 0, typ2)
                            If Error_Happened Then Exit Function
                        End If
                        evalednextele:
                        blockn = blockn + 1
                        block(blockn) = c$
                        evaledblock(blockn) = 2
                        blocktype(blockn) = typ2
                        If (typ2 And ISSTRING) Then stringprocessinghappened = 1
                        GoTo evaled
                    End If

                    If try = 2 Then findanotherid = 1: try = findid(l$) Else try = 0
                    If Error_Happened Then Exit Function
                Loop
            Next 'try method (1-4)

            'assume l$ an undefined array?

            If i <> n Then
                If getelement$(a$, i + 1) = "(" Then
                    If isoperator(l$) = 0 Then
                        If isvalidvariable(l$) Then
                            dtyp$ = removesymbol(l$)
                            If Error_Happened Then Exit Function
                            'count the number of elements
                            nume = 1
                            b2 = 0
                            For i2 = i + 2 To n
                                e$ = getelement(a$, i2)
                                If e$ = "(" Then b2 = b2 + 1
                                If b2 = 0 And e$ = "," Then nume = nume + 1
                                If e$ = ")" Then b2 = b2 - 1
                                If b2 = -1 Then Exit For
                            Next
                            fakee$ = "10": For i2 = 2 To nume: fakee$ = fakee$ + sp + "," + sp + "10": Next
                            If optionexplicit Or optionexplicitarray Then Give_Error "Array '" + l$ + "' (" + symbol2fulltypename$(dtyp$) + ") not defined": Exit Function
                            If Error_Happened Then Exit Function
                            olddimstatic = dimstatic
                            method = 1
                            If subfuncn Then
                                autoarray = 1 'move dimensioning of auto array to data???.txt from inline
                                'static array declared by STATIC name()?
                                'check if varname is on the static list
                                xi = 1
                                For x = 1 To staticarraylistn
                                    varname2$ = getelement$(staticarraylist, xi): xi = xi + 1
                                    typ2$ = getelement$(staticarraylist, xi): xi = xi + 1
                                    dimmethod2 = Val(getelement$(staticarraylist, xi)): xi = xi + 1
                                    'check if they are similar
                                    If UCase$(l$) = UCase$(varname2$) Then
                                        l3$ = l2$: s$ = removesymbol(l3$)
                                        If symbol2fulltypename$(dtyp$) = typ2$ Or (dimmethod2 = 0 And s$ = "") Then
                                            If Error_Happened Then Exit Function
                                            'adopt properties
                                            l$ = varname2$
                                            dtyp$ = typ2$
                                            method = dimmethod2
                                            dimstatic = 3
                                        End If 'typ
                                        If Error_Happened Then Exit Function
                                    End If 'varname
                                Next
                            End If 'subfuncn
                            bypassNextVariable = -1
                            ignore = dim2(l$, dtyp$, method, fakee$)
                            If Error_Happened Then Exit Function
                            dimstatic = olddimstatic
                            GoTo reevaluate
                        End If
                    End If
                End If
            End If

            l$ = l2$ 'restore l$

        End If 'b=0

        If l$ = "(" Then
            If b = 0 Then i1 = i + 1
            b = b + 1
        End If

        If b = 0 Then
            blockn = blockn + 1
            block(blockn) = l$
            evaledblock(blockn) = 0
        End If

        If l$ = ")" Then
            b = b - 1
            If b = 0 Then
                c$ = evaluate(getelements$(a$, i1, i - 1), typ2)
                If Error_Happened Then Exit Function
                If (typ2 And ISSTRING) Then stringprocessinghappened = 1
                blockn = blockn + 1
                If (typ2 And ISPOINTER) Then
                    block(blockn) = c$
                Else
                    block(blockn) = "(" + c$ + ")"
                End If
                evaledblock(blockn) = 1
                blocktype(blockn) = typ2
            End If
        End If
        evaled:
    Next

    r$ = "" 'return value

    'identify any referencable values
    For i = 1 To blockn
        If isoperator(block(i)) = 0 Then
            If evaledblock(i) = 0 Then

                'a number?
                c = Asc(Left$(block(i), 1))
                If c = 45 Or (c >= 48 And c <= 57) Then
                    num$ = block(i)
                    'a float?
                    f = 0
                    x = InStr(num$, "E")
                    If x Then
                        f = 1: blocktype(i) = SINGLETYPE - ISPOINTER
                    Else
                        x = InStr(num$, "D")
                        If x Then
                            f = 2: blocktype(i) = DOUBLETYPE - ISPOINTER
                        Else
                            x = InStr(num$, "F")
                            If x Then
                                f = 3: blocktype(i) = FLOATTYPE - ISPOINTER
                            End If
                        End If
                    End If
                    If f Then
                        'float
                        If f = 2 Or f = 3 Then Mid$(num$, x, 1) = "E" 'D,F invalid in C++
                        If f = 3 Then num$ = num$ + "L" 'otherwise number is rounded to a double
                    Else
                        'integer
                        blocktype(i) = typname2typ(removesymbol$(num$))
                        If Error_Happened Then Exit Function
                        If blocktype(i) And ISPOINTER Then blocktype(i) = blocktype(i) - ISPOINTER
                        If (blocktype(i) And 511) > 32 Then
                            If blocktype(i) And ISUNSIGNED Then num$ = num$ + "ull" Else num$ = num$ + "ll"
                        End If
                    End If
                    block(i) = " " + num$ + " " 'pad with spaces to avoid C++ computation errors
                    evaledblock(i) = 1
                    GoTo evaledblock
                End If

                'a typed string in ""
                If Left$(block(i), 1) = Chr$(34) Then
                    If Right$(block(i), 1) <> Chr$(34) Then
                        block(i) = "qbs_new_txt_len(" + block(i) + ")"
                    Else
                        block(i) = "qbs_new_txt(" + block(i) + ")"
                    End If
                    blocktype(i) = ISSTRING
                    evaledblock(i) = 1
                    stringprocessinghappened = 1
                    GoTo evaledblock
                End If

                'create variable
                If isvalidvariable(block(i)) Then
                    x$ = block(i)

                    typ$ = removesymbol$(x$)
                    If Error_Happened Then Exit Function

                    'add symbol extension if none given
                    If Len(typ$) = 0 Then
                        If Left$(x$, 1) = "_" Then v = 27 Else v = Asc(UCase$(x$)) - 64
                        typ$ = defineextaz(v)
                    End If

                    'check that it hasn't just been created within this loop (a=b+b)
                    try = findid(x$ + typ$)
                    If Error_Happened Then Exit Function
                    Do While try
                        If id.t <> 0 And (id.t And ISUDT) = 0 Then 'is x$ a simple variable?
                            GoTo simplevarfound
                        End If
                        If try = 2 Then findanotherid = 1: try = findid(x$ + typ$) Else try = 0
                        If Error_Happened Then Exit Function
                    Loop

                    If optionexplicit Then Give_Error "Variable '" + x$ + "' (" + symbol2fulltypename$(typ$) + ") not defined": Exit Function
                    bypassNextVariable = -1
                    retval = dim2(x$, typ$, 1, "")
                    If Error_Happened Then Exit Function

                    simplevarfound:
                    constequation = 0
                    makeidrefer block(i), blocktype(i)
                    If (blocktype(i) And ISSTRING) Then stringprocessinghappened = 1
                    If blockn = 1 Then
                        If (blocktype(i) And ISREFERENCE) Then GoTo returnpointer
                    End If
                    'reference value
                    block(i) = refer(block(i), blocktype(i), 0): If Error_Happened Then Exit Function
                    evaledblock(i) = 1
                    GoTo evaledblock
                End If
                Give_Error "Invalid expression": Exit Function

            Else
                If (blocktype(i) And ISREFERENCE) Then
                    If blockn = 1 Then GoTo returnpointer
                    'if blocktype(i) and ISUDT then PRINT "UDT passed to refer by evaluate"
                    block(i) = refer(block(i), blocktype(i), 0)
                    If Error_Happened Then Exit Function
                End If
            End If
        End If
        evaledblock:
    Next

    'return a POINTER if possible
    If blockn = 1 Then
        If evaledblock(1) Then
            If (blocktype(1) And ISREFERENCE) Then
                returnpointer:
                If (blocktype(1) And ISSTRING) Then stringprocessinghappened = 1
                typ = blocktype(1)
                evaluate$ = block(1)
                Exit Function
            End If
        End If
    End If
    'it cannot be returned as a pointer

    If typ = -1 Then
        typ = blocktype(1) 'init typ with first blocktype
        If isoperator(block(1)) Then 'but what if it starts with a UNARY operator?
            typ = blocktype(2) 'init typ with second blocktype
        End If
    End If

    nonop = 0
    For i = 1 To blockn

        If evaledblock(i) = 0 Then
            isop = isoperator(block(i))
            If isop Then
                nonop = 0

                constequation = 0

                'operator found
                o$ = block(i)
                u = operatorusage(o$, typ, i$, lhstyp, rhstyp, result)

                If u <> 5 Then 'not unary
                    nonop = 1
                    If i = 1 Or evaledblock(i - 1) = 0 Then
                        If i = 1 And blockn = 1 And o$ = "-" Then Give_Error "Expected variable/value after '" + UCase$(o$) + "'": Exit Function 'guess - is neg in this case
                        Give_Error "Expected variable/value before '" + UCase$(o$) + "'": Exit Function
                    End If
                End If
                If i = blockn Or evaledblock(i + 1) = 0 Then Give_Error "Expected variable/value after '" + UCase$(o$) + "'": Exit Function

                'lhstyp & rhstyp bit-field values
                '1=integeral
                '2=floating point
                '4=string
                '8=bool *only used for result

                oldtyp = typ
                newtyp = blocktype(i + 1)

                'numeric->string is illegal!
                If (typ And ISSTRING) = 0 And (newtyp And ISSTRING) <> 0 Then
                    Give_Error "Cannot convert number to string": Exit Function
                End If

                'Offset protection: Override conversion rules for operator as necessary
                offsetmode = 0
                offsetcvi = 0
                If (oldtyp And ISOFFSET) <> 0 Or (newtyp And ISOFFSET) <> 0 Then
                    offsetmode = 2
                    If newtyp And ISOFFSET Then
                        If (newtyp And ISUNSIGNED) = 0 Then offsetmode = 1
                    End If
                    If oldtyp And ISOFFSET Then
                        If (oldtyp And ISUNSIGNED) = 0 Then offsetmode = 1
                    End If

                    'depending on the operater we may do things differently
                    'the default method is convert both sides to integer first
                    'but these operators are different: * / ^
                    If o$ = "*" Or o$ = "/" Or o$ = "^" Then
                        If o$ = "*" Or o$ = "^" Then
                            'for mult, if either side is a float cast integers to 'long double's first
                            If (newtyp And ISFLOAT) <> 0 Or (oldtyp And ISFLOAT) <> 0 Then
                                offsetcvi = 1
                                If (oldtyp And ISFLOAT) = 0 Then lhstyp = 2
                                If (newtyp And ISFLOAT) = 0 Then rhstyp = 2
                            End If
                        End If
                        If o$ = "/" Or o$ = "^" Then
                            'for division or exponentials, to prevent integer division cast integers to 'long double's
                            offsetcvi = 1
                            If (oldtyp And ISFLOAT) = 0 Then lhstyp = 2
                            If (newtyp And ISFLOAT) = 0 Then rhstyp = 2
                        End If
                    Else
                        If lhstyp And 2 Then lhstyp = 1 'force lhs and rhs to be integer values
                        If rhstyp And 2 Then rhstyp = 1
                    End If

                    If result = 2 Then result = 1 'force integer result
                    'note: result=1 just sets typ&=64 if typ is a float

                End If

                'STEP 1: convert oldtyp and/or newtyp if required for the operator
                'convert lhs
                If (oldtyp And ISSTRING) Then
                    If (lhstyp And 4) = 0 Then Give_Error "Cannot convert string to number": Exit Function
                Else
                    'oldtyp is numeric
                    If lhstyp = 4 Then Give_Error "Cannot convert number to string": Exit Function
                    If (oldtyp And ISFLOAT) Then
                        If (lhstyp And 2) = 0 Then
                            'convert float to int
                            block(i - 1) = "qbr(" + block(i - 1) + ")"
                            oldtyp = 64&
                        End If
                    Else
                        'oldtyp is an int
                        If (lhstyp And 1) = 0 Then
                            'convert int to float
                            block(i - 1) = "((long double)(" + block(i - 1) + "))"
                            oldtyp = 256& + ISFLOAT
                        End If
                    End If
                End If
                'convert rhs
                If (newtyp And ISSTRING) Then
                    If (rhstyp And 4) = 0 Then Give_Error "Cannot convert string to number": Exit Function
                Else
                    'newtyp is numeric
                    If rhstyp = 4 Then Give_Error "Cannot convert number to string": Exit Function
                    If (newtyp And ISFLOAT) Then
                        If (rhstyp And 2) = 0 Then
                            'convert float to int
                            block(i + 1) = "qbr(" + block(i + 1) + ")"
                            newtyp = 64&
                        End If
                    Else
                        'newtyp is an int
                        If (rhstyp And 1) = 0 Then
                            'convert int to float
                            block(i + 1) = "((long double)(" + block(i + 1) + "))"
                            newtyp = 256& + ISFLOAT
                        End If
                    End If
                End If

                'Reduce floating point values to common base for comparison?
                If isop = 7 Then 'comparitive operator
                    'Corrects problems encountered such as:
                    '    S = 2.1
                    '    IF S = 2.1 THEN PRINT "OK" ELSE PRINT "ERROR S PRINTS AS"; S; "BUT IS SEEN BY QB64 AS..."
                    '    IF S < 2.1 THEN PRINT "LESS THAN 2.1"
                    'concerns:
                    '1. Return value from TIMER will be reduced to a SINGLE in direct comparisons
                    'solution: assess, and only apply to SINGLE variables/arrays
                    '2. Comparison of a double higher/lower than single range may fail
                    'solution: out of range values convert to +/-1.#INF, making comparison still possible
                    If (oldtyp And ISFLOAT) <> 0 And (newtyp And ISFLOAT) <> 0 Then 'both floating point
                        s1 = oldtyp And 511: s2 = newtyp And 511
                        If s2 < s1 Then s1 = s2
                        If s1 = 32 Then
                            block(i - 1) = "((float)(" + block(i - 1) + "))": oldtyp = 32& + ISFLOAT
                            block(i + 1) = "((float)(" + block(i + 1) + "))": newtyp = 32& + ISFLOAT
                        End If
                        If s1 = 64 Then
                            block(i - 1) = "((double)(" + block(i - 1) + "))": oldtyp = 64& + ISFLOAT
                            block(i + 1) = "((double)(" + block(i + 1) + "))": newtyp = 64& + ISFLOAT
                        End If
                    End If 'both floating point
                End If 'comparitive operator

                typ = newtyp

                'STEP 2: markup typ
                '        if either side is a float, markup typ to largest float
                '        if either side is integer, markup typ
                'Note: A markup is a GUESS of what the return type will be,
                '      'result' can override this markup
                If (oldtyp And ISSTRING) = 0 And (newtyp And ISSTRING) = 0 Then
                    If (oldtyp And ISFLOAT) <> 0 Or (newtyp And ISFLOAT) <> 0 Then
                        'float
                        b = 0: If (oldtyp And ISFLOAT) Then b = oldtyp And 511
                        If (newtyp And ISFLOAT) Then
                            b2 = newtyp And 511: If b2 > b Then b = b2
                        End If
                        typ = ISFLOAT + b
                    Else
                        'integer
                        '***THIS IS THE IDEAL MARKUP FOR A 64-BIT SYSTEM***
                        'In reality 32-bit C++ only marks-up to 32-bit integers
                        b = oldtyp And 511: b2 = newtyp And 511: If b2 > b Then b = b2
                        typ = 64&
                        If b = 64 Then
                            If (oldtyp And ISUNSIGNED) <> 0 And (newtyp And ISUNSIGNED) <> 0 Then typ = 64& + ISUNSIGNED
                        End If
                    End If
                End If

                If result = 1 Then
                    If (typ And ISFLOAT) <> 0 Or (typ And ISSTRING) <> 0 Then typ = 64 'otherwise keep markuped integer type
                End If
                If result = 2 Then
                    If (typ And ISFLOAT) = 0 Then typ = ISFLOAT + 256
                End If
                If result = 4 Then
                    typ = ISSTRING
                End If
                If result = 8 Then 'bool
                    typ = 32
                End If

                'Offset protection: Force result to be an offset type with correct signage
                If offsetmode Then
                    If result <> 8 Then 'boolean comparison results are allowed
                        typ = OFFSETTYPE - ISPOINTER: If offsetmode = 2 Then typ = typ + ISUNSIGNED
                    End If
                End If

                'override typ=ISFLOAT+256 to typ=ISFLOAT+64 for ^ operator's result
                If u = 2 Then
                    If i$ = "pow2" Then

                        If offsetmode Then Give_Error "Operator '^' cannot be used with an _OFFSET": Exit Function

                        'QB-like conversion of math functions returning floating point values
                        'reassess oldtype & newtype
                        b = oldtyp And 511
                        If oldtyp And ISFLOAT Then
                            'no change to b
                        Else
                            If b > 16 Then b = 64 'larger than INTEGER? return DOUBLE
                            If b > 32 Then b = 256 'larger than LONG? return FLOAT
                            If b <= 16 Then b = 32
                        End If
                        b2 = newtyp And 511
                        If newtyp And ISFLOAT Then
                            If b2 > b Then b = b2
                        Else
                            b3 = 32
                            If b2 > 16 Then b3 = 64 'larger than INTEGER? return DOUBLE
                            If b2 > 32 Then b3 = 256 'larger than LONG? return FLOAT
                            If b3 > b Then b = b3
                        End If
                        typ = ISFLOAT + b

                    End If 'pow2
                End If 'u=2

                'STEP 3: apply operator appropriately

                If u = 5 Then
                    block(i + 1) = i$ + "(" + block(i + 1) + ")"
                    block(i) = "": i = i + 1: GoTo operatorapplied
                End If

                'binary operators

                If u = 1 Then
                    block(i + 1) = block(i - 1) + i$ + block(i + 1)
                    block(i - 1) = "": block(i) = "": i = i + 1: GoTo operatorapplied
                End If

                If u = 2 Then
                    block(i + 1) = i$ + "(" + block(i - 1) + "," + block(i + 1) + ")"
                    block(i - 1) = "": block(i) = "": i = i + 1: GoTo operatorapplied
                End If

                If u = 3 Then
                    block(i + 1) = "-(" + block(i - 1) + i$ + block(i + 1) + ")"
                    block(i - 1) = "": block(i) = "": i = i + 1: GoTo operatorapplied
                End If

                If u = 4 Then
                    block(i + 1) = "~" + block(i - 1) + i$ + block(i + 1)
                    block(i - 1) = "": block(i) = "": i = i + 1: GoTo operatorapplied
                End If

                '...more?...

                Give_Error "ERROR: Operator could not be applied correctly!": Exit Function '<--should never happen!
                operatorapplied:

                If offsetcvi Then block(i) = "qbr(" + block(i) + ")": offsetcvi = 0
                offsetmode = 0

            Else
                nonop = nonop + 1
            End If
        Else
            nonop = nonop + 1
        End If
        If nonop > 1 Then Give_Error "Expected operator in equation": Exit Function
    Next

    'join blocks
    For i = 1 To blockn
        r$ = r$ + block(i)
    Next

    evaluate$ = r$

End Function




Function evaluatefunc$ (a2$, args As Long, typ As Long)
    a$ = a2$

    Dim id2 As idstruct

    id2 = id
    n$ = RTrim$(id2.n)
    typ = id2.ret
    targetid = currentid

    If RTrim$(id2.callname) = "func_stub" Then Give_Error "Command not implemented": Exit Function
    If RTrim$(id2.callname) = "func_input" And args = 1 And inputfunctioncalled = 0 Then
        inputfunctioncalled = -1
    End If

    SetDependency id2.Dependency

    passomit = 0
    omitarg_first = 0: omitarg_last = 0

    f$ = RTrim$(id2.specialformat)
    If Len(f$) Then 'special format given

        'count omittable args
        sqb = 0
        a = 0
        For fi = 1 To Len(f$)
            fa = Asc(f$, fi)
            If fa = ASC_QUESTIONMARK Then
                a = a + 1
                If sqb <> 0 And omitarg_first = 0 Then omitarg_first = a
            End If
            If fa = ASC_LEFTSQUAREBRACKET Then sqb = 1
            If fa = ASC_RIGHTSQUAREBRACKET Then sqb = 0: omitarg_last = a
        Next
        omitargs = omitarg_last - omitarg_first + 1

        If args <> id2.args - omitargs And args <> id2.args Then
            If Len(id2.hr_syntax) > 0 Then
                Give_Error "Incorrect number of arguments - Reference: " + id2.hr_syntax
            Else
                Give_Error "Incorrect number of arguments passed to function"
            End If
            Exit Function
        End If

        passomit = 1 'pass omit flags param to function

        If id2.args = args Then omitarg_first = 0: omitarg_last = 0 'all arguments were passed!

    Else 'no special format given

        If n$ = "ASC" And args = 2 Then GoTo skipargnumchk
        If id2.overloaded = -1 And (args >= id2.minargs And args <= id2.args) Then GoTo skipargnumchk

        If id2.args <> args Then
            If Len(id2.hr_syntax) > 0 Then
                Give_Error "Incorrect number of arguments - Reference: " + id2.hr_syntax
            Else
                Give_Error "Incorrect number of arguments passed to function"
            End If
            Exit Function
        End If

    End If

    skipargnumchk:

    r$ = RTrim$(id2.callname) + "("


    If id2.args <> 0 Then

        curarg = 1
        firsti = 1

        n = numelements(a$)
        If n = 0 Then i = 0: GoTo noargs

        For i = 1 To n



            If curarg >= omitarg_first And curarg <= omitarg_last Then
                noargs:
                targettyp = CVL(Mid$(id2.arg, curarg * 4 - 4 + 1, 4))

                'IF (targettyp AND ISSTRING) THEN Give_Error "QB64 doesn't support optional string arguments for functions yet!": EXIT FUNCTION

                For fi = 1 To omitargs - 1: r$ = r$ + "NULL,": Next: r$ = r$ + "NULL"
                curarg = curarg + omitargs
                If i = n Then Exit For
                r$ = r$ + ","
            End If

            l$ = getelement(a$, i)
            If l$ = "(" Then b = b + 1
            If l$ = ")" Then b = b - 1
            If (l$ = "," And b = 0) Or (i = n) Then

                targettyp = CVL(Mid$(id2.arg, curarg * 4 - 4 + 1, 4))
                nele = Asc(Mid$(id2.nele, curarg, 1))
                nelereq = Asc(Mid$(id2.nelereq, curarg, 1))

                If i = n Then
                    e$ = getelements$(a$, firsti, i)
                Else
                    e$ = getelements$(a$, firsti, i - 1)
                End If

                If Left$(e$, 2) = "(" + sp Then dereference = 1 Else dereference = 0



                '*special case CVI,CVL,CVS,CVD,_CV (part #1)
                If n$ = "_CV" Then
                    If curarg = 1 Then
                        cvtype$ = type2symbol$(e$)
                        If Error_Happened Then Exit Function
                        e$ = ""
                        GoTo dontevaluate
                    End If
                End If

                '*special case MKI,MKL,MKS,MKD,_MK (part #1)

                If n$ = "_MK" Then
                    If RTrim$(id2.musthave) = "$" Then
                        If curarg = 1 Then
                            mktype$ = type2symbol$(e$)
                            If Error_Happened Then Exit Function
                            e$ = ""
                            GoTo dontevaluate
                        End If
                    End If
                End If

                If n$ = "UBOUND" Or n$ = "LBOUND" Then
                    If curarg = 1 Then
                        'perform a "fake" evaluation of the array
                        e$ = e$ + sp + "(" + sp + ")"
                        e$ = evaluate(e$, sourcetyp)
                        If Error_Happened Then Exit Function
                        If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected array-name": Exit Function
                        If (sourcetyp And ISARRAY) = 0 Then Give_Error "Expected array-name": Exit Function
                        'make a note of the array's index for later
                        ulboundarray$ = e$
                        ulboundarraytyp = sourcetyp
                        e$ = ""
                        r$ = ""
                        GoTo dontevaluate
                    End If
                End If


                '*special case: INPUT$ function
                If n$ = "INPUT" Then
                    If RTrim$(id2.musthave) = "$" Then
                        If curarg = 2 Then
                            If Left$(e$, 2) = "#" + sp Then e$ = Right$(e$, Len(e$) - 2)
                        End If
                    End If
                End If


                '*special case*
                If n$ = "ASC" Then
                    If curarg = 2 Then
                        e$ = evaluatetotyp$(e$, 32&)
                        If Error_Happened Then Exit Function
                        typ& = LONGTYPE - ISPOINTER
                        r$ = r$ + e$ + ")"
                        GoTo evalfuncspecial
                    End If
                End If


                'PRINT #12, "n$="; n$
                'PRINT #12, "curarg="; curarg
                'PRINT #12, "e$="; e$
                'PRINT #12, "r$="; r$

                '*special case*
                If n$ = "_MEMGET" Then
                    If curarg = 1 Then
                        memget_blk$ = e$
                    End If
                    If curarg = 2 Then
                        memget_offs$ = e$
                    End If
                    If curarg = 3 Then
                        e$ = UCase$(e$)
                        If InStr(e$, sp + "*" + sp) Then 'multiplier will have an appended %,& or && symbol
                            If Right$(e$, 2) = "&&" Then
                                e$ = Left$(e$, Len(e$) - 2)
                            Else
                                If Right$(e$, 1) = "&" Or Right$(e$, 1) = "%" Then e$ = Left$(e$, Len(e$) - 1)
                            End If
                        End If
                        t = typname2typ(e$)
                        If t = 0 Then Give_Error "Invalid TYPE name": Exit Function
                        If t And ISOFFSETINBITS Then Give_Error qb64prefix$ + "BIT TYPE unsupported": Exit Function
                        memget_size = typname2typsize
                        If t And ISSTRING Then
                            If (t And ISFIXEDLENGTH) = 0 Then Give_Error "Expected STRING * ...": Exit Function
                            memget_ctyp$ = "qbs*"
                        Else
                            If t And ISUDT Then
                                memget_size = udtxsize(t And 511) \ 8
                                memget_ctyp$ = "void*"
                            Else
                                memget_size = (t And 511) \ 8
                                memget_ctyp$ = typ2ctyp$(t, "")
                            End If
                        End If





                        'assume checking off
                        offs$ = evaluatetotyp(memget_offs$, OFFSETTYPE - ISPOINTER)
                        blkoffs$ = evaluatetotyp(memget_blk$, -6)
                        If NoChecks = 0 Then
                            'change offs$ to be the return of the safe version
                            offs$ = "func__memget((mem_block*)" + blkoffs$ + "," + offs$ + "," + str2(memget_size) + ")"
                        End If
                        If t And ISSTRING Then
                            r$ = "qbs_new_txt_len((char*)" + offs$ + "," + str2(memget_size) + ")"
                        Else
                            If t And ISUDT Then
                                r$ = "((void*)+" + offs$ + ")"
                                t = ISUDT + ISPOINTER + (t And 511)
                            Else
                                r$ = "*(" + memget_ctyp$ + "*)(" + offs$ + ")"
                                If t And ISPOINTER Then t = t - ISPOINTER
                            End If
                        End If







                        typ& = t


                        GoTo evalfuncspecial
                    End If
                End If

                '------------------------------------------------------------------------------------------------------------
                e2$ = e$
                e$ = evaluate(e$, sourcetyp)
                If Error_Happened Then Exit Function
                '------------------------------------------------------------------------------------------------------------

                '***special case***
                If n$ = "_MEM" Then
                    If curarg = 1 Then
                        If args = 1 Then
                            targettyp = -7
                        End If
                        If args = 2 Then
                            r$ = RTrim$(id2.callname) + "_at_offset" + Right$(r$, Len(r$) - Len(RTrim$(id2.callname)))
                            If (sourcetyp And ISOFFSET) = 0 Then Give_Error "Expected _MEM(_OFFSET-value,...)": Exit Function
                        End If
                    End If
                End If

                '*special case*
                If n$ = "_OFFSET" Then
                    If (sourcetyp And ISREFERENCE) = 0 Then
                        Give_Error qb64prefix$ + "OFFSET expects the name of a variable/array": Exit Function
                    End If
                    If (sourcetyp And ISARRAY) Then
                        If (sourcetyp And ISOFFSETINBITS) Then Give_Error qb64prefix$ + "OFFSET cannot reference _BIT type arrays": Exit Function
                    End If
                    r$ = "((uptrszint)(" + evaluatetotyp$(e2$, -6) + "))"
                    If Error_Happened Then Exit Function
                    typ& = UOFFSETTYPE - ISPOINTER
                    GoTo evalfuncspecial
                End If '_OFFSET

                '*_OFFSET exceptions*
                If sourcetyp And ISOFFSET Then
                    If n$ = "MKSMBF" And RTrim$(id2.musthave) = "$" Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    If n$ = "MKDMBF" And RTrim$(id2.musthave) = "$" Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                End If

                '*special case*
                If n$ = "ENVIRON" Then
                    If sourcetyp And ISSTRING Then
                        If sourcetyp And ISREFERENCE Then e$ = refer(e$, sourcetyp, 0)
                        If Error_Happened Then Exit Function
                        GoTo dontevaluate
                    End If
                End If

                '*special case*
                If n$ = "LEN" Then
                    typ& = LONGTYPE - ISPOINTER
                    If (sourcetyp And ISREFERENCE) = 0 Then
                        'could be a string expression
                        If sourcetyp And ISSTRING Then
                            r$ = "((int32)(" + e$ + ")->len)"
                            GoTo evalfuncspecial
                        End If
                        Give_Error "String expression or variable name required in LEN statement": Exit Function
                    End If
                    r$ = evaluatetotyp$(e2$, -5) 'use evaluatetotyp to get 'element' size
                    If Error_Happened Then Exit Function
                    GoTo evalfuncspecial
                End If


                '*special case*
                If n$ = "_BIN" Then
                    If RTrim$(id2.musthave) = "$" Then
                        bits = sourcetyp And 511

                        If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                        wasref = 0
                        If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0): wasref = 1
                        If Error_Happened Then Exit Function
                        bits = sourcetyp And 511
                        If (sourcetyp And ISOFFSETINBITS) Then
                            e$ = "func__bin(" + e$ + "," + str2$(bits) + ")"
                        Else
                            If (sourcetyp And ISFLOAT) Then
                                e$ = "func__bin_float(" + e$ + ")"
                            Else
                                If bits = 64 Then
                                    If wasref = 0 Then bits = 0
                                End If
                                e$ = "func__bin(" + e$ + "," + str2$(bits) + ")"
                            End If
                        End If
                        typ& = STRINGTYPE - ISPOINTER
                        r$ = e$
                        GoTo evalfuncspecial
                    End If
                End If

                '*special case*
                If n$ = "OCT" Then
                    If RTrim$(id2.musthave) = "$" Then
                        bits = sourcetyp And 511

                        If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                        wasref = 0
                        If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0): wasref = 1
                        If Error_Happened Then Exit Function
                        bits = sourcetyp And 511
                        If (sourcetyp And ISOFFSETINBITS) Then
                            e$ = "func_oct(" + e$ + "," + str2$(bits) + ")"
                        Else
                            If (sourcetyp And ISFLOAT) Then
                                e$ = "func_oct_float(" + e$ + ")"
                            Else
                                If bits = 64 Then
                                    If wasref = 0 Then bits = 0
                                End If
                                e$ = "func_oct(" + e$ + "," + str2$(bits) + ")"
                            End If
                        End If
                        typ& = STRINGTYPE - ISPOINTER
                        r$ = e$
                        GoTo evalfuncspecial
                    End If
                End If

                '*special case*
                If n$ = "HEX" Then
                    If RTrim$(id2.musthave) = "$" Then
                        bits = sourcetyp And 511
                        If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                        wasref = 0
                        If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0): wasref = 1
                        If Error_Happened Then Exit Function
                        bits = sourcetyp And 511
                        If (sourcetyp And ISOFFSETINBITS) Then
                            chars = (bits + 3) \ 4
                            e$ = "func_hex(" + e$ + "," + str2$(chars) + ")"
                        Else
                            If (sourcetyp And ISFLOAT) Then
                                e$ = "func_hex_float(" + e$ + ")"
                            Else
                                If bits = 8 Then chars = 2
                                If bits = 16 Then chars = 4
                                If bits = 32 Then chars = 8
                                If bits = 64 Then
                                    If wasref = 1 Then chars = 16 Else chars = 0
                                End If
                                e$ = "func_hex(" + e$ + "," + str2$(chars) + ")"
                            End If
                        End If
                        typ& = STRINGTYPE - ISPOINTER
                        r$ = e$
                        GoTo evalfuncspecial
                    End If
                End If


                '*special case*
                If n$ = "EXP" Then
                    bits = sourcetyp And 511
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    bits = sourcetyp And 511
                    typ& = SINGLETYPE - ISPOINTER
                    If (sourcetyp And ISFLOAT) Then
                        If bits = 32 Then e$ = "func_exp_single(" + e$ + ")" Else e$ = "func_exp_float(" + e$ + ")": typ& = FLOATTYPE - ISPOINTER
                    Else
                        If (sourcetyp And ISOFFSETINBITS) Then
                            e$ = "func_exp_float(" + e$ + ")": typ& = FLOATTYPE - ISPOINTER
                        Else
                            If bits <= 16 Then e$ = "func_exp_single(" + e$ + ")" Else e$ = "func_exp_float(" + e$ + ")": typ& = FLOATTYPE - ISPOINTER
                        End If
                    End If
                    r$ = e$
                    GoTo evalfuncspecial
                End If

                '*special case*
                If n$ = "INT" Then
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    If (sourcetyp And ISFLOAT) Then e$ = "floor(" + e$ + ")" Else e$ = "(" + e$ + ")"
                    r$ = e$
                    typ& = sourcetyp
                    GoTo evalfuncspecial
                End If

                '*special case*
                If n$ = "FIX" Then
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    bits = sourcetyp And 511
                    If (sourcetyp And ISFLOAT) Then
                        If bits > 64 Then e$ = "func_fix_float(" + e$ + ")" Else e$ = "func_fix_double(" + e$ + ")"
                    Else
                        e$ = "(" + e$ + ")"
                    End If
                    r$ = e$
                    typ& = sourcetyp
                    GoTo evalfuncspecial
                End If

                '*special case*
                If n$ = "_ROUND" Then
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    If (sourcetyp And ISFLOAT) Then
                        bits = sourcetyp And 511
                        If bits > 64 Then e$ = "func_round_float(" + e$ + ")" Else e$ = "func_round_double(" + e$ + ")"
                    Else
                        e$ = "(" + e$ + ")"
                    End If
                    r$ = e$
                    typ& = 64&
                    If (sourcetyp And ISOFFSET) Then
                        If sourcetyp And ISUNSIGNED Then typ& = UOFFSETTYPE - ISPOINTER Else typ& = OFFSETTYPE - ISPOINTER
                    End If
                    GoTo evalfuncspecial
                End If


                '*special case*
                If n$ = "CDBL" Then
                    If (sourcetyp And ISOFFSET) Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    bits = sourcetyp And 511
                    If (sourcetyp And ISFLOAT) Then
                        If bits > 64 Then e$ = "func_cdbl_float(" + e$ + ")"
                    Else
                        e$ = "((double)(" + e$ + "))"
                    End If
                    r$ = e$
                    typ& = DOUBLETYPE - ISPOINTER
                    GoTo evalfuncspecial
                End If

                '*special case*
                If n$ = "CSNG" Then
                    If (sourcetyp And ISOFFSET) Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    bits = sourcetyp And 511
                    If (sourcetyp And ISFLOAT) Then
                        If bits = 64 Then e$ = "func_csng_double(" + e$ + ")"
                        If bits > 64 Then e$ = "func_csng_float(" + e$ + ")"
                    Else
                        e$ = "((double)(" + e$ + "))"
                    End If
                    r$ = e$
                    typ& = SINGLETYPE - ISPOINTER
                    GoTo evalfuncspecial
                End If


                '*special case*
                If n$ = "CLNG" Then
                    If (sourcetyp And ISOFFSET) Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    bits = sourcetyp And 511
                    If (sourcetyp And ISFLOAT) Then
                        If bits > 64 Then e$ = "func_clng_float(" + e$ + ")" Else e$ = "func_clng_double(" + e$ + ")"
                    Else 'integer
                        If (sourcetyp And ISUNSIGNED) Then
                            If bits = 32 Then e$ = "func_clng_ulong(" + e$ + ")"
                            If bits > 32 Then e$ = "func_clng_uint64(" + e$ + ")"
                        Else 'signed
                            If bits > 32 Then e$ = "func_clng_int64(" + e$ + ")"
                        End If
                    End If
                    r$ = e$
                    typ& = 32&
                    GoTo evalfuncspecial
                End If

                '*special case*
                If n$ = "CINT" Then
                    If (sourcetyp And ISOFFSET) Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    If (sourcetyp And ISSTRING) Then Give_Error "Expected numeric value": Exit Function
                    If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    'establish which function (if any!) should be used
                    bits = sourcetyp And 511
                    If (sourcetyp And ISFLOAT) Then
                        If bits > 64 Then e$ = "func_cint_float(" + e$ + ")" Else e$ = "func_cint_double(" + e$ + ")"
                    Else 'integer
                        If (sourcetyp And ISUNSIGNED) Then
                            If bits > 15 And bits <= 32 Then e$ = "func_cint_ulong(" + e$ + ")"
                            If bits > 32 Then e$ = "func_cint_uint64(" + e$ + ")"
                        Else 'signed
                            If bits > 16 And bits <= 32 Then e$ = "func_cint_long(" + e$ + ")"
                            If bits > 32 Then e$ = "func_cint_int64(" + e$ + ")"
                        End If
                    End If
                    r$ = e$
                    typ& = 16&
                    GoTo evalfuncspecial
                End If

                '*special case MKI,MKL,MKS,MKD,_MK (part #2)
                mktype = 0
                size = 0
                If n$ = "MKI" Then mktype = 1: mktype$ = "%"
                If n$ = "MKL" Then mktype = 2: mktype$ = "&"
                If n$ = "MKS" Then mktype = 3: mktype$ = "!"
                If n$ = "MKD" Then mktype = 4: mktype$ = "#"
                If n$ = "_MK" Then mktype = -1
                If mktype Then
                    If mktype <> -1 Or curarg = 2 Then
                        'IF (sourcetyp AND ISOFFSET) THEN Give_Error "Cannot convert " + qb64prefix$ + "OFFSET type to other types": EXIT FUNCTION
                        'both _MK and trad. process the following
                        qtyp& = 0
                        If mktype$ = "%%" Then ctype$ = "b": qtyp& = BYTETYPE - ISPOINTER
                        If mktype$ = "~%%" Then ctype$ = "ub": qtyp& = UBYTETYPE - ISPOINTER
                        If mktype$ = "%" Then ctype$ = "i": qtyp& = INTEGERTYPE - ISPOINTER
                        If mktype$ = "~%" Then ctype$ = "ui": qtyp& = UINTEGERTYPE - ISPOINTER
                        If mktype$ = "&" Then ctype$ = "l": qtyp& = LONGTYPE - ISPOINTER
                        If mktype$ = "~&" Then ctype$ = "ul": qtyp& = ULONGTYPE - ISPOINTER
                        If mktype$ = "&&" Then ctype$ = "i64": qtyp& = INTEGER64TYPE - ISPOINTER
                        If mktype$ = "~&&" Then ctype$ = "ui64": qtyp& = UINTEGER64TYPE - ISPOINTER
                        If mktype$ = "!" Then ctype$ = "s": qtyp& = SINGLETYPE - ISPOINTER
                        If mktype$ = "#" Then ctype$ = "d": qtyp& = DOUBLETYPE - ISPOINTER
                        If mktype$ = "##" Then ctype$ = "f": qtyp& = FLOATTYPE - ISPOINTER
                        If mktype$ = "%&" Then ctype$ = "o": qtyp& = OFFSETTYPE - ISPOINTER
                        If mktype$ = "~%&" Then ctype$ = "uo": qtyp& = UOFFSETTYPE - ISPOINTER
                        If Left$(mktype$, 2) = "~`" Then ctype$ = "ubit": qtyp& = UINTEGER64TYPE - ISPOINTER: size = Val(Right$(mktype$, Len(mktype$) - 2))
                        If Left$(mktype$, 1) = "`" Then ctype$ = "bit": qtyp& = INTEGER64TYPE - ISPOINTER: size = Val(Right$(mktype$, Len(mktype$) - 1))
                        If qtyp& = 0 Then Give_Error qb64prefix$ + "MK only accepts numeric types": Exit Function
                        If size Then
                            r$ = ctype$ + "2string(" + str2(size) + ","
                        Else
                            r$ = ctype$ + "2string("
                        End If
                        nocomma = 1
                        targettyp = qtyp&
                    End If
                End If

                '*special case CVI,CVL,CVS,CVD,_CV (part #2)
                cvtype = 0
                If n$ = "CVI" Then cvtype = 1: cvtype$ = "%"
                If n$ = "CVL" Then cvtype = 2: cvtype$ = "&"
                If n$ = "CVS" Then cvtype = 3: cvtype$ = "!"
                If n$ = "CVD" Then cvtype = 4: cvtype$ = "#"
                If n$ = "_CV" Then cvtype = -1
                If cvtype Then
                    If cvtype <> -1 Or curarg = 2 Then
                        If (sourcetyp And ISSTRING) = 0 Then Give_Error n$ + " requires a STRING argument": Exit Function
                        If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                        If Error_Happened Then Exit Function
                        typ& = 0
                        If cvtype$ = "%%" Then ctype$ = "b": typ& = BYTETYPE - ISPOINTER
                        If cvtype$ = "~%%" Then ctype$ = "ub": typ& = UBYTETYPE - ISPOINTER
                        If cvtype$ = "%" Then ctype$ = "i": typ& = INTEGERTYPE - ISPOINTER
                        If cvtype$ = "~%" Then ctype$ = "ui": typ& = UINTEGERTYPE - ISPOINTER
                        If cvtype$ = "&" Then ctype$ = "l": typ& = LONGTYPE - ISPOINTER
                        If cvtype$ = "~&" Then ctype$ = "ul": typ& = ULONGTYPE - ISPOINTER
                        If cvtype$ = "&&" Then ctype$ = "i64": typ& = INTEGER64TYPE - ISPOINTER
                        If cvtype$ = "~&&" Then ctype$ = "ui64": typ& = UINTEGER64TYPE - ISPOINTER
                        If cvtype$ = "!" Then ctype$ = "s": typ& = SINGLETYPE - ISPOINTER
                        If cvtype$ = "#" Then ctype$ = "d": typ& = DOUBLETYPE - ISPOINTER
                        If cvtype$ = "##" Then ctype$ = "f": typ& = FLOATTYPE - ISPOINTER
                        If cvtype$ = "%&" Then ctype$ = "o": typ& = OFFSETTYPE - ISPOINTER
                        If cvtype$ = "~%&" Then ctype$ = "uo": typ& = UOFFSETTYPE - ISPOINTER
                        If Left$(cvtype$, 2) = "~`" Then ctype$ = "ubit": typ& = UINTEGER64TYPE - ISPOINTER: size = Val(Right$(cvtype$, Len(cvtype$) - 2))
                        If Left$(cvtype$, 1) = "`" Then ctype$ = "bit": typ& = INTEGER64TYPE - ISPOINTER: size = Val(Right$(cvtype$, Len(cvtype$) - 1))
                        If typ& = 0 Then Give_Error qb64prefix$ + "CV cannot return STRING type!": Exit Function
                        If ctype$ = "bit" Or ctype$ = "ubit" Then
                            r$ = "string2" + ctype$ + "(" + e$ + "," + str2(size) + ")"
                        Else
                            r$ = "string2" + ctype$ + "(" + e$ + ")"
                        End If
                        GoTo evalfuncspecial
                    End If
                End If

                '*special case
                If RTrim$(id2.n) = "STRING" Then
                    If curarg = 2 Then
                        If (sourcetyp And ISSTRING) Then
                            If (sourcetyp And ISREFERENCE) Then e$ = refer(e$, sourcetyp, 0)
                            If Error_Happened Then Exit Function
                            sourcetyp = 64&
                            e$ = "(" + e$ + "->chr[0])"
                        End If
                    End If
                End If

                '*special case
                If RTrim$(id2.n) = "SADD" Then
                    If (sourcetyp And ISREFERENCE) = 0 Then
                        Give_Error "SADD only accepts variable-length string variables": Exit Function
                    End If
                    If (sourcetyp And ISFIXEDLENGTH) Then
                        Give_Error "SADD only accepts variable-length string variables": Exit Function
                    End If
                    If (sourcetyp And ISINCONVENTIONALMEMORY) = 0 Then
                        recompile = 1
                        cmemlist(Val(e$)) = 1
                        r$ = "[CONVENTIONAL_MEMORY_REQUIRED]"
                        typ& = 64&
                        GoTo evalfuncspecial
                    End If
                    r$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    r$ = "((unsigned short)(" + r$ + "->chr-&cmem[1280]))"
                    typ& = 64&
                    GoTo evalfuncspecial
                End If

                '*special case
                If RTrim$(id2.n) = "VARPTR" Then
                    If (sourcetyp And ISREFERENCE) = 0 Then
                        Give_Error "Expected reference to a variable/array": Exit Function
                    End If

                    If RTrim$(id2.musthave) = "$" Then
                        If (sourcetyp And ISINCONVENTIONALMEMORY) = 0 Then
                            recompile = 1
                            cmemlist(Val(e$)) = 1
                            r$ = "[CONVENTIONAL_MEMORY_REQUIRED]"
                            typ& = ISSTRING
                            GoTo evalfuncspecial
                        End If

                        If (sourcetyp And ISARRAY) Then
                            If (sourcetyp And ISSTRING) = 0 Then Give_Error "VARPTR$ only accepts variable-length string arrays": Exit Function
                            If (sourcetyp And ISFIXEDLENGTH) Then Give_Error "VARPTR$ only accepts variable-length string arrays": Exit Function
                        End If

                        'must be a simple variable
                        '!assuming it is in cmem in DBLOCK
                        r$ = refer(e$, sourcetyp, 1)
                        If Error_Happened Then Exit Function
                        If (sourcetyp And ISSTRING) Then
                            If (sourcetyp And ISARRAY) Then r$ = refer(e$, sourcetyp, 0)
                            If Error_Happened Then Exit Function
                            r$ = r$ + "->cmem_descriptor_offset"
                            t = 3
                        Else
                            r$ = "((unsigned short)(((uint8*)" + r$ + ")-&cmem[1280]))"
                            '*top bit on=unsigned
                            '*second top bit on=bit-value (lower bits indicate the size)
                            'BYTE=1
                            'INTEGER=2
                            'STRING=3
                            'SINGLE=4
                            'INT64=5
                            'FLOAT=6
                            'DOUBLE=8
                            'LONG=20
                            'BIT=64+n
                            t = 0
                            If (sourcetyp And ISUNSIGNED) Then t = t + 128
                            If (sourcetyp And ISOFFSETINBITS) Then
                                t = t + 64
                                t = t + (sourcetyp And 63)
                            Else
                                bits = sourcetyp And 511
                                If (sourcetyp And ISFLOAT) Then
                                    If bits = 32 Then t = t + 4
                                    If bits = 64 Then t = t + 8
                                    If bits = 256 Then t = t + 6
                                Else
                                    If bits = 8 Then t = t + 1
                                    If bits = 16 Then t = t + 2
                                    If bits = 32 Then t = t + 20
                                    If bits = 64 Then t = t + 5
                                End If
                            End If
                        End If
                        r$ = "func_varptr_helper(" + str2(t) + "," + r$ + ")"
                        typ& = ISSTRING
                        GoTo evalfuncspecial
                    End If 'end of varptr$











                    'VARPTR
                    If (sourcetyp And ISINCONVENTIONALMEMORY) = 0 Then
                        recompile = 1
                        cmemlist(Val(e$)) = 1
                        r$ = "[CONVENTIONAL_MEMORY_REQUIRED]"
                        typ& = 64&
                        GoTo evalfuncspecial
                    End If

                    If (sourcetyp And ISARRAY) Then
                        If (sourcetyp And ISOFFSETINBITS) Then Give_Error "VARPTR cannot reference _BIT type arrays": Exit Function

                        'string array?
                        If (sourcetyp And ISSTRING) Then
                            If (sourcetyp And ISFIXEDLENGTH) Then
                                getid Val(e$)
                                If Error_Happened Then Exit Function
                                m = id.tsize
                                index$ = Right$(e$, Len(e$) - InStr(e$, sp3))
                                typ = 64&
                                r$ = "((" + index$ + ")*" + str2(m) + ")"
                                GoTo evalfuncspecial
                            Else
                                'return the offset of the string's descriptor
                                r$ = refer(e$, sourcetyp, 0)
                                If Error_Happened Then Exit Function
                                r$ = r$ + "->cmem_descriptor_offset"
                                typ = 64&
                                GoTo evalfuncspecial
                            End If
                        End If

                        If sourcetyp And ISUDT Then
                            e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip idnumber
                            e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip u
                            o$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip e
                            typ = 64&
                            r$ = "(" + o$ + ")"
                            GoTo evalfuncspecial
                        End If

                        'non-UDT array
                        m = (sourcetyp And 511) \ 8 'calculate size multiplier
                        index$ = Right$(e$, Len(e$) - InStr(e$, sp3))
                        typ = 64&
                        r$ = "((" + index$ + ")*" + str2(m) + ")"
                        GoTo evalfuncspecial

                    End If

                    'not an array

                    If sourcetyp And ISUDT Then
                        r$ = refer(e$, sourcetyp, 1)
                        If Error_Happened Then Exit Function
                        e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip idnumber
                        e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip u
                        o$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip e
                        typ = 64&

                        'if sub/func arg, may not be in DBLOCK
                        getid Val(e$)
                        If Error_Happened Then Exit Function
                        If id.sfarg Then 'could be in DBLOCK
                            'note: segment could be the closest segment to UDT element or the base of DBLOCK
                            r$ = "varptr_dblock_check(((uint8*)" + r$ + ")+(" + o$ + "))"
                        Else 'definitely in DBLOCK
                            'give offset relative to DBLOCK
                            r$ = "((unsigned short)(((uint8*)" + r$ + ") - &cmem[1280] + (" + o$ + ") ))"
                        End If

                        GoTo evalfuncspecial
                    End If

                    typ = 64&
                    r$ = refer(e$, sourcetyp, 1)
                    If Error_Happened Then Exit Function
                    If (sourcetyp And ISSTRING) Then
                        If (sourcetyp And ISFIXEDLENGTH) Then

                            'if sub/func arg, may not be in DBLOCK
                            getid Val(e$)
                            If Error_Happened Then Exit Function
                            If id.sfarg Then 'could be in DBLOCK
                                r$ = "varptr_dblock_check(" + r$ + "->chr)"
                            Else 'definitely in DBLOCK
                                r$ = "((unsigned short)(" + r$ + "->chr-&cmem[1280]))"
                            End If

                        Else
                            r$ = r$ + "->cmem_descriptor_offset"
                        End If
                        GoTo evalfuncspecial
                    End If

                    'single, simple variable
                    'if sub/func arg, may not be in DBLOCK
                    getid Val(e$)
                    If Error_Happened Then Exit Function
                    If id.sfarg Then 'could be in DBLOCK
                        r$ = "varptr_dblock_check((uint8*)" + r$ + ")"
                    Else 'definitely in DBLOCK
                        r$ = "((unsigned short)(((uint8*)" + r$ + ")-&cmem[1280]))"
                    End If

                    GoTo evalfuncspecial
                End If

                '*special case*
                If RTrim$(id2.n) = "VARSEG" Then
                    If (sourcetyp And ISREFERENCE) = 0 Then
                        Give_Error "Expected reference to a variable/array": Exit Function
                    End If
                    If (sourcetyp And ISINCONVENTIONALMEMORY) = 0 Then
                        recompile = 1
                        cmemlist(Val(e$)) = 1
                        r$ = "[CONVENTIONAL_MEMORY_REQUIRED]"
                        typ& = 64&
                        GoTo evalfuncspecial
                    End If
                    'array?
                    If (sourcetyp And ISARRAY) Then
                        If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                            If (sourcetyp And ISSTRING) Then
                                r$ = "80"
                                typ = 64&
                                GoTo evalfuncspecial
                            End If
                        End If
                        typ = 64&
                        r$ = "( ( ((ptrszint)(" + refer(e$, sourcetyp, 1) + "[0])) - ((ptrszint)(&cmem[0])) ) /16)"
                        If Error_Happened Then Exit Function
                        GoTo evalfuncspecial
                    End If

                    'single variable/(var-len)string/udt? (usually stored in DBLOCK)
                    typ = 64&
                    'if sub/func arg, may not be in DBLOCK
                    getid Val(e$)
                    If Error_Happened Then Exit Function
                    If id.sfarg <> 0 And (sourcetyp And ISSTRING) = 0 Then
                        If sourcetyp And ISUDT Then
                            r$ = refer(e$, sourcetyp, 1)
                            If Error_Happened Then Exit Function
                            e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip idnumber
                            e$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip u
                            o$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'skip e
                            r$ = "varseg_dblock_check(((uint8*)" + r$ + ")+(" + o$ + "))"
                        Else
                            r$ = "varseg_dblock_check((uint8*)" + refer(e$, sourcetyp, 1) + ")"
                            If Error_Happened Then Exit Function
                        End If
                    Else
                        'can be assumed to be in DBLOCK
                        r$ = "80"
                    End If
                    GoTo evalfuncspecial
                End If 'varseg

                'note: this code has already been called...
                '------------------------------------------------------------------------------------------------------------
                'e2$ = e$
                'e$ = evaluate(e$, sourcetyp)
                '------------------------------------------------------------------------------------------------------------

                'note: this comment makes no sense...
                'any numeric variable, but it must be type-speficied

                If targettyp = -2 Then
                    e$ = evaluatetotyp(e2$, -2)
                    If Error_Happened Then Exit Function
                    GoTo dontevaluate
                End If '-2

                If targettyp = -7 Then
                    e$ = evaluatetotyp(e2$, -7)
                    If Error_Happened Then Exit Function
                    GoTo dontevaluate
                End If '-7

                If targettyp = -8 Then
                    e$ = evaluatetotyp(e2$, -8)
                    If Error_Happened Then Exit Function
                    GoTo dontevaluate
                End If '-8

                If sourcetyp And ISOFFSET Then
                    If (targettyp And ISOFFSET) = 0 Then
                        If id2.internal_subfunc = 0 Then Give_Error "Cannot convert _OFFSET type to other types": Exit Function
                    End If
                End If

                'note: this is used for functions like STR(...) which accept all types...
                explicitreference = 0
                If targettyp = -1 Then
                    explicitreference = 1
                    If (sourcetyp And ISSTRING) Then Give_Error "Number required for function": Exit Function
                    targettyp = sourcetyp
                    If (targettyp And ISPOINTER) Then targettyp = targettyp - ISPOINTER
                End If

                'pointer?
                If (targettyp And ISPOINTER) Then
                    If dereference = 0 Then 'check deferencing wasn't used



                        'note: array pointer
                        If (targettyp And ISARRAY) Then
                            If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected arrayname()": Exit Function
                            If (sourcetyp And ISARRAY) = 0 Then Give_Error "Expected arrayname()": Exit Function

                            'check arrays are of same type
                            targettyp2 = targettyp: sourcetyp2 = sourcetyp
                            targettyp2 = targettyp2 And (511 + ISOFFSETINBITS + ISUDT + ISSTRING + ISFIXEDLENGTH + ISFLOAT)
                            sourcetyp2 = sourcetyp2 And (511 + ISOFFSETINBITS + ISUDT + ISSTRING + ISFIXEDLENGTH + ISFLOAT)
                            If sourcetyp2 <> targettyp2 Then Give_Error "Incorrect array type passed to function": Exit Function

                            'check arrayname was followed by '()'
                            If targettyp And ISUDT Then
                                'get UDT info
                                udtrefid = Val(e$)
                                getid udtrefid
                                If Error_Happened Then Exit Function
                                udtrefi = InStr(e$, sp3) 'end of id
                                udtrefi2 = InStr(udtrefi + 1, e$, sp3) 'end of u
                                udtrefu = Val(Mid$(e$, udtrefi + 1, udtrefi2 - udtrefi - 1))
                                udtrefi3 = InStr(udtrefi2 + 1, e$, sp3) 'skip e
                                udtrefe = Val(Mid$(e$, udtrefi2 + 1, udtrefi3 - udtrefi2 - 1))
                                o$ = Right$(e$, Len(e$) - udtrefi3)
                                'note: most of the UDT info above is not required
                                If Left$(o$, 4) <> "(0)*" Then Give_Error "Expected arrayname()": Exit Function
                            Else
                                If Right$(e$, 2) <> sp3 + "0" Then Give_Error "Expected arrayname()": Exit Function
                            End If

                            idnum = Val(Left$(e$, InStr(e$, sp3) - 1))
                            getid idnum
                            If Error_Happened Then Exit Function

                            If targettyp And ISFIXEDLENGTH Then
                                targettypsize = CVL(Mid$(id2.argsize, curarg * 4 - 4 + 1, 4))
                                If id.tsize <> targettypsize Then Give_Error "Incorrect array type passed to function": Exit Function
                            End If

                            If Mid$(sfcmemargs(targetid), curarg, 1) = Chr$(1) Then 'cmem required?
                                If cmemlist(idnum) = 0 Then
                                    cmemlist(idnum) = 1

                                    recompile = 1
                                End If
                            End If

                            If id.linkid = 0 Then
                                'if id.linkid is 0, it means the number of array elements is definietly
                                'known of the array being passed, this is not some "fake"/unknown array.
                                'using the numer of array elements of a fake array would be dangerous!

                                If nelereq = 0 Then
                                    'only continue if the number of array elements required is unknown
                                    'and it needs to be set

                                    If id.arrayelements <> -1 Then
                                        nelereq = id.arrayelements
                                        Mid$(id2.nelereq, curarg, 1) = Chr$(nelereq)
                                    End If

                                    ids(targetid) = id2

                                Else

                                    'the number of array elements required is known AND
                                    'the number of elements in the array to be passed is known



                                    'REMOVE FOR TESTING PURPOSES ONLY!!! SHOULD BE UNREM'd!
                                    'print id.arrayelements,nelereq
                                    '             1       ,  2
                                    If id.arrayelements <> nelereq Then Give_Error "Passing arrays with a differing number of elements to a SUB/FUNCTION is not supported": Exit Function
                                End If
                            End If

                            e$ = refer(e$, sourcetyp, 1)
                            If Error_Happened Then Exit Function
                            GoTo dontevaluate
                        End If

                        'note: not an array...

                        'target is not an array

                        If (targettyp And ISSTRING) = 0 Then
                            If (sourcetyp And ISREFERENCE) Then
                                idnum = Val(Left$(e$, InStr(e$, sp3) - 1)) 'id# of sourcetyp

                                targettyp2 = targettyp: sourcetyp2 = sourcetyp

                                'get info about source/target
                                arr = 0: If (sourcetyp2 And ISARRAY) Then arr = 1
                                passudtelement = 0: If (targettyp2 And ISUDT) = 0 And (sourcetyp2 And ISUDT) <> 0 Then passudtelement = 1: sourcetyp2 = sourcetyp2 - ISUDT

                                'remove flags irrelevant for comparison... ISPOINTER,ISREFERENCE,ISINCONVENTIONALMEMORY,ISARRAY
                                targettyp2 = targettyp2 And (511 + ISOFFSETINBITS + ISUDT + ISFLOAT + ISSTRING)
                                sourcetyp2 = sourcetyp2 And (511 + ISOFFSETINBITS + ISUDT + ISFLOAT + ISSTRING)

                                'compare types
                                If sourcetyp2 = targettyp2 Then

                                    If sourcetyp And ISUDT Then
                                        'udt/udt array

                                        'get info
                                        udtrefid = Val(e$)
                                        getid udtrefid
                                        If Error_Happened Then Exit Function
                                        udtrefi = InStr(e$, sp3) 'end of id
                                        udtrefi2 = InStr(udtrefi + 1, e$, sp3) 'end of u
                                        udtrefu = Val(Mid$(e$, udtrefi + 1, udtrefi2 - udtrefi - 1))
                                        udtrefi3 = InStr(udtrefi2 + 1, e$, sp3) 'skip e
                                        udtrefe = Val(Mid$(e$, udtrefi2 + 1, udtrefi3 - udtrefi2 - 1))
                                        o$ = Right$(e$, Len(e$) - udtrefi3)
                                        'note: most of the UDT info above is not required

                                        If arr Then
                                            n2$ = scope$ + "ARRAY_UDT_" + RTrim$(id.n) + "[0]"
                                        Else
                                            n2$ = scope$ + "UDT_" + RTrim$(id.n)
                                        End If

                                        e$ = "(void*)( ((char*)(" + n2$ + ")) + (" + o$ + ") )"

                                        'convert void* to target type*
                                        If passudtelement Then e$ = "(" + typ2ctyp$(targettyp2 + (targettyp And ISUNSIGNED), "") + "*)" + e$
                                        If Error_Happened Then Exit Function

                                    Else
                                        'not a udt
                                        If arr Then
                                            If (sourcetyp2 And ISOFFSETINBITS) Then Give_Error "Cannot pass BIT array offsets": Exit Function
                                            e$ = "(&(" + refer(e$, sourcetyp, 0) + "))"
                                            If Error_Happened Then Exit Function
                                        Else
                                            e$ = refer(e$, sourcetyp, 1)
                                            If Error_Happened Then Exit Function
                                        End If

                                        'note: signed/unsigned mismatch requires casting
                                        If (sourcetyp And ISUNSIGNED) <> (targettyp And ISUNSIGNED) Then
                                            e$ = "(" + typ2ctyp$(targettyp2 + (targettyp And ISUNSIGNED), "") + "*)" + e$
                                            If Error_Happened Then Exit Function
                                        End If

                                    End If 'udt?

                                    'force recompile if target needs to be in cmem and the source is not
                                    If Mid$(sfcmemargs(targetid), curarg, 1) = Chr$(1) Then 'cmem required?
                                        If cmemlist(idnum) = 0 Then
                                            cmemlist(idnum) = 1
                                            recompile = 1
                                        End If
                                    End If

                                    GoTo dontevaluate
                                End If 'similar

                            End If 'source is a reference

                        Else 'string
                            'its a string

                            If (sourcetyp And ISREFERENCE) Then
                                idnum = Val(Left$(e$, InStr(e$, sp3) - 1)) 'id# of sourcetyp
                                If Mid$(sfcmemargs(targetid), curarg, 1) = Chr$(1) Then 'cmem required?
                                    If cmemlist(idnum) = 0 Then
                                        cmemlist(idnum) = 1
                                        recompile = 1
                                    End If
                                End If
                            End If 'reference

                        End If 'string

                    End If 'dereference was not used
                End If 'pointer

                'note: Target is not a pointer...
                'String-numeric mismatch?
                If targettyp And ISSTRING Then
                    If (sourcetyp And ISSTRING) = 0 Then
                        nth = curarg
                        If omitarg_last <> 0 And nth > omitarg_last Then nth = nth - 1
                        If ids(targetid).args = 1 Then Give_Error "String required for function": Exit Function
                        Give_Error str_nth$(nth) + " function argument requires a string": Exit Function
                    End If
                End If
                If (targettyp And ISSTRING) = 0 Then
                    If sourcetyp And ISSTRING Then
                        nth = curarg
                        If omitarg_last <> 0 And nth > omitarg_last Then nth = nth - 1
                        If ids(targetid).args = 1 Then Give_Error "Number required for function": Exit Function
                        Give_Error str_nth$(nth) + " function argument requires a number": Exit Function
                    End If
                End If

                'change to "non-pointer" value
                If (sourcetyp And ISREFERENCE) Then
                    e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                End If

                If explicitreference = 0 Then
                    If targettyp And ISUDT Then
                        nth = curarg
                        If omitarg_last <> 0 And nth > omitarg_last Then nth = nth - 1
                        x$ = "'" + RTrim$(udtxcname(targettyp And 511)) + "'"
                        If ids(targetid).args = 1 Then Give_Error "TYPE " + x$ + " required for function": Exit Function
                        Give_Error str_nth$(nth) + " function argument requires TYPE " + x$: Exit Function
                    End If
                Else
                    If sourcetyp And ISUDT Then Give_Error "Number required for function": Exit Function
                End If

                'round to integer if required
                If (sourcetyp And ISFLOAT) Then
                    If (targettyp And ISFLOAT) = 0 Then
                        '**32 rounding fix
                        bits = targettyp And 511
                        If bits <= 16 Then e$ = "qbr_float_to_long(" + e$ + ")"
                        If bits > 16 And bits < 32 Then e$ = "qbr_double_to_long(" + e$ + ")"
                        If bits >= 32 Then e$ = "qbr(" + e$ + ")"
                    End If
                End If

                If explicitreference Then
                    If (targettyp And ISOFFSETINBITS) Then
                        'integer value can fit inside int64
                        e$ = "(int64)(" + e$ + ")"
                    Else
                        If (targettyp And ISFLOAT) Then
                            If (targettyp And 511) = 32 Then e$ = "(float)(" + e$ + ")"
                            If (targettyp And 511) = 64 Then e$ = "(double)(" + e$ + ")"
                            If (targettyp And 511) = 256 Then e$ = "(long double)(" + e$ + ")"
                        Else
                            If (targettyp And ISUNSIGNED) Then
                                If (targettyp And 511) = 8 Then e$ = "(uint8)(" + e$ + ")"
                                If (targettyp And 511) = 16 Then e$ = "(uint16)(" + e$ + ")"
                                If (targettyp And 511) = 32 Then e$ = "(uint32)(" + e$ + ")"
                                If (targettyp And 511) = 64 Then e$ = "(uint64)(" + e$ + ")"
                            Else
                                If (targettyp And 511) = 8 Then e$ = "(int8)(" + e$ + ")"
                                If (targettyp And 511) = 16 Then e$ = "(int16)(" + e$ + ")"
                                If (targettyp And 511) = 32 Then e$ = "(int32)(" + e$ + ")"
                                If (targettyp And 511) = 64 Then e$ = "(int64)(" + e$ + ")"
                            End If
                        End If 'float?
                    End If 'offset in bits?
                End If 'explicit?

                If (targettyp And ISPOINTER) Then 'pointer required
                    If (targettyp And ISSTRING) Then GoTo dontevaluate 'no changes required
                    '20090703
                    t$ = typ2ctyp$(targettyp, "")
                    If Error_Happened Then Exit Function
                    v$ = "pass" + str2$(uniquenumber)
                    'assume numeric type
                    If Mid$(sfcmemargs(targetid), curarg, 1) = Chr$(1) Then 'cmem required?
                        bytesreq = ((targettyp And 511) + 7) \ 8
                        Print #defdatahandle, t$ + " *" + v$ + "=NULL;"
                        Print #13, "if(" + v$ + "==NULL){"
                        Print #13, "cmem_sp-=" + str2(bytesreq) + ";"
                        Print #13, v$ + "=(" + t$ + "*)(dblock+cmem_sp);"
                        Print #13, "if (cmem_sp<qbs_cmem_sp) error(257);"
                        Print #13, "}"
                        e$ = "&(*" + v$ + "=" + e$ + ")"
                    Else
                        Print #13, t$ + " " + v$ + ";"
                        e$ = "&(" + v$ + "=" + e$ + ")"
                    End If
                    GoTo dontevaluate
                End If

                dontevaluate:

                If id2.ccall Then

                    'if a forced cast from a returned ccall function is in e$, remove it
                    If Left$(e$, 3) = "(  " Then
                        e$ = removecast$(e$)
                    End If

                    If targettyp And ISSTRING Then
                        e$ = "(char*)(" + e$ + ")->chr"
                    End If

                    If LTrim$(RTrim$(e$)) = "0" Then e$ = "NULL"

                End If

                r$ = r$ + e$

                '***special case****
                If n$ = "_MEM" Then
                    If args = 1 Then
                        If curarg = 1 Then r$ = r$ + ")": GoTo evalfuncspecial
                    End If
                    If args = 2 Then
                        If curarg = 2 Then r$ = r$ + ")": GoTo evalfuncspecial
                    End If
                End If

                If i <> n And nocomma = 0 Then r$ = r$ + ","
                nocomma = 0
                firsti = i + 1
                curarg = curarg + 1
            End If

            If (curarg >= omitarg_first And curarg <= omitarg_last) And i = n Then
                targettyp = CVL(Mid$(id2.arg, curarg * 4 - 4 + 1, 4))
                'IF (targettyp AND ISSTRING) THEN Give_Error "QB64 doesn't support optional string arguments for functions yet!": EXIT FUNCTION
                For fi = 1 To omitargs: r$ = r$ + ",NULL": Next
                curarg = curarg + omitargs
            End If

        Next
    End If

    If n$ = "UBOUND" Or n$ = "LBOUND" Then
        If r$ = ",NULL" Then r$ = ",1"
        If n$ = "UBOUND" Then r2$ = "func_ubound(" Else r2$ = "func_lbound("
        e$ = refer$(ulboundarray$, sourcetyp, 1)
        If Error_Happened Then Exit Function
        'note: ID contins refer'ed array info

        arrayelements = id.arrayelements '2009
        If arrayelements = -1 Then arrayelements = 1 '2009

        r$ = r2$ + e$ + r$ + "," + str2$(arrayelements) + ")"
        typ& = INTEGER64TYPE - ISPOINTER
        GoTo evalfuncspecial
    End If

    If passomit Then
        If omitarg_first Then r$ = r$ + ",0" Else r$ = r$ + ",1"
    End If
    r$ = r$ + ")"

    evalfuncspecial:

    If n$ = "ABS" Then typ& = sourcetyp 'ABS Note: ABS() returns argument #1's type

    'QB-like conversion of math functions returning floating point values
    If n$ = "SIN" Or n$ = "COS" Or n$ = "TAN" Or n$ = "ATN" Or n$ = "SQR" Or n$ = "LOG" Then
        b = sourcetyp And 511
        If sourcetyp And ISFLOAT Then
            'Default is FLOATTYPE
            If b = 64 Then typ& = DOUBLETYPE - ISPOINTER
            If b = 32 Then typ& = SINGLETYPE - ISPOINTER
        Else
            'Default is FLOATTYPE
            If b <= 32 Then typ& = DOUBLETYPE - ISPOINTER
            If b <= 16 Then typ& = SINGLETYPE - ISPOINTER
        End If
    End If

    If id2.ret = ISUDT + (1) Then
        '***special case***
        v$ = "func" + str2$(uniquenumber)
        Print #defdatahandle, "mem_block " + v$ + ";"
        r$ = "(" + v$ + "=" + r$ + ")"
    End If

    If id2.ccall Then
        If Left$(r$, 11) = "(  char*  )" Then
            r$ = "qbs_new_txt(" + r$ + ")"
        End If
    End If

    evaluatefunc$ = r$
End Function

Function variablesize$ (i As Long) 'ID or -1 (if ID already 'loaded')
    'Note: assumes whole bytes, no bit offsets/sizes
    If i <> -1 Then getid i
    If Error_Happened Then Exit Function
    'find base size from type
    t = id.t: If t = 0 Then t = id.arraytype
    bytes = (t And 511) \ 8

    If t And ISUDT Then 'correct size for UDTs
        u = t And 511
        bytes = udtxsize(u) \ 8
    End If

    If t And ISSTRING Then 'correct size for strings
        If t And ISFIXEDLENGTH Then
            bytes = id.tsize
        Else
            If id.arraytype Then Give_Error "Cannot determine size of variable-length string array": Exit Function
            variablesize$ = scope$ + "STRING_" + RTrim$(id.n) + "->len"
            Exit Function
        End If
    End If

    If id.arraytype Then 'multiply size for arrays
        n$ = RTrim$(id.callname)
        s$ = str2(bytes) + "*(" + n$ + "[2]&1)" 'note: multiplying by 0 if array not currently defined (affects dynamic arrays)
        arrayelements = id.arrayelements: If arrayelements = -1 Then arrayelements = 1 '2009
        For i2 = 1 To arrayelements
            s$ = s$ + "*" + n$ + "[" + str2(i2 * 4 - 4 + 5) + "]"
        Next
        variablesize$ = "(" + s$ + ")"
        Exit Function
    End If

    variablesize$ = str2(bytes)
End Function

Function evaluatetotyp$ (a2$, targettyp As Long)
    'note: 'evaluatetotyp' no longer performs 'fixoperationorder' on a2$ (in many cases, this has already been done)
    a$ = a2$
    e$ = evaluate(a$, sourcetyp)
    If Error_Happened Then Exit Function

    'Offset protection:
    If sourcetyp And ISOFFSET Then
        If (targettyp And ISOFFSET) = 0 And targettyp >= 0 Then
            Give_Error "Cannot convert _OFFSET type to other types": Exit Function
        End If
    End If

    '-5 size
    '-6 offset
    If targettyp = -4 Or targettyp = -5 Or targettyp = -6 Then '? -> byte_element(offset,element size in bytes)
        If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected variable name/array element": Exit Function
        If (sourcetyp And ISOFFSETINBITS) Then Give_Error "Variable/element cannot be BIT aligned": Exit Function

        ' print "-4: evaluated as ["+e$+"]":sleep 1

        If (sourcetyp And ISUDT) Then 'User Defined Type -> byte_element(offset,bytes)
            If udtxvariable(sourcetyp And 511) Then Give_Error "UDT must have fixed size": Exit Function
            idnumber = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            u = Val(e$) 'closest parent
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            E = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            o$ = e$
            getid idnumber
            If Error_Happened Then Exit Function
            n$ = "UDT_" + RTrim$(id.n)
            If id.arraytype Then
                n$ = "ARRAY_" + n$ + "[0]"
                'whole array reference examplename()?
                If Left$(o$, 3) = "(0)" Then
                    'use -2 type method
                    GoTo method2usealludt
                End If
            End If

            dst$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"

            'determine size of element
            If E = 0 Then 'no specific element, use size of entire type
                bytes$ = str2(udtxsize(u) \ 8)
            Else 'a specific element
                If (udtetype(E) And ISSTRING) > 0 And (udtetype(E) And ISFIXEDLENGTH) = 0 And (targettyp = -5) Then
                    evaluatetotyp$ = "(*(qbs**)" + dst$ + ")->len"
                    Exit Function
                ElseIf (udtetype(E) And ISSTRING) > 0 And (udtetype(E) And ISFIXEDLENGTH) = 0 And (targettyp = -4) Then
                    dst$ = "(*((qbs**)((char*)" + scope$ + n$ + "+(" + o$ + "))))->chr"
                    bytes$ = "(*((qbs**)((char*)" + scope$ + n$ + "+(" + o$ + "))))->len"
                    evaluatetotyp$ = "byte_element((uint64)" + dst$ + "," + bytes$ + "," + NewByteElement$ + ")"
                    Exit Function
                End If
                bytes$ = str2(udtesize(E) \ 8)
            End If
            evaluatetotyp$ = "byte_element((uint64)" + dst$ + "," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = dst$
            Exit Function
        End If

        If (sourcetyp And ISARRAY) Then 'Array reference -> byte_element(offset,bytes)
            'whole array reference examplename()?
            If Right$(e$, 2) = sp3 + "0" Then
                'use -2 type method
                If sourcetyp And ISSTRING Then
                    If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                        Give_Error "Cannot pass array of variable-length strings": Exit Function
                    End If
                End If
                GoTo method2useall
            End If
            'assume a specific element
            If sourcetyp And ISSTRING Then
                If sourcetyp And ISFIXEDLENGTH Then
                    idnumber = Val(e$)
                    getid idnumber
                    If Error_Happened Then Exit Function
                    bytes$ = str2(id.tsize)
                    e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    evaluatetotyp$ = "byte_element((uint64)" + e$ + "->chr," + bytes$ + "," + NewByteElement$ + ")"
                    If targettyp = -5 Then evaluatetotyp$ = bytes$
                    If targettyp = -6 Then evaluatetotyp$ = e$ + "->chr"
                Else
                    e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function

                    evaluatetotyp$ = "byte_element((uint64)" + e$ + "->chr," + e$ + "->len," + NewByteElement$ + ")"
                    If targettyp = -5 Then evaluatetotyp$ = e$ + "->len"
                    If targettyp = -6 Then evaluatetotyp$ = e$ + "->chr"
                End If
                Exit Function
            End If
            e$ = refer(e$, sourcetyp, 0)
            If Error_Happened Then Exit Function
            e$ = "(&(" + e$ + "))"
            bytes$ = str2((sourcetyp And 511) \ 8)
            evaluatetotyp$ = "byte_element((uint64)" + e$ + "," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = e$
            Exit Function
        End If

        If sourcetyp And ISSTRING Then 'String -> byte_element(offset,bytes)
            If sourcetyp And ISFIXEDLENGTH Then
                idnumber = Val(e$)
                getid idnumber
                If Error_Happened Then Exit Function
                bytes$ = str2(id.tsize)
                e$ = refer(e$, sourcetyp, 0)
                If Error_Happened Then Exit Function
            Else
                e$ = refer(e$, sourcetyp, 0)
                If Error_Happened Then Exit Function
                bytes$ = e$ + "->len"
            End If
            evaluatetotyp$ = "byte_element((uint64)" + e$ + "->chr," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = e$ + "->chr"
            Exit Function
        End If

        'Standard variable -> byte_element(offset,bytes)
        e$ = refer(e$, sourcetyp, 1) 'get the variable's formal name
        If Error_Happened Then Exit Function
        size = (sourcetyp And 511) \ 8 'calculate its size in bytes
        evaluatetotyp$ = "byte_element((uint64)" + e$ + "," + str2(size) + "," + NewByteElement$ + ")"
        If targettyp = -5 Then evaluatetotyp$ = str2(size)
        If targettyp = -6 Then evaluatetotyp$ = e$
        Exit Function

    End If '-4, -5, -6

    If targettyp = -8 Then '? -> _MEM structure helper {offset, fullsize, typeval, elementsize, sf_mem_lock|???}
        If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected variable name/array element": Exit Function
        If (sourcetyp And ISOFFSETINBITS) Then Give_Error "Variable/element cannot be BIT aligned": Exit Function

        If (sourcetyp And ISUDT) Then 'User Defined Type -> byte_element(offset,bytes)
            idnumber = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            u = Val(e$) 'closest parent
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            E = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            o$ = e$
            getid idnumber
            If Error_Happened Then Exit Function
            n$ = "UDT_" + RTrim$(id.n)
            If id.arraytype Then
                n$ = "ARRAY_" + n$ + "[0]"
                'whole array reference examplename()?
                If Left$(o$, 3) = "(0)" Then
                    'use -7 type method
                    GoTo method2usealludt__7
                End If
            End If
            'determine size of element
            If E = 0 Then 'no specific element, use size of entire type
                bytes$ = str2(udtxsize(u) \ 8)
                t1 = ISUDT + udtetype(u)
            Else 'a specific element
                bytes$ = str2(udtesize(E) \ 8)
                t1 = udtetype(E)
            End If
            dst$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"
            'evaluatetotyp$ = "byte_element((uint64)" + dst$ + "," + bytes$ + "," + NewByteElement$ + ")"
            'IF targettyp = -5 THEN evaluatetotyp$ = bytes$
            'IF targettyp = -6 THEN evaluatetotyp$ = dst$

            t = Type2MemTypeValue(t1)
            evaluatetotyp$ = "(ptrszint)" + dst$ + "," + bytes$ + "," + str2(t) + "," + bytes$ + ",sf_mem_lock"

            Exit Function
        End If

        If (sourcetyp And ISARRAY) Then 'Array reference -> byte_element(offset,bytes)
            'whole array reference examplename()?
            If Right$(e$, 2) = sp3 + "0" Then
                'use -7 type method
                If sourcetyp And ISSTRING Then
                    If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                        Give_Error "Cannot pass array of variable-length strings": Exit Function
                    End If
                End If
                GoTo method2useall__7
            End If

            idnumber = Val(e$)
            getid idnumber
            If Error_Happened Then Exit Function
            n$ = RTrim$(id.callname)
            lk$ = "(mem_lock*)((ptrszint*)" + n$ + ")[" + str2(4 * id.arrayelements + 4 + 1 - 1) + "]"

            'assume a specific element

            If sourcetyp And ISSTRING Then
                If sourcetyp And ISFIXEDLENGTH Then
                    bytes$ = str2(id.tsize)
                    e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function

                    t = Type2MemTypeValue(sourcetyp)
                    evaluatetotyp$ = "(ptrszint)" + e$ + "->chr," + bytes$ + "," + str2(t) + "," + bytes$ + "," + lk$
                Else
                    Give_Error qb64prefix$ + "MEMELEMENT cannot reference variable-length strings": Exit Function
                End If
                Exit Function
            End If

            e$ = refer(e$, sourcetyp, 0)
            If Error_Happened Then Exit Function
            e$ = "(&(" + e$ + "))"
            bytes$ = str2((sourcetyp And 511) \ 8)
            'evaluatetotyp$ = "byte_element((uint64)" + e$ + "," + bytes$ + "," + NewByteElement$ + ")"
            'IF targettyp = -5 THEN evaluatetotyp$ = bytes$
            'IF targettyp = -6 THEN evaluatetotyp$ = e$

            t = Type2MemTypeValue(sourcetyp)
            evaluatetotyp$ = "(ptrszint)" + e$ + "," + bytes$ + "," + str2(t) + "," + bytes$ + "," + lk$

            Exit Function
        End If 'isarray

        If sourcetyp And ISSTRING Then 'String -> byte_element(offset,bytes)
            If sourcetyp And ISFIXEDLENGTH Then
                idnumber = Val(e$)
                getid idnumber
                If Error_Happened Then Exit Function
                bytes$ = str2(id.tsize)
                e$ = refer(e$, sourcetyp, 0)
                If Error_Happened Then Exit Function
            Else
                Give_Error qb64prefix$ + "MEMELEMENT cannot reference variable-length strings": Exit Function
            End If

            t = Type2MemTypeValue(sourcetyp)
            evaluatetotyp$ = "(ptrszint)" + e$ + "->chr," + bytes$ + "," + str2(t) + "," + bytes$ + ",sf_mem_lock"

            Exit Function
        End If

        'Standard variable -> byte_element(offset,bytes)
        e$ = refer(e$, sourcetyp, 1) 'get the variable's formal name
        If Error_Happened Then Exit Function
        size = (sourcetyp And 511) \ 8 'calculate its size in bytes

        t = Type2MemTypeValue(sourcetyp)
        evaluatetotyp$ = "(ptrszint)" + e$ + "," + str2(size) + "," + str2(t) + "," + str2(size) + ",sf_mem_lock"

        Exit Function
    End If '-8

    If targettyp = -7 Then '? -> _MEM structure helper {offset, fullsize, typeval, elementsize, sf_mem_lock|???}
        method2useall__7:
        If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected variable name/array element": Exit Function
        If (sourcetyp And ISOFFSETINBITS) Then Give_Error "Variable/element cannot be BIT aligned": Exit Function

        'User Defined Type
        If (sourcetyp And ISUDT) Then
            '           print "CI: -2 type from a UDT":sleep 1
            idnumber = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            u = Val(e$) 'closest parent
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            E = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)

            o$ = e$
            getid idnumber
            If Error_Happened Then Exit Function
            n$ = "UDT_" + RTrim$(id.n): If id.arraytype Then n$ = "ARRAY_" + n$ + "[0]"
            method2usealludt__7:
            bytes$ = variablesize$(-1) + "-(" + o$ + ")"
            If Error_Happened Then Exit Function
            dst$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"

            'note: myudt.myelement results in a size of 1 because it is a continuous run of no consistent granularity
            If E <> 0 Then size = 1 Else size = udtxsize(u) \ 8

            t = Type2MemTypeValue(sourcetyp)
            evaluatetotyp$ = "(ptrszint)" + dst$ + "," + bytes$ + "," + str2(t) + "," + str2(size) + ",sf_mem_lock"

            Exit Function
        End If

        'Array reference
        If (sourcetyp And ISARRAY) Then
            If sourcetyp And ISSTRING Then
                If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                    Give_Error qb64prefix$ + "MEM cannot reference variable-length strings": Exit Function
                End If
            End If

            idnumber = Val(e$)
            getid idnumber
            If Error_Happened Then Exit Function

            n$ = RTrim$(id.callname)
            lk$ = "(mem_lock*)((ptrszint*)" + n$ + ")[" + str2(4 * id.arrayelements + 4 + 1 - 1) + "]"

            tsize = id.tsize 'used later to determine element size of fixed length strings
            'note: array references consist of idnumber|unmultiplied-element-index
            index$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'get element index
            bytes$ = variablesize$(-1)
            If Error_Happened Then Exit Function
            e$ = refer(e$, sourcetyp, 0)
            If Error_Happened Then Exit Function

            If sourcetyp And ISSTRING Then
                e$ = "((" + e$ + ")->chr)" '[2013] handle fixed string arrays differently because they are already pointers
            Else
                e$ = "(&(" + e$ + "))"
            End If

            'print "CI: array: e$["+e$+"], bytes$["+bytes$+"]":sleep 1
            'calculate size of elements
            If sourcetyp And ISSTRING Then
                bytes = tsize
            Else
                bytes = (sourcetyp And 511) \ 8
            End If
            bytes$ = bytes$ + "-(" + str2(bytes) + "*(" + index$ + "))"

            t = Type2MemTypeValue(sourcetyp)
            evaluatetotyp$ = "(ptrszint)" + e$ + "," + bytes$ + "," + str2(t) + "," + str2(bytes) + "," + lk$

            Exit Function
        End If

        'String
        If sourcetyp And ISSTRING Then
            If (sourcetyp And ISFIXEDLENGTH) = 0 Then Give_Error qb64prefix$ + "MEM cannot reference variable-length strings": Exit Function

            idnumber = Val(e$)
            getid idnumber: If Error_Happened Then Exit Function
            bytes$ = str2(id.tsize)
            e$ = refer(e$, sourcetyp, 0): If Error_Happened Then Exit Function

            t = Type2MemTypeValue(sourcetyp)
            evaluatetotyp$ = "(ptrszint)" + e$ + "->chr," + bytes$ + "," + str2(t) + "," + bytes$ + ",sf_mem_lock"

            Exit Function
        End If

        'Standard variable -> byte_element(offset,bytes)
        e$ = refer(e$, sourcetyp, 1) 'get the variable's formal name
        If Error_Happened Then Exit Function
        size = (sourcetyp And 511) \ 8 'calculate its size in bytes

        t = Type2MemTypeValue(sourcetyp)
        evaluatetotyp$ = "(ptrszint)" + e$ + "," + str2(size) + "," + str2(t) + "," + str2(size) + ",sf_mem_lock"

        Exit Function

    End If '-7 _MEM structure helper


    If targettyp = -2 Then '? -> byte_element(offset,max possible bytes)
        method2useall:
        ' print "CI: eval2typ detected target type of -2 for ["+a2$+"] evaluated as ["+e$+"]":sleep 1

        If (sourcetyp And ISREFERENCE) = 0 Then Give_Error "Expected variable name/array element": Exit Function
        If (sourcetyp And ISOFFSETINBITS) Then Give_Error "Variable/element cannot be BIT aligned": Exit Function

        'User Defined Type -> byte_element(offset,bytes)
        If (sourcetyp And ISUDT) Then
            '           print "CI: -2 type from a UDT":sleep 1
            idnumber = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            u = Val(e$) 'closest parent
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            E = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i)
            o$ = e$
            getid idnumber
            If Error_Happened Then Exit Function
            n$ = "UDT_" + RTrim$(id.n): If id.arraytype Then n$ = "ARRAY_" + n$ + "[0]"
            method2usealludt:
            bytes$ = variablesize$(-1) + "-(" + o$ + ")"
            If Error_Happened Then Exit Function
            dst$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"
            evaluatetotyp$ = "byte_element((uint64)" + dst$ + "," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = dst$
            Exit Function
        End If

        'Array reference -> byte_element(offset,bytes)
        If (sourcetyp And ISARRAY) Then
            'array of variable length strings (special case, can only refer to single element)
            If sourcetyp And ISSTRING Then
                If (sourcetyp And ISFIXEDLENGTH) = 0 Then
                    e$ = refer(e$, sourcetyp, 0)
                    If Error_Happened Then Exit Function
                    evaluatetotyp$ = "byte_element((uint64)" + e$ + "->chr," + e$ + "->len," + NewByteElement$ + ")"
                    If targettyp = -5 Then evaluatetotyp$ = e$ + "->len"
                    If targettyp = -6 Then evaluatetotyp$ = e$ + "->chr"
                    Exit Function
                End If
            End If
            idnumber = Val(e$)
            getid idnumber
            If Error_Happened Then Exit Function
            tsize = id.tsize 'used later to determine element size of fixed length strings
            'note: array references consist of idnumber|unmultiplied-element-index
            index$ = Right$(e$, Len(e$) - InStr(e$, sp3)) 'get element index
            bytes$ = variablesize$(-1)
            If Error_Happened Then Exit Function
            e$ = refer(e$, sourcetyp, 0)
            If Error_Happened Then Exit Function
            e$ = "(&(" + e$ + "))"
            '           print "CI: array: e$["+e$+"], bytes$["+bytes$+"]":sleep 1
            'calculate size of elements
            If sourcetyp And ISSTRING Then
                bytes = tsize
            Else
                bytes = (sourcetyp And 511) \ 8
            End If
            bytes$ = bytes$ + "-(" + str2(bytes) + "*(" + index$ + "))"
            evaluatetotyp$ = "byte_element((uint64)" + e$ + "," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = e$
            '           print "CI: array ->["+"byte_element((uint64)" + e$ + "," + bytes$+ ","+NewByteElement$+")"+"]":sleep 1
            Exit Function
        End If

        'String -> byte_element(offset,bytes)
        If sourcetyp And ISSTRING Then
            If sourcetyp And ISFIXEDLENGTH Then
                idnumber = Val(e$)
                getid idnumber
                If Error_Happened Then Exit Function
                bytes$ = str2(id.tsize)
                e$ = refer(e$, sourcetyp, 0)
                If Error_Happened Then Exit Function
            Else
                e$ = refer(e$, sourcetyp, 0)
                If Error_Happened Then Exit Function
                bytes$ = e$ + "->len"
            End If
            evaluatetotyp$ = "byte_element((uint64)" + e$ + "->chr," + bytes$ + "," + NewByteElement$ + ")"
            If targettyp = -5 Then evaluatetotyp$ = bytes$
            If targettyp = -6 Then evaluatetotyp$ = e$ + "->chr"
            Exit Function
        End If

        'Standard variable -> byte_element(offset,bytes)
        e$ = refer(e$, sourcetyp, 1) 'get the variable's formal name
        If Error_Happened Then Exit Function
        size = (sourcetyp And 511) \ 8 'calculate its size in bytes
        evaluatetotyp$ = "byte_element((uint64)" + e$ + "," + str2(size) + "," + NewByteElement$ + ")"
        If targettyp = -5 Then evaluatetotyp$ = str2(size)
        If targettyp = -6 Then evaluatetotyp$ = e$
        Exit Function

    End If '-2 byte_element(offset,bytes)

    'string?
    If (sourcetyp And ISSTRING) <> (targettyp And ISSTRING) Then
        Give_Error "Illegal string-number conversion": Exit Function
    End If

    If (sourcetyp And ISSTRING) Then
        evaluatetotyp$ = e$
        If (sourcetyp And ISREFERENCE) Then
            evaluatetotyp$ = refer(e$, sourcetyp, 0)
            If Error_Happened Then Exit Function
        End If
        Exit Function
    End If

    'pointer required?
    If (targettyp And ISPOINTER) Then
        Give_Error "evaluatetotyp received a request for a pointer (unsupported)": Exit Function
        '...
        Give_Error "Invalid pointer": Exit Function
    End If

    'change to "non-pointer" value
    If (sourcetyp And ISREFERENCE) Then
        e$ = refer(e$, sourcetyp, 0)
        If Error_Happened Then Exit Function
    End If
    'check if successful
    If (sourcetyp And ISPOINTER) Then
        Give_Error "evaluatetotyp couldn't convert pointer type!": Exit Function
    End If

    'round to integer if required
    If (sourcetyp And ISFLOAT) Then
        If (targettyp And ISFLOAT) = 0 Then
            bits = targettyp And 511
            '**32 rounding fix
            If bits <= 16 Then e$ = "qbr_float_to_long(" + e$ + ")"
            If bits > 16 And bits < 32 Then e$ = "qbr_double_to_long(" + e$ + ")"
            If bits >= 32 Then e$ = "qbr(" + e$ + ")"
        End If
    End If

    evaluatetotyp$ = e$
End Function

Function findid& (n2$)
    n$ = UCase$(n2$) 'case insensitive

    'return all strings as 'not found'
    If Asc(n$) = 34 Then GoTo noid

    'if findidsecondarg was set, it will be used for finding the name of a sub (not a func or variable)
    secondarg$ = findidsecondarg: findidsecondarg = ""

    'if findanotherid was set, findid will continue scan from last index, otherwise, it will begin a new search
    findanother = findanotherid: findanotherid = 0
    If findanother <> 0 And findidinternal <> 2 Then Give_Error "FINDID() ERROR: Invalid repeat search requested!": Exit Function 'cannot continue search, no more indexes left!
    If Error_Happened Then Exit Function
    '(the above should never happen)
    findid& = 2 '2=not finished searching all indexes

    'seperate symbol from name (if a symbol has been added), this is the only way symbols can be passed to findid
    i = 0
    i = InStr(n$, "~"): If i Then GoTo gotsc
    i = InStr(n$, "`"): If i Then GoTo gotsc
    i = InStr(n$, "%"): If i Then GoTo gotsc
    i = InStr(n$, "&"): If i Then GoTo gotsc
    i = InStr(n$, "!"): If i Then GoTo gotsc
    i = InStr(n$, "#"): If i Then GoTo gotsc
    i = InStr(n$, "$"): If i Then GoTo gotsc
    gotsc:
    If i Then
        sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1)
        If sc$ = "`" Or sc$ = "~`" Then sc$ = sc$ + "1" 'clarify abbreviated 1 bit reference
    Else
        '''    'no symbol passed, so check what symbol could be assumed under the current DEF...
        '''    v = ASC(n$): IF v = 95 THEN v = 27 ELSE v = v - 64
        '''    IF v >= 1 AND v <= 27 THEN 'safeguard against n$ not being a standard name
        '''        couldhavesc$ = defineextaz(v)
        '''        IF couldhavesc$ = "`" OR couldhavesc$ = "~`" THEN couldhavesc$ = couldhavesc$ + "1" 'clarify abbreviated 1 bit reference
        '''    END IF 'safeguard
    End If

    'optimizations for later comparisons
    insf$ = subfunc + Space$(256 - Len(subfunc))
    secondarg$ = secondarg$ + Space$(256 - Len(secondarg$))
    If Len(sc$) Then scpassed = 1: sc$ = sc$ + Space$(8 - Len(sc$)) Else scpassed = 0
    '''IF LEN(couldhavesc$) THEN couldhavesc$ = couldhavesc$ + SPACE$(8 - LEN(couldhavesc$)): couldhavescpassed = 1 ELSE couldhavescpassed = 0
    If Len(n$) < 256 Then n$ = n$ + Space$(256 - Len(n$))

    'FUNCTION HashFind (a$, searchflags, resultflags, resultreference)
    '(0,1,2)z=hashfind[rev]("RUMI",Hashflag_label,resflag,resref)
    '0=doesn't exist
    '1=found, no more items to scan
    '2=found, more items still to scan

    'NEW HASH SYSTEM
    n$ = RTrim$(n$)
    If findanother Then
        hashretry:
        z = HashFindCont(unrequired, i)
    Else
        z = HashFind(n$, 1, unrequired, i)
    End If
    findidinternal = z
    If z = 0 Then GoTo noid
    findid = z

    'in scope?
    If ids(i).subfunc = 0 And ids(i).share = 0 Then 'scope check required (not a shared variable or the name of a sub/function)
        If ids(i).insubfunc <> insf$ Then GoTo findidnomatch
    End If

    'some subs require a second argument (eg. PUT #, DEF SEG, etc.)
    If ids(i).subfunc = 2 Then
        If Asc(ids(i).secondargmustbe) <> 32 Then 'exists?
            If RTrim$(secondarg$) = UCase$(RTrim$(ids(i).secondargmustbe)) Then
            ElseIf Left$(ids(i).secondargmustbe, 1) = "_" And Left$(secondarg$, 1) <> "_" And RTrim$(secondarg$) = UCase$(Mid$(RTrim$(ids(i).secondargmustbe), 2)) Then
            Else
                GoTo findidnomatch
            End If
        End If
        If Asc(ids(i).secondargcantbe) <> 32 Then 'exists?
            If RTrim$(secondarg$) <> UCase$(RTrim$(ids(i).secondargcantbe)) Then
            ElseIf Left$(ids(i).secondargcantbe, 1) = "_" And Left$(secondarg$, 1) <> "_" And RTrim$(secondarg$) <> UCase$(Mid$(RTrim$(ids(i).secondargcantbe), 2)) Then
            Else
                GoTo findidnomatch
            End If
        End If
    End If 'second sub argument possible

    'must have symbol?
    'typically for variables defined automatically or by a symbol and not the full type name
    imusthave = CVI(ids(i).musthave) 'speed up checks of first 2 characters
    amusthave = imusthave And 255 'speed up checks of first character
    If amusthave <> 32 Then
        If scpassed Then
            If sc$ = ids(i).musthave Then GoTo findidok
        End If
        '''    IF couldhavescpassed THEN
        '''        IF couldhavesc$ = ids(i).musthave THEN GOTO findidok
        '''    END IF
        'Q: why is the above triple-commented?
        'A: because if something must have a symbol to refer to it, then a could-have is
        '   not sufficient, and it could mask shared variables in global scope

        'note: symbol defined fixed length strings cannot be referred to by $ without an extension
        'note: sc$ and couldhavesc$ are already changed from ` to `1 to match stored musthave
        GoTo findidnomatch
    End If

    'may have symbol?
    'typically for variables formally dim'd
    'note: couldhavesc$ needn't be considered for mayhave checks
    If scpassed Then 'symbol was passed, so it must match the mayhave symbol
        imayhave = CVI(ids(i).mayhave) 'speed up checks of first 2 characters
        amayhave = imayhave And 255 'speed up checks of first character
        If amayhave = 32 Then GoTo findidnomatch 'it cannot have the symbol passed (nb. musthave symbols have already been ok'd)
        'note: variable length strings are not a problem here, as they can only have one possible extension

        If amayhave = 36 Then '"$"
            If imayhave <> 8228 Then '"$ "
                'it is a fixed length string
                If CVI(sc$) = 8228 Then GoTo findidok 'allow myvariable$ to become myvariable$10
                'allow later comparison to verify if extension is correct
            End If
        End If
        If sc$ <> ids(i).mayhave Then GoTo findidnomatch
    End If 'scpassed

    'return id
    findidok:

    id = ids(i)

    t = id.t
    temp$ = refer$(str2$(i), t, 1)
    currentid = i
    Exit Function

    'END IF 'same name
    findidnomatch:
    'NEXT
    If z = 2 Then GoTo hashretry

    'totally unclassifiable
    noid:
    findid& = 0
    currentid = -1
End Function

Function FindArray (secure$)
    FindArray = -1
    n$ = secure$
    If alphanumeric(Asc(n$)) = 0 Then FindArray = 0: Exit Function

    'establish whether n$ includes an extension
    i = InStr(n$, "~"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "`"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "%"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "&"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "!"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "#"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    i = InStr(n$, "$"): If i Then sc$ = Right$(n$, Len(n$) - i + 1): n$ = Left$(n$, i - 1): GoTo gotsc2
    gotsc2:
    n2$ = n$ + sc$

    If sc$ <> "" Then
        'has an extension
        'note! findid must unambiguify ` to `5 or $ to $10 where applicable
        try = findid(n2$): If Error_Happened Then Exit Function
        Do While try
            If id.arraytype Then
                Exit Function
            End If
            If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
            If Error_Happened Then Exit Function
        Loop

    Else
        'no extension

        '1. pass as is, without any extension (local)
        try = findid(n2$): If Error_Happened Then Exit Function
        Do While try
            If id.arraytype Then
                If subfuncn = 0 Then Exit Function
                If id.insubfuncn = subfuncn Then Exit Function
            End If
            If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
            If Error_Happened Then Exit Function
        Loop

        '2. that failed, so apply the _define'd extension and pass (local)
        a = Asc(UCase$(n$)): If a = 95 Then a = 91
        a = a - 64 'so A=1, Z=27 and _=28
        n2$ = n$ + defineextaz(a)
        try = findid(n2$): If Error_Happened Then Exit Function
        Do While try
            If id.arraytype Then
                If subfuncn = 0 Then Exit Function
                If id.insubfuncn = subfuncn Then Exit Function
                Exit Function
            End If
            If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
            If Error_Happened Then Exit Function
        Loop

        '3. pass as is, without any extension (global)
        n2$ = n$
        try = findid(n2$): If Error_Happened Then Exit Function
        Do While try
            If id.arraytype Then
                Exit Function
            End If
            If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
            If Error_Happened Then Exit Function
        Loop

        '4. that failed, so apply the _define'd extension and pass (global)
        a = Asc(UCase$(n$)): If a = 95 Then a = 91
        a = a - 64 'so A=1, Z=27 and _=28
        n2$ = n$ + defineextaz(a)
        try = findid(n2$): If Error_Happened Then Exit Function
        Do While try
            If id.arraytype Then
                Exit Function
            End If
            If try = 2 Then findanotherid = 1: try = findid(n2$) Else try = 0
            If Error_Happened Then Exit Function
        Loop

    End If
    FindArray = 0
End Function

Function fixoperationorder$ (savea$)
    Static uboundlbound As _Byte

    a$ = savea$

    fooindwel = fooindwel + 1

    n = numelements(a$) 'n is maintained throughout function

    If fooindwel = 1 Then 'actions to take on initial call only
        uboundlbound = 0

        'Quick check for duplicate binary operations
        uppercasea$ = UCase$(a$) 'capitalize it once to reduce calls to ucase over and over
        For i = 1 To n - 1
            temp1$ = getelement(uppercasea$, i)
            temp2$ = getelement(uppercasea$, i + 1)
            If temp1$ = "AND" And temp2$ = "AND" Then Give_Error "Error: AND AND": Exit Function
            If temp1$ = "OR" And temp2$ = "OR" Then Give_Error "Error: OR OR": Exit Function
            If temp1$ = "XOR" And temp2$ = "XOR" Then Give_Error "Error: XOR XOR": Exit Function
            If temp1$ = "IMP" And temp2$ = "IMP" Then Give_Error "Error: IMP IMP": Exit Function
            If temp1$ = "EQV" And temp2$ = "EQV" Then Give_Error "Error: EQV EQV": Exit Function
        Next

        '----------------A. 'Quick' mismatched brackets check----------------
        b = 0
        a2$ = sp + a$ + sp
        b1$ = sp + "(" + sp
        b2$ = sp + ")" + sp
        i = 1
        findmmb:
        i1 = InStr(i, a2$, b1$)
        i2 = InStr(i, a2$, b2$)
        i3 = i1
        If i2 Then
            If i1 = 0 Then
                i3 = i2
            Else
                If i2 < i1 Then i3 = i2
            End If
        End If
        If i3 Then
            If i3 = i1 Then b = b + 1
            If i3 = i2 Then b = b - 1
            i = i3 + 2
            If b < 0 Then Give_Error "Missing (": Exit Function
            GoTo findmmb
        End If
        If b > 0 Then Give_Error "Missing )": Exit Function

        '----------------B. 'Quick' correction of over-use of +,- ----------------
        'note: the results of this change are beneficial to foolayout
        a2$ = sp + a$ + sp

        'rule 1: change ++ to +
        rule1:
        i = InStr(a2$, sp + "+" + sp + "+" + sp)
        If i Then
            a2$ = Left$(a2$, i + 2) + Right$(a2$, Len(a2$) - i - 4)
            a$ = Mid$(a2$, 2, Len(a2$) - 2)
            n = n - 1
            GoTo rule1
        End If

        'rule 2: change -+ to -
        rule2:
        i = InStr(a2$, sp + "-" + sp + "+" + sp)
        If i Then
            a2$ = Left$(a2$, i + 2) + Right$(a2$, Len(a2$) - i - 4)
            a$ = Mid$(a2$, 2, Len(a2$) - 2)
            n = n - 1
            GoTo rule2
        End If

        'rule 3: change anyoperator-- to anyoperator
        rule3:
        If InStr(a2$, sp + "-" + sp + "-" + sp) Then
            For i = 1 To n - 2
                If isoperator(getelement(a$, i)) Then
                    If getelement(a$, i + 1) = "-" Then
                        If getelement(a$, i + 2) = "-" Then
                            removeelements a$, i + 1, i + 2, 0
                            a2$ = sp + a$ + sp
                            n = n - 2
                            GoTo rule3
                        End If
                    End If
                End If
            Next
        End If 'rule 3



        '----------------C. 'Quick' location of negation----------------
        'note: the results of this change are beneficial to foolayout

        'for numbers...
        'before: anyoperator,-,number
        'after:  anyoperator,-number

        'for variables...
        'before: anyoperator,-,variable
        'after:  anyoperator,CHR$(241),variable

        'exception for numbers followed by ^... (they will be bracketed up along with the ^ later)
        'before: anyoperator,-,number,^
        'after:  anyoperator,CHR$(241),number,^

        For i = 1 To n - 1
            If i > n - 1 Then Exit For 'n changes, so manually exit if required

            If Asc(getelement(a$, i)) = 45 Then '-

                neg = 0
                If i = 1 Then
                    neg = 1
                Else
                    a2$ = getelement(a$, i - 1)
                    c = Asc(a2$)
                    If c = 40 Or c = 44 Then '(,
                        neg = 1
                    Else
                        If isoperator(a2$) Then neg = 1
                    End If '()
                End If 'i=1
                If neg = 1 Then

                    a2$ = getelement(a$, i + 1)
                    c = Asc(a2$)
                    If c >= 48 And c <= 57 Then
                        c2 = 0: If i < n - 1 Then c2 = Asc(getelement(a$, i + 2))
                        If c2 <> 94 Then 'not ^
                            'number...
                            i2 = InStr(a2$, ",")
                            If i2 And Asc(a2$, i2 + 1) <> 38 Then '&H/&O/&B values don't need the assumed negation
                                a2$ = "-" + Left$(a2$, i2) + "-" + Right$(a2$, Len(a2$) - i2)
                            Else
                                a2$ = "-" + a2$
                            End If
                            removeelements a$, i, i + 1, 0
                            insertelements a$, i - 1, a2$
                            n = n - 1
                            GoTo negdone

                        End If
                    End If


                    'not a number (or for exceptions)...
                    removeelements a$, i, i, 0
                    insertelements a$, i - 1, Chr$(241)

                End If 'isoperator
            End If '-
            negdone:
        Next
    End If 'fooindwel=1

    '----------------D. 'Quick' Add 'power of' with negation {}bracketing to bottom bracket level----------------
    pownegused = 0
    powneg:
    If InStr(a$, "^" + sp + Chr$(241)) Then 'quick check
        b = 0
        b1 = 0
        For i = 1 To n
            a2$ = getelement(a$, i)
            c = Asc(a2$)
            If c = 40 Then b = b + 1
            If c = 41 Then b = b - 1
            If b = 0 Then
                If b1 Then
                    If isoperator(a2$) Then
                        If a2$ <> "^" And a2$ <> Chr$(241) Then
                            insertelements a$, i - 1, "}"
                            insertelements a$, b1, "{"
                            n = n + 2
                            GoTo powneg
                            pownegused = 1
                        End If
                    End If
                End If
                If c = 94 Then '^
                    If getelement$(a$, i + 1) = Chr$(241) Then b1 = i: i = i + 1
                End If
            End If 'b=0
        Next i
        If b1 Then
            insertelements a$, b1, "{"
            a$ = a$ + sp + "}"
            n = n + 2
            pownegused = 1
            GoTo powneg
        End If

    End If 'quick check

    '----------------E. Find lowest & highest operator level in bottom bracket level----------------
    NOT_recheck:
    lco = 255
    hco = 0
    b = 0
    For i = 1 To n
        a2$ = getelement(a$, i)
        c = Asc(a2$)
        If c = 40 Or c = 123 Then b = b + 1
        If c = 41 Or c = 125 Then b = b - 1
        If b = 0 Then
            op = isoperator(a2$)
            If op Then
                If op < lco Then lco = op
                If op > hco Then hco = op
            End If
        End If
    Next

    '----------------F. Add operator {}bracketting----------------
    'apply bracketting only if required
    If hco <> 0 Then 'operators were used
        If lco <> hco Then
            'brackets needed

            If lco = 6 Then 'NOT exception
                'Step 1: Add brackets as follows ~~~ ( NOT ( ~~~ NOT ~~~ NOT ~~~ NOT ~~~ ))
                'Step 2: Recheck line from beginning
                If n = 1 Then Give_Error "Expected NOT ...": Exit Function
                b = 0
                For i = 1 To n
                    a2$ = getelement(a$, i)
                    c = Asc(a2$)
                    If c = 40 Or c = 123 Then b = b + 1
                    If c = 41 Or c = 125 Then b = b - 1
                    If b = 0 Then
                        If UCase$(a2$) = "NOT" Then
                            If i = n Then Give_Error "Expected NOT ...": Exit Function
                            If i = 1 Then a$ = "NOT" + sp + "{" + sp + getelements$(a$, 2, n) + sp + "}": n = n + 2: GoTo lco_bracketting_done
                            a$ = getelements$(a$, 1, i - 1) + sp + "{" + sp + "NOT" + sp + "{" + sp + getelements$(a$, i + 1, n) + sp + "}" + sp + "}"
                            n = n + 4
                            GoTo NOT_recheck
                        End If 'not
                    End If 'b=0
                Next
            End If 'NOT exception

            n2 = n
            b = 0
            a3$ = "{"
            n = 1
            For i = 1 To n2
                a2$ = getelement(a$, i)
                c = Asc(a2$)
                If c = 40 Or c = 123 Then b = b + 1
                If c = 41 Or c = 125 Then b = b - 1
                If b = 0 Then
                    op = isoperator(a2$)
                    If op = lco Then
                        If i = 1 Then
                            a3$ = a2$ + sp + "{"
                            n = 2
                        Else
                            If i = n2 Then Give_Error "Expected variable/value after '" + UCase$(a2$) + "'": Exit Function
                            a3$ = a3$ + sp + "}" + sp + a2$ + sp + "{"
                            n = n + 3
                        End If
                        GoTo fixop0
                    End If

                End If 'b=0
                a3$ = a3$ + sp + a2$
                n = n + 1
                fixop0:
            Next
            a3$ = a3$ + sp + "}"
            n = n + 1
            a$ = a3$

            lco_bracketting_done:

            '--------(F)G. Remove indwelling {}bracketting from power-negation--------
            If pownegused Then
                b = 0
                i = 0
                Do
                    i = i + 1
                    If i > n Then Exit Do
                    c = Asc(getelement(a$, i))
                    If c = 41 Or c = 125 Then b = b - 1
                    If (c = 123 Or c = 125) And b <> 0 Then
                        removeelements a$, i, i, 0
                        n = n - 1
                        i = i - 1
                    End If
                    If c = 40 Or c = 123 Then b = b + 1
                Loop
            End If 'pownegused

        End If 'lco <> hco
    End If 'hco <> 0

    '--------Bracketting of multiple NOT/negation unary operators--------
    If Left$(a$, 4) = Chr$(241) + sp + Chr$(241) + sp Then
        a$ = Chr$(241) + sp + "{" + sp + getelements$(a$, 2, n) + sp + "}": n = n + 2
    End If
    If UCase$(Left$(a$, 8)) = "NOT" + sp + "NOT" + sp Then
        a$ = "NOT" + sp + "{" + sp + getelements$(a$, 2, n) + sp + "}": n = n + 2
    End If

    '----------------H. Identification/conversion of elements within bottom bracket level----------------
    'actions performed:
    '   ->builds f$(tlayout)
    '   ->adds symbols to all numbers
    '   ->evaluates constants to numbers

    f$ = ""
    b = 0
    c = 0
    lastt = 0: lastti = 0
    For i = 1 To n
        f2$ = getelement(a$, i)
        lastc = c
        c = Asc(f2$)

        If c = 40 Or c = 123 Then
            If c <> 40 Or b <> 0 Then f2$ = "" 'skip temporary & indwelling  brackets
            b = b + 1
            GoTo classdone
        End If
        If c = 41 Or c = 125 Then

            b = b - 1

            'check for "("+sp+")" after literal-string, operator, number or nothing
            If b = 0 Then 'must be within the lowest level
                If c = 41 Then
                    If lastc = 40 Then
                        If lastti = i - 2 Or lastti = 0 Then
                            If lastt >= 0 And lastt <= 3 Then
                                Give_Error "Unexpected (": Exit Function
                            End If
                        End If
                    End If
                End If
            End If

            If c <> 41 Or b <> 0 Then f2$ = "" 'skip temporary & indwelling  brackets
            GoTo classdone
        End If

        If b = 0 Then

            'classifications/conversions:
            '1. quoted string ("....)
            '2. number
            '3. operator
            '4. constant
            '5. variable/array/udt/function (note: nothing can share the same name as a function except a label)


            'quoted string?
            If c = 34 Then '"
                lastt = 1: lastti = i

                'convert \\ to \
                'convert \??? to CHR$(&O???)
                x2 = 1
                x = InStr(x2, f2$, "\")
                Do While x
                    c2 = Asc(f2$, x + 1)
                    If c2 = 92 Then '\\
                        f2$ = Left$(f2$, x) + Right$(f2$, Len(f2$) - x - 1) 'remove second \
                        x2 = x + 1
                    Else
                        'octal triplet value
                        c3 = (Asc(f2$, x + 3) - 48) + (Asc(f2$, x + 2) - 48) * 8 + (Asc(f2$, x + 1) - 48) * 64
                        f2$ = Left$(f2$, x - 1) + Chr$(c3) + Right$(f2$, Len(f2$) - x - 3)
                        x2 = x + 1
                    End If
                    x = InStr(x2, f2$, "\")
                Loop
                'remove ',len' (if it exists)
                x = InStr(2, f2$, Chr$(34) + ","): If x Then f2$ = Left$(f2$, x)
                GoTo classdone
            End If

            'number?
            If (c >= 48 And c <= 57) Or c = 45 Then
                lastt = 2: lastti = i

                x = InStr(f2$, ",")
                If x Then
                    removeelements a$, i, i, 0: insertelements a$, i - 1, Left$(f2$, x - 1)
                    f2$ = Right$(f2$, Len(f2$) - x)
                End If

                If x = 0 Then
                    c2 = Asc(f2$, Len(f2$))
                    If c2 < 48 Or c2 > 57 Then
                        x = 1 'extension given
                    Else
                        x = InStr(f2$, "`")
                    End If
                End If

                'add appropriate integer symbol if none present
                If x = 0 Then
                    f3$ = f2$
                    s$ = ""
                    If c = 45 Then
                        s$ = "&&"
                        If (f3$ < "-2147483648" And Len(f3$) = 11) Or Len(f3$) < 11 Then s$ = "&"
                        If (f3$ <= "-32768" And Len(f3$) = 6) Or Len(f3$) < 6 Then s$ = "%"
                    Else
                        s$ = "~&&"
                        If (f3$ <= "9223372036854775807" And Len(f3$) = 19) Or Len(f3$) < 19 Then s$ = "&&"
                        If (f3$ <= "2147483647" And Len(f3$) = 10) Or Len(f3$) < 10 Then s$ = "&"
                        If (f3$ <= "32767" And Len(f3$) = 5) Or Len(f3$) < 5 Then s$ = "%"
                    End If
                    f3$ = f3$ + s$
                    removeelements a$, i, i, 0: insertelements a$, i - 1, f3$
                End If 'x=0

                GoTo classdone
            End If

            'operator?
            If isoperator(f2$) Then
                lastt = 3: lastti = i
                If Len(f2$) > 1 Then
                    If f2$ <> SCase2$(f2$) Then
                        f2$ = SCase2$(f2$)
                        removeelements a$, i, i, 0
                        insertelements a$, i - 1, f2$
                    End If
                End If
                'append negation
                If f2$ = Chr$(241) Then f$ = f$ + sp + "-": GoTo classdone_special
                GoTo classdone
            End If

            If alphanumeric(c) Then
                lastt = 4: lastti = i

                If i < n Then nextc = Asc(getelement(a$, i + 1)) Else nextc = 0

                ' a constant?
                If nextc <> 40 Then '<>"(" (not an array)
                    If lastc <> 46 Then '<>"." (not an element of a UDT)

                        e$ = UCase$(f2$)
                        es$ = removesymbol$(e$)
                        If Error_Happened Then Exit Function

                        hashfound = 0
                        hashname$ = e$
                        hashchkflags = HASHFLAG_CONSTANT
                        hashres = HashFindRev(hashname$, hashchkflags, hashresflags, hashresref)
                        Do While hashres
                            If constsubfunc(hashresref) = subfuncn Or constsubfunc(hashresref) = 0 Then
                                If constdefined(hashresref) Then
                                    hashfound = 1
                                    Exit Do
                                End If
                            End If
                            If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
                        Loop

                        If hashfound Then
                            i2 = hashresref

                            'is a STATIC variable overriding this constant?
                            staticvariable = 0
                            try = findid(e$ + es$)
                            If Error_Happened Then Exit Function
                            Do While try
                                If id.arraytype = 0 Then staticvariable = 1: Exit Do 'if it's not an array, it's probably a static variable
                                If try = 2 Then findanotherid = 1: try = findid(e$ + es$) Else try = 0
                                If Error_Happened Then Exit Function
                            Loop
                            'add symbol and try again
                            If staticvariable = 0 Then
                                If Len(es$) = 0 Then
                                    a = Asc(UCase$(e$)): If a = 95 Then a = 91
                                    a = a - 64 'so A=1, Z=27 and _=28
                                    es2$ = defineextaz(a)
                                    try = findid(e$ + es2$)
                                    If Error_Happened Then Exit Function
                                    Do While try
                                        If id.arraytype = 0 Then staticvariable = 1: Exit Do 'if it's not an array, it's probably a static variable
                                        If try = 2 Then findanotherid = 1: try = findid(e$ + es2$) Else try = 0
                                        If Error_Happened Then Exit Function
                                    Loop
                                End If
                            End If

                            If staticvariable = 0 Then

                                t = consttype(i2)
                                If t And ISSTRING Then
                                    If Len(es$) > 0 And es$ <> "$" Then Give_Error "Type mismatch": Exit Function
                                    e$ = conststring(i2)
                                Else 'not a string
                                    If Len(es$) Then et = typname2typ(es$) Else et = 0
                                    If Error_Happened Then Exit Function
                                    If et And ISSTRING Then Give_Error "Type mismatch": Exit Function
                                    'convert value to general formats
                                    If t And ISFLOAT Then
                                        v## = constfloat(i2)
                                        v&& = v##
                                        v~&& = v&&
                                    Else
                                        If t And ISUNSIGNED Then
                                            v~&& = constuinteger(i2)
                                            v&& = v~&&
                                            v## = v&&
                                        Else
                                            v&& = constinteger(i2)
                                            v## = v&&
                                            v~&& = v&&
                                        End If
                                    End If
                                    'apply type conversion if necessary
                                    If et Then t = et
                                    '(todo: range checking)
                                    'convert value into string for returning
                                    If t And ISFLOAT Then
                                        e$ = LTrim$(RTrim$(Str$(v##)))
                                    Else
                                        If t And ISUNSIGNED Then
                                            e$ = LTrim$(RTrim$(Str$(v~&&)))
                                        Else
                                            e$ = LTrim$(RTrim$(Str$(v&&)))
                                        End If
                                    End If

                                    'floats returned by str$ must be converted to qb64 standard format
                                    If t And ISFLOAT Then
                                        t2 = t And 511
                                        'find E,D or F
                                        s$ = ""
                                        If InStr(e$, "E") Then s$ = "E"
                                        If InStr(e$, "D") Then s$ = "D"
                                        If InStr(e$, "F") Then s$ = "F"
                                        If Len(s$) Then
                                            'E,D,F found
                                            x = InStr(e$, s$)
                                            'as incorrect type letter may have been returned by STR$, override it
                                            If t2 = 32 Then s$ = "E"
                                            If t2 = 64 Then s$ = "D"
                                            If t2 = 256 Then s$ = "F"
                                            Mid$(e$, x, 1) = s$
                                            If InStr(e$, ".") = 0 Then e$ = Left$(e$, x - 1) + ".0" + Right$(e$, Len(e$) - x + 1): x = x + 2
                                            If Left$(e$, 1) = "." Then e$ = "0" + e$
                                            If Left$(e$, 2) = "-." Then e$ = "-0" + Right$(e$, Len(e$) - 1)
                                            If InStr(e$, "+") = 0 And InStr(e$, "-") = 0 Then
                                                e$ = Left$(e$, x) + "+" + Right$(e$, Len(e$) - x)
                                            End If
                                        Else
                                            'E,D,F not found
                                            If InStr(e$, ".") = 0 Then e$ = e$ + ".0"
                                            If Left$(e$, 1) = "." Then e$ = "0" + e$
                                            If Left$(e$, 2) = "-." Then e$ = "-0" + Right$(e$, Len(e$) - 1)
                                            If t2 = 32 Then e$ = e$ + "E+0"
                                            If t2 = 64 Then e$ = e$ + "D+0"
                                            If t2 = 256 Then e$ = e$ + "F+0"
                                        End If
                                    Else
                                        s$ = typevalue2symbol$(t)
                                        If Error_Happened Then Exit Function
                                        e$ = e$ + s$ 'simply append symbol to integer
                                    End If

                                End If 'not a string

                                removeelements a$, i, i, 0
                                insertelements a$, i - 1, e$
                                'alter f2$ here to original casing
                                f2$ = constcname(i2) + es$
                                GoTo classdone

                            End If 'not static
                        End If 'hashfound
                    End If 'not udt element
                End If 'not array

                'variable/array/udt?
                u$ = f2$

                try_string$ = f2$
                try_string2$ = try_string$ 'pure version of try_string$

                For try_method = 1 To 4
                    try_string$ = try_string2$
                    If try_method = 2 Or try_method = 4 Then
                        dtyp$ = removesymbol(try_string$)
                        If Len(dtyp$) = 0 Then
                            If isoperator(try_string$) = 0 Then
                                If isvalidvariable(try_string$) Then
                                    If Left$(try_string$, 1) = "_" Then v = 27 Else v = Asc(UCase$(try_string$)) - 64
                                    try_string$ = try_string$ + defineextaz(v)
                                End If
                            End If
                        Else
                            try_string$ = try_string2$
                        End If
                    End If
                    try = findid(try_string$)
                    If Error_Happened Then Exit Function
                    Do While try
                        If (subfuncn = id.insubfuncn And try_method <= 2) Or try_method >= 3 Then

                            If nextc = 40 Or uboundlbound <> 0 Then '(

                                uboundlbound = 0

                                'function or array?
                                If id.arraytype <> 0 Or id.subfunc = 1 Then
                                    'note: even if it's an array of UDTs, the bracketted index will follow immediately

                                    'correct name
                                    f3$ = f2$
                                    s$ = removesymbol$(f3$)
                                    If Error_Happened Then Exit Function
                                    If id.internal_subfunc Then
                                        f2$ = SCase$(RTrim$(id.cn)) + s$
                                        If (UCase$(f2$) = "UBOUND" Or UCase$(f2$) = "LBOUND") Then
                                            uboundlbound = 2
                                        End If
                                    Else
                                        f2$ = RTrim$(id.cn) + s$
                                    End If
                                    removeelements a$, i, i, 0
                                    insertelements a$, i - 1, UCase$(f2$)
                                    f$ = f$ + f2$ + sp + "(" + sp

                                    'skip (but record with nothing inside them) brackets
                                    b2 = 1 'already in first bracket
                                    For i2 = i + 2 To n
                                        c2 = Asc(getelement(a$, i2))
                                        If c2 = 40 Then b2 = b2 + 1
                                        If c2 = 41 Then b2 = b2 - 1
                                        If b2 = 0 Then Exit For 'note: mismatched brackets check ensures this always succeeds
                                        f$ = f$ + sp
                                    Next

                                    'adjust i accordingly
                                    i = i2

                                    f$ = f$ + ")"

                                    'jump to UDT section if array is of UDT type (and elements are referenced)
                                    If id.arraytype And ISUDT Then
                                        If i < n Then nextc = Asc(getelement(a$, i + 1)) Else nextc = 0
                                        If nextc = 46 Then t = id.arraytype: GoTo fooudt
                                    End If

                                    f$ = f$ + sp
                                    GoTo classdone_special
                                End If 'id.arraytype
                            End If 'nextc "("

                            If nextc <> 40 Then 'not "(" (this avoids confusing simple variables with arrays)
                                If id.t <> 0 Or id.subfunc = 1 Then 'simple variable or function (without parameters)

                                    If id.t And ISUDT Then
                                        'note: it may or may not be followed by a period (eg. if whole udt is being referred to)
                                        'check if next item is a period

                                        'correct name
                                        If id.internal_subfunc Then
                                            f2$ = SCase$(RTrim$(id.cn)) + removesymbol$(f2$)
                                        Else
                                            f2$ = RTrim$(id.cn) + removesymbol$(f2$)
                                        End If
                                        If Error_Happened Then Exit Function
                                        removeelements a$, i, i, 0
                                        insertelements a$, i - 1, UCase$(f2$)
                                        f$ = f$ + f2$

                                        If nextc <> 46 Then f$ = f$ + sp: GoTo classdone_special 'no sub-elements referenced
                                        t = id.t

                                        fooudt:

                                        f$ = f$ + sp + "." + sp
                                        E = udtxnext(t And 511) 'next element to check
                                        i = i + 2

                                        'loop

                                        '"." encountered, i must be an element
                                        If i > n Then Give_Error "Expected .element": Exit Function
                                        f2$ = getelement(a$, i)
                                        s$ = removesymbol$(f2$)
                                        If Error_Happened Then Exit Function
                                        u$ = UCase$(f2$) + Space$(256 - Len(f2$)) 'fast scanning

                                        'is f$ the same as element e?
                                        fooudtnexte:
                                        If udtename(E) = u$ Then
                                            'match found
                                            'todo: check symbol(s$) matches element's type

                                            'correct name
                                            f2$ = RTrim$(udtecname(E)) + s$
                                            removeelements a$, i, i, 0
                                            insertelements a$, i - 1, UCase$(f2$)
                                            f$ = f$ + f2$

                                            If i = n Then f$ = f$ + sp: GoTo classdone_special
                                            nextc = Asc(getelement(a$, i + 1))
                                            If nextc <> 46 Then f$ = f$ + sp: GoTo classdone_special 'no sub-elements referenced
                                            'sub-element exists
                                            t = udtetype(E)
                                            If (t And ISUDT) = 0 Then Give_Error "Invalid . after element": Exit Function
                                            GoTo fooudt

                                        End If 'match found

                                        'no, so check next element
                                        E = udtenext(E)
                                        If E = 0 Then Give_Error "Element not defined": Exit Function
                                        GoTo fooudtnexte

                                    End If 'udt

                                    'non array/udt based variable
                                    f3$ = f2$
                                    s$ = removesymbol$(f3$)
                                    If Error_Happened Then Exit Function
                                    If id.internal_subfunc Then
                                        f2$ = SCase$(RTrim$(id.cn)) + s$
                                    Else
                                        f2$ = RTrim$(id.cn) + s$
                                    End If
                                    'change was is returned to uppercase
                                    removeelements a$, i, i, 0
                                    insertelements a$, i - 1, UCase$(f2$)
                                    GoTo CouldNotClassify
                                End If 'id.t

                            End If 'nextc not "("

                        End If
                        If try = 2 Then findanotherid = 1: try = findid(try_string$) Else try = 0
                        If Error_Happened Then Exit Function
                    Loop
                Next 'try method (1-4)
                CouldNotClassify:

                'alphanumeric, but item name is unknown... is it an internal type? if so, use capitals
                f3$ = UCase$(f2$)
                internaltype = 0
                If f3$ = "STRING" Then internaltype = 1
                If f3$ = "_UNSIGNED" Then internaltype = 1
                If f3$ = "_BIT" Then internaltype = 1
                If f3$ = "_BYTE" Then internaltype = 1
                If f3$ = "INTEGER" Then internaltype = 1
                If f3$ = "LONG" Then internaltype = 1
                If f3$ = "_INTEGER64" Then internaltype = 1
                If f3$ = "SINGLE" Then internaltype = 1
                If f3$ = "DOUBLE" Then internaltype = 1
                If f3$ = "_FLOAT" Then internaltype = 1
                If f3$ = "_OFFSET" Then internaltype = 1
                If internaltype = 1 Then
                    f2$ = SCase2$(f3$)
                    removeelements a$, i, i, 0
                    insertelements a$, i - 1, f3$
                    GoTo classdone
                End If

                GoTo classdone
            End If 'alphanumeric

            classdone:
            f$ = f$ + f2$
        End If 'b=0
        f$ = f$ + sp
        classdone_special:
    Next

    If Len(f$) Then f$ = Left$(f$, Len(f$) - 1) 'remove trailing 'sp'

    '----------------I. Pass (){}bracketed items (if any) to fixoperationorder & build return----------------
    'note: items seperated by commas are done seperately

    ff$ = ""
    b = 0
    b2 = 0
    p1 = 0 'where level 1 began
    aa$ = ""
    n = numelements(a$)
    For i = 1 To n
        openbracket = 0

        a2$ = getelement(a$, i)
        c = Asc(a2$)

        If c = 40 Or c = 123 Then '({
            b = b + 1
            If b = 1 Then
                p1 = i + 1
                aa$ = aa$ + "(" + sp
            End If
            openbracket = 1
            GoTo foopass
        End If '({

        If c = 44 Then ',
            If b = 1 Then
                GoTo foopassit
            End If
        End If

        If c = 41 Or c = 125 Then ')}
            If uboundlbound Then uboundlbound = uboundlbound - 1
            b = b - 1

            If b = 0 Then
                foopassit:
                If p1 <> i Then
                    foo$ = fixoperationorder(getelements(a$, p1, i - 1))
                    If Error_Happened Then Exit Function
                    If Len(foo$) Then
                        aa$ = aa$ + foo$ + sp
                        If c = 125 Then ff$ = ff$ + tlayout$ + sp Else ff$ = ff$ + tlayout$ + sp2 'spacing between ) } , varies
                    End If
                End If
                If c = 44 Then aa$ = aa$ + "," + sp: ff$ = ff$ + "," + sp Else aa$ = aa$ + ")" + sp
                p1 = i + 1
            End If

            GoTo foopass
        End If ')}

        If b = 0 Then aa$ = aa$ + a2$ + sp

        foopass:

        f2$ = getelementspecial(f$, i)
        If Error_Happened Then Exit Function
        If Len(f2$) Then

            'use sp2 to join items connected by a period
            If c = 46 Then '"."
                If i > 1 And i < n Then 'stupidity check
                    If Len(ff$) Then Mid$(ff$, Len(ff$), 1) = sp2 'convert last spacer to a sp2
                    ff$ = ff$ + "." + sp2
                    GoTo fooloopnxt
                End If
            End If

            'spacing just before (
            If openbracket Then

                'convert last spacer?
                If i <> 1 Then
                    If isoperator(getelement$(a$, i - 1)) = 0 Then
                        Mid$(ff$, Len(ff$), 1) = sp2
                    End If
                End If
                ff$ = ff$ + f2$ + sp2
            Else 'not openbracket
                ff$ = ff$ + f2$ + sp
            End If

        End If 'len(f2$)

        fooloopnxt:

    Next

    If Len(aa$) Then aa$ = Left$(aa$, Len(aa$) - 1)
    If Len(ff$) Then ff$ = Left$(ff$, Len(ff$) - 1)

    tlayout$ = ff$
    fixoperationorder$ = aa$

    fooindwel = fooindwel - 1
End Function

Function getelementspecial$ (savea$, elenum)
    a$ = savea$
    If a$ = "" Then Exit Function 'no elements!

    n = 1
    p = 1
    getelementspecialnext:
    i = InStr(p, a$, sp)

    'avoid sp inside "..."
    i2 = InStr(p, a$, Chr$(34))
    If i2 < i And i2 <> 0 Then
        i3 = InStr(i2 + 1, a$, Chr$(34)): If i3 = 0 Then Give_Error "Expected " + Chr$(34): Exit Function
        i = InStr(i3, a$, sp)
    End If

    If elenum = n Then
        If i Then
            getelementspecial$ = Mid$(a$, p, i - p)
        Else
            getelementspecial$ = Right$(a$, Len(a$) - p + 1)
        End If
        Exit Function
    End If

    If i = 0 Then Exit Function 'no more elements!
    n = n + 1
    p = i + 1
    GoTo getelementspecialnext
End Function

Function getelement$ (a$, elenum)
    If a$ = "" Then Exit Function 'no elements!

    n = 1
    p = 1
    getelementnext:
    i = InStr(p, a$, sp)

    If elenum = n Then
        If i Then
            getelement$ = Mid$(a$, p, i - p)
        Else
            getelement$ = Right$(a$, Len(a$) - p + 1)
        End If
        Exit Function
    End If

    If i = 0 Then Exit Function 'no more elements!
    n = n + 1
    p = i + 1
    GoTo getelementnext
End Function

Function getelements$ (a$, i1, i2)
    If i2 < i1 Then getelements$ = "": Exit Function
    n = 1
    p = 1
    getelementsnext:
    i = InStr(p, a$, sp)
    If n = i1 Then
        i1pos = p
    End If
    If n = i2 Then
        If i Then
            getelements$ = Mid$(a$, i1pos, i - i1pos)
        Else
            getelements$ = Right$(a$, Len(a$) - i1pos + 1)
        End If
        Exit Function
    End If
    n = n + 1
    p = i + 1
    GoTo getelementsnext
End Function

Sub getid (i As Long)
    If i = -1 Then Give_Error "-1 passed to getid!": Exit Sub

    id = ids(i)

    currentid = i
End Sub

Sub insertelements (a$, i, elements$)
    If i = 0 Then
        If a$ = "" Then
            a$ = elements$
            Exit Sub
        End If
        a$ = elements$ + sp + a$
        Exit Sub
    End If

    a2$ = ""
    n = numelements(a$)

    For i2 = 1 To n
        If i2 > 1 Then a2$ = a2$ + sp
        a2$ = a2$ + getelement$(a$, i2)
        If i = i2 Then a2$ = a2$ + sp + elements$
    Next

    a$ = a2$
End Sub

Function isoperator (a2$)
    a$ = UCase$(a2$)
    l = 0
    l = l + 1: If a$ = "IMP" Then GoTo opfound
    l = l + 1: If a$ = "EQV" Then GoTo opfound
    l = l + 1: If a$ = "XOR" Then GoTo opfound
    l = l + 1: If a$ = "OR" Then GoTo opfound
    l = l + 1: If a$ = "AND" Then GoTo opfound
    l = l + 1: If a$ = "NOT" Then GoTo opfound
    l = l + 1
    If a$ = "=" Then GoTo opfound
    If a$ = ">" Then GoTo opfound
    If a$ = "<" Then GoTo opfound
    If a$ = "<>" Then GoTo opfound
    If a$ = "<=" Then GoTo opfound
    If a$ = ">=" Then GoTo opfound
    l = l + 1
    If a$ = "+" Then GoTo opfound
    If a$ = "-" Then GoTo opfound '!CAREFUL! could be negation
    l = l + 1: If a$ = "MOD" Then GoTo opfound
    l = l + 1: If a$ = "\" Then GoTo opfound
    l = l + 1
    If a$ = "*" Then GoTo opfound
    If a$ = "/" Then GoTo opfound
    'NEGATION LEVEL (MUST BE SET AFTER CALLING ISOPERATOR BY CONTEXT)
    l = l + 1: If a$ = Chr$(241) Then GoTo opfound
    l = l + 1: If a$ = "^" Then GoTo opfound
    Exit Function
    opfound:
    isoperator = l
End Function

Function isuinteger (i$)
    If Len(i$) = 0 Then Exit Function
    If Asc(i$, 1) = 48 And Len(i$) > 1 Then Exit Function
    For c = 1 To Len(i$)
        v = Asc(i$, c)
        If v < 48 Or v > 57 Then Exit Function
    Next
    isuinteger = -1
End Function

Function isvalidvariable (a$)
    For i = 1 To Len(a$)
        c = Asc(a$, i)
        t = 0
        If c >= 48 And c <= 57 Then t = 1 'numeric
        If c >= 65 And c <= 90 Then t = 2 'uppercase
        If c >= 97 And c <= 122 Then t = 2 'lowercase
        If c = 95 Then t = 2 '_ underscore
        If t = 2 Or (t = 1 And i > 1) Then
            'valid (continue)
        Else
            If i = 1 Then isvalidvariable = 0: Exit Function
            Exit For
        End If
    Next

    isvalidvariable = 1
    If i > n Then Exit Function 'i is always greater than n because n is undefined here. Why didn't I remove this line and the ones below it, which will never run? Cause I'm a coward. F.h.
    e$ = Right$(a$, Len(a$) - i - 1)
    If e$ = "%%" Or e$ = "~%%" Then Exit Function
    If e$ = "%" Or e$ = "~%" Then Exit Function
    If e$ = "&" Or e$ = "~&" Then Exit Function
    If e$ = "&&" Or e$ = "~&&" Then Exit Function
    If e$ = "!" Or e$ = "#" Or e$ = "##" Then Exit Function
    If e$ = "$" Then Exit Function
    If e$ = "`" Then Exit Function
    If Left$(e$, 1) <> "$" And Left$(e$, 1) <> "`" Then isvalidvariable = 0: Exit Function
    e$ = Right$(e$, Len(e$) - 1)
    If isuinteger(e$) Then isvalidvariable = 1: Exit Function
    isvalidvariable = 0
End Function

Function lineformat$ (a$)
    a2$ = ""
    linecontinuation = 0

    continueline:

    a$ = a$ + "  " 'add 2 extra spaces to make reading next char easier

    ca$ = a$
    a$ = UCase$(a$)

    n = Len(a$)
    i = 1
    lineformatnext:
    If i >= n Then GoTo lineformatdone

    c = Asc(a$, i)
    c$ = Chr$(c) '***remove later***

    '----------------quoted string----------------
    If c = 34 Then '"
        a2$ = a2$ + sp + Chr$(34)
        p1 = i + 1
        For i2 = i + 1 To n - 2
            c2 = Asc(a$, i2)

            If c2 = 34 Then
                a2$ = a2$ + Mid$(ca$, p1, i2 - p1 + 1) + "," + str2$(i2 - (i + 1))
                i = i2 + 1
                Exit For
            End If

            If c2 = 92 Then '\
                a2$ = a2$ + Mid$(ca$, p1, i2 - p1) + "\\"
                p1 = i2 + 1
            End If

            If c2 < 32 Or c2 > 126 Then
                o$ = Oct$(c2)
                If Len(o$) < 3 Then
                    o$ = "0" + o$
                    If Len(o$) < 3 Then o$ = "0" + o$
                End If
                a2$ = a2$ + Mid$(ca$, p1, i2 - p1) + "\" + o$
                p1 = i2 + 1
            End If

        Next

        If i2 = n - 1 Then 'no closing "
            a2$ = a2$ + Mid$(ca$, p1, (n - 2) - p1 + 1) + Chr$(34) + "," + str2$((n - 2) - (i + 1) + 1)
            i = n - 1
        End If

        GoTo lineformatnext

    End If

    '----------------number----------------
    firsti = i
    If c = 46 Then
        c2$ = Mid$(a$, i + 1, 1): c2 = Asc(c2$)
        If (c2 >= 48 And c2 <= 57) Then GoTo lfnumber
    End If
    If (c >= 48 And c <= 57) Then '0-9
        lfnumber:

        'handle 'IF a=1 THEN a=2 ELSE 100' by assuming numeric after ELSE to be a
        If Right$(a2$, 5) = sp + "ELSE" Then
            a2$ = a2$ + sp + "GOTO"
        End If

        'Number will be converted to the following format:
        ' 999999  .        99999  E        +         999
        '[whole$][dp(0/1)][frac$][ed(1/2)][pm(1/-1)][ex$]
        ' 0                1               2         3    <-mode

        mode = 0
        whole$ = ""
        dp = 0
        frac$ = ""
        ed = 0 'E=1, D=2, F=3
        pm = 1
        ex$ = ""

        lfreadnumber:
        valid = 0

        If c = 46 Then
            If mode = 0 Then valid = 1: dp = 1: mode = 1
        End If

        If c >= 48 And c <= 57 Then '0-9
            valid = 1
            If mode = 0 Then whole$ = whole$ + c$
            If mode = 1 Then frac$ = frac$ + c$
            If mode = 2 Then mode = 3
            If mode = 3 Then ex$ = ex$ + c$
        End If

        If c = 69 Or c = 68 Or c = 70 Then 'E,D,F
            If mode < 2 Then
                valid = 1
                If c = 69 Then ed = 1
                If c = 68 Then ed = 2
                If c = 70 Then ed = 3
                mode = 2
            End If
        End If

        If c = 43 Or c = 45 Then '+,-
            If mode = 2 Then
                valid = 1
                If c = 45 Then pm = -1
                mode = 3
            End If
        End If

        If valid Then
            If i <= n Then i = i + 1: c$ = Mid$(a$, i, 1): c = Asc(c$): GoTo lfreadnumber
        End If

        'cull leading 0s off whole$
        Do While Left$(whole$, 1) = "0": whole$ = Right$(whole$, Len(whole$) - 1): Loop
        'cull trailing 0s off frac$
        Do While Right$(frac$, 1) = "0": frac$ = Left$(frac$, Len(frac$) - 1): Loop
        'cull leading 0s off ex$
        Do While Left$(ex$, 1) = "0": ex$ = Right$(ex$, Len(ex$) - 1): Loop

        If dp <> 0 Or ed <> 0 Then float = 1 Else float = 0

        extused = 1

        If ed Then e$ = "": GoTo lffoundext 'no extensions valid after E/D/F specified

        '3-character extensions
        If i <= n - 2 Then
            e$ = Mid$(a$, i, 3)
            If e$ = "~%%" And float = 0 Then i = i + 3: GoTo lffoundext
            If e$ = "~&&" And float = 0 Then i = i + 3: GoTo lffoundext
            If e$ = "~%&" And float = 0 Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
        End If
        '2-character extensions
        If i <= n - 1 Then
            e$ = Mid$(a$, i, 2)
            If e$ = "%%" And float = 0 Then i = i + 2: GoTo lffoundext
            If e$ = "~%" And float = 0 Then i = i + 2: GoTo lffoundext
            If e$ = "&&" And float = 0 Then i = i + 2: GoTo lffoundext
            If e$ = "~&" And float = 0 Then i = i + 2: GoTo lffoundext
            If e$ = "%&" And float = 0 Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
            If e$ = "##" Then
                i = i + 2
                ed = 3
                e$ = ""
                GoTo lffoundext
            End If
            If e$ = "~`" Then
                i = i + 2
                GoTo lffoundbitext
            End If
        End If
        '1-character extensions
        If i <= n Then
            e$ = Mid$(a$, i, 1)
            If e$ = "%" And float = 0 Then i = i + 1: GoTo lffoundext
            If e$ = "&" And float = 0 Then i = i + 1: GoTo lffoundext
            If e$ = "!" Then
                i = i + 1
                ed = 1
                e$ = ""
                GoTo lffoundext
            End If
            If e$ = "#" Then
                i = i + 1
                ed = 2
                e$ = ""
                GoTo lffoundext
            End If
            If e$ = "`" Then
                i = i + 1
                lffoundbitext:
                bitn$ = ""
                Do While i <= n
                    c2 = Asc(Mid$(a$, i, 1))
                    If c2 >= 48 And c2 <= 57 Then
                        bitn$ = bitn$ + Chr$(c2)
                        i = i + 1
                    Else
                        Exit Do
                    End If
                Loop
                If bitn$ = "" Then bitn$ = "1"
                'cull leading 0s off bitn$
                Do While Left$(bitn$, 1) = "0": bitn$ = Right$(bitn$, Len(bitn$) - 1): Loop
                e$ = e$ + bitn$
                GoTo lffoundext
            End If
        End If

        If float Then 'floating point types CAN be assumed
            'calculate first significant digit offset & number of significant digits
            If whole$ <> "" Then
                offset = Len(whole$) - 1
                sigdigits = Len(whole$) + Len(frac$)
            Else
                If frac$ <> "" Then
                    offset = -1
                    sigdigits = Len(frac$)
                    For i2 = 1 To Len(frac$)
                        If Mid$(frac$, i2, 1) <> "0" Then Exit For
                        offset = offset - 1
                        sigdigits = sigdigits - 1
                    Next
                Else
                    'number is 0
                    offset = 0
                    sigdigits = 0
                End If
            End If
            sigdig$ = Right$(whole$ + frac$, sigdigits)
            'SINGLE?
            If sigdigits <= 7 Then 'QBASIC interprets anything with more than 7 sig. digits as a DOUBLE
                If offset <= 38 And offset >= -38 Then 'anything outside this range cannot be represented as a SINGLE
                    If offset = 38 Then
                        If sigdig$ > "3402823" Then GoTo lfxsingle
                    End If
                    If offset = -38 Then
                        If sigdig$ < "1175494" Then GoTo lfxsingle
                    End If
                    ed = 1
                    e$ = ""
                    GoTo lffoundext
                End If
            End If
            lfxsingle:
            'DOUBLE?
            If sigdigits <= 16 Then 'QB64 handles DOUBLES with 16-digit precision
                If offset <= 308 And offset >= -308 Then 'anything outside this range cannot be represented as a DOUBLE
                    If offset = 308 Then
                        If sigdig$ > "1797693134862315" Then GoTo lfxdouble
                    End If
                    If offset = -308 Then
                        If sigdig$ < "2225073858507201" Then GoTo lfxdouble
                    End If
                    ed = 2
                    e$ = ""
                    GoTo lffoundext
                End If
            End If
            lfxdouble:
            'assume _FLOAT
            ed = 3
            e$ = "": GoTo lffoundext
        End If

        extused = 0
        e$ = ""
        lffoundext:

        'make sure a leading numberic character exists
        If whole$ = "" Then whole$ = "0"
        'if a float, ensure frac$<>"" and dp=1
        If float Then
            dp = 1
            If frac$ = "" Then frac$ = "0"
        End If
        'if ed is specified, make sure ex$ exists
        If ed <> 0 And ex$ = "" Then ex$ = "0"

        a2$ = a2$ + sp
        a2$ = a2$ + whole$
        If dp Then a2$ = a2$ + "." + frac$
        If ed Then
            If ed = 1 Then a2$ = a2$ + "E"
            If ed = 2 Then a2$ = a2$ + "D"
            If ed = 3 Then a2$ = a2$ + "F"
            If pm = -1 And ex$ <> "0" Then a2$ = a2$ + "-" Else a2$ = a2$ + "+"
            a2$ = a2$ + ex$
        End If
        a2$ = a2$ + e$

        If extused Then a2$ = a2$ + "," + Mid$(a$, firsti, i - firsti)

        GoTo lineformatnext
    End If

    '----------------(number)&H...----------------
    'note: the final value, not the number of hex characters, sets the default type
    If c = 38 Then '&
        If Mid$(a$, i + 1, 1) = "H" Then
            i = i + 2
            hx$ = ""
            lfreadhex:
            If i <= n Then
                c$ = Mid$(a$, i, 1): c = Asc(c$)
                If (c >= 48 And c <= 57) Or (c >= 65 And c <= 70) Then hx$ = hx$ + c$: i = i + 1: GoTo lfreadhex
            End If
            fullhx$ = "&H" + hx$

            'cull leading 0s off hx$
            Do While Left$(hx$, 1) = "0": hx$ = Right$(hx$, Len(hx$) - 1): Loop
            If hx$ = "" Then hx$ = "0"

            bitn$ = ""
            '3-character extensions
            If i <= n - 2 Then
                e$ = Mid$(a$, i, 3)
                If e$ = "~%%" Then i = i + 3: GoTo lfhxext
                If e$ = "~&&" Then i = i + 3: GoTo lfhxext
                If e$ = "~%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
            End If
            '2-character extensions
            If i <= n - 1 Then
                e$ = Mid$(a$, i, 2)
                If e$ = "%%" Then i = i + 2: GoTo lfhxext
                If e$ = "~%" Then i = i + 2: GoTo lfhxext
                If e$ = "&&" Then i = i + 2: GoTo lfhxext
                If e$ = "%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
                If e$ = "~&" Then i = i + 2: GoTo lfhxext
                If e$ = "~`" Then
                    i = i + 2
                    GoTo lfhxbitext
                End If
            End If
            '1-character extensions
            If i <= n Then
                e$ = Mid$(a$, i, 1)
                If e$ = "%" Then i = i + 1: GoTo lfhxext
                If e$ = "&" Then i = i + 1: GoTo lfhxext
                If e$ = "`" Then
                    i = i + 1
                    lfhxbitext:
                    Do While i <= n
                        c2 = Asc(Mid$(a$, i, 1))
                        If c2 >= 48 And c2 <= 57 Then
                            bitn$ = bitn$ + Chr$(c2)
                            i = i + 1
                        Else
                            Exit Do
                        End If
                    Loop
                    If bitn$ = "" Then bitn$ = "1"
                    'cull leading 0s off bitn$
                    Do While Left$(bitn$, 1) = "0": bitn$ = Right$(bitn$, Len(bitn$) - 1): Loop
                    GoTo lfhxext
                End If
            End If
            'if no valid extension context was given, assume one
            'note: leading 0s have been culled, so LEN(hx$) reflects its values size
            e$ = "&&"
            If Len(hx$) <= 8 Then e$ = "&" 'as in QBASIC, signed values must be used
            If Len(hx$) <= 4 Then e$ = "%" 'as in QBASIC, signed values must be used
            GoTo lfhxext2
            lfhxext:
            fullhx$ = fullhx$ + e$ + bitn$
            lfhxext2:

            'build 8-byte unsigned integer rep. of hx$
            If Len(hx$) > 16 Then Give_Error "Overflow": Exit Function
            v~&& = 0
            For i2 = 1 To Len(hx$)
                v2 = Asc(Mid$(hx$, i2, 1))
                If v2 <= 57 Then v2 = v2 - 48 Else v2 = v2 - 65 + 10
                v~&& = v~&& * 16 + v2
            Next

            finishhexoctbin:
            num$ = str2u64$(v~&&) 'correct for unsigned values (overflow of unsigned can be checked later)
            If Left$(e$, 1) <> "~" Then 'note: range checking will be performed later in fixop.order
                'signed

                If e$ = "%%" Then
                    If v~&& > 127 Then
                        If v~&& > 255 Then Give_Error "Overflow": Exit Function
                        v~&& = ((Not v~&&) And 255) + 1
                        num$ = "-" + sp + str2u64$(v~&&)
                    End If
                End If

                If e$ = "%" Then
                    If v~&& > 32767 Then
                        If v~&& > 65535 Then Give_Error "Overflow": Exit Function
                        v~&& = ((Not v~&&) And 65535) + 1
                        num$ = "-" + sp + str2u64$(v~&&)
                    End If
                End If

                If e$ = "&" Then
                    If v~&& > 2147483647 Then
                        If v~&& > 4294967295 Then Give_Error "Overflow": Exit Function
                        v~&& = ((Not v~&&) And 4294967295) + 1
                        num$ = "-" + sp + str2u64$(v~&&)
                    End If
                End If

                If e$ = "&&" Then
                    If v~&& > 9223372036854775807 Then
                        'note: no error checking necessary
                        v~&& = (Not v~&&) + 1
                        num$ = "-" + sp + str2u64$(v~&&)
                    End If
                End If

                If e$ = "`" Then
                    vbitn = Val(bitn$)
                    h~&& = 1: For i2 = 1 To vbitn - 1: h~&& = h~&& * 2: Next: h~&& = h~&& - 1 'build h~&&
                    If v~&& > h~&& Then
                        h~&& = 1: For i2 = 1 To vbitn: h~&& = h~&& * 2: Next: h~&& = h~&& - 1 'build h~&&
                        If v~&& > h~&& Then Give_Error "Overflow": Exit Function
                        v~&& = ((Not v~&&) And h~&&) + 1
                        num$ = "-" + sp + str2u64$(v~&&)
                    End If
                End If

            End If '<>"~"

            a2$ = a2$ + sp + num$ + e$ + bitn$ + "," + fullhx$

            GoTo lineformatnext
        End If
    End If

    '----------------(number)&O...----------------
    'note: the final value, not the number of oct characters, sets the default type
    If c = 38 Then '&
        If Mid$(a$, i + 1, 1) = "O" Then
            i = i + 2
            'note: to avoid mistakes, hx$ is used instead of 'ot$'
            hx$ = ""
            lfreadoct:
            If i <= n Then
                c$ = Mid$(a$, i, 1): c = Asc(c$)
                If c >= 48 And c <= 55 Then hx$ = hx$ + c$: i = i + 1: GoTo lfreadoct
            End If
            fullhx$ = "&O" + hx$

            'cull leading 0s off hx$
            Do While Left$(hx$, 1) = "0": hx$ = Right$(hx$, Len(hx$) - 1): Loop
            If hx$ = "" Then hx$ = "0"

            bitn$ = ""
            '3-character extensions
            If i <= n - 2 Then
                e$ = Mid$(a$, i, 3)
                If e$ = "~%%" Then i = i + 3: GoTo lfotext
                If e$ = "~&&" Then i = i + 3: GoTo lfotext
                If e$ = "~%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
            End If
            '2-character extensions
            If i <= n - 1 Then
                e$ = Mid$(a$, i, 2)
                If e$ = "%%" Then i = i + 2: GoTo lfotext
                If e$ = "~%" Then i = i + 2: GoTo lfotext
                If e$ = "&&" Then i = i + 2: GoTo lfotext
                If e$ = "%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
                If e$ = "~&" Then i = i + 2: GoTo lfotext
                If e$ = "~`" Then
                    i = i + 2
                    GoTo lfotbitext
                End If
            End If
            '1-character extensions
            If i <= n Then
                e$ = Mid$(a$, i, 1)
                If e$ = "%" Then i = i + 1: GoTo lfotext
                If e$ = "&" Then i = i + 1: GoTo lfotext
                If e$ = "`" Then
                    i = i + 1
                    lfotbitext:
                    bitn$ = ""
                    Do While i <= n
                        c2 = Asc(Mid$(a$, i, 1))
                        If c2 >= 48 And c2 <= 57 Then
                            bitn$ = bitn$ + Chr$(c2)
                            i = i + 1
                        Else
                            Exit Do
                        End If
                    Loop
                    If bitn$ = "" Then bitn$ = "1"
                    'cull leading 0s off bitn$
                    Do While Left$(bitn$, 1) = "0": bitn$ = Right$(bitn$, Len(bitn$) - 1): Loop
                    GoTo lfotext
                End If
            End If
            'if no valid extension context was given, assume one
            'note: leading 0s have been culled, so LEN(hx$) reflects its values size
            e$ = "&&"
            '37777777777
            If Len(hx$) <= 11 Then
                If Len(hx$) < 11 Or Asc(Left$(hx$, 1)) <= 51 Then e$ = "&"
            End If
            '177777
            If Len(hx$) <= 6 Then
                If Len(hx$) < 6 Or Left$(hx$, 1) = "1" Then e$ = "%"
            End If

            GoTo lfotext2
            lfotext:
            fullhx$ = fullhx$ + e$ + bitn$
            lfotext2:

            'build 8-byte unsigned integer rep. of hx$
            '1777777777777777777777 (22 digits)
            If Len(hx$) > 22 Then Give_Error "Overflow": Exit Function
            If Len(hx$) = 22 Then
                If Left$(hx$, 1) <> "1" Then Give_Error "Overflow": Exit Function
            End If
            '********change v& to v~&&********
            v~&& = 0
            For i2 = 1 To Len(hx$)
                v2 = Asc(Mid$(hx$, i2, 1))
                v2 = v2 - 48
                v~&& = v~&& * 8 + v2
            Next

            GoTo finishhexoctbin
        End If
    End If

    '----------------(number)&B...----------------
    'note: the final value, not the number of bin characters, sets the default type
    If c = 38 Then '&
        If Mid$(a$, i + 1, 1) = "B" Then
            i = i + 2
            'note: to avoid mistakes, hx$ is used instead of 'bi$'
            hx$ = ""
            lfreadbin:
            If i <= n Then
                c$ = Mid$(a$, i, 1): c = Asc(c$)
                If c >= 48 And c <= 49 Then hx$ = hx$ + c$: i = i + 1: GoTo lfreadbin
            End If
            fullhx$ = "&B" + hx$

            'cull leading 0s off hx$
            Do While Left$(hx$, 1) = "0": hx$ = Right$(hx$, Len(hx$) - 1): Loop
            If hx$ = "" Then hx$ = "0"

            bitn$ = ""
            '3-character extensions
            If i <= n - 2 Then
                e$ = Mid$(a$, i, 3)
                If e$ = "~%%" Then i = i + 3: GoTo lfbiext
                If e$ = "~&&" Then i = i + 3: GoTo lfbiext
                If e$ = "~%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
            End If
            '2-character extensions
            If i <= n - 1 Then
                e$ = Mid$(a$, i, 2)
                If e$ = "%%" Then i = i + 2: GoTo lfbiext
                If e$ = "~%" Then i = i + 2: GoTo lfbiext
                If e$ = "&&" Then i = i + 2: GoTo lfbiext
                If e$ = "%&" Then Give_Error "Cannot use _OFFSET symbols after numbers": Exit Function
                If e$ = "~&" Then i = i + 2: GoTo lfbiext
                If e$ = "~`" Then
                    i = i + 2
                    GoTo lfbibitext
                End If
            End If


            '1-character extensions
            If i <= n Then
                e$ = Mid$(a$, i, 1)
                If e$ = "%" Then i = i + 1: GoTo lfbiext
                If e$ = "&" Then i = i + 1: GoTo lfbiext
                If e$ = "`" Then
                    i = i + 1
                    lfbibitext:
                    bitn$ = ""
                    Do While i <= n
                        c2 = Asc(Mid$(a$, i, 1))
                        If c2 >= 48 And c2 <= 57 Then
                            bitn$ = bitn$ + Chr$(c2)
                            i = i + 1
                        Else
                            Exit Do
                        End If
                    Loop
                    If bitn$ = "" Then bitn$ = "1"
                    'cull leading 0s off bitn$
                    Do While Left$(bitn$, 1) = "0": bitn$ = Right$(bitn$, Len(bitn$) - 1): Loop
                    GoTo lfbiext
                End If
            End If
            'if no valid extension context was given, assume one
            'note: leading 0s have been culled, so LEN(hx$) reflects its values size
            e$ = "&&"
            If Len(hx$) <= 32 Then e$ = "&"
            If Len(hx$) <= 16 Then e$ = "%"

            GoTo lfbiext2
            lfbiext:
            fullhx$ = fullhx$ + e$ + bitn$
            lfbiext2:

            'build 8-byte unsigned integer rep. of hx$
            If Len(hx$) > 64 Then Give_Error "Overflow": Exit Function

            v~&& = 0
            For i2 = 1 To Len(hx$)
                v2 = Asc(Mid$(hx$, i2, 1))
                v2 = v2 - 48
                v~&& = v~&& * 2 + v2
            Next

            GoTo finishhexoctbin
        End If
    End If

    '----------------(number)&H??? error----------------
    If c = 38 Then Give_Error "Expected &H... or &O...": Exit Function

    '----------------variable/name----------------
    '*trailing _ is treated as a seperate line extension*
    If (c >= 65 And c <= 90) Or c = 95 Then 'A-Z(a-z) or _
        If c = 95 Then p2 = 0 Else p2 = i
        For i2 = i + 1 To n
            c2 = Asc(a$, i2)
            If Not alphanumeric(c2) Then Exit For
            If c2 <> 95 Then p2 = i2
        Next
        If p2 Then 'not just underscores!
            'char is from i to p2
            n2 = p2 - i + 1
            a3$ = Mid$(a$, i, n2)

            '----(variable/name)rem----
            If n2 = 3 Then
                If a3$ = "REM" Then
                    i = i + n2
                    If i < n Then
                        c = Asc(a$, i)
                        If c = 46 Then a2$ = a2$ + sp + Mid$(ca$, i - n2, n2): GoTo extcheck 'rem.Variable is a valid variable name in QB45
                    End If

                    'note: In QBASIC 'IF cond THEN REM comment' counts as a single line IF statement, however use of ' instead of REM does not
                    If UCase$(Right$(a2$, 5)) = sp + "THEN" Then a2$ = a2$ + sp + "'" 'add nop
                    layoutcomment = SCase$("Rem")
                    GoTo comment
                End If
            End If

            '----(variable/name)data----
            If n2 = 4 Then
                If a3$ = "DATA" Then
                    x$ = ""
                    i = i + n2
                    If i < n Then
                        c = Asc(a$, i)
                        If c = 46 Then a2$ = a2$ + sp + Mid$(ca$, i - n2, n2): GoTo extcheck 'data.Variable is a valid variable name in QB45
                    End If

                    scan = 0
                    speechmarks = 0
                    commanext = 0
                    finaldata = 0
                    e$ = ""
                    p1 = 0
                    p2 = 0
                    nextdatachr:
                    If i < n Then
                        c = Asc(a$, i)
                        If c = 9 Or c = 32 Then
                            If scan = 0 Then GoTo skipwhitespace
                        End If

                        If c = 58 Then '":"
                            If speechmarks = 0 Then finaldata = 1: GoTo adddata
                        End If

                        If c = 44 Then '","
                            If speechmarks = 0 Then
                                adddata:
                                If prepass = 0 Then
                                    If p1 Then
                                        'FOR i2 = p1 TO p2
                                        '    DATA_add ASC(ca$, i2)
                                        'NEXT
                                        x$ = x$ + Mid$(ca$, p1, p2 - p1 + 1)
                                    End If
                                    'assume closing "
                                    If speechmarks Then
                                        'DATA_add 34
                                        x$ = x$ + Chr$(34)
                                    End If
                                    'append comma
                                    'DATA_add 44
                                    x$ = x$ + Chr$(44)
                                End If
                                If finaldata = 1 Then GoTo finisheddata
                                e$ = ""
                                p1 = 0
                                p2 = 0
                                speechmarks = 0
                                scan = 0
                                commanext = 0
                                i = i + 1
                                GoTo nextdatachr
                            End If
                        End If '","

                        If commanext = 1 Then
                            If c <> 32 And c <> 9 Then Give_Error "Expected , after quoted string in DATA statement": Exit Function
                        End If

                        If c = 34 Then
                            If speechmarks = 1 Then
                                commanext = 1
                                speechmarks = 0
                            End If
                            If scan = 0 Then speechmarks = 1
                        End If

                        scan = 1

                        If p1 = 0 Then p1 = i: p2 = i
                        If c <> 9 And c <> 32 Then p2 = i

                        skipwhitespace:
                        i = i + 1: GoTo nextdatachr
                    End If 'i<n
                    finaldata = 1: GoTo adddata
                    finisheddata:
                    e$ = ""
                    If prepass = 0 Then
                        Put #16, , x$
                        DataOffset = DataOffset + Len(x$)

                        e$ = Space$((Len(x$) - 1) * 2)
                        For ec = 1 To Len(x$) - 1
                            '2 chr hex encode each character
                            v1 = Asc(x$, ec)
                            v2 = v1 \ 16: If v2 <= 9 Then v2 = v2 + 48 Else v2 = v2 + 55
                            v1 = v1 And 15: If v1 <= 9 Then v1 = v1 + 48 Else v1 = v1 + 55
                            Asc(e$, ec * 2 - 1) = v1
                            Asc(e$, ec * 2) = v2
                        Next

                    End If

                    a2$ = a2$ + sp + "DATA": If Len(e$) Then a2$ = a2$ + sp + "_" + e$
                    GoTo lineformatnext
                End If
            End If

            a2$ = a2$ + sp + Mid$(ca$, i, n2)
            i = i + n2

            '----(variable/name)extensions----
            extcheck:
            If n2 > 40 Then Give_Error "Identifier longer than 40 character limit": Exit Function
            c3 = Asc(a$, i)
            m = 0
            If c3 = 126 Then '"~"
                e2$ = Mid$(a$, i + 1, 2)
                If e2$ = "&&" Then e2$ = "~&&": GoTo lfgetve
                If e2$ = "%%" Then e2$ = "~%%": GoTo lfgetve
                If e2$ = "%&" Then e2$ = "~%&": GoTo lfgetve
                e2$ = Chr$(Asc(e2$))
                If e2$ = "&" Then e2$ = "~&": GoTo lfgetve
                If e2$ = "%" Then e2$ = "~%": GoTo lfgetve
                If e2$ = "`" Then m = 1: e2$ = "~`": GoTo lfgetve
            End If
            If c3 = 37 Then
                c4 = Asc(a$, i + 1)
                If c4 = 37 Then e2$ = "%%": GoTo lfgetve
                If c4 = 38 Then e2$ = "%&": GoTo lfgetve
                e2$ = "%": GoTo lfgetve
            End If
            If c3 = 38 Then
                c4 = Asc(a$, i + 1)
                If c4 = 38 Then e2$ = "&&": GoTo lfgetve
                e2$ = "&": GoTo lfgetve
            End If
            If c3 = 33 Then e2$ = "!": GoTo lfgetve
            If c3 = 35 Then
                c4 = Asc(a$, i + 1)
                If c4 = 35 Then e2$ = "##": GoTo lfgetve
                e2$ = "#": GoTo lfgetve
            End If
            If c3 = 36 Then m = 1: e2$ = "$": GoTo lfgetve
            If c3 = 96 Then m = 1: e2$ = "`": GoTo lfgetve
            '(no symbol)

            'cater for unusual names/labels (eg a.0b%)
            If Asc(a$, i) = 46 Then '"."
                c2 = Asc(a$, i + 1)
                If c2 >= 48 And c2 <= 57 Then
                    'scan until no further alphanumerics
                    p2 = i + 1
                    For i2 = i + 2 To n
                        c = Asc(a$, i2)

                        If Not alphanumeric(c) Then Exit For
                        If c <> 95 Then p2 = i2 'don't including trailing _
                    Next
                    a2$ = a2$ + sp + "." + sp + Mid$(ca$, i + 1, p2 - (i + 1) + 1) 'case sensitive
                    n2 = n2 + 1 + (p2 - (i + 1) + 1)
                    i = p2 + 1
                    GoTo extcheck 'it may have an extension or be continued with another "."
                End If
            End If

            GoTo lineformatnext

            lfgetve:
            i = i + Len(e2$)
            a2$ = a2$ + e2$
            If m Then 'allow digits after symbol
                lfgetvd:
                If i < n Then
                    c = Asc(a$, i)
                    If c >= 48 And c <= 57 Then a2$ = a2$ + Chr$(c): i = i + 1: GoTo lfgetvd
                End If
            End If 'm

            GoTo lineformatnext

        End If 'p2
    End If 'variable/name
    '----------------variable/name end----------------

    '----------------spacing----------------
    If c = 32 Or c = 9 Then i = i + 1: GoTo lineformatnext

    '----------------symbols----------------
    '--------single characters--------
    If lfsinglechar(c) Then
        If (c = 60) Or (c = 61) Or (c = 62) Then
            count = 0
            Do
                count = count + 1
                If i + count >= Len(a$) - 2 Then Exit Do
            Loop Until Asc(a$, i + count) <> 32
            c2 = Asc(a$, i + count)
            If c = 60 Then '<
                If c2 = 61 Then a2$ = a2$ + sp + "<=": i = i + count + 1: GoTo lineformatnext
                If c2 = 62 Then a2$ = a2$ + sp + "<>": i = i + count + 1: GoTo lineformatnext
            ElseIf c = 62 Then '>
                If c2 = 61 Then a2$ = a2$ + sp + ">=": i = i + count + 1: GoTo lineformatnext
                If c2 = 60 Then a2$ = a2$ + sp + "<>": i = i + count + 1: GoTo lineformatnext '>< to <>
            ElseIf c = 61 Then '=
                If c2 = 62 Then a2$ = a2$ + sp + ">=": i = i + count + 1: GoTo lineformatnext '=> to >=
                If c2 = 60 Then a2$ = a2$ + sp + "<=": i = i + count + 1: GoTo lineformatnext '=< to <=
            End If
        End If

        If c = 36 And Len(a2$) Then GoTo badusage '$

        a2$ = a2$ + sp + Chr$(c)
        i = i + 1
        GoTo lineformatnext
    End If
    badusage:

    If c <> 39 Then Give_Error "Unexpected character on line": Exit Function 'invalid symbol encountered

    '----------------comment(')----------------
    layoutcomment = "'"
    i = i + 1
    comment:
    If i >= n Then GoTo lineformatdone2
    c$ = Right$(a$, Len(a$) - i + 1)
    cc$ = Right$(ca$, Len(ca$) - i + 1)
    If Len(c$) = 0 Then GoTo lineformatdone2
    layoutcomment$ = RTrim$(layoutcomment$ + cc$)

    c$ = LTrim$(c$)
    If Len(c$) = 0 Then GoTo lineformatdone2
    ac = Asc(c$)
    'note: any non-whitespace character between the comment leader and the
    '      first '$' renders this a plain comment
    '    : the leading '$' does NOT have to be part of a valid metacommand.
    '      E.g., REM $FOO $DYNAMIC is a valid metacommand line
    If ac <> 36 Then GoTo lineformatdone2
    nocasec$ = LTrim$(Right$(ca$, Len(ca$) - i + 1))
    memmode = 0
    x = 1
    Do
        'note: metacommands may appear on a line any number of times but only
        '      the last appearance of $INCLUDE, and either $STATIC or $DYNAMIC,
        '      is processed
        '    : metacommands do not need to be terminated by word boundaries.
        '      E.g., $STATICanychars$DYNAMIC is valid

        If Mid$(c$, x, 7) = "$STATIC" Then
            memmode = 1
        ElseIf Mid$(c$, x, 8) = "$DYNAMIC" Then
            memmode = 2
        ElseIf Mid$(c$, x, 8) = "$INCLUDE" Then
            'note: INCLUDE adds the file AFTER the line it is on has been processed
            'skip spaces until :
            For xx = x + 8 To Len(c$)
                ac = Asc(Mid$(c$, xx, 1))
                If ac = 58 Then Exit For ':
                If ac <> 32 And ac <> 9 Then Give_Error "Expected $INCLUDE:'filename'": Exit Function
            Next
            x = xx
            'skip spaces until '
            For xx = x + 1 To Len(c$)
                ac = Asc(Mid$(c$, xx, 1))
                If ac = 39 Then Exit For 'character:'
                If ac <> 32 And ac <> 9 Then Give_Error "Expected $INCLUDE:'filename'": Exit Function
            Next
            x = xx
            xx = InStr(x + 1, c$, "'")
            If xx = 0 Then Give_Error "Expected $INCLUDE:'filename'": Exit Function
            addmetainclude$ = Mid$(nocasec$, x + 1, xx - x - 1)
            If addmetainclude$ = "" Then Give_Error "Expected $INCLUDE:'filename'": Exit Function
        End If

        x = InStr(x + 1, c$, "$")
    Loop While x <> 0

    If memmode = 1 Then addmetastatic = 1
    If memmode = 2 Then addmetadynamic = 1

    GoTo lineformatdone2

    lineformatdone:

    'line continuation?
    'note: line continuation in idemode is illegal
    If Len(a2$) Then
        If Right$(a2$, 1) = "_" Then

            linecontinuation = 1 'avoids auto-format glitches
            layout$ = ""

            'remove _ from the end of the building string
            If Len(a2$) >= 2 Then
                If Right$(a2$, 2) = sp + "_" Then a2$ = Left$(a2$, Len(a2$) - 1)
            End If
            a2$ = Left$(a2$, Len(a2$) - 1)

            If inclevel Then
                fh = 99 + inclevel
                If EOF(fh) Then GoTo lineformatdone2
                Line Input #fh, a$
                inclinenumber(inclevel) = inclinenumber(inclevel) + 1
                GoTo includecont 'note: should not increase linenumber
            End If

            If idemode Then
                idecommand$ = Chr$(100)
                ignore = ide(0)
                ideerror = 0
                a$ = idereturn$
                If a$ = "" Then GoTo lineformatdone2
            Else
                a$ = lineinput3$
                If a$ = Chr$(13) Then GoTo lineformatdone2
            End If

            linenumber = linenumber + 1

            includecont:

            contline = 1
            GoTo continueline
        End If
    End If

    lineformatdone2:
    If Left$(a2$, 1) = sp Then a2$ = Right$(a2$, Len(a2$) - 1)

    'fix for trailing : error
    If Right$(a2$, 1) = ":" Then a2$ = a2$ + sp + "'" 'add nop

    If Error_Happened Then Exit Function
    lineformat$ = a2$
End Function

Sub makeidrefer (ref$, typ As Long)
    ref$ = str2$(currentid)
    typ = id.t + ISREFERENCE
End Sub

Function numelements (a$)
    If a$ = "" Then Exit Function
    n = 1
    p = 1
    numelementsnext:
    i = InStr(p, a$, sp)
    If i = 0 Then numelements = n: Exit Function
    n = n + 1
    p = i + 1
    GoTo numelementsnext
End Function

Function operatorusage (operator$, typ As Long, info$, lhs As Long, rhs As Long, result As Long)
    lhs = 7: rhs = 7: result = 0
    'return values
    '1 = use info$ as the operator without any other changes
    '2 = use the function returned in info$ to apply this operator
    '    upon left and right side of equation
    '3=  bracket left and right side with negation and change operator to info$
    '4=  BINARY NOT l.h.s, then apply operator in info$
    '5=  UNARY, bracket up rhs, apply operator info$ to left, rebracket again

    'lhs & rhs bit-field values
    '1=integeral
    '2=floating point
    '4=string
    '8=bool

    'string operator
    If (typ And ISSTRING) Then
        lhs = 4: rhs = 4
        result = 4
        If operator$ = "+" Then info$ = "qbs_add": operatorusage = 2: Exit Function
        result = 8
        If operator$ = "=" Then info$ = "qbs_equal": operatorusage = 2: Exit Function
        If operator$ = "<>" Then info$ = "qbs_notequal": operatorusage = 2: Exit Function
        If operator$ = ">" Then info$ = "qbs_greaterthan": operatorusage = 2: Exit Function
        If operator$ = "<" Then info$ = "qbs_lessthan": operatorusage = 2: Exit Function
        If operator$ = ">=" Then info$ = "qbs_greaterorequal": operatorusage = 2: Exit Function
        If operator$ = "<=" Then info$ = "qbs_lessorequal": operatorusage = 2: Exit Function
    End If

    'assume numeric operator
    lhs = 1 + 2: rhs = 1 + 2
    If operator$ = "^" Then result = 2: info$ = "pow2": operatorusage = 2: Exit Function
    If operator$ = Chr$(241) Then info$ = "-": operatorusage = 5: Exit Function
    If operator$ = "/" Then
        info$ = "/ ": operatorusage = 1
        'for / division, either the lhs or the rhs must be a float to make
        'c++ return a result in floating point form
        If (typ And ISFLOAT) Then
            'lhs is a float
            lhs = 2
            rhs = 1 + 2
        Else
            'lhs isn't a float!
            lhs = 1 + 2
            rhs = 2
        End If
        result = 2
        Exit Function
    End If
    If operator$ = "*" Then info$ = "*": operatorusage = 1: Exit Function
    If operator$ = "+" Then info$ = "+": operatorusage = 1: Exit Function
    If operator$ = "-" Then info$ = "-": operatorusage = 1: Exit Function

    result = 8
    If operator$ = "=" Then info$ = "==": operatorusage = 3: Exit Function
    If operator$ = ">" Then info$ = ">": operatorusage = 3: Exit Function
    If operator$ = "<" Then info$ = "<": operatorusage = 3: Exit Function
    If operator$ = "<>" Then info$ = "!=": operatorusage = 3: Exit Function
    If operator$ = "<=" Then info$ = "<=": operatorusage = 3: Exit Function
    If operator$ = ">=" Then info$ = ">=": operatorusage = 3: Exit Function

    lhs = 1: rhs = 1: result = 1
    operator$ = UCase$(operator$)
    If operator$ = "MOD" Then info$ = "%": operatorusage = 1: Exit Function
    If operator$ = "\" Then info$ = "/ ": operatorusage = 1: Exit Function
    If operator$ = "IMP" Then info$ = "|": operatorusage = 4: Exit Function
    If operator$ = "EQV" Then info$ = "^": operatorusage = 4: Exit Function
    If operator$ = "XOR" Then info$ = "^": operatorusage = 1: Exit Function
    If operator$ = "OR" Then info$ = "|": operatorusage = 1: Exit Function
    If operator$ = "AND" Then info$ = "&": operatorusage = 1: Exit Function

    lhs = 7
    If operator$ = "NOT" Then info$ = "~": operatorusage = 5: Exit Function

End Function

Function refer$ (a2$, typ As Long, method As Long)
    typbak = typ
    'method: 0 return an equation which calculates the value of the "variable"
    '        1 return the C name of the variable, typ will be left unchanged

    a$ = a2$

    'retrieve ID
    i = InStr(a$, sp3)
    If i Then
        idnumber = Val(Left$(a$, i - 1)): a$ = Right$(a$, Len(a$) - i)
    Else
        idnumber = Val(a$)
    End If
    getid idnumber
    If Error_Happened Then Exit Function

    'UDT?
    If typ And ISUDT Then
        If method = 1 Then
            n$ = "UDT_" + RTrim$(id.n)
            If id.t = 0 Then n$ = "ARRAY_" + n$
            n$ = scope$ + n$
            refer$ = n$
            Exit Function
        End If

        'print "UDTSUBSTRING[idX|u|e|o]:"+a$

        u = Val(a$)
        i = InStr(a$, sp3): a$ = Right$(a$, Len(a$) - i): E = Val(a$)
        i = InStr(a$, sp3): o$ = Right$(a$, Len(a$) - i)
        n$ = "UDT_" + RTrim$(id.n): If id.t = 0 Then n$ = "ARRAY_" + n$ + "[0]"
        If E = 0 Then Give_Error "User defined types in expressions are invalid": Exit Function
        If typ And ISOFFSETINBITS Then Give_Error "Cannot resolve bit-length variables inside user defined types": Exit Function

        If typ And ISSTRING Then
            If typ And ISFIXEDLENGTH Then
                o2$ = "(((uint8*)" + scope$ + n$ + ")+(" + o$ + "))"
                r$ = "qbs_new_fixed(" + o2$ + "," + str2(udtetypesize(E)) + ",1)"
                typ = STRINGTYPE + ISFIXEDLENGTH 'ISPOINTER retained, it is still a pointer!
            Else
                r$ = "*((qbs**)((char*)" + scope$ + n$ + "+(" + o$ + ")))"
                typ = STRINGTYPE
            End If
        Else
            typ = typ - ISUDT - ISREFERENCE - ISPOINTER
            If typ And ISARRAY Then typ = typ - ISARRAY
            t$ = typ2ctyp$(typ, "")
            If Error_Happened Then Exit Function
            o2$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"
            r$ = "*" + "(" + t$ + "*)" + o2$
        End If

        'print "REFER:"+r$+","+str2$(typ)
        refer$ = r$
        Exit Function
    End If

    'array?
    If id.arraytype Then

        n$ = RTrim$(id.callname)
        If method = 1 Then
            refer$ = n$
            typ = typbak
            Exit Function
        End If
        typ = typ - ISPOINTER - ISREFERENCE 'typ now looks like a regular value

        If (typ And ISSTRING) Then
            If (typ And ISFIXEDLENGTH) Then
                offset$ = "&((uint8*)(" + n$ + "[0]))[(" + a$ + ")*" + str2(id.tsize) + "]"
                r$ = "qbs_new_fixed(" + offset$ + "," + str2(id.tsize) + ",1)"
            Else
                r$ = "((qbs*)(((uint64*)(" + n$ + "[0]))[" + a$ + "]))"
            End If
            stringprocessinghappened = 1
            refer$ = r$
            Exit Function
        End If

        If (typ And ISOFFSETINBITS) Then
            'IF (typ AND ISUNSIGNED) THEN r$ = "getubits_" ELSE r$ = "getbits_"
            'r$ = r$ + str2(typ AND 511) + "("
            If (typ And ISUNSIGNED) Then r$ = "getubits" Else r$ = "getbits"
            r$ = r$ + "(" + str2(typ And 511) + ","
            r$ = r$ + "(uint8*)(" + n$ + "[0])" + ","
            r$ = r$ + a$ + ")"
            refer$ = r$
            Exit Function
        Else
            t$ = ""
            If (typ And ISFLOAT) Then
                If (typ And 511) = 32 Then t$ = "float"
                If (typ And 511) = 64 Then t$ = "double"
                If (typ And 511) = 256 Then t$ = "long double"
            Else
                If (typ And ISUNSIGNED) Then
                    If (typ And 511) = 8 Then t$ = "uint8"
                    If (typ And 511) = 16 Then t$ = "uint16"
                    If (typ And 511) = 32 Then t$ = "uint32"
                    If (typ And 511) = 64 Then t$ = "uint64"
                    If typ And ISOFFSET Then t$ = "uptrszint"
                Else
                    If (typ And 511) = 8 Then t$ = "int8"
                    If (typ And 511) = 16 Then t$ = "int16"
                    If (typ And 511) = 32 Then t$ = "int32"
                    If (typ And 511) = 64 Then t$ = "int64"
                    If typ And ISOFFSET Then t$ = "ptrszint"
                End If
            End If
        End If
        If t$ = "" Then Give_Error "Cannot find C type to return array data": Exit Function
        r$ = "((" + t$ + "*)(" + n$ + "[0]))[" + a$ + "]"
        refer$ = r$
        Exit Function
    End If 'array

    'variable?
    If id.t Then
        r$ = RTrim$(id.n)
        t = id.t
        'remove irrelavant flags
        If (t And ISINCONVENTIONALMEMORY) Then t = t - ISINCONVENTIONALMEMORY
        'string?
        If (t And ISSTRING) Then
            If (t And ISFIXEDLENGTH) Then
                r$ = scope$ + "STRING" + str2(id.tsize) + "_" + r$: GoTo ref
            End If
            r$ = scope$ + "STRING_" + r$: GoTo ref
        End If
        'bit-length single variable?
        If (t And ISOFFSETINBITS) Then
            If (t And ISUNSIGNED) Then
                r$ = "*" + scope$ + "UBIT" + str2(t And 511) + "_" + r$
            Else
                r$ = "*" + scope$ + "BIT" + str2(t And 511) + "_" + r$
            End If
            GoTo ref
        End If
        If t = BYTETYPE Then r$ = "*" + scope$ + "BYTE_" + r$: GoTo ref
        If t = UBYTETYPE Then r$ = "*" + scope$ + "UBYTE_" + r$: GoTo ref
        If t = INTEGERTYPE Then r$ = "*" + scope$ + "INTEGER_" + r$: GoTo ref
        If t = UINTEGERTYPE Then r$ = "*" + scope$ + "UINTEGER_" + r$: GoTo ref
        If t = LONGTYPE Then r$ = "*" + scope$ + "LONG_" + r$: GoTo ref
        If t = ULONGTYPE Then r$ = "*" + scope$ + "ULONG_" + r$: GoTo ref
        If t = INTEGER64TYPE Then r$ = "*" + scope$ + "INTEGER64_" + r$: GoTo ref
        If t = UINTEGER64TYPE Then r$ = "*" + scope$ + "UINTEGER64_" + r$: GoTo ref
        If t = SINGLETYPE Then r$ = "*" + scope$ + "SINGLE_" + r$: GoTo ref
        If t = DOUBLETYPE Then r$ = "*" + scope$ + "DOUBLE_" + r$: GoTo ref
        If t = FLOATTYPE Then r$ = "*" + scope$ + "FLOAT_" + r$: GoTo ref
        If t = OFFSETTYPE Then r$ = "*" + scope$ + "OFFSET_" + r$: GoTo ref
        If t = UOFFSETTYPE Then r$ = "*" + scope$ + "UOFFSET_" + r$: GoTo ref
        ref:
        If (t And ISSTRING) Then stringprocessinghappened = 1
        If (t And ISPOINTER) Then t = t - ISPOINTER
        typ = t
        If method = 1 Then
            If Left$(r$, 1) = "*" Then r$ = Right$(r$, Len(r$) - 1)
            typ = typbak
        End If
        refer$ = r$
        Exit Function
    End If 'variable
End Function

Sub regid
    idn = idn + 1

    If idn > ids_max Then
        ids_max = ids_max * 2
        ReDim _Preserve ids(1 To ids_max) As idstruct
        ReDim _Preserve cmemlist(1 To ids_max + 1) As Integer
        ReDim _Preserve sfcmemargs(1 To ids_max + 1) As String * 100
        ReDim _Preserve arrayelementslist(1 To ids_max + 1) As Integer
    End If

    n$ = RTrim$(id.n)

    If reginternalsubfunc = 0 Then
        If validname(n$) = 0 Then Give_Error "Invalid name": Exit Sub
    End If

    'register case sensitive name if none given
    If Asc(id.cn) = 32 Then
        n$ = RTrim$(id.n)
        id.n = UCase$(n$)
        id.cn = n$
    End If

    id.insubfunc = subfunc
    id.insubfuncn = subfuncn

    'note: cannot be STATIC and SHARED at the same time
    If dimshared Then
        id.share = dimshared
    Else
        If dimstatic Then id.staticscope = 1
    End If

    ids(idn) = id

    currentid = idn

    'prepare hash flags and check for conflicts
    hashflags = 1

    'sub/function?
    'Note: QBASIC does not allow: Internal type names (INTEGER,LONG,...)
    If id.subfunc Then
        ids(currentid).internal_subfunc = reginternalsubfunc
        If id.subfunc = 1 Then hashflags = hashflags + HASHFLAG_FUNCTION Else hashflags = hashflags + HASHFLAG_SUB
        If reginternalsubfunc = 0 Then 'allow internal definition of subs/functions without checks
            hashchkflags = HASHFLAG_RESERVED + HASHFLAG_CONSTANT
            If id.subfunc = 1 Then hashchkflags = hashchkflags + HASHFLAG_FUNCTION Else hashchkflags = hashchkflags + HASHFLAG_SUB
            hashres = HashFind(n$, hashchkflags, hashresflags, hashresref)
            Do While hashres
                If hashres Then
                    'Note: Numeric sub/function names like 'mid' do not clash with Internal string sub/function names
                    '      like 'MID$' because MID$ always requires a '$'. For user defined string sub/function names
                    '      the '$' would be optional so the rule should not be applied there.
                    allow = 0
                    If hashresflags And (HASHFLAG_FUNCTION + HASHFLAG_SUB) Then
                        If RTrim$(ids(hashresref).musthave) = "$" Then
                            If InStr(ids(currentid).mayhave, "$") = 0 Then allow = 1
                        End If
                    End If
                    If allow = 0 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                End If 'hashres
                If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
            Loop
            If idemode Then
                If InStr(listOfCustomKeywords$, "@" + UCase$(n$) + "@") = 0 Then
                    listOfCustomKeywords$ = listOfCustomKeywords$ + "@" + UCase$(n$) + "@"
                End If
            End If
        End If 'reginternalsubfunc = 0
    End If

    'variable?
    If id.t Then
        hashflags = hashflags + HASHFLAG_VARIABLE
        If reginternalvariable = 0 Then
            allow = 0
            var_recheck:
            If Asc(id.musthave) = 32 Then astype2 = 1 '"AS type" declaration?
            scope2 = subfuncn
            hashchkflags = HASHFLAG_RESERVED + HASHFLAG_SUB + HASHFLAG_FUNCTION + HASHFLAG_CONSTANT + HASHFLAG_VARIABLE
            hashres = HashFind(n$, hashchkflags, hashresflags, hashresref)
            Do While hashres

                'conflict with reserved word?
                If hashresflags And HASHFLAG_RESERVED Then
                    musthave$ = RTrim$(id.musthave)
                    If InStr(musthave$, "$") Then
                        'All reserved words can be used as variables in QBASIC if "$" is appended to the variable name!
                        '(allow)
                    Else
                        Give_Error "Name already in use (" + n$ + ")": Exit Sub 'Conflicts with reserved word
                    End If
                End If 'HASHFLAG_RESERVED

                'conflict with sub/function?
                If hashresflags And (HASHFLAG_FUNCTION + HASHFLAG_SUB) Then
                    If ids(hashresref).internal_subfunc = 0 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'QBASIC doesn't allow a variable of the same name as a user-defined sub/func
                    If RTrim$(id.n) = "WIDTH" And ids(hashresref).subfunc = 2 Then GoTo varname_exception
                    musthave$ = RTrim$(id.musthave)
                    If Len(musthave$) = 0 Then
                        If RTrim$(ids(hashresref).musthave) = "$" Then
                            'a sub/func requiring "$" can co-exist with implicit numeric variables
                            If InStr(id.mayhave, "$") Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                        Else
                            Give_Error "Name already in use (" + n$ + ")": Exit Sub 'Implicitly defined variables cannot conflict with sub/func names
                        End If
                    End If 'len(musthave$)=0
                    If InStr(musthave$, "$") Then
                        If RTrim$(ids(hashresref).musthave) = "$" Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'A sub/function name already exists as a string
                        '(allow)
                    Else
                        If RTrim$(ids(hashresref).musthave) <> "$" Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'A non-"$" sub/func name already exists with this name
                    End If
                End If 'HASHFLAG_FUNCTION + HASHFLAG_SUB

                'conflict with constant?
                If hashresflags And HASHFLAG_CONSTANT Then
                    scope1 = constsubfunc(hashresref)
                    If (scope1 = 0 And AllowLocalName = 0) Or scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                End If

                'conflict with variable?
                If hashresflags And HASHFLAG_VARIABLE Then
                    astype1 = 0: If Asc(ids(hashresref).musthave) = 32 Then astype1 = 1
                    scope1 = ids(hashresref).insubfuncn
                    If astype1 = 1 And astype2 = 1 Then
                        If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                    End If
                    'same type?
                    If id.t = ids(hashresref).t Then
                        If id.tsize = ids(hashresref).tsize Then
                            If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                        End If
                    End If
                    'will astype'd fixed STRING-variable mask a non-fixed string?
                    If id.t And ISFIXEDLENGTH Then
                        If astype2 = 1 Then
                            If ids(hashresref).t And ISSTRING Then
                                If (ids(hashresref).t And ISFIXEDLENGTH) = 0 Then
                                    If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                                End If
                            End If
                        End If
                    End If
                End If

                varname_exception:
                If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
            Loop
        End If 'reginternalvariable
    End If 'variable

    'array?
    If id.arraytype Then
        hashflags = hashflags + HASHFLAG_ARRAY
        allow = 0
        ary_recheck:
        scope2 = subfuncn
        If Asc(id.musthave) = 32 Then astype2 = 1 '"AS type" declaration?
        hashchkflags = HASHFLAG_RESERVED + HASHFLAG_SUB + HASHFLAG_FUNCTION + HASHFLAG_ARRAY
        hashres = HashFind(n$, hashchkflags, hashresflags, hashresref)
        Do While hashres

            'conflict with reserved word?
            If hashresflags And HASHFLAG_RESERVED Then
                musthave$ = RTrim$(id.musthave)
                If InStr(musthave$, "$") Then
                    'All reserved words can be used as variables in QBASIC if "$" is appended to the variable name!
                    '(allow)
                Else
                    Give_Error "Name already in use (" + n$ + ")": Exit Sub 'Conflicts with reserved word
                End If
            End If 'HASHFLAG_RESERVED

            'conflict with sub/function?
            If hashresflags And (HASHFLAG_FUNCTION + HASHFLAG_SUB) Then
                If ids(hashresref).internal_subfunc = 0 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'QBASIC doesn't allow a variable of the same name as a user-defined sub/func
                If RTrim$(id.n) = "WIDTH" And ids(hashresref).subfunc = 2 Then GoTo arrayname_exception
                musthave$ = RTrim$(id.musthave)

                If Len(musthave$) = 0 Then
                    If RTrim$(ids(hashresref).musthave) = "$" Then
                        'a sub/func requiring "$" can co-exist with implicit numeric variables
                        If InStr(id.mayhave, "$") Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                    Else
                        Give_Error "Name already in use (" + n$ + ")": Exit Sub 'Implicitly defined variables cannot conflict with sub/func names
                    End If
                End If 'len(musthave$)=0
                If InStr(musthave$, "$") Then
                    If RTrim$(ids(hashresref).musthave) = "$" Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'A sub/function name already exists as a string
                    '(allow)
                Else
                    If RTrim$(ids(hashresref).musthave) <> "$" Then Give_Error "Name already in use (" + n$ + ")": Exit Sub 'A non-"$" sub/func name already exists with this name
                End If
            End If 'HASHFLAG_FUNCTION + HASHFLAG_SUB

            'conflict with array?
            If hashresflags And HASHFLAG_ARRAY Then
                astype1 = 0: If Asc(ids(hashresref).musthave) = 32 Then astype1 = 1
                scope1 = ids(hashresref).insubfuncn
                If astype1 = 1 And astype2 = 1 Then
                    If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                End If
                'same type?
                If id.arraytype = ids(hashresref).arraytype Then
                    If id.tsize = ids(hashresref).tsize Then
                        If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                    End If
                End If
                'will astype'd fixed STRING-variable mask a non-fixed string?
                If id.arraytype And ISFIXEDLENGTH Then
                    If astype2 = 1 Then
                        If ids(hashresref).arraytype And ISSTRING Then
                            If (ids(hashresref).arraytype And ISFIXEDLENGTH) = 0 Then
                                If scope1 = scope2 Then Give_Error "Name already in use (" + n$ + ")": Exit Sub
                            End If
                        End If
                    End If
                End If
            End If

            arrayname_exception:
            If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
        Loop
    End If 'array

    'add it to the hash table
    HashAdd n$, hashflags, currentid
End Sub

Sub reginternal
    reginternalsubfunc = 1

    'special codes:

    '-1 Any numeric variable (will be made explicit by a C cast)
    '   Typically, these are used when multiple C functions exist

    '-2 Offset+Size(in bytes)
    '   Size is the largest safe memory block available from the offset
    '   used for: CALL INTERRUPT[X]

    '-3 Offset+Size(in bytes)
    '   Size is the largest safe memory block available from the offset
    '   *Like -2, but restrictions apply
    '   used for: GET/PUT(graphics)

    '-4 Offset+Size(in bytes)
    '   Size is the size of the element referenced
    '   used for: GET/PUT(file)
    ' -5 Offset only
    ' -6 Size only

    '-7 '_MEM' structure referring to the passed variable

    'special return codes:
    'none

    'stubs for internally handled commands:
    clearid
    id.n = "Asc": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Asc": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "End": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "LSet": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "RSet": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Mid": id.subfunc = 2: id.callname = "sub_stub": id.musthave = "$": regid
    clearid
    id.n = "Print": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Option": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Swap": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "System": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Write": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Read": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Close": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Reset": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Input": id.subfunc = 2: id.callname = "sub_stub": regid
    'stubs for unimplemented commands:
    clearid
    id.n = "TrOn": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "TrOff": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "List": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "Def": id.subfunc = 2: id.callname = "sub_stub": id.secondargcantbe = "SEG": regid
    clearid
    id.n = "IoCtl": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = "IoCtl": id.subfunc = 1: id.callname = "func_stub": id.musthave = "$": id.args = 1: id.arg = MKL$(LONGTYPE - ISPOINTER): id.ret = STRINGTYPE - ISPOINTER: regid
    clearid
    id.n = "Fre": id.subfunc = 1: id.callname = "func_stub": id.args = 1: id.arg = MKL$(LONGTYPE - ISPOINTER): id.ret = LONGTYPE - ISPOINTER: regid
    clearid
    id.n = "SetMem": id.subfunc = 1: id.callname = "func_stub": id.args = 1: id.arg = MKL$(LONGTYPE - ISPOINTER): id.ret = LONGTYPE - ISPOINTER: regid
    clearid
    id.n = "FileAttr": id.subfunc = 1: id.callname = "func_stub": id.args = 2: id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER): id.ret = LONGTYPE - ISPOINTER: regid
    clearid
    id.n = qb64prefix$ + "MemGet": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = qb64prefix$ + "MemPut": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = qb64prefix$ + "MemFill": id.subfunc = 2: id.callname = "sub_stub": regid
    clearid
    id.n = qb64prefix$ + "Continue": id.subfunc = 2: id.callname = "sub_stub": regid

    clearid
    id.n = qb64prefix$ + "Resize"
    id.subfunc = 2
    id.callname = "sub__resize"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{On|Off}][,{_Stretch|_Smooth}]"
    id.hr_syntax = "_RESIZE [{ON|OFF}][, {_STRETCH|_SMOOTH}]"
    regid

    clearid
    id.n = qb64prefix$ + "Resize"
    id.subfunc = 1
    id.callname = "func__resize"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_RESIZE"
    regid

    clearid
    id.n = qb64prefix$ + "ResizeWidth"
    id.subfunc = 1
    id.callname = "func__resizewidth"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_RESIZEWIDTH"
    regid

    clearid
    id.n = qb64prefix$ + "ResizeHeight"
    id.subfunc = 1
    id.callname = "func__resizeheight"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_RESIZEHEIGHT"
    regid

    clearid
    id.n = qb64prefix$ + "ScaledWidth"
    id.subfunc = 1
    id.callname = "func__scaledwidth"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCALEDWIDTH"
    regid

    clearid
    id.n = qb64prefix$ + "ScaledHeight"
    id.subfunc = 1
    id.callname = "func__scaledheight"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCALEDHEIGHT"
    regid

    clearid
    id.n = qb64prefix$ + "GLRender"
    id.subfunc = 2
    id.callname = "sub__glrender"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{_Behind|_OnTop|_Only}"
    id.hr_syntax = "_GLRENDER {_Behind|_OnTop|_Only}"
    regid

    clearid
    id.n = qb64prefix$ + "DisplayOrder"
    id.subfunc = 2
    id.callname = "sub__displayorder"
    id.args = 4
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Software|_Hardware|_Hardware1|_GLRender}[,{_Software|_Hardware|_Hardware1|_GLRender}[,{_Software|_Hardware|_Hardware1|_GLRender}[,{_Software|_Hardware|_Hardware1|_GLRender}]]]]"
    id.hr_syntax = "_DISPLAYORDER {_Software|_Hardware|_Hardware1|_GLRender} (any combination/order)"
    regid

    clearid
    id.n = qb64prefix$ + "MemGet"
    id.subfunc = 1
    id.callname = "func__memget"
    id.args = 3
    id.arg = MKL$(UDTTYPE + (1)) + MKL$(OFFSETTYPE - ISPOINTER) + MKL$(-1) 'x = _MEMGET(block, offset, type)
    id.ret = -1
    id.hr_syntax = "_MEMGET(block, offset, type)"
    regid

    clearid
    id.n = qb64prefix$ + "Mem"
    id.subfunc = 1
    id.callname = "func__mem"
    id.args = 2
    id.arg = MKL$(OFFSETTYPE - ISPOINTER) + MKL$(OFFSETTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = ISUDT + (1) 'the _MEM type is the first TYPE defined
    id.hr_syntax = "_MEM(referenceVariable) or _MEM(offset, byteSize)"
    regid
    '---special case---

    clearid
    id.n = qb64prefix$ + "MemElement"
    id.subfunc = 1
    id.callname = "func__mem"
    id.args = 1
    id.arg = MKL$(-8)
    id.ret = ISUDT + (1) 'the _MEM type is the first TYPE defined
    id.hr_syntax = "_MEMELEMENT(referenceVariable)"
    regid
    '---special case---

    clearid
    id.n = qb64prefix$ + "MemFree"
    id.subfunc = 2
    id.callname = "sub__memfree"
    id.args = 1
    id.arg = MKL$(UDTTYPE + (1))
    id.hr_syntax = "_MEMFREE memoryVariable"
    regid

    clearid
    id.n = qb64prefix$ + "MemExists"
    id.subfunc = 1
    id.callname = "func__memexists"
    id.args = 1
    id.arg = MKL$(UDTTYPE + (1))
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_MEMEXISTS(memBlock)"
    regid

    clearid
    id.n = qb64prefix$ + "MemNew"
    id.subfunc = 1
    id.callname = "func__memnew"
    id.args = 1
    id.arg = MKL$(OFFSETTYPE - ISPOINTER)
    id.ret = ISUDT + (1) 'the _MEM type is the first TYPE defined
    id.hr_syntax = "_MEMNEW(byteSize)"
    regid

    clearid
    id.n = qb64prefix$ + "MemImage"
    id.subfunc = 1
    id.callname = "func__memimage"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]" 'dest is default
    id.ret = ISUDT + (1) 'the _MEM type is the first TYPE defined
    id.hr_syntax = "_MEMIMAGE or _MEMIMAGE(imageHandle)"
    regid

    clearid
    id.n = qb64prefix$ + "MemSound": id.Dependency = DEPENDENCY_AUDIO_DECODE
    id.subfunc = 1
    id.callname = "func__memsound"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = ISUDT + (1) 'the _MEM type is the first TYPE defined
    id.hr_syntax = "_MEMSOUND(soundHandle)"
    regid

    clearid '_MEMCOPY a, aoffset, bytes TO b, boffset
    id.n = qb64prefix$ + "MemCopy"
    id.subfunc = 2
    id.callname = "sub__memcopy"
    id.args = 5
    id.arg = MKL$(UDTTYPE + (1)) + MKL$(OFFSETTYPE - ISPOINTER) + MKL$(OFFSETTYPE - ISPOINTER) + MKL$(UDTTYPE + (1)) + MKL$(OFFSETTYPE - ISPOINTER)
    id.specialformat = "?,?,?{To}?,?" 'dest is default
    id.hr_syntax = "_MEMCOPY sourceBlock, sourceBlock.OFFSET, sourceBlock.SIZE TO destBlock, destBlock.OFFSET"
    regid

    clearid
    id.n = qb64prefix$ + "ConsoleTitle"
    id.subfunc = 2
    id.callname = "sub__consoletitle"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "_CONSOLETITLE title$"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenShow"
    id.subfunc = 2
    id.callname = "sub__screenshow"
    id.hr_syntax = "_SCREENSHOW"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenHide"
    id.subfunc = 2
    id.callname = "sub__screenhide"
    id.hr_syntax = "_SCREENHIDE"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenHide"
    id.subfunc = 1
    id.callname = "func__screenhide"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCREENHIDE"
    regid

    clearid
    id.n = qb64prefix$ + "Console"
    id.subfunc = 1
    id.callname = "func__console"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CONSOLE"
    regid

    clearid
    id.n = qb64prefix$ + "Console"
    id.subfunc = 2
    id.callname = "sub__console"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{On|Off}"
    id.hr_syntax = "_CONSOLE {On|Off}"
    regid

    clearid
    id.n = qb64prefix$ + "ControlChr"
    id.subfunc = 2
    id.callname = "sub__controlchr"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{On|Off}"
    id.hr_syntax = "_CONTROLCHR {On|Off}"
    regid

    clearid
    id.n = qb64prefix$ + "Blink"
    id.subfunc = 2
    id.callname = "sub__blink"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{On|Off}"
    id.hr_syntax = "_BLINK {On|Off}"
    regid

    clearid
    id.n = qb64prefix$ + "Blink"
    id.subfunc = 1
    id.callname = "func__blink"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_BLINK"
    regid

    clearid
    id.n = qb64prefix$ + "FileExists"
    id.subfunc = 1
    id.callname = "func__fileexists"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FILEEXISTS(fileName$)"
    regid

    clearid
    id.n = qb64prefix$ + "DirExists"
    id.subfunc = 1
    id.callname = "func__direxists"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DIREXISTS(path$)"
    regid

    'QB64 DEVICE interface

    clearid
    id.n = "Stick": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func_stick"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "?[,?]"
    id.hr_syntax = "STICK(direction%) or STICK(direction%, axis_number%)"
    regid

    clearid
    id.n = "Strig": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func_strig"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "?[,?]"
    id.hr_syntax = "STRIG(button_function%) or STRIG(button_function%, device_number%)"
    regid

    clearid
    id.n = "Strig": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 2
    id.callname = "sub_strig"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[(?[,?])]{On|Off|Stop}"
    'In previous versions of BASIC, the statement STRIG ON enables testing of the joystick triggers; STRIG OFF disables joystick trigger testing. QuickBASIC ignores STRIG ON and STRIG OFF statements--the statements are provided for compatibility with earlier versions.
    id.hr_syntax = "STRIG(button%) {On|Off|Stop}"
    regid

    clearid
    id.n = qb64prefix$ + "Devices": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__devices"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DEVICES"
    regid

    clearid
    id.n = qb64prefix$ + "Device": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__device"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_DEVICE$(device_number)"
    regid

    clearid
    id.n = qb64prefix$ + "DeviceInput": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__deviceinput"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_DEVICEINPUT or _DEVICEINPUT(device_number%)"
    regid

    clearid
    id.n = qb64prefix$ + "LastButton": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__lastbutton"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_LASTBUTTON(deviceNumber)"
    regid

    clearid
    id.n = qb64prefix$ + "LastAxis": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__lastaxis"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_LASTAXIS(deviceNumber)"
    regid

    clearid
    id.n = qb64prefix$ + "LastWheel": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__lastwheel"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_LASTWHEEL(deviceNumber)"
    regid

    clearid
    id.n = qb64prefix$ + "Button": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__button"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_BUTTON(button_number%)"
    regid

    clearid
    id.n = qb64prefix$ + "ButtonChange": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__buttonchange"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_BUTTONCHANGE(button_number%)"
    regid

    clearid
    id.n = qb64prefix$ + "Axis": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__axis"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_AXIS(axis_number%)"
    regid

    clearid
    id.n = qb64prefix$ + "Wheel": id.Dependency = DEPENDENCY_DEVICEINPUT
    id.subfunc = 1
    id.callname = "func__wheel"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_WHEEL(wheelNumber%)"
    regid

    clearid
    id.n = "Key"
    id.subfunc = 2
    id.callname = "sub_key"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "(?){On|Off|Stop}"
    id.hr_syntax = "KEY(number) {On|Off|Stop}"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenX"
    id.subfunc = 1
    id.callname = "func__screenx"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCREENX"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenY"
    id.subfunc = 1
    id.callname = "func__screeny"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCREENY"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenMove"
    id.subfunc = 2
    id.callname = "sub__screenmove"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Middle}][?,?]"
    id.hr_syntax = "_SCREENMOVE x, y or _SCREENMOVE _Middle"
    regid

    clearid
    id.n = qb64prefix$ + "MouseMove"
    id.subfunc = 2
    id.callname = "sub__mousemove"
    id.args = 2
    id.arg = MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER)
    id.hr_syntax = "_MOUSEMOVE x, y"
    regid

    clearid
    id.n = qb64prefix$ + "OS"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__os"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_OS$"
    regid

    clearid
    id.n = qb64prefix$ + "Title"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__title"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_TITLE$"
    regid

    clearid
    id.n = qb64prefix$ + "MapUnicode"
    id.subfunc = 2
    id.callname = "sub__mapunicode"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?{To}?"
    id.hr_syntax = "_MAPUNICODE unicode& TO asciiCode%"
    regid

    clearid
    id.n = qb64prefix$ + "MapUnicode"
    id.subfunc = 1
    id.callname = "func__mapunicode"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_MAPUNICODE(asciiCode%)"
    regid

    clearid
    id.n = qb64prefix$ + "KeyDown"
    id.subfunc = 1
    id.callname = "func__keydown"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_KEYDOWN(code&)"
    regid

    clearid
    id.n = qb64prefix$ + "KeyHit"
    id.subfunc = 1
    id.callname = "func__keyhit"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_KEYHIT"
    regid

    clearid
    id.n = qb64prefix$ + "WindowHandle"
    id.subfunc = 1
    id.callname = "func__handle"
    id.ret = INTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_WINDOWHANDLE"
    regid

    clearid
    id.n = "Files"
    id.subfunc = 2
    id.callname = "sub_files"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "FILES fileSpec$"
    regid

    clearid
    id.n = qb64prefix$ + "PrintImage": id.Dependency = DEPENDENCY_PRINTER
    id.subfunc = 2
    id.callname = "sub__printimage"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    ''proposed version:
    ''id.specialformat = "[_SQUAREPIXELS][?][,(?,?)-(?,?)]"
    id.hr_syntax = "_PRINTIMAGE imageHandle&"
    regid

    'remote desktop

    clearid
    id.n = qb64prefix$ + "ScreenClick"
    id.subfunc = 2
    id.callname = "sub__screenclick"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.hr_syntax = "_SCREENCLICK x, y[, button%]"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenPrint"
    id.subfunc = 2
    id.callname = "sub__screenprint"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "_SCREENPRINT text$"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenImage": id.Dependency = DEPENDENCY_SCREENIMAGE
    id.subfunc = 1
    id.callname = "func__screenimage"
    id.args = 4
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?,?,?,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCREENIMAGE(column1, row1, column2, row2)"
    regid

    clearid
    id.n = "Lock"
    id.subfunc = 2
    id.callname = "sub_lock"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(INTEGER64TYPE - ISPOINTER) + MKL$(INTEGER64TYPE - ISPOINTER)
    id.specialformat = "[#]?[,[?][{To}?]]"
    id.hr_syntax = "LOCK #fileNumber%, record& or LOCK #fileNumber% firstRecord& TO lastRecord&"
    regid

    clearid
    id.n = "Unlock"
    id.subfunc = 2
    id.callname = "sub_unlock"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(INTEGER64TYPE - ISPOINTER) + MKL$(INTEGER64TYPE - ISPOINTER)
    id.specialformat = "[#]?[,[?][{To}?]]"
    id.hr_syntax = "UNLOCK #fileNumber%, record& or UNLOCK #fileNumber% firstRecord& TO lastRecord&"
    regid

    clearid
    id.n = qb64prefix$ + "FreeTimer"
    id.subfunc = 1
    id.callname = "func__freetimer"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FREETIMER"
    regid

    clearid
    id.n = "Timer"
    id.subfunc = 2
    id.callname = "sub_timer"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[(?)]{On|Off|Stop|Free}"
    id.hr_syntax = "TIMER[(number%)] {On|Off|Stop|Free}"
    regid

    clearid
    id.n = qb64prefix$ + "FullScreen"
    id.subfunc = 2
    id.callname = "sub__fullscreen"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Off|_Stretch|_SquarePixels|Off}][,{_Smooth}]"
    id.hr_syntax = "_FULLSCREEN [{_Off|_Stretch|_SquarePixels|Off}][,{_Smooth}]"
    regid

    clearid
    id.n = qb64prefix$ + "AllowFullScreen"
    id.subfunc = 2
    id.callname = "sub__allowfullscreen"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Stretch|_SquarePixels|_Off|_All|Off}][,{_Smooth|_Off|_All|Off}]"
    id.hr_syntax = "_ALLOWFULLSCREEN [{_Stretch|_SquarePixels|_Off|_All|Off}][,{_Smooth|_Off|_All|Off}]"
    regid

    clearid
    id.n = qb64prefix$ + "FullScreen"
    id.subfunc = 1
    id.callname = "func__fullscreen"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FULLSCREEN"
    regid

    clearid
    id.n = qb64prefix$ + "Smooth"
    id.subfunc = 1
    id.callname = "func__fullscreensmooth"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SMOOTH"
    regid

    clearid
    id.n = qb64prefix$ + "WindowHasFocus"
    id.subfunc = 1
    id.callname = "func__hasfocus"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_WINDOWHASFOCUS"
    regid

    clearid
    id.n = qb64prefix$ + "Clipboard"
    id.musthave = "$"
    id.subfunc = 2
    id.callname = "sub__clipboard"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "=?"
    id.hr_syntax = "_CLIPBOARD$ = text$"
    regid

    clearid
    id.n = qb64prefix$ + "Clipboard"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__clipboard"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_CLIPBOARD$"
    regid

    clearid
    id.n = qb64prefix$ + "ClipboardImage": id.Dependency = DEPENDENCY_SCREENIMAGE
    id.subfunc = 1
    id.callname = "func__clipboardimage"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CLIPBOARDIMAGE"
    regid

    clearid
    id.n = qb64prefix$ + "ClipboardImage": id.Dependency = DEPENDENCY_SCREENIMAGE
    id.subfunc = 2
    id.callname = "sub__clipboardimage"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "=?"
    id.hr_syntax = "_CLIPBOARDIMAGE = existingImageHandle&"
    regid

    clearid
    id.n = qb64prefix$ + "Exit"
    id.subfunc = 1
    id.callname = "func__exit"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_EXIT"
    regid

    clearid
    id.n = qb64prefix$ + "OpenHost": id.Dependency = DEPENDENCY_SOCKETS
    id.subfunc = 1
    id.callname = "func__openhost"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_OPENHOST(" + Chr$(34) + "TCP/IP:portNumber" + Chr$(34) + ")"
    regid

    clearid
    id.n = qb64prefix$ + "Connected"
    id.subfunc = 1
    id.callname = "func__connected"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CONNECTED(connectionHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "ConnectionAddress"
    id.mayhave = "$"
    id.subfunc = 1
    id.callname = "func__connectionaddress"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_CONNECTIONADDRESS(connectionHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "OpenConnection"
    id.subfunc = 1
    id.callname = "func__openconnection"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_OPENCONNECTION(hostHandle)"
    regid

    clearid
    id.n = qb64prefix$ + "OpenClient": id.Dependency = DEPENDENCY_SOCKETS
    id.subfunc = 1
    id.callname = "func__openclient"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_OPENCLIENT(" + Chr$(34) + "TCP/IP:port:address" + Chr$(34) + ")"
    regid

    clearid
    id.n = qb64prefix$ + "EnvironCount"
    id.subfunc = 1
    id.callname = "func__environcount"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_ENVIRONCOUNT"
    regid

    clearid
    id.n = "Environ"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_environ"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "ENVIRON$(listIndex%) or ENVIRON$(systemID$)"
    regid

    clearid
    id.n = "Environ"
    id.subfunc = 2
    id.callname = "sub_environ"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "ENVIRON stringExpression$"
    regid

    clearid
    id.n = qb64prefix$ + "ErrorLine"
    id.subfunc = 1
    id.callname = "func__errorline"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_ERRORLINE"
    regid

    clearid
    id.n = qb64prefix$ + "InclErrorLine"
    id.subfunc = 1
    id.callname = "func__inclerrorline"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_INCLERRORLINE"
    regid

    clearid
    id.n = qb64prefix$ + "ErrorMessage"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__errormessage"
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.args = 1
    id.specialformat = "[?]"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_ERRORMESSAGE$ or _ERRORMESSAGE$(errorCode%)"
    regid

    clearid
    id.n = qb64prefix$ + "Assert"
    id.subfunc = 2
    id.callname = "sub__assert"
    id.args = 2
    id.specialformat = "?[,?]"
    id.arg = MKL$(INTEGERTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "_ASSERT condition[, errorMessage$]"
    regid

    clearid
    id.n = qb64prefix$ + "Display"
    id.subfunc = 2
    id.callname = "sub__display"
    id.hr_syntax = "_DISPLAY"
    regid

    clearid
    id.n = qb64prefix$ + "AutoDisplay"
    id.subfunc = 2
    id.callname = "sub__autodisplay"
    id.hr_syntax = "_AUTODISPLAY"
    regid

    clearid
    id.n = qb64prefix$ + "Limit"
    id.subfunc = 2
    id.callname = "sub__limit"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.hr_syntax = "_LIMIT framesPerSecond!"
    regid

    clearid
    id.n = qb64prefix$ + "FPS"
    id.subfunc = 2
    id.callname = "sub__fps"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.specialformat = "[{_Auto}][?]"
    id.hr_syntax = "_FPS fps! or _FPS _Auto"
    regid

    clearid
    id.n = qb64prefix$ + "Delay"
    id.subfunc = 2
    id.callname = "sub__delay"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.hr_syntax = "_DELAY seconds!"
    regid

    clearid
    id.n = qb64prefix$ + "Icon": id.Dependency = DEPENDENCY_ICON
    id.subfunc = 2
    id.callname = "sub__icon"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?[,?]]"
    id.hr_syntax = "_ICON [mainImageHandle&[, smallImageHandle&]]"
    regid

    clearid
    id.n = qb64prefix$ + "Title"
    id.subfunc = 2
    id.callname = "sub__title"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "_TITLE text$"
    regid

    clearid
    id.n = qb64prefix$ + "Echo"
    id.subfunc = 2
    id.callname = "sub__echo"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "_ECHO text$"
    regid

    clearid
    id.n = qb64prefix$ + "AcceptFileDrop"
    id.subfunc = 2
    id.callname = "sub__filedrop"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{On|Off}]"
    id.hr_syntax = "_ACCEPTFILEDROP [{On|Off}]"
    regid

    clearid
    id.n = qb64prefix$ + "AcceptFileDrop"
    id.subfunc = 1
    id.callname = "func__filedrop"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_ACCEPTFILEDROP"
    regid

    clearid
    id.n = qb64prefix$ + "FinishDrop"
    id.subfunc = 2
    id.callname = "sub__finishdrop"
    id.hr_syntax = "_FINISHDROP"
    regid

    clearid
    id.n = qb64prefix$ + "TotalDroppedFiles"
    id.subfunc = 1
    id.callname = "func__totaldroppedfiles"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_TOTALDROPPEDFILES"
    regid

    clearid
    id.n = qb64prefix$ + "DroppedFile"
    id.mayhave = "$"
    id.subfunc = 1
    id.callname = "func__droppedfile"
    id.ret = STRINGTYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_DROPPEDFILE$ or _DROPPEDFILE$(index&)"
    regid

    clearid
    id.n = "Clear"
    id.subfunc = 2
    id.callname = "sub_clear"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?][,[?][,?]]"
    id.hr_syntax = "CLEAR"
    regid

    'IMAGE CREATION/FREEING

    clearid
    id.n = qb64prefix$ + "NewImage"
    id.subfunc = 1
    id.callname = "func__newimage"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_NEWIMAGE(width&, height&, mode)"
    regid

    clearid
    id.n = qb64prefix$ + "LoadImage": id.Dependency = DEPENDENCY_IMAGE_CODEC
    id.subfunc = 1
    id.callname = "func__loadimage"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_LOADIMAGE(fileName$[, mode])"
    regid

    clearid
    id.n = qb64prefix$ + "FreeImage"
    id.subfunc = 2
    id.callname = "sub__freeimage"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_FREEIMAGE handle&"
    regid

    clearid
    id.n = qb64prefix$ + "CopyImage"
    id.subfunc = 1
    id.callname = "func__copyimage"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_COPYIMAGE[(imageHandle&[, mode])]"
    regid

    'IMAGE SELECTION

    clearid
    id.n = qb64prefix$ + "Source"
    id.subfunc = 2
    id.callname = "sub__source"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?"
    id.hr_syntax = "_SOURCE handle&"
    regid

    clearid
    id.n = qb64prefix$ + "Dest"
    id.subfunc = 2
    id.callname = "sub__dest"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?"
    id.hr_syntax = "_DEST imageHandle&"
    regid

    clearid
    id.n = qb64prefix$ + "Source"
    id.subfunc = 1
    id.callname = "func__source"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SOURCE"
    regid

    clearid
    id.n = qb64prefix$ + "Dest"
    id.subfunc = 1
    id.callname = "func__dest"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DEST"
    regid

    clearid
    id.n = qb64prefix$ + "Display"
    id.subfunc = 1
    id.callname = "func__display"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DISPLAY"
    regid

    'IMAGE SETTINGS

    clearid
    id.n = qb64prefix$ + "Blend"
    id.subfunc = 2
    id.callname = "sub__blend"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_BLEND [imageHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "DontBlend"
    id.subfunc = 2
    id.callname = "sub__dontblend"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_DONTBLEND [imageHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "ClearColor"
    id.subfunc = 2
    id.callname = "sub__clearcolor"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_None}][?][,?]"
    id.hr_syntax = "_CLEARCOLOR {color&|_None}[,dest_handle&]"
    regid

    'USING/CHANGING A SURFACE

    clearid
    id.n = qb64prefix$ + "PutImage"
    id.subfunc = 2
    id.callname = "sub__putimage"
    id.args = 10
    id.arg = MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER)
    id.specialformat = "[[{Step}](?,?)[-[{Step}](?,?)]][,[?][,[?][,[[{Step}](?,?)[-[{Step}](?,?)]][,{_Smooth}]]]]"
    id.hr_syntax = "_PUTIMAGE [STEP] [(dx1, dy1)-[STEP][(dx2, dy2)]][, sourceHandle&][, destHandle&][, ][STEP][(sx1, sy1)[-STEP][(sx2, sy2)]][_SMOOTH]"
    regid

    clearid
    id.n = qb64prefix$ + "MapTriangle"
    id.subfunc = 2
    id.callname = "sub__maptriangle"
    id.args = 19
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Clockwise|_AntiClockwise}][{_Seamless}](?,?)-(?,?)-(?,?)[,?]{To}(?,?[,?])-(?,?[,?])-(?,?[,?])[,[?][,{_Smooth|_SmoothShrunk|_SmoothStretched}]]"
    id.hr_syntax = "_MAPTRIANGLE [{_SEAMLESS}] (sx1, sy1)-(sx2, sy2)-(sx3, sy3), source& TO (dx1, dy1)-(dx2, dy2)-(dx3, dy3)[, destination&][{_SMOOTH|_SMOOTHSHRUNK|_SMOOTHSTRETCHED}]]"
    regid

    clearid
    id.n = qb64prefix$ + "DepthBuffer"
    id.subfunc = 2
    id.callname = "sub__depthbuffer"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{On|Off|Lock|_Clear}[,?]"
    id.hr_syntax = "_DEPTHBUFFER {On|Off|Lock|_Clear}[,handle&]"
    regid

    clearid
    id.n = qb64prefix$ + "SetAlpha"
    id.subfunc = 2
    id.callname = "sub__setalpha"
    id.args = 4
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,[?[{To}?]][,?]]"
    id.hr_syntax = "_SETALPHA alpha& or _SETALPHA color1& TO color2&[, imageHandle&]"
    regid

    'IMAGE INFO

    clearid
    id.n = qb64prefix$ + "Width"
    id.subfunc = 1
    id.callname = "func__width"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_WIDTH(imageHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "Height"
    id.subfunc = 1
    id.callname = "func__height"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_HEIGHT(imageHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "PixelSize"
    id.subfunc = 1
    id.callname = "func__pixelsize"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_PIXELSIZE[(imageHandle&)]"
    regid

    clearid
    id.n = qb64prefix$ + "ClearColor"
    id.subfunc = 1
    id.callname = "func__clearcolor"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CLEARCOLOR[(sourceHandle&)]"
    regid

    clearid
    id.n = qb64prefix$ + "Blend"
    id.subfunc = 1
    id.callname = "func__blend"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_BLEND[(imageHandle&)]"
    regid

    clearid
    id.n = qb64prefix$ + "DefaultColor"
    id.subfunc = 1
    id.callname = "func__defaultcolor"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_DEFAULTCOLOR[(imageHandle&)]"
    regid

    clearid
    id.n = qb64prefix$ + "BackgroundColor"
    id.subfunc = 1
    id.callname = "func__backgroundcolor"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_BACKGROUNDCOLOR(imageHandle&)]"
    regid

    '256 COLOR PALETTES

    clearid
    id.n = qb64prefix$ + "PaletteColor"
    id.subfunc = 1
    id.callname = "func__palettecolor"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_PALETTECOLOR(attributeNumber%, imgHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "PaletteColor"
    id.subfunc = 2
    id.callname = "sub__palettecolor"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.hr_syntax = "_PALETTECOLOR attribute%, newColor&[, imgHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "CopyPalette"
    id.subfunc = 2
    id.callname = "sub__copypalette"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?][,?]"
    id.hr_syntax = "_COPYPALETTE [sourceImageHandle&[, destinationImageHandle&]]"
    regid

    'FONT SUPPORT

    clearid
    id.n = qb64prefix$ + "LoadFont": id.Dependency = DEPENDENCY_LOADFONT
    id.subfunc = 1
    id.callname = "func__loadfont"
    id.args = 3
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_LOADFONT(fileName$, size%[, " + Chr$(34) + "{MONOSPACE|, BOLD|, ITALIC|, UNDERLINE|, UNICODE|, DONTBLEND}" + Chr$(34) + "])"
    regid

    clearid
    id.n = qb64prefix$ + "Font"
    id.subfunc = 2
    id.callname = "sub__font"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.hr_syntax = "_FONT fontHandle&[, imageHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "FontWidth"
    id.subfunc = 1
    id.callname = "func__fontwidth"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FONTWIDTH or _FONTWIDTH(fontHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "FontHeight"
    id.subfunc = 1
    id.callname = "func__fontheight"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FONTHEIGHT or _FONTHEIGHT(fontHandle&)"
    regid

    clearid
    id.n = qb64prefix$ + "Font"
    id.subfunc = 1
    id.callname = "func__font"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FONT[(imageHandle&)]"
    regid

    clearid
    id.n = qb64prefix$ + "PrintString"
    id.subfunc = 2
    id.callname = "sub__printstring"
    id.args = 4
    id.arg = MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?),?[,?]"
    id.hr_syntax = "_PRINTSTRING(x, y), text$[, imageHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "PrintWidth"
    id.subfunc = 1
    id.callname = "func__printwidth"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_PRINTWIDTH(textToPrint$[, destinationHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "FreeFont"
    id.subfunc = 2
    id.callname = "sub__freefont"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?"
    id.hr_syntax = "_FREEFONT fontHandle&"
    regid

    clearid
    id.n = qb64prefix$ + "PrintMode"
    id.subfunc = 2
    id.callname = "sub__printmode"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{_FillBackground|_KeepBackground|_OnlyBackground}[,?]"
    id.hr_syntax = "_PRINTMODE {_FillBackground|_KeepBackground|_OnlyBackground}[, imageHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "PrintMode"
    id.subfunc = 1
    id.callname = "func__printmode"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_PRINTMODE[(imageHandle&)]"
    regid

    'WORKING WITH COLORS

    clearid
    id.n = qb64prefix$ + "RGBA"
    id.subfunc = 1
    id.callname = "func__rgba"
    id.args = 5
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?,?,?[,?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_RGBA(red&, green&, blue&, alpha&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "RGB"
    id.subfunc = 1
    id.callname = "func__rgb"
    id.args = 4
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?,?[,?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_RGB(red&, green&, blue&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "Red"
    id.subfunc = 1
    id.callname = "func__red"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_RED(rgbaColorIndex&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "Green"
    id.subfunc = 1
    id.callname = "func__green"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_GREEN(rgbaColorIndex&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "Blue"
    id.subfunc = 1
    id.callname = "func__blue"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_BLUE(rgbaColorIndex&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "Alpha"
    id.subfunc = 1
    id.callname = "func__alpha"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_ALPHA(color~&[, imageHandle&])"
    regid

    clearid
    id.n = qb64prefix$ + "RGBA32"
    id.subfunc = 1
    id.callname = "func__rgba32"
    id.args = 4
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_RGBA32(red&, green&, blue&, alpha&)"
    regid

    clearid
    id.n = qb64prefix$ + "RGB32"
    id.subfunc = 1
    id.callname = "func__rgb32"
    id.overloaded = -1
    id.minargs = 1
    id.args = 4
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_RGB32(red&, green&, blue&[, alpha&]) or _RGB32(intensity&[, alpha&])"
    regid

    clearid
    id.n = qb64prefix$ + "Red32"
    id.subfunc = 1
    id.callname = "func__red32"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_RED32(rgbaColor&)"
    regid

    clearid
    id.n = qb64prefix$ + "Green32"
    id.subfunc = 1
    id.callname = "func__green32"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_GREEN32(rgbaColor&)"
    regid

    clearid
    id.n = qb64prefix$ + "Blue32"
    id.subfunc = 1
    id.callname = "func__blue32"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_BLUE32(rgbaColor&)"
    regid

    clearid
    id.n = qb64prefix$ + "Alpha32"
    id.subfunc = 1
    id.callname = "func__alpha32"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_ALPHA32(rgbaColor&)"
    regid

    clearid
    id.n = "Draw"
    id.subfunc = 2
    id.callname = "sub_draw"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "DRAW drawString$"
    regid

    clearid
    id.n = "Play": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub_play"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "PLAY commandString$"
    regid

    clearid
    id.n = "Play": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func_play"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "PLAY"
    regid

    'QB64 MOUSE
    clearid
    id.n = qb64prefix$ + "MouseShow"
    id.subfunc = 2
    id.callname = "sub__mouseshow"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSESHOW [cursorShape$]"
    regid

    clearid
    id.n = qb64prefix$ + "MouseHide"
    id.subfunc = 2
    id.callname = "sub__mousehide"
    id.hr_syntax = "_MOUSEHIDE"
    regid

    clearid
    id.n = qb64prefix$ + "MouseInput"
    id.subfunc = 1
    id.callname = "func__mouseinput"
    id.ret = LONGTYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEINPUT"
    regid

    clearid
    id.n = qb64prefix$ + "MouseX"
    id.subfunc = 1
    id.callname = "func__mousex"
    id.ret = SINGLETYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEX"
    regid

    clearid
    id.n = qb64prefix$ + "MouseY"
    id.subfunc = 1
    id.callname = "func__mousey"
    id.ret = SINGLETYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEY"
    regid

    clearid
    id.n = qb64prefix$ + "MouseMovementX"
    id.subfunc = 1
    id.callname = "func__mousemovementx"
    id.ret = SINGLETYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEMOVEMENTX"
    regid

    clearid
    id.n = qb64prefix$ + "MouseMovementY"
    id.subfunc = 1
    id.callname = "func__mousemovementy"
    id.ret = SINGLETYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEMOVEMENTY"
    regid

    clearid
    id.n = qb64prefix$ + "MouseButton"
    id.subfunc = 1
    id.callname = "func__mousebutton"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "?[,?]"
    id.hr_syntax = "_MOUSEBUTTON(buttonNumber)"
    regid

    clearid
    id.n = qb64prefix$ + "MouseWheel"
    id.subfunc = 1
    id.callname = "func__mousewheel"
    id.ret = LONGTYPE - ISPOINTER
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_MOUSEWHEEL"
    regid

    clearid
    id.n = qb64prefix$ + "MousePipeOpen"
    id.subfunc = 1
    id.callname = "func__mousepipeopen"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_MOUSEPIPEOPEN"
    regid

    clearid
    id.n = qb64prefix$ + "MouseInputPipe"
    id.subfunc = 2
    id.callname = "sub__mouseinputpipe"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "_MOUSEINPUTPIPE(context)"
    regid

    clearid
    id.n = qb64prefix$ + "MousePipeClose"
    id.subfunc = 2
    id.callname = "sub__mousepipeclose"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "_MOUSEPIPECLOSE(context)"
    regid

    clearid
    id.n = "FreeFile"
    id.subfunc = 1
    id.callname = "func_freefile"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_FREEFILE"
    regid

    clearid
    id.n = "Name"
    id.subfunc = 2
    id.callname = "sub_name"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "?{As}?"
    id.hr_syntax = "NAME oldFileOrFolderName$ AS newFileOrFolderName$"
    regid

    clearid
    id.n = "Kill"
    id.subfunc = 2
    id.callname = "sub_kill"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "KILL fileSpec$"
    regid

    clearid
    id.n = "ChDir"
    id.subfunc = 2
    id.callname = "sub_chdir"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "CHDIR path$"
    regid

    clearid
    id.n = "MkDir"
    id.subfunc = 2
    id.callname = "sub_mkdir"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "MKDIR pathSpec$"
    regid

    clearid
    id.n = "RmDir"
    id.subfunc = 2
    id.callname = "sub_rmdir"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "RMDIR path$"
    regid

    clearid
    id.n = "Chain"
    id.subfunc = 2
    id.callname = "sub_chain"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "CHAIN moduleName$"
    regid

    clearid
    id.n = "Shell"
    id.subfunc = 2
    id.callname = "sub_shell2"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "{_Hide}[{_DontWait}][?]"
    id.secondargmustbe = "_Hide"
    id.hr_syntax = "SHELL [_DONTWAIT] [_HIDE] commandToRun$"
    regid

    clearid
    id.n = "Shell"
    id.subfunc = 2
    id.callname = "sub_shell3"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "{_DontWait}[{_Hide}][?]"
    id.secondargmustbe = "_DontWait"
    id.hr_syntax = "SHELL [_DONTWAIT] [_HIDE] commandToRun$"
    regid

    clearid
    id.n = "Shell"
    id.subfunc = 2
    id.callname = "sub_shell"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    'id.secondargcantbe = "_HIDE"
    id.hr_syntax = "SHELL [_DONTWAIT] [_HIDE] commandToRun$"
    regid

    clearid
    id.n = "Shell"
    id.subfunc = 1
    id.callname = "func_shell"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = INTEGER64TYPE - ISPOINTER
    id.hr_syntax = "SHELL(commandToRun$)"
    regid

    clearid
    id.n = qb64prefix$ + "ShellHide"
    id.subfunc = 1
    id.callname = "func__shellhide"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = INTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_SHELLHIDE(commandToRun$)"
    regid

    clearid
    id.n = "Command"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_command"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "COMMAND$[(index%)]"
    regid

    clearid
    id.n = qb64prefix$ + "CommandCount"
    id.subfunc = 1
    id.callname = "func__commandcount"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_COMMANDCOUNT"
    regid

    'QB64 AUDIO

    clearid
    id.n = qb64prefix$ + "SndRate": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndrate"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDRATE"
    regid

    clearid
    id.n = qb64prefix$ + "SndRaw": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndraw"
    id.args = 3
    id.arg = MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,[?][,?]]"
    id.hr_syntax = "_SNDRAW leftSample[, rightSample][, pipeHandle&]"
    regid

    clearid
    id.n = qb64prefix$ + "SndRawDone": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndrawdone"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "_SNDRAWDONE"
    regid

    clearid
    id.n = qb64prefix$ + "SndOpenRaw": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndopenraw"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDOPENRAW"
    regid

    clearid
    id.n = qb64prefix$ + "SndRawLen": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndrawlen"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "_SNDRAWLEN"
    regid

    clearid
    id.n = qb64prefix$ + "SndLen": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndlen"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "_SNDLEN(handle&)"
    regid

    clearid
    id.n = qb64prefix$ + "SndPaused": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndpaused"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDPAUSED(handle&)"
    regid

    clearid
    id.n = qb64prefix$ + "SndPlayFile": id.Dependency = DEPENDENCY_AUDIO_DECODE
    id.subfunc = 2
    id.callname = "sub__sndplayfile"
    id.args = 3
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.specialformat = "?[,[?][,?]]"
    id.hr_syntax = "_SNDPLAYFILE fileName$[, , volume!]"
    regid

    clearid
    id.n = qb64prefix$ + "SndPlayCopy": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndplaycopy"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.hr_syntax = "_SNDPLAYCOPY handle&[, volume!]"
    regid

    clearid
    id.n = qb64prefix$ + "SndStop": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndstop"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "_SNDSTOP handle&"
    regid

    clearid
    id.n = qb64prefix$ + "SndLoop": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndloop"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "_SNDLOOP handle&"
    regid

    clearid
    id.n = qb64prefix$ + "SndLimit": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndlimit"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.hr_syntax = "_SNDLIMIT handle&, numberOfSeconds!"
    regid

    clearid
    id.n = qb64prefix$ + "SndOpen": id.Dependency = DEPENDENCY_AUDIO_DECODE
    id.subfunc = 1
    id.callname = "func__sndopen"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDOPEN(fileName$)"
    regid

    clearid
    id.n = qb64prefix$ + "SndSetPos": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndsetpos"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER)
    id.hr_syntax = "_SNDSETPOS handle&, position!"
    regid

    clearid
    id.n = qb64prefix$ + "SndGetPos": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndgetpos"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "_SNDGETPOS(handle&)"
    regid

    clearid
    id.n = qb64prefix$ + "SndPlaying": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndplaying"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDPLAYING(handle&)"
    regid

    clearid
    id.n = qb64prefix$ + "SndPause": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndpause"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "_SNDPAUSE handle&"
    regid

    clearid
    id.n = qb64prefix$ + "SndBal": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndbal"
    id.args = 5
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "?,[?][,[?][,[?][,[?]]]]"
    id.hr_syntax = "_SNDBAL handle&[, x!][, y!][, z!][, channel&]]"
    regid

    clearid
    id.n = qb64prefix$ + "SndVol": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndvol"
    id.args = 2
    id.arg = MKL$(ULONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.hr_syntax = "_SNDVOL handle&, volume!"
    regid

    clearid
    id.n = qb64prefix$ + "SndPlay": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndplay"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "_SNDPLAY handle&"
    regid

    clearid
    id.n = qb64prefix$ + "SndCopy": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 1
    id.callname = "func__sndcopy"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "_SNDCOPY(handle&)"
    regid

    clearid
    id.n = qb64prefix$ + "SndClose": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub__sndclose"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "_SNDCLOSE handle&"
    regid

    clearid
    id.n = "Input"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_input"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "INPUT$(numberOfBytes%[, fileOrPortNumber])"
    regid

    clearid
    id.n = "Seek"
    id.subfunc = 2
    id.callname = "sub_seek"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[#]?,?"
    id.hr_syntax = "SEEK filenumber&, position"
    regid

    clearid
    id.n = "Seek"
    id.subfunc = 1
    id.callname = "func_seek"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "SEEK(filenumber&)"
    regid

    clearid
    id.n = "Loc"
    id.subfunc = 1
    id.callname = "func_loc"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "LOC(fileOrPortNumber%)"
    regid

    clearid
    id.n = "EOF"
    id.subfunc = 1
    id.callname = "func_eof"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "EOF(fileNumber&)"
    regid

    clearid
    id.n = "LOF"
    id.subfunc = 1
    id.callname = "func_lof"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "LOF(fileNumber&)"
    regid

    clearid
    id.n = "Screen"
    id.subfunc = 1
    id.callname = "func_screen"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "SCREEN(x, y[, colorflag%])"
    regid

    clearid
    id.n = "PMap"
    id.subfunc = 1
    id.callname = "func_pmap"
    id.args = 2
    id.arg = MKL$(SINGLETYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "PMAP(coordinate, function_number%)"
    regid

    clearid
    id.n = "Point"
    id.subfunc = 1
    id.callname = "func_point"
    id.args = 2
    id.arg = MKL$(SINGLETYPE - ISPOINTER) + MKL$(SINGLETYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "POINT(x, y) or POINT({0|1|2|3})"
    regid

    clearid
    id.n = "Tab"
    id.subfunc = 1
    id.callname = "func_tab"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "TAB(column%)"
    regid

    clearid
    id.n = "Spc"
    id.subfunc = 1
    id.callname = "func_spc"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "SPC(count%)"
    regid

    clearid
    id.n = "Wait"
    id.subfunc = 2
    id.callname = "sub_wait"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,?[,?]"
    id.hr_syntax = "WAIT port%, andMask%[, xorMask%]"
    regid

    clearid
    id.n = "Inp"
    id.subfunc = 1
    id.callname = "func_inp"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "INP(address)"
    regid

    clearid
    id.n = "Pos"
    id.subfunc = 1
    id.callname = "func_pos"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "POS(0)"
    regid

    clearid
    id.n = "Sgn"
    id.subfunc = 1
    id.callname = "func_sgn"
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "SGN(value)"
    regid

    clearid
    id.n = "LBound"
    id.subfunc = 1
    id.args = 2
    id.arg = MKL$(-1) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "LBOUND(arrayName[, dimension%])"
    regid

    clearid
    id.n = "UBound"
    id.subfunc = 1
    id.args = 2
    id.arg = MKL$(-1) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "UBOUND(arrayName[, dimension%])"
    regid

    clearid
    id.n = qb64prefix$ + "Bin"
    id.musthave = "$"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_BIN$(number)"
    regid

    clearid
    id.n = "Oct"
    id.musthave = "$"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "OCT$(number)"
    regid

    clearid
    id.n = "Hex"
    id.musthave = "$"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "HEX$(decimalNumber)"
    regid

    clearid
    id.n = "Sleep"
    id.subfunc = 2
    id.callname = "sub_sleep"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.hr_syntax = "SLEEP seconds%"
    regid

    clearid
    id.n = "Exp"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = -1
    id.hr_syntax = "EXP(numericExpression)"
    regid

    clearid
    id.n = "Fix"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = -1
    id.hr_syntax = "FIX(expression)"
    regid

    clearid
    id.n = "Int"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = -1
    id.hr_syntax = "INT(expression)"
    regid

    clearid
    id.n = "CDbl"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "CDBL(expression)"
    regid

    clearid
    id.n = "CSng"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "CSNG(expression)"
    regid

    clearid
    id.n = qb64prefix$ + "Round"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = INTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_ROUND(number)"
    regid

    clearid
    id.n = "CInt"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = INTEGERTYPE - ISPOINTER
    id.hr_syntax = "CINT(expression)"
    regid

    clearid
    id.n = "CLng"
    id.subfunc = 1
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = INTEGERTYPE - ISPOINTER
    id.hr_syntax = "CLNG(expression)"
    regid

    clearid
    id.n = "Time"
    id.musthave = "$"
    id.subfunc = 2
    id.callname = "sub_time"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "=?"
    id.hr_syntax = "TIME$ = timeToSet$"
    regid

    clearid
    id.n = "Time"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_time"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "TIME$"
    regid

    clearid
    id.n = "Date"
    id.musthave = "$"
    id.subfunc = 2
    id.callname = "sub_date"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "=?"
    id.hr_syntax = "DATE$ = dateToSet$"
    regid

    clearid
    id.n = "Date"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_date"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "DATE$"
    regid

    clearid
    id.n = "CsrLin"
    id.subfunc = 1
    id.callname = "func_csrlin"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "CSRLIN"
    regid

    clearid
    id.n = "Paint"
    id.subfunc = 2
    id.callname = "sub_paint"
    id.args = 5
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?)[,[?][,[?][,?]]]"
    id.hr_syntax = "PAINT [STEP] (x!, y!)[,[fillColor&] [,[bordercolor&] [,pattern$]]]"
    regid

    clearid
    id.n = "Circle"
    id.subfunc = 2
    id.callname = "sub_circle"
    id.args = 7
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?),?[,[?][,[?][,[?][,?]]]]"
    id.hr_syntax = "CIRCLE [STEP] (x!, y!), radius![, [color&] [, [start!] [, [end!] [, aspect!]]]]"
    regid

    clearid
    id.n = "BLoad"
    id.subfunc = 2
    id.callname = "sub_bload"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.hr_syntax = "BLOAD fileName$, VARPTR(imageArray%(index))"
    regid

    clearid
    id.n = "BSave"
    id.subfunc = 2
    id.callname = "sub_bsave"
    id.args = 3
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "BSAVE saveFile$, VARPTR(array(index)), fileSize&"
    regid

    'double definition
    clearid
    id.n = "Get"
    id.subfunc = 2
    id.callname = "sub_graphics_get"
    id.args = 6
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(-3) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?)-[{Step}](?,?),?[,?]"
    id.secondargmustbe = "Step"
    id.hr_syntax = "GET [STEP] (column1, row1)-[STEP](column2, row2), array([index])[, offscreenColor]"
    regid

    clearid
    id.n = "Get"
    id.subfunc = 2
    id.callname = "sub_graphics_get"
    id.args = 6
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(-3) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?)-[{Step}](?,?),?[,?]"
    id.secondargmustbe = "("
    id.hr_syntax = "GET [STEP] (column1, row1)-[STEP](column2, row2), array([index])[, offscreenColor]"
    regid

    'double definition
    clearid
    id.n = "Put"
    id.subfunc = 2
    id.callname = "sub_graphics_put"
    id.args = 5
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(-3) + MKL$(LONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?),?[,[{_Clip}][{PSet|PReset|And|Or|Xor}][,?]]"
    id.secondargmustbe = "Step"
    id.hr_syntax = "PUT [STEP](column, row), Array([index])[,] [_CLIP]  [{PSET|PRESET|AND|OR|XOR}]][, omitcolor]"
    regid
    clearid
    id.n = "Put"
    id.subfunc = 2
    id.callname = "sub_graphics_put"
    id.args = 5
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(-3) + MKL$(LONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?),?[,[{_Clip}][{PSet|PReset|And|Or|Xor}][,?]]"
    id.secondargmustbe = "("
    id.hr_syntax = "PUT [STEP](column, row), Array([index])[,] [_CLIP]  [{PSET|PRESET|AND|OR|XOR}]][, omitcolor]"
    regid

    clearid
    id.n = "Get"
    id.subfunc = 2
    id.callname = "sub_get"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(-4)
    id.specialformat = "[#]?[,[?][,?]]" 'field complient definition
    id.hr_syntax = "GET #fileNumber&, [position][, targetVariable|targetArray()}]"
    regid

    clearid
    id.n = "Put"
    id.subfunc = 2
    id.callname = "sub_put"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(-4)
    id.specialformat = "[#]?[,[?][,?]]" 'field complient definition
    id.hr_syntax = "PUT #filenumber&, [position][, {holdingvariable|holdingarray()}]"
    regid

    clearid
    id.n = "Open"
    id.subfunc = 2
    id.callname = "sub_open"
    id.args = 6
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?[{For Random|For Binary|For Input|For Output|For Append}][{Access Read Write|Access Read|Access Write}][{Shared|Lock Read Write|Lock Read|Lock Write}]{As}[#]?[{Len =}?]"
    id.hr_syntax = "OPEN fileName$ [FOR mode] [ACCESS|LOCK|SHARED [{READ|WRITE}] AS [#]fileNumber& [LEN = recordLength]"
    regid

    clearid
    id.n = "Open"
    id.subfunc = 2
    id.callname = "sub_open_gwbasic"
    id.args = 4
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "?,[#]?,?[,?]"
    id.hr_syntax = "OPEN modeLetter$, [#]fileNumber&, fileName$[, recordLength]"
    regid

    clearid
    id.n = "Val"
    id.subfunc = 1
    id.callname = "func_val"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "VAL(string_value$)"
    regid

    clearid
    id.n = "MKSMBF"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_mksmbf"
    id.args = 1
    id.arg = MKL$(SINGLETYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKSMBF$(value!)"
    regid

    clearid
    id.n = "MKDMBF"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_mkdmbf"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKDMBF$(value#)"
    regid

    clearid
    id.n = "MKI"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(INTEGERTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKI$(integerVariableOrLiteral%)"
    regid

    clearid
    id.n = "MKL"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKL$(longVariableOrLiteral&)"
    regid

    clearid
    id.n = "MKS"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(SINGLETYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKS$(singlePrecisionVariableOrLiteral!)"
    regid

    clearid
    id.n = "MKD"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "MKD$(doublePrecisionVariableOrLiteral#)"
    regid

    clearid
    id.n = qb64prefix$ + "MK"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = ""
    id.args = 2
    id.arg = MKL$(-1) + MKL$(-1)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_MK$(numericalType, numericalValue)"
    regid

    clearid
    id.n = "CVSMBF"
    id.subfunc = 1
    id.callname = "func_cvsmbf"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "CVSMBF(stringData$)"
    regid

    clearid
    id.n = "CVDMBF"
    id.subfunc = 1
    id.callname = "func_cvdmbf"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "CVDMBF(stringData$)"
    regid

    clearid
    id.n = "CVI"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = INTEGERTYPE - ISPOINTER
    id.hr_syntax = "CVI(stringData$)"
    regid

    clearid
    id.n = "CVL"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "CVL(stringData$)"
    regid

    clearid
    id.n = "CVS"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.hr_syntax = "CVS(stringData$)"
    regid

    clearid
    id.n = "CVD"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "CVD(stringData$)"
    regid

    clearid
    id.n = qb64prefix$ + "CV"
    id.subfunc = 1
    id.callname = ""
    id.args = 2
    id.arg = MKL$(-1) + MKL$(STRINGTYPE - ISPOINTER)
    id.ret = -1
    id.hr_syntax = "_CV(numericalType, MKstringValue$)"
    regid

    clearid
    id.n = "String"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_string"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "STRING$(count&, {character$ | ASCIIcode%})"
    regid

    clearid
    id.n = "Space"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_space"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "SPACE$(count&)"
    regid

    clearid
    id.n = "InStr"
    id.subfunc = 1
    id.callname = "func_instr"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?],?,?" 'checked!
    id.hr_syntax = "INSTR([start%,] baseString$, searchString$)"
    regid

    clearid
    id.n = qb64prefix$ + "InStrRev"
    id.subfunc = 1
    id.callname = "func__instrrev"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.specialformat = "[?],?,?" 'checked!
    id.hr_syntax = "_INSTRREV([start%,] baseString$, searchString$)"
    regid

    clearid
    id.n = "Mid"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_mid"
    id.args = 3
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.specialformat = "?,?,[?]" 'checked!
    id.hr_syntax = "MID$(stringValue$, startPosition%[, bytes%])"
    regid

    clearid
    id.n = "SAdd"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(-1) '!this value is ignored, the qb64 compiler handles this function
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "SADD(stringVariable$)"
    regid

    clearid
    id.n = "Cls"
    id.subfunc = 2
    id.callname = "sub_cls"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(ULONGTYPE - ISPOINTER)
    id.specialformat = "[?][,?]"
    id.hr_syntax = "CLS [method%] [, bgColor&]"
    regid

    clearid
    id.n = "Sqr"
    id.subfunc = 1
    id.callname = "func_sqr"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "SQR(value)"
    regid

    clearid
    id.n = "Chr"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func_chr"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "CHR$(code%)"
    regid

    clearid
    id.n = "VarPtr"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(-1) '!this value is ignored, the qb64 compiler handles this function
    id.ret = STRINGTYPE - ISPOINTER
    id.musthave = "$"
    id.hr_syntax = "VARPTR(variable_name[(reference_index%)])"
    regid

    clearid
    id.n = "VarPtr"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(-1) '!this value is ignored, the qb64 compiler handles this function
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "VARPTR(variable_name[(reference_index%)])"
    regid

    clearid
    id.n = qb64prefix$ + "Offset"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(-1) '!this value is ignored, the qb64 compiler handles this function
    id.ret = UOFFSETTYPE - ISPOINTER
    id.hr_syntax = "_OFFSET(variable)"
    regid

    clearid
    id.n = "VarSeg"
    id.subfunc = 1
    id.callname = ""
    id.args = 1
    id.arg = MKL$(-1) '!this value is ignored, the qb64 compiler handles this function
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "VARSEG(variable_name[(start_index)])"
    regid

    clearid
    id.n = "Poke"
    id.subfunc = 2
    id.callname = "sub_poke"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "POKE segment_offset, offset_value"
    regid

    clearid
    id.n = "Peek"
    id.subfunc = 1
    id.callname = "func_peek"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "PEEK(segment_offset)"
    regid

    clearid
    id.n = "Def"
    id.subfunc = 2
    id.callname = "sub_defseg"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{Seg}[=?]" 'checked!
    id.secondargmustbe = "Seg"
    id.hr_syntax = "DEF SEG [=][{segment|VARSEG(variable}]"
    regid

    clearid
    id.n = "Sin"
    id.subfunc = 1
    id.callname = "sin"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "SIN(radian_angle!)"
    regid

    clearid
    id.n = "Cos"
    id.subfunc = 1
    id.callname = "cos"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "COS(radian_angle!)"
    regid

    clearid
    id.n = "Tan"
    id.subfunc = 1
    id.callname = "tan"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "TAN(radian_angle!)"
    regid

    clearid
    id.n = "Atn"
    id.subfunc = 1
    id.callname = "atan"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "ATN(tangent!)"
    regid

    clearid
    id.n = "Log"
    id.subfunc = 1
    id.callname = "func_log"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "LOG(value)"
    regid

    clearid
    id.n = "Abs"
    id.subfunc = 1
    id.callname = "func_abs"
    id.args = 1
    id.arg = MKL$(-1) 'takes anything numerical
    id.ret = FLOATTYPE - ISPOINTER '***overridden by function evaluatefunc***
    id.hr_syntax = "ABS(numericalValue)"
    regid

    clearid
    id.n = "Erl"
    id.subfunc = 1
    id.callname = "get_error_erl"
    id.args = 0
    id.ret = DOUBLETYPE - ISPOINTER
    id.hr_syntax = "ERL"
    regid

    clearid
    id.n = "Err"
    id.subfunc = 1
    id.callname = "get_error_err"
    id.args = 0
    id.ret = ULONGTYPE - ISPOINTER
    id.hr_syntax = "ERR"
    regid

    clearid
    id.n = "Error"
    id.subfunc = 2
    id.callname = "error"
    id.args = 1
    id.arg = MKL$(ULONGTYPE - ISPOINTER)
    id.hr_syntax = "ERROR codeNumber%"
    regid

    clearid
    id.n = "Line"
    id.subfunc = 2
    id.callname = "sub_line"
    id.args = 7
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[[{Step}](?,?)]-[{Step}](?,?)[,[?][,[{B|BF}][,?]]]"
    id.hr_syntax = "LINE [STEP] [(column1, row1)]-[STEP] (column2, row2), color[, [{B|BF}], style%]"
    regid

    clearid
    id.n = "Sound": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub_sound"
    id.args = 2
    id.arg = MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER)
    id.hr_syntax = "SOUND frequency, duration"
    regid

    clearid
    id.n = "Beep": id.Dependency = DEPENDENCY_AUDIO_OUT
    id.subfunc = 2
    id.callname = "sub_beep"
    id.args = 0
    id.hr_syntax = "BEEP"
    regid

    clearid
    id.n = "Timer"
    id.subfunc = 1
    id.callname = "func_timer"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "TIMER[(accuracy!)]"
    regid

    clearid
    id.n = "Rnd"
    id.subfunc = 1
    id.callname = "func_rnd"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = SINGLETYPE - ISPOINTER
    id.specialformat = "[?]" 'checked!
    id.hr_syntax = "RND[(behavior)]"
    regid

    clearid
    id.n = "Randomize"
    id.subfunc = 2
    id.callname = "sub_randomize"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.specialformat = "[[{Using}]?]" 'checked!
    id.hr_syntax = "RANDOMIZE [USING] {seednumber|TIMER}"
    regid

    clearid
    id.n = "Out"
    id.subfunc = 2
    id.callname = "sub_out"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "OUT registerAddress%, value%"
    regid

    clearid
    id.n = "PCopy"
    id.subfunc = 2
    id.callname = "sub_pcopy"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.hr_syntax = "PCOPY sourcePage%, destinationPage%"
    regid

    clearid
    id.n = "View"
    id.subfunc = 2
    id.callname = "qbg_sub_view"
    id.args = 6
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[[{Screen}](?,?)-(?,?)[,[?][,?]]]"
    id.secondargcantbe = "Print"
    id.hr_syntax = "VIEW [SCREEN] (column1, row1)-(column2, row2)[, color][, border]"
    regid

    clearid
    id.n = "View"
    id.subfunc = 2
    id.callname = "qbg_sub_view_print"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "{Print}[?{To}?]" 'new!
    id.secondargmustbe = "Print"
    id.hr_syntax = "VIEW PRINT [topRow% TO bottomRow%]"
    regid

    clearid
    id.n = "Window"
    id.subfunc = 2
    id.callname = "qbg_sub_window"
    id.args = 4
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER)
    id.specialformat = "[[{Screen}](?,?)-(?,?)]"
    id.hr_syntax = "WINDOW [[SCREEN] (x1!, y1!) - (x2!, y2!)]"
    regid

    clearid
    id.n = "Locate"
    id.subfunc = 2
    id.callname = "qbg_sub_locate"
    id.args = 5
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?][,[?][,[?][,[?][,?]]]]"
    id.hr_syntax = "LOCATE [row%][, column%] [, cursor%][, cursorStart%, cursorStop%]"
    regid

    clearid
    id.n = "Color"
    id.subfunc = 2
    id.callname = "qbg_sub_color"
    id.args = 3
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?][,[?][,?]]"
    id.hr_syntax = "COLOR [foreground&][, background&]"
    regid

    clearid
    id.n = "Palette"
    id.subfunc = 2
    id.callname = "qbg_palette"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?,?]"
    id.hr_syntax = "PALETTE [attribute%, red% + (green% * 256) + (blue% * 65536)] or PALETTE [existingAttribute%, newAttribute%]"
    regid

    clearid
    id.n = "Width"
    id.subfunc = 2
    id.callname = "qbsub_width"
    id.args = 5
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{#|LPrint}][?][,[?][,[?][,[?]]]]" 'new!
    id.hr_syntax = "WIDTH [columns%][, rows%] or WIDTH {file_number|device}, columnwidth%"
    regid

    clearid
    id.n = "Screen"
    id.subfunc = 2
    id.callname = "qbg_screen"
    id.args = 5
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?][,[?][,[?][,[?][,[{_ManualDisplay}?]]]]]" 'a temp format for transition reasons"
    id.hr_syntax = "SCREEN {mode%|imagehandle&} [, , active_page, visual_page]"
    regid

    clearid
    id.n = "PSet"
    id.subfunc = 2
    id.callname = "sub_pset"
    id.args = 3
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?)[,?]"
    id.hr_syntax = "PSET [STEP](column%, row%)[, colorAttribute]"
    regid

    clearid
    id.n = "PReset"
    id.subfunc = 2
    id.callname = "sub_preset"
    id.args = 3
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{Step}](?,?)[,?]"
    id.hr_syntax = "PRESET [STEP](column%, row%)[, colorAttribute]"
    regid

    clearid
    id.n = "Asc"
    id.subfunc = 1
    id.callname = "qbs_asc"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "ASC(text$[, position%])"
    regid

    clearid
    id.n = "Len"
    id.subfunc = 1
    id.callname = "" 'callname is not used
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER) 'note: LEN is a special case, any input is actually accepted
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "LEN(literalTextOrVariable$)"
    regid

    clearid
    id.n = "InKey"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_inkey"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "INKEY$"
    regid

    clearid
    id.n = "Str"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_str"
    id.args = 1
    id.arg = MKL$(-1)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "STR$(number)"
    regid

    clearid
    id.n = "UCase"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_ucase"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "UCASE$(text$)"
    regid

    clearid
    id.n = "LCase"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_lcase"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "LCASE$(text$)"
    regid

    clearid
    id.n = "Left"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_left"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "LEFT$(stringValue$, numberOfCharacters%)"
    regid

    clearid
    id.n = "Right"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_right"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "RIGHT$(stringValue$, numberOfCharacters%)"
    regid

    clearid
    id.n = "LTrim"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_ltrim"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "LTRIM$(text$)"
    regid

    clearid
    id.n = "RTrim"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs_rtrim"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "RTRIM$(text$)"
    regid

    clearid
    id.n = qb64prefix$ + "Trim"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "qbs__trim"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_TRIM$(text$)"
    regid

    clearid
    id.n = "Print"
    id.subfunc = 2
    id.callname = "qbs_print" 'not called directly
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "PRINT [expression] [{;|,] [expression...]"
    regid

    clearid
    id.n = "LPrint": id.Dependency = DEPENDENCY_PRINTER
    id.subfunc = 2
    id.callname = "qbs_lprint" 'not called directly
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.hr_syntax = "LPRINT [expression] [{;|,}]"
    regid

    clearid
    id.n = "LPos": id.Dependency = DEPENDENCY_PRINTER
    id.subfunc = 1
    id.callname = "func_lpos"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "LPOS(index%)"
    regid

    'Get Current Working Directory
    clearid
    id.n = qb64prefix$ + "CWD"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__cwd"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_CWD$"
    regid

    'Get the directory the program was started from (before the currenct directory is automatically changed to the executables directory)
    clearid
    id.n = qb64prefix$ + "StartDir"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__startdir"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_STARTDIR$"
    regid

    'Return a path that best represents the context provided e.g. _DIR$("DESKTOP")
    clearid
    id.n = qb64prefix$ + "Dir"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__dir"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_DIR$(" + Chr$(34) + "folderspecification" + Chr$(34) + ")"
    regid

    'Return the name of the included file in which the last error occurred
    clearid
    id.n = qb64prefix$ + "InclErrorFile"
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__inclerrorfile"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_INCLERRORFILE$"
    regid

    clearid
    id.n = qb64prefix$ + "KeyClear"
    id.subfunc = 2
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.callname = "sub__keyclear"
    id.hr_syntax = "_KEYCLEAR buffer&"
    regid

    clearid
    id.n = qb64prefix$ + "D2R"
    id.subfunc = 1
    id.callname = "func_deg2rad"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_D2R(angleInDegrees!)"
    regid

    clearid
    id.n = qb64prefix$ + "D2G"
    id.subfunc = 1
    id.callname = "func_deg2grad"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_D2G(angleInDegrees!)"
    regid

    clearid
    id.n = qb64prefix$ + "R2D"
    id.subfunc = 1
    id.callname = "func_rad2deg"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_R2D(angleInRadians!)"
    regid

    clearid
    id.n = qb64prefix$ + "R2G"
    id.subfunc = 1
    id.callname = "func_rad2grad"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_R2G(angleInRadians!)"
    regid

    clearid
    id.n = qb64prefix$ + "G2D"
    id.subfunc = 1
    id.callname = "func_grad2deg"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_G2D(gradient!)"
    regid

    clearid
    id.n = qb64prefix$ + "G2R"
    id.subfunc = 1
    id.callname = "func_grad2rad"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_G2R(gradient!)"
    regid

    clearid 'Clear the old id info so we set the slate for a new one
    id.n = qb64prefix$ + "Atan2" 'The name of our new one
    id.subfunc = 1 'And this is a function
    id.callname = "atan2" 'The C name of the function
    id.args = 2 'It takes 2 parameters to work
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) 'These simply add up to represent the 2 patameters from what I can tell
    id.ret = FLOATTYPE - ISPOINTER 'we want it to return to us a nice _FLOAT value
    id.hr_syntax = "_ATAN2(y, x)"
    regid 'and we're finished with ID registration

    clearid 'Clear the old id info so we set the slate for a new one
    id.n = qb64prefix$ + "Hypot" 'The name of our new one
    id.subfunc = 1 'And this is a function
    id.callname = "hypot" 'The C name of the function
    id.args = 2 'It takes 2 parameters to work
    id.arg = MKL$(FLOATTYPE - ISPOINTER) + MKL$(FLOATTYPE - ISPOINTER) 'These simply add up to represent the 2 patameters from what I can tell
    id.ret = FLOATTYPE - ISPOINTER 'we want it to return to us a nice _FLOAT value
    id.hr_syntax = "_HYPOT(x, y)"
    regid 'and we're finished with ID registration

    clearid
    id.n = qb64prefix$ + "Asin"
    id.subfunc = 1
    id.callname = "asin"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ASIN(sine_value!)"
    regid

    clearid
    id.n = qb64prefix$ + "Acos"
    id.subfunc = 1
    id.callname = "acos"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ACOS(cosine_value!)"
    regid

    clearid
    id.n = qb64prefix$ + "Sinh"
    id.subfunc = 1
    id.callname = "sinh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_SINH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Cosh"
    id.subfunc = 1
    id.callname = "cosh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_COSH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Tanh"
    id.subfunc = 1
    id.callname = "tanh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_TANH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Asinh"
    id.subfunc = 1
    id.callname = "asinh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ASINH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Acosh"
    id.subfunc = 1
    id.callname = "acosh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ACOSH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Atanh"
    id.subfunc = 1
    id.callname = "atanh"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ATANH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Ceil"
    id.subfunc = 1
    id.callname = "ceil"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_CEIL(expression)"
    regid

    clearid
    id.n = qb64prefix$ + "Pi"
    id.subfunc = 1
    id.callname = "func_pi"
    id.args = 1
    id.arg = MKL$(DOUBLETYPE - ISPOINTER)
    id.ret = DOUBLETYPE - ISPOINTER
    id.specialformat = "[?]"
    id.hr_syntax = "_PI[(multiplier)]"
    regid

    clearid
    id.n = qb64prefix$ + "DesktopHeight"
    id.subfunc = 1
    id.callname = "func_screenheight"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DESKTOPHEIGHT"
    regid

    clearid
    id.n = qb64prefix$ + "DesktopWidth"
    id.subfunc = 1
    id.callname = "func_screenwidth"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_DESKTOPWIDTH"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenIcon" 'name change to from _ICONIFYWINDOW to _SCREENICON to match the screenshow and screenhide
    id.subfunc = 2
    id.callname = "sub_screenicon"
    id.hr_syntax = "_SCREENICON"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenExists"
    id.subfunc = 1
    id.callname = "func_windowexists"
    id.hr_syntax = "_SCREENEXISTS"
    regid

    clearid
    id.n = qb64prefix$ + "ControlChr"
    id.subfunc = 1
    id.callname = "func__controlchr"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CONTROLCHR"
    regid

    clearid
    id.n = qb64prefix$ + "StriCmp"
    id.subfunc = 1
    id.callname = "func__str_nc_compare"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_STRICMP(string1$, string2$)"
    regid

    clearid
    id.n = qb64prefix$ + "StrCmp"
    id.subfunc = 1
    id.callname = "func__str_compare"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(STRINGTYPE - ISPOINTER)
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_STRCMP(string1$, string2$)"
    regid

    clearid
    id.n = qb64prefix$ + "Arcsec"
    id.subfunc = 1
    id.callname = "func_arcsec"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ARCSEC(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Arccsc"
    id.subfunc = 1
    id.callname = "func_arccsc"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ARCCSC(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Arccot"
    id.subfunc = 1
    id.callname = "func_arccot"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_ARCCOT(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Sech"
    id.subfunc = 1
    id.callname = "func_sech"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_SECH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Csch"
    id.subfunc = 1
    id.callname = "func_csch"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_CSCH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Coth"
    id.subfunc = 1
    id.callname = "func_coth"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_COTH(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Sec"
    id.subfunc = 1
    id.callname = "func_sec"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_SEC(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Csc"
    id.subfunc = 1
    id.callname = "func_csc"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_CSC(value)"
    regid

    clearid
    id.n = qb64prefix$ + "Cot"
    id.subfunc = 1
    id.callname = "func_cot"
    id.args = 1
    id.arg = MKL$(FLOATTYPE - ISPOINTER)
    id.ret = FLOATTYPE - ISPOINTER
    id.hr_syntax = "_COT(value)"
    regid

    clearid
    id.n = qb64prefix$ + "ScreenIcon"
    id.subfunc = 1
    id.callname = "func_screenicon"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCREENICON"
    regid

    clearid
    id.n = qb64prefix$ + "AutoDisplay"
    id.subfunc = 1
    id.callname = "func__autodisplay"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_AUTODISPLAY"
    regid

    clearid
    id.n = qb64prefix$ + "SHR"
    id.subfunc = 1
    id.callname = "func__shr"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = UINTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_SHR(numericalVariable, numericalValue)"
    regid

    clearid
    id.n = qb64prefix$ + "SHL"
    id.subfunc = 1
    id.callname = "func__shl"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = UINTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_SHL(numericalVariable, numericalValue)"
    regid

    clearid
    id.n = qb64prefix$ + "Deflate"
    id.Dependency = DEPENDENCY_ZLIB
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__deflate"
    id.args = 1
    id.arg = MKL$(STRINGTYPE - ISPOINTER)
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_DEFLATE$(stringToCompress$)"
    regid

    clearid
    id.n = qb64prefix$ + "Inflate"
    id.Dependency = DEPENDENCY_ZLIB
    id.musthave = "$"
    id.subfunc = 1
    id.callname = "func__inflate"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(INTEGER64TYPE - ISPOINTER)
    id.specialformat = "?[,?]"
    id.ret = STRINGTYPE - ISPOINTER
    id.hr_syntax = "_INFLATE$(stringToDecompress$[, originalSize&])"
    regid

    clearid
    id.n = qb64prefix$ + "CInp"
    id.subfunc = 1
    id.callname = "func__cinp"
    id.args = 1
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[?]"
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CINP"
    regid

    clearid
    id.n = qb64prefix$ + "CapsLock"
    id.subfunc = 1
    id.callname = "func__capslock"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CAPSLOCK"
    regid

    clearid
    id.n = qb64prefix$ + "ScrollLock"
    id.subfunc = 1
    id.callname = "func__scrolllock"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_SCROLLLOCK"
    regid

    clearid
    id.n = qb64prefix$ + "NumLock"
    id.subfunc = 1
    id.callname = "func__numlock"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_NUMLOCK"
    regid

    clearid
    id.n = qb64prefix$ + "CapsLock"
    id.subfunc = 2
    id.callname = "sub__capslock"
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.args = 1
    id.specialformat = "{On|Off|_Toggle}"
    id.hr_syntax = "_CAPSLOCK {On|Off|_Toggle}"
    regid

    clearid
    id.n = qb64prefix$ + "Scrolllock"
    id.subfunc = 2
    id.callname = "sub__scrolllock"
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.args = 1
    id.specialformat = "{On|Off|_Toggle}"
    id.hr_syntax = "_SCROLLLOCK {On|Off|_Toggle}"
    regid

    clearid
    id.n = qb64prefix$ + "Numlock"
    id.subfunc = 2
    id.callname = "sub__numlock"
    id.arg = MKL$(LONGTYPE - ISPOINTER)
    id.args = 1
    id.specialformat = "{On|Off|_Toggle}"
    id.hr_syntax = "_NUMLOCK {On|Off|_Toggle}"
    regid

    clearid
    id.n = qb64prefix$ + "ConsoleFont"
    id.subfunc = 2
    id.callname = "sub__consolefont"
    id.args = 2
    id.arg = MKL$(STRINGTYPE - ISPOINTER) + MKL$(INTEGERTYPE - ISPOINTER)
    id.hr_syntax = "_CONSOLEFONT fontFile$"
    regid

    clearid
    id.n = qb64prefix$ + "ConsoleCursor"
    id.subfunc = 2
    id.callname = "sub__console_cursor"
    id.args = 2
    id.arg = MKL$(LONGTYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.specialformat = "[{_Show|_Hide}][,?]"
    id.hr_syntax = "_CONSOLECURSOR {_Show|_Hide}[, size%]"
    regid

    clearid
    id.n = qb64prefix$ + "ConsoleInput"
    id.subfunc = 1
    id.callname = "func__getconsoleinput"
    id.args = 0
    id.ret = LONGTYPE - ISPOINTER
    id.hr_syntax = "_CONSOLEINPUT"
    regid

    clearid
    id.n = qb64prefix$ + "ReadBit"
    id.subfunc = 1
    id.callname = "func__readbit"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = INTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_READBIT(numericalVariable, numericalValue)"
    regid

    clearid
    id.n = qb64prefix$ + "SetBit"
    id.subfunc = 1
    id.callname = "func__setbit"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = UINTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_SETBIT(numericalVariable, numericalValue)"
    regid

    clearid
    id.n = qb64prefix$ + "ResetBit"
    id.subfunc = 1
    id.callname = "func__resetbit"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = UINTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_RESETBIT(numericalVariable, numericalValue)"
    regid

    clearid
    id.n = qb64prefix$ + "ToggleBit"
    id.subfunc = 1
    id.callname = "func__togglebit"
    id.args = 2
    id.arg = MKL$(UINTEGER64TYPE - ISPOINTER) + MKL$(LONGTYPE - ISPOINTER)
    id.ret = UINTEGER64TYPE - ISPOINTER
    id.hr_syntax = "_TOGGLEBIT(numericalVariable, numericalValue)"
    regid

    reginternalsubfunc = 0
End Sub

Sub removeelements (a$, first, last, keepindexing)
    a2$ = ""
    'note: first and last MUST be valid
    '      keepindexing means the number of elements will stay the same
    '       but some elements will be equal to ""

    n = numelements(a$)
    For i = 1 To n
        If i < first Or i > last Then
            a2$ = a2$ + sp + getelement(a$, i)
        Else
            If keepindexing Then a2$ = a2$ + sp
        End If
    Next
    If Left$(a2$, 1) = sp Then a2$ = Right$(a2$, Len(a2$) - 1)

    a$ = a2$

End Sub



Function symboltype (s$) 'returns type or 0(not a valid symbol)
    'note: sets symboltype_size for fixed length strings
    'created: 2011 (fast & comprehensive)
    If Len(s$) = 0 Then Exit Function
    'treat common cases first
    a = Asc(s$)
    l = Len(s$)
    If a = 37 Then '%
        If l = 1 Then symboltype = 16: Exit Function
        If l > 2 Then Exit Function
        If Asc(s$, 2) = 37 Then symboltype = 8: Exit Function
        If Asc(s$, 2) = 38 Then symboltype = OFFSETTYPE - ISPOINTER: Exit Function '%&
        Exit Function
    End If
    If a = 38 Then '&
        If l = 1 Then symboltype = 32: Exit Function
        If l > 2 Then Exit Function
        If Asc(s$, 2) = 38 Then symboltype = 64: Exit Function
        Exit Function
    End If
    If a = 33 Then '!
        If l = 1 Then symboltype = 32 + ISFLOAT: Exit Function
        Exit Function
    End If
    If a = 35 Then '#
        If l = 1 Then symboltype = 64 + ISFLOAT: Exit Function
        If l > 2 Then Exit Function
        If Asc(s$, 2) = 35 Then symboltype = 64 + ISFLOAT: Exit Function
        Exit Function
    End If
    If a = 36 Then '$
        If l = 1 Then symboltype = ISSTRING: Exit Function
        If isuinteger(Right$(s$, l - 1)) Then
            If l >= (1 + 10) Then
                If l > (1 + 10) Then Exit Function
                If s$ > "$2147483647" Then Exit Function
            End If
            symboltype_size = Val(Right$(s$, l - 1))
            symboltype = ISSTRING + ISFIXEDLENGTH
            Exit Function
        End If
        Exit Function
    End If
    If a = 96 Then '`
        If l = 1 Then symboltype = 1 + ISOFFSETINBITS: Exit Function
        If isuinteger(Right$(s$, l - 1)) Then
            If l > 3 Then Exit Function
            n = Val(Right$(s$, l - 1))
            If n > 64 Then Exit Function
            symboltype = n + ISOFFSETINBITS: Exit Function
        End If
        Exit Function
    End If
    If a = 126 Then '~
        If l = 1 Then Exit Function
        a = Asc(s$, 2)
        If a = 37 Then '%
            If l = 2 Then symboltype = 16 + ISUNSIGNED: Exit Function
            If l > 3 Then Exit Function
            If Asc(s$, 3) = 37 Then symboltype = 8 + ISUNSIGNED: Exit Function
            If Asc(s$, 3) = 38 Then symboltype = UOFFSETTYPE - ISPOINTER: Exit Function '~%&
            Exit Function
        End If
        If a = 38 Then '&
            If l = 2 Then symboltype = 32 + ISUNSIGNED: Exit Function
            If l > 3 Then Exit Function
            If Asc(s$, 3) = 38 Then symboltype = 64 + ISUNSIGNED: Exit Function
            Exit Function
        End If
        If a = 96 Then '`
            If l = 2 Then symboltype = 1 + ISOFFSETINBITS + ISUNSIGNED: Exit Function
            If isuinteger(Right$(s$, l - 2)) Then
                If l > 4 Then Exit Function
                n = Val(Right$(s$, l - 2))
                If n > 64 Then Exit Function
                symboltype = n + ISOFFSETINBITS + ISUNSIGNED: Exit Function
            End If
            Exit Function
        End If
    End If '~
End Function

Function removesymbol$ (varname$)
    i = InStr(varname$, "~"): If i Then GoTo foundsymbol
    i = InStr(varname$, "`"): If i Then GoTo foundsymbol
    i = InStr(varname$, "%"): If i Then GoTo foundsymbol
    i = InStr(varname$, "&"): If i Then GoTo foundsymbol
    i = InStr(varname$, "!"): If i Then GoTo foundsymbol
    i = InStr(varname$, "#"): If i Then GoTo foundsymbol
    i = InStr(varname$, "$"): If i Then GoTo foundsymbol
    Exit Function
    foundsymbol:
    If i = 1 Then Give_Error "Expected variable name before symbol": Exit Function
    symbol$ = Right$(varname$, Len(varname$) - i + 1)
    If symboltype(symbol$) = 0 Then Give_Error "Invalid symbol": Exit Function
    removesymbol$ = symbol$
    varname$ = Left$(varname$, i - 1)
End Function

Function scope$
    If id.share Then scope$ = module$ + "__": Exit Function
    scope$ = module$ + "_" + subfunc$ + "_"
End Function

Function seperateargs (a$, ca$, pass&)
    pass& = 0

    For i = 1 To OptMax: separgs(i) = "": Next
    For i = 1 To OptMax + 1: separgslayout(i) = "": Next
    For i = 1 To OptMax
        Lev(i) = 0
        EntryLev(i) = 0
        DitchLev(i) = 0
        DontPass(i) = 0
        TempList(i) = 0
        PassRule(i) = 0
        LevelEntered(i) = 0
    Next

    Dim id2 As idstruct

    id2 = id

    If id2.args = 0 Then Exit Function 'no arguments!


    s$ = id2.specialformat
    s$ = RTrim$(s$)

    'build a special format if none exists
    If s$ = "" Then
        For i = 1 To id2.args
            If i <> 1 Then s$ = s$ + ",?" Else s$ = "?"
        Next
    End If

    'note: dim'd arrays moved to global to prevent high recreation cost

    PassFlag = 1
    nextentrylevel = 0
    nextentrylevelset = 1
    level = 0
    lastt = 0
    ditchlevel = 0
    For i = 1 To Len(s$)
        s2$ = Mid$(s$, i, 1)

        If s2$ = "[" Then
            level = level + 1
            LevelEntered(level) = 0
            GoTo nextsymbol
        End If

        If s2$ = "]" Then
            level = level - 1
            If level < ditchlevel Then ditchlevel = level
            GoTo nextsymbol
        End If

        If s2$ = "{" Then
            lastt = lastt + 1: Lev(lastt) = level: PassRule(lastt) = 0
            DitchLev(lastt) = ditchlevel: ditchlevel = level 'store & reset ditch level
            i = i + 1
            i2 = InStr(i, s$, "}")
            numopts = 0
            nextopt:
            numopts = numopts + 1
            i3 = InStr(i + 1, s$, "|")
            If i3 <> 0 And i3 < i2 Then
                Opt(lastt, numopts) = Mid$(s$, i, i3 - i)
                i = i3 + 1: GoTo nextopt
            End If
            Opt(lastt, numopts) = Mid$(s$, i, i2 - i)
            T(lastt) = numopts
            'calculate words in each option
            For x = 1 To T(lastt)
                w = 1
                x2 = 1
                newword:
                If InStr(x2, RTrim$(Opt(lastt, x)), " ") Then w = w + 1: x2 = InStr(x2, RTrim$(Opt(lastt, x)), " ") + 1: GoTo newword
                OptWords(lastt, x) = w
            Next
            i = i2

            'set entry level routine
            EntryLev(lastt) = level 'default level when continuing a previously entered level
            If LevelEntered(level) = 0 Then
                EntryLev(lastt) = 0
                For i2 = 1 To level - 1
                    If LevelEntered(i2) = 1 Then EntryLev(lastt) = i2
                Next
            End If
            LevelEntered(level) = 1

            GoTo nextsymbol
        End If

        If s2$ = "?" Then
            lastt = lastt + 1: Lev(lastt) = level: PassRule(lastt) = 0
            DitchLev(lastt) = ditchlevel: ditchlevel = level 'store & reset ditch level
            T(lastt) = 0
            'set entry level routine
            EntryLev(lastt) = level 'default level when continuing a previously entered level
            If LevelEntered(level) = 0 Then
                EntryLev(lastt) = 0
                For i2 = 1 To level - 1
                    If LevelEntered(i2) = 1 Then EntryLev(lastt) = i2
                Next
            End If
            LevelEntered(level) = 1

            GoTo nextsymbol
        End If

        'assume "special" character (like ( ) , . - etc.)
        lastt = lastt + 1: Lev(lastt) = level: PassRule(lastt) = 0
        DitchLev(lastt) = ditchlevel: ditchlevel = level 'store & reset ditch level
        T(lastt) = 1: Opt(lastt, 1) = s2$: OptWords(lastt, 1) = 1: DontPass(lastt) = 1

        'set entry level routine
        EntryLev(lastt) = level 'default level when continuing a previously entered level
        If LevelEntered(level) = 0 Then
            EntryLev(lastt) = 0
            For i2 = 1 To level - 1
                If LevelEntered(i2) = 1 Then EntryLev(lastt) = i2
            Next
        End If
        LevelEntered(level) = 1

        GoTo nextsymbol

        nextsymbol:
    Next

    'Any symbols already have dontpass() set to 1
    'This sets any {}blocks with only one option/word (eg. {PRINT}) at the lowest level to dontpass()=1
    'because their content is manadatory and there is no choice as to which word to use
    For x = 1 To lastt
        If Lev(x) = 0 Then
            If T(x) = 1 Then DontPass(x) = 1
        End If
    Next

    x1 = 0 'the 'x' position of the beginning element of the current levelled block
    MustPassOpt = 0 'the 'x' position of the FIRST opt () in the block which must be passed
    MustPassOptNeedsFlag = 0 '{}blocks don't need a flag, ? blocks do

    'Note: For something like [{HELLO}x] a choice between passing 'hello' or passing a flag to signify x was specified
    '      has to be made, in such cases, a flag is preferable to wasting a full new int32 on 'hello'

    templistn = 0
    For l = 1 To 32767
        scannextlevel = 0
        For x = 1 To lastt
            If Lev(x) > l Then scannextlevel = 1

            If x1 Then
                If EntryLev(x) < l Then 'end of block reached
                    If MustPassOpt Then
                        'If there's an opt () which must be passed that will be identified,
                        'all the 1 option {}blocks can be assumed...
                        If MustPassOptNeedsFlag Then
                            'The MustPassOpt requires a flag, so use the same flag for everything
                            For x2 = 1 To templistn
                                PassRule(TempList(x2)) = PassFlag
                            Next
                            PassFlag = PassFlag * 2
                        Else
                            'The MustPassOpt is a {}block which doesn't need a flag, so everything else needs to
                            'reference it
                            For x2 = 1 To templistn
                                If TempList(x2) <> MustPassOpt Then PassRule(TempList(x2)) = -MustPassOpt
                            Next
                        End If
                    Else
                        'if not, use a unique flag for everything in this block
                        For x2 = 1 To templistn: PassRule(TempList(x2)) = PassFlag: Next
                        If templistn <> 0 Then PassFlag = PassFlag * 2
                    End If
                    x1 = 0
                End If
            End If


            If Lev(x) = l Then 'on same level
                If EntryLev(x) < l Then 'just (re)entered this level (not continuing along it)
                    x1 = x 'set x1 to the starting element of this level
                    MustPassOpt = 0
                    templistn = 0
                End If
            End If

            If x1 Then
                If Lev(x) = l Then 'same level

                    If T(x) <> 1 Then
                        'It isn't a symbol or a {}block with only one option therefore this opt () must be passed
                        If MustPassOpt = 0 Then
                            MustPassOpt = x 'Only record the first instance (it MAY require a flag)
                            If T(x) = 0 Then MustPassOptNeedsFlag = 1 Else MustPassOptNeedsFlag = 0
                        Else
                            'Update current MustPassOpt to non-flag-based {}block if possible (to save flag usage)
                            '(Consider [{A|B}?], where a flag is not required)
                            If MustPassOptNeedsFlag = 1 Then
                                If T(x) > 1 Then
                                    MustPassOpt = x: MustPassOptNeedsFlag = 0
                                End If
                            End If
                        End If
                        'add to list
                        templistn = templistn + 1: TempList(templistn) = x
                    End If

                    If T(x) = 1 Then
                        'It is a symbol or a {}block with only one option
                        'a {}block with only one option MAY not need to be passed
                        'depending on if anything else is in this block could make the existance of this opt () assumed
                        'Note: Symbols which are not encapsulated inside a {}block never need to be passed
                        '      Symbols already have dontpass() set to 1
                        If DontPass(x) = 0 Then templistn = templistn + 1: TempList(templistn) = x: DontPass(x) = 1
                    End If

                End If
            End If

        Next

        'scan last run (mostly just a copy of code from above)
        If x1 Then
            If MustPassOpt Then
                'If there's an opt () which must be passed that will be identified,
                'all the 1 option {}blocks can be assumed...
                If MustPassOptNeedsFlag Then
                    'The MustPassOpt requires a flag, so use the same flag for everything
                    For x2 = 1 To templistn
                        PassRule(TempList(x2)) = PassFlag
                    Next
                    PassFlag = PassFlag * 2
                Else
                    'The MustPassOpt is a {}block which doesn't need a flag, so everything else needs to
                    'reference it
                    For x2 = 1 To templistn
                        If TempList(x2) <> MustPassOpt Then PassRule(TempList(x2)) = -MustPassOpt
                    Next
                End If
            Else
                'if not, use a unique flag for everything in this block
                For x2 = 1 To templistn: PassRule(TempList(x2)) = PassFlag: Next
                If templistn <> 0 Then PassFlag = PassFlag * 2
            End If
            x1 = 0
        End If

        If scannextlevel = 0 Then Exit For
    Next

    For i = 1 To lastt: separgs(i) = "n-ll": Next

    'Consider: "?,[?]"
    'Notes: The comma is mandatory but the second ? is entirely optional
    'Consider: "[?[{B}?]{A}]?"
    'Notes: As unlikely as the above is, it is still valid, but pivots on the outcome of {A} being present
    'Consider: "[?]{A}"
    'Consider: "[?{A}][?{B}][?{C}]?"
    'Notes: The trick here is to realize {A} has greater priority than {B}, so all lines of enquiry must
    '       be exhausted before considering {B}

    'Use inquiry approach to solve format
    'Each line of inquiry must be exhausted
    'An expression ("?") simply means a branch where you can scan ahead

    Branches = 0
    Dim BranchFormatPos(1 To 100) As Long
    Dim BranchTaken(1 To 100) As Long
    '1=taken (this usually involves moving up a level)
    '0=not taken
    Dim BranchInputPos(1 To 100) As Long
    Dim BranchWithExpression(1 To 100) As Long
    'non-zero=expression expected before next item for format item value represents
    '0=no expression allowed before next item
    Dim BranchLevel(1 To 100) As Long 'Level before this branch was/wasn't taken

    n = numelements(ca$)
    i = 1 'Position within ca$

    level = 0
    Expression = 0
    For x = 1 To lastt

        ContinueScan:

        If DitchLev(x) < level Then 'dropping down to a lower level
            'we can only go as low as the 'ditch' will allow us, which will limit our options
            level = DitchLev(x)
        End If

        If EntryLev(x) <= level Then 'possible to enter level

            'But was this optional or were we forced to be on this level?
            If EntryLev(x) < Lev(x) Then
                optional = 1
                If level > EntryLev(x) Then optional = 0
            Else
                'entrylev=lev
                optional = 0
            End If

            t = T(x)

            If t = 0 Then 'A "?" expression
                If Expression Then
                    '*********backtrack************
                    'We are tracking an expression which we assumed would be present but was not
                    GoTo Backtrack
                    '******************************
                End If
                If optional Then
                    Branches = Branches + 1
                    BranchFormatPos(Branches) = x
                    BranchTaken(Branches) = 1
                    BranchInputPos(Branches) = i
                    BranchWithExpression(Branches) = 0
                    BranchLevel(Branches) = level
                    level = Lev(x)
                End If
                Expression = x
            End If 'A "?" expression

            If t Then

                currentlev = level

                'Add new branch if new level will be entered
                If optional Then
                    Branches = Branches + 1
                    BranchFormatPos(Branches) = x
                    BranchTaken(Branches) = 1
                    BranchInputPos(Branches) = i
                    BranchWithExpression(Branches) = Expression
                    BranchLevel(Branches) = level
                End If

                'Scan for Opt () options
                i1 = i: i2 = i
                If Expression Then i2 = n
                'Scan a$ for opt () x
                'Note: Finding the closest opt option is necessary
                'Note: This needs to be bracket sensitive
                OutOfRange = 2147483647
                position = OutOfRange
                which = 0
                removePrefix = 0
                If i <= n Then 'Past end of contect check
                    For o = 1 To t
                        words = OptWords(x, o)
                        b = 0
                        For i3 = i1 To i2
                            If i3 + words - 1 <= n Then 'enough elements exist
                                c$ = getelement$(a$, i3)
                                If b = 0 Then
                                    'Build comparison string (spacing elements)
                                    For w = 2 To words
                                        c$ = c$ + " " + getelement$(a$, i3 + w - 1)
                                    Next w
                                    'Compare
                                    If c$ = UCase$(RTrim$(Opt(x, o))) Then
                                        'Record Match
                                        If i3 < position Then
                                            position = i3
                                            which = o
                                            bvalue = b
                                            Exit For 'Exit the i3 loop
                                        End If 'position check
                                    End If 'match
                                End If

                                If Asc(c$) = 44 And b = 0 Then
                                    Exit For 'Expressions cannot contain a "," in their base level
                                    'Because this wasn't interceppted by the above code it isn't the Opt either
                                End If
                                If Asc(c$) = 40 Then
                                    b = b + 1
                                End If
                                If Asc(c$) = 41 Then
                                    b = b - 1
                                    If b = -1 Then Exit For 'Exited current bracketting level, making any following match invalid
                                End If

                            End If 'enough elements exist
                        Next i3
                    Next o
                End If 'Past end of contect check

                If position <> OutOfRange Then 'Found?
                    'Found...
                    level = Lev(x) 'Adjust level
                    If Expression Then
                        'Found...Expression...
                        'Has an expression been provided?
                        If position > i And bvalue = 0 Then
                            'Found...Expression...Provided...
                            separgs(Expression) = getelements$(ca$, i, position - 1)
                            Expression = 0
                            i = position
                        Else
                            'Found...Expression...Omitted...
                            '*********backtrack************
                            GoTo OptCheckBacktrack
                            '******************************
                        End If
                    End If 'Expression
                    i = i + OptWords(x, which)
                    separgslayout(x) = Chr$(Len(RTrim$(Opt(x, which))) - removePrefix) + SCase$(Mid$(RTrim$(Opt(x, which)), removePrefix + 1))
                    separgs(x) = Chr$(0) + str2(which)
                Else
                    'Not Found...
                    '*********backtrack************
                    OptCheckBacktrack:
                    'Was this optional?
                    If Lev(x) > EntryLev(x) Then 'Optional Opt ()?
                        'Not Found...Optional...
                        'Simply don't enter the optional higher level and continue as normal
                        BranchTaken(Branches) = 0
                        level = currentlev 'We aren't entering the level after all, so our level should remain at the opt's entrylevel
                    Else
                        Backtrack:
                        'Not Found...Mandatory...
                        '1)Erase previous branches where both options have been tried
                        For branch = Branches To 1 Step -1 'Remove branches until last taken branch is found
                            If BranchTaken(branch) Then Exit For
                            Branches = Branches - 1 'Remove branch (it has already been tried with both possible combinations)
                        Next
                        If Branches = 0 Then 'All options have been exhausted
                            seperateargs_error = 1
                            seperateargs_error_message = "Syntax error"
                            If Len(id2.hr_syntax) > 0 Then seperateargs_error_message = seperateargs_error_message + " - Reference: " + id2.hr_syntax
                            Exit Function
                        End If
                        '2)Toggle taken branch to untaken and revert
                        BranchTaken(Branches) = 0 'toggle branch to untaken
                        Expression = BranchWithExpression(Branches)
                        i = BranchInputPos(Branches)
                        x = BranchFormatPos(Branches)
                        level = BranchLevel(Branches)
                        '3)Erase any content created after revert position
                        If Expression Then separgs(Expression) = "n-ll"
                        For x2 = x To lastt
                            separgs(x2) = "n-ll"
                            separgslayout(x2) = ""
                        Next
                    End If 'Optional Opt ()?
                    '******************************

                End If 'Found?

            End If 't

        End If 'possible to enter level

    Next x

    'Final expression?
    If Expression Then
        If i <= n Then
            separgs(Expression) = getelements$(ca$, i, n)

            'can this be an expression?
            'check it passes bracketting and comma rules
            b = 0
            For i2 = i To n
                c$ = getelement$(a$, i2)
                If Asc(c$) = 44 And b = 0 Then
                    GoTo Backtrack
                End If
                If Asc(c$) = 40 Then
                    b = b + 1
                End If
                If Asc(c$) = 41 Then
                    b = b - 1
                    If b = -1 Then GoTo Backtrack
                End If
            Next
            If b <> 0 Then GoTo Backtrack

            i = n + 1 'So it passes the test below
        Else
            GoTo Backtrack
        End If
    End If 'Expression

    If i <> n + 1 Then GoTo Backtrack 'Trailing content?

    '   DIM PassRule(1 TO 100) AS LONG
    '   '0 means no pass rule
    '   'negative values refer to an opt () element
    '   'positive values refer to a flag value
    '   PassFlag = 1


    If PassFlag <> 1 Then seperateargs = 1 'Return whether a 'passed' flags variable is required
    pass& = 0 'The 'passed' value (shared by argument reference)

    'Note: The separgs() elements will be compacted to the C++ function arguments
    x = 1 'The new index to move compacted content to within separgs()

    For i = 1 To lastt

        If DontPass(i) = 0 Then

            If PassRule(i) > 0 Then
                If separgs(i) <> "n-ll" Then pass& = pass& Or PassRule(i) 'build 'passed' flags
            End If

            separgs(x) = separgs(i)
            separgslayout(x) = separgslayout(i)

            If Len(separgs(x)) Then
                If Asc(separgs(x)) = 0 Then
                    'switch omit layout tag from item to layout info
                    separgs(x) = Right$(separgs(x), Len(separgs(x)) - 1)
                    separgslayout(x) = separgslayout(x) + Chr$(0)
                End If
            End If

            If separgs(x) = "n-ll" Then separgs(x) = "N-LL"
            x = x + 1

        Else
            'its gonna be skipped!
            'add layout to the next one to be safe

            'for syntax such as [{HELLO}] which uses a flag instead of being passed
            If PassRule(i) > 0 Then
                If separgs(i) <> "n-ll" Then pass& = pass& Or PassRule(i) 'build 'passed' flags
            End If

            separgslayout(i + 1) = separgslayout(i) + separgslayout(i + 1)

        End If
    Next
    separgslayout(x) = separgslayout(i) 'set final layout

    'x = x - 1
    'PRINT "total arguments:"; x
    'PRINT "pass omit (0/1):"; omit
    'PRINT "pass&="; pass&

End Function

Sub setrefer (a2$, typ2 As Long, e2$, method As Long)
    a$ = a2$: typ = typ2: e$ = e2$
    If method <> 1 Then e$ = fixoperationorder$(e$)
    If Error_Happened Then Exit Sub
    tl$ = tlayout$

    'method: 0 evaulatetotyp e$
    '        1 skip evaluation of e$ and use as is
    '*due to the complexity of setting a reference with a value/string
    ' this function handles the problem

    'retrieve ID
    i = InStr(a$, sp3)
    If i Then
        idnumber = Val(Left$(a$, i - 1)): a$ = Right$(a$, Len(a$) - i)
    Else
        idnumber = Val(a$)
    End If
    getid idnumber
    If Error_Happened Then Exit Sub

    'UDT?
    If typ And ISUDT Then

        'print "setrefer-ing a UDT!"
        u = Val(a$)
        i = InStr(a$, sp3): a$ = Right$(a$, Len(a$) - i): E = Val(a$)
        i = InStr(a$, sp3): o$ = Right$(a$, Len(a$) - i)
        n$ = "UDT_" + RTrim$(id.n): If id.t = 0 Then n$ = "ARRAY_" + n$ + "[0]"

        If E <> 0 And u = 1 Then 'Setting _MEM type elements is not allowed!
            Give_Error "Cannot set read-only element of _MEM TYPE": Exit Sub
        End If

        If E = 0 Then
            'use u and u's size

            If method <> 0 Then Give_Error "Unexpected internal code reference to UDT": Exit Sub
            lhsscope$ = scope$
            e$ = evaluate(e$, t2)
            If Error_Happened Then Exit Sub
            If (t2 And ISUDT) = 0 Then Give_Error "Expected = similar user defined type": Exit Sub

            If (t2 And ISREFERENCE) = 0 Then
                If t2 And ISPOINTER Then
                    src$ = "((char*)" + e$ + ")"
                    e2 = 0: u2 = t2 And 511
                Else
                    src$ = "((char*)&" + e$ + ")"
                    e2 = 0: u2 = t2 And 511
                End If
                GoTo directudt
            End If

            '****problem****
            idnumber2 = Val(e$)
            getid idnumber2


            If Error_Happened Then Exit Sub
            n2$ = "UDT_" + RTrim$(id.n): If id.t = 0 Then n2$ = "ARRAY_" + n2$ + "[0]"
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i): u2 = Val(e$)
            i = InStr(e$, sp3): e$ = Right$(e$, Len(e$) - i): e2 = Val(e$)
            i = InStr(e$, sp3): o2$ = Right$(e$, Len(e$) - i)
            'WARNING: u2 may need minor modifications based on e to see if they are the same

            'we have now established we have 2 pointers to similar data types!
            'ASSUME BYTE TYPE!!!
            src$ = "((char*)" + scope$ + n2$ + ")+(" + o2$ + ")"
            directudt:
            If u <> u2 Or e2 <> 0 Then Give_Error "Expected = similar user defined type": Exit Sub
            dst$ = "((char*)" + lhsscope$ + n$ + ")+(" + o$ + ")"
            copy_full_udt dst$, src$, 12, 0, u

            'print "setFULLUDTrefer!"

            tlayout$ = tl$
            Exit Sub

        End If 'e=0

        If typ And ISOFFSETINBITS Then Give_Error "Cannot resolve bit-length variables inside user defined types": Exit Sub
        If typ And ISSTRING Then
            If typ And ISFIXEDLENGTH Then
                o2$ = "(((uint8*)" + scope$ + n$ + ")+(" + o$ + "))"
                r$ = "qbs_new_fixed(" + o2$ + "," + str2(udtetypesize(E)) + ",1)"
            Else
                r$ = "*((qbs**)((char*)(" + scope$ + n$ + ")+(" + o$ + ")))"
            End If
            If method = 0 Then e$ = evaluatetotyp(e$, STRINGTYPE - ISPOINTER)
            If Error_Happened Then Exit Sub
            Print #12, "qbs_set(" + r$ + "," + e$ + ");"
            Print #12, cleanupstringprocessingcall$ + "0);"
        Else
            typ = typ - ISUDT - ISREFERENCE - ISPOINTER
            If typ And ISARRAY Then typ = typ - ISARRAY
            t$ = typ2ctyp$(typ, "")
            If Error_Happened Then Exit Sub
            o2$ = "(((char*)" + scope$ + n$ + ")+(" + o$ + "))"
            r$ = "*" + "(" + t$ + "*)" + o2$
            If method = 0 Then e$ = evaluatetotyp(e$, typ)
            If Error_Happened Then Exit Sub
            Print #12, r$ + "=" + e$ + ";"
        End If

        'print "setUDTrefer:"+r$,e$
        tlayout$ = tl$
        If Left$(r$, 1) = "*" Then r$ = Mid$(r$, 2)
        Exit Sub
    End If


    'array?
    If id.arraytype Then
        n$ = RTrim$(id.callname)
        typ = typ - ISPOINTER - ISREFERENCE 'typ now looks like a regular value

        If (typ And ISSTRING) Then
            If (typ And ISFIXEDLENGTH) Then
                offset$ = "&((uint8*)(" + n$ + "[0]))[tmp_long*" + str2(id.tsize) + "]"
                r$ = "qbs_new_fixed(" + offset$ + "," + str2(id.tsize) + ",1)"
                Print #12, "tmp_long=" + a$ + ";"
                If method = 0 Then
                    l$ = "if (!new_error) qbs_set(" + r$ + "," + evaluatetotyp(e$, typ) + ");"
                    If Error_Happened Then Exit Sub
                Else
                    l$ = "if (!new_error) qbs_set(" + r$ + "," + e$ + ");"
                End If
                Print #12, l$
            Else
                Print #12, "tmp_long=" + a$ + ";"
                If method = 0 Then
                    l$ = "if (!new_error) qbs_set( ((qbs*)(((uint64*)(" + n$ + "[0]))[tmp_long]))," + evaluatetotyp(e$, typ) + ");"
                    If Error_Happened Then Exit Sub
                Else
                    l$ = "if (!new_error) qbs_set( ((qbs*)(((uint64*)(" + n$ + "[0]))[tmp_long]))," + e$ + ");"
                End If
                Print #12, l$
            End If
            Print #12, cleanupstringprocessingcall$ + "0);"
            tlayout$ = tl$
            If Left$(r$, 1) = "*" Then r$ = Mid$(r$, 2)
            Exit Sub
        End If

        If (typ And ISOFFSETINBITS) Then
            'r$ = "setbits_" + str2(typ AND 511) + "("
            r$ = "setbits(" + str2(typ And 511) + ","
            r$ = r$ + "(uint8*)(" + n$ + "[0])" + ",tmp_long,"
            Print #12, "tmp_long=" + a$ + ";"
            If method = 0 Then
                l$ = "if (!new_error) " + r$ + evaluatetotyp(e$, typ) + ");"
                If Error_Happened Then Exit Sub
            Else
                l$ = "if (!new_error) " + r$ + e$ + ");"
            End If
            Print #12, l$
            tlayout$ = tl$
            Exit Sub
        Else
            t$ = ""
            If (typ And ISFLOAT) Then
                If (typ And 511) = 32 Then t$ = "float"
                If (typ And 511) = 64 Then t$ = "double"
                If (typ And 511) = 256 Then t$ = "long double"
            Else
                If (typ And ISUNSIGNED) Then
                    If (typ And 511) = 8 Then t$ = "uint8"
                    If (typ And 511) = 16 Then t$ = "uint16"
                    If (typ And 511) = 32 Then t$ = "uint32"
                    If (typ And 511) = 64 Then t$ = "uint64"
                    If typ And ISOFFSET Then t$ = "uptrszint"
                Else
                    If (typ And 511) = 8 Then t$ = "int8"
                    If (typ And 511) = 16 Then t$ = "int16"
                    If (typ And 511) = 32 Then t$ = "int32"
                    If (typ And 511) = 64 Then t$ = "int64"
                    If typ And ISOFFSET Then t$ = "ptrszint"
                End If
            End If
        End If
        If t$ = "" Then Give_Error "Cannot find C type to return array data": Exit Sub
        Print #12, "tmp_long=" + a$ + ";"
        If method = 0 Then
            l$ = "if (!new_error) ((" + t$ + "*)(" + n$ + "[0]))[tmp_long]=" + evaluatetotyp(e$, typ) + ";"
            If Error_Happened Then Exit Sub
        Else
            l$ = "if (!new_error) ((" + t$ + "*)(" + n$ + "[0]))[tmp_long]=" + e$ + ";"
        End If

        Print #12, l$
        tlayout$ = tl$
        Exit Sub
    End If 'array

    'variable?
    If id.t Then
        r$ = RTrim$(id.n)
        t = id.t
        'remove irrelavant flags
        If (t And ISINCONVENTIONALMEMORY) Then t = t - ISINCONVENTIONALMEMORY
        typ = t

        'string variable?
        If (t And ISSTRING) Then
            If (t And ISFIXEDLENGTH) Then
                r$ = scope$ + "STRING" + str2(id.tsize) + "_" + r$
            Else
                r$ = scope$ + "STRING_" + r$
            End If
            If method = 0 Then e$ = evaluatetotyp(e$, ISSTRING)
            If Error_Happened Then Exit Sub
            Print #12, "qbs_set(" + r$ + "," + e$ + ");"
            Print #12, cleanupstringprocessingcall$ + "0);"
            If arrayprocessinghappened Then arrayprocessinghappened = 0
            tlayout$ = tl$
            If Left$(r$, 1) = "*" Then r$ = Mid$(r$, 2)
            Exit Sub
        End If

        'bit-length variable?
        If (t And ISOFFSETINBITS) Then
            b = t And 511
            If (t And ISUNSIGNED) Then
                r$ = "*" + scope$ + "UBIT" + str2(t And 511) + "_" + r$
                If method = 0 Then e$ = evaluatetotyp(e$, 64& + ISUNSIGNED)
                If Error_Happened Then Exit Sub
                l$ = r$ + "=(" + e$ + ")&" + str2(bitmask(b)) + ";"
                Print #12, l$
            Else
                r$ = "*" + scope$ + "BIT" + str2(t And 511) + "_" + r$
                If method = 0 Then e$ = evaluatetotyp(e$, 64&)
                If Error_Happened Then Exit Sub
                l$ = "if ((" + r$ + "=" + e$ + ")&" + str2(2 ^ (b - 1)) + "){"
                Print #12, l$
                'signed bit is set
                l$ = r$ + "|=" + str2(bitmaskinv(b)) + ";"
                Print #12, l$
                Print #12, "}else{"
                'signed bit is not set
                l$ = r$ + "&=" + str2(bitmask(b)) + ";"
                Print #12, l$
                Print #12, "}"
            End If
            If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);": stringprocessinghappened = 0
            If arrayprocessinghappened Then arrayprocessinghappened = 0
            tlayout$ = tl$
            If Left$(r$, 1) = "*" Then r$ = Mid$(r$, 2)
            Exit Sub
        End If

        'standard variable?
        If t = BYTETYPE Then r$ = "*" + scope$ + "BYTE_" + r$: GoTo sref
        If t = UBYTETYPE Then r$ = "*" + scope$ + "UBYTE_" + r$: GoTo sref
        If t = INTEGERTYPE Then r$ = "*" + scope$ + "INTEGER_" + r$: GoTo sref
        If t = UINTEGERTYPE Then r$ = "*" + scope$ + "UINTEGER_" + r$: GoTo sref
        If t = LONGTYPE Then r$ = "*" + scope$ + "LONG_" + r$: GoTo sref
        If t = ULONGTYPE Then r$ = "*" + scope$ + "ULONG_" + r$: GoTo sref
        If t = INTEGER64TYPE Then r$ = "*" + scope$ + "INTEGER64_" + r$: GoTo sref
        If t = UINTEGER64TYPE Then r$ = "*" + scope$ + "UINTEGER64_" + r$: GoTo sref
        If t = SINGLETYPE Then r$ = "*" + scope$ + "SINGLE_" + r$: GoTo sref
        If t = DOUBLETYPE Then r$ = "*" + scope$ + "DOUBLE_" + r$: GoTo sref
        If t = FLOATTYPE Then r$ = "*" + scope$ + "FLOAT_" + r$: GoTo sref
        If t = OFFSETTYPE Then r$ = "*" + scope$ + "OFFSET_" + r$: GoTo sref
        If t = UOFFSETTYPE Then r$ = "*" + scope$ + "UOFFSET_" + r$: GoTo sref
        sref:
        t2 = t - ISPOINTER
        If method = 0 Then e$ = evaluatetotyp(e$, t2)
        If Error_Happened Then Exit Sub
        l$ = r$ + "=" + e$ + ";"
        Print #12, l$
        If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);": stringprocessinghappened = 0
        If arrayprocessinghappened Then arrayprocessinghappened = 0
        tlayout$ = tl$

        If Left$(r$, 1) = "*" Then r$ = Mid$(r$, 2)
        Exit Sub
    End If 'variable

    tlayout$ = tl$
End Sub

Function str2$ (v As Long)
    str2$ = _Trim$(Str$(v))
End Function

Function str2u64$ (v~&&)
    str2u64$ = LTrim$(RTrim$(Str$(v~&&)))
End Function

Function str2i64$ (v&&)
    str2i64$ = LTrim$(RTrim$(Str$(v&&)))
End Function

Function typ2ctyp$ (t As Long, tstr As String)
    ctyp$ = ""
    'typ can be passed as either: (the unused value is ignored)
    'i. as a typ value in t
    'ii. as a typ symbol (eg. "~%") in tstr
    'iii. as a typ name (eg. _UNSIGNED INTEGER) in tstr
    If tstr$ = "" Then
        If (t And ISARRAY) Then Exit Function 'cannot return array types
        If (t And ISSTRING) Then typ2ctyp$ = "qbs": Exit Function
        b = t And 511
        If (t And ISUDT) Then typ2ctyp$ = "void": Exit Function
        If (t And ISOFFSETINBITS) Then
            If b <= 32 Then ctyp$ = "int32" Else ctyp$ = "int64"
            If (t And ISUNSIGNED) Then ctyp$ = "u" + ctyp$
            typ2ctyp$ = ctyp$: Exit Function
        End If
        If (t And ISFLOAT) Then
            If b = 32 Then ctyp$ = "float"
            If b = 64 Then ctyp$ = "double"
            If b = 256 Then ctyp$ = "long double"
        Else
            If b = 8 Then ctyp$ = "int8"
            If b = 16 Then ctyp$ = "int16"
            If b = 32 Then ctyp$ = "int32"
            If b = 64 Then ctyp$ = "int64"
            If t And ISOFFSET Then ctyp$ = "ptrszint"
            If (t And ISUNSIGNED) Then ctyp$ = "u" + ctyp$
        End If
        If t And ISOFFSET Then
            ctyp$ = "ptrszint": If (t And ISUNSIGNED) Then ctyp$ = "uptrszint"
        End If
        typ2ctyp$ = ctyp$: Exit Function
    End If

    ts$ = tstr$
    'is ts$ a symbol?
    If ts$ = "$" Then ctyp$ = "qbs"
    If ts$ = "!" Then ctyp$ = "float"
    If ts$ = "#" Then ctyp$ = "double"
    If ts$ = "##" Then ctyp$ = "long double"
    If Left$(ts$, 1) = "~" Then unsgn = 1: ts$ = Right$(ts$, Len(ts$) - 1)
    If Left$(ts$, 1) = "`" Then
        n$ = Right$(ts$, Len(ts$) - 1)
        b = 1
        If n$ <> "" Then
            If isuinteger(n$) = 0 Then Give_Error "Invalid index after _BIT type": Exit Function
            b = Val(n$)
            If b > 64 Then Give_Error "Invalid index after _BIT type": Exit Function
        End If
        If b <= 32 Then ctyp$ = "int32" Else ctyp$ = "int64"
        If unsgn Then ctyp$ = "u" + ctyp$
        typ2ctyp$ = ctyp$: Exit Function
    End If
    If ts$ = "%&" Then
        typ2ctyp$ = "ptrszint": If (t And ISUNSIGNED) Then typ2ctyp$ = "uptrszint"
        Exit Function
    End If
    If ts$ = "%%" Then ctyp$ = "int8"
    If ts$ = "%" Then ctyp$ = "int16"
    If ts$ = "&" Then ctyp$ = "int32"
    If ts$ = "&&" Then ctyp$ = "int64"
    If ctyp$ <> "" Then
        If unsgn Then ctyp$ = "u" + ctyp$
        typ2ctyp$ = ctyp$: Exit Function
    End If
    'is tstr$ a named type? (eg. 'LONG')
    s$ = type2symbol$(tstr$)
    If Error_Happened Then Exit Function
    If Len(s$) Then
        typ2ctyp$ = typ2ctyp$(0, s$)
        If Error_Happened Then Exit Function
        Exit Function
    End If

    Give_Error "Invalid type": Exit Function

End Function

Function type2symbol$ (typ$)
    t$ = typ$
    For i = 1 To Len(t$)
        If Mid$(t$, i, 1) = sp Then Mid$(t$, i, 1) = " "
    Next
    e$ = "Cannot convert type (" + typ$ + ") to symbol"
    t2$ = "_UNSIGNED _BIT": s$ = "~`1": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_UNSIGNED _BYTE": s$ = "~%%": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_UNSIGNED LONG": s$ = "~&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_UNSIGNED _INTEGER64": s$ = "~&&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_UNSIGNED INTEGER": s$ = "~%": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_UNSIGNED _OFFSET": s$ = "~%&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_BIT": s$ = "`1": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_BYTE": s$ = "%%": If t$ = t2$ Then GoTo t2sfound
    t2$ = "LONG": s$ = "&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_INTEGER64": s$ = "&&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_OFFSET": s$ = "%&": If t$ = t2$ Then GoTo t2sfound
    t2$ = "SINGLE": s$ = "!": If t$ = t2$ Then GoTo t2sfound
    t2$ = "DOUBLE": s$ = "#": If t$ = t2$ Then GoTo t2sfound
    t2$ = "_FLOAT": s$ = "##": If t$ = t2$ Then GoTo t2sfound
    t2$ = "STRING": s$ = "$": If t$ = t2$ Then GoTo t2sfound
    t2$ = "INTEGER": s$ = "%": If t$ = t2$ Then GoTo t2sfound
    Give_Error e$: Exit Function
    t2sfound:
    type2symbol$ = s$
    If Len(t2$) <> Len(t$) Then
        If s$ <> "$" And s$ <> "~`1" And s$ <> "`1" Then Give_Error e$: Exit Function
        t$ = Right$(t$, Len(t$) - Len(t2$))
        If Left$(t$, 3) <> " * " Then Give_Error e$: Exit Function
        t$ = Right$(t$, Len(t$) - 3)
        If isuinteger(t$) = 0 Then Give_Error e$: Exit Function
        v = Val(t$)
        If v = 0 Then Give_Error e$: Exit Function
        If s$ <> "$" And v > 64 Then Give_Error e$: Exit Function
        If s$ = "$" Then
            s$ = s$ + str2$(v)
        Else
            s$ = Left$(s$, Len(s$) - 1) + str2$(v)
        End If
        type2symbol$ = s$
    End If
End Function

'Strips away bits/indentifiers which make locating a variables source difficult
Function typecomp (typ)
    typ2 = typ
    If (typ2 And ISINCONVENTIONALMEMORY) Then typ2 = typ2 - ISINCONVENTIONALMEMORY
    typecomp = typ2
End Function

Function typname2typ& (t2$)
    typname2typsize = 0 'the default

    t$ = t2$

    'symbol?
    ts$ = t$
    If ts$ = "$" Then typname2typ& = STRINGTYPE: Exit Function
    If ts$ = "!" Then typname2typ& = SINGLETYPE: Exit Function
    If ts$ = "#" Then typname2typ& = DOUBLETYPE: Exit Function
    If ts$ = "##" Then typname2typ& = FLOATTYPE: Exit Function

    'fixed length string?
    If Left$(ts$, 1) = "$" Then
        n$ = Right$(ts$, Len(ts$) - 1)
        If isuinteger(n$) = 0 Then Give_Error "Invalid index after STRING * type": Exit Function
        b = Val(n$)
        If b = 0 Then Give_Error "Invalid index after STRING * type": Exit Function
        typname2typsize = b
        typname2typ& = STRINGTYPE + ISFIXEDLENGTH
        Exit Function
    End If

    'unsigned?
    If Left$(ts$, 1) = "~" Then unsgn = 1: ts$ = Right$(ts$, Len(ts$) - 1)

    'bit-type?
    If Left$(ts$, 1) = "`" Then
        n$ = Right$(ts$, Len(ts$) - 1)
        b = 1
        If n$ <> "" Then
            If isuinteger(n$) = 0 Then Give_Error "Invalid index after _BIT type": Exit Function
            b = Val(n$)
            If b > 64 Then Give_Error "Invalid index after _BIT type": Exit Function
        End If
        If unsgn Then typname2typ& = UBITTYPE + (b - 1) Else typname2typ& = BITTYPE + (b - 1)
        Exit Function
    End If

    t = 0
    If ts$ = "%%" Then t = BYTETYPE
    If ts$ = "%" Then t = INTEGERTYPE
    If ts$ = "&" Then t = LONGTYPE
    If ts$ = "&&" Then t = INTEGER64TYPE
    If ts$ = "%&" Then t = OFFSETTYPE

    If t Then
        If unsgn Then t = t + ISUNSIGNED
        typname2typ& = t: Exit Function
    End If
    'not a valid symbol

    'type name?
    For i = 1 To Len(t$)
        If Mid$(t$, i, 1) = sp Then Mid$(t$, i, 1) = " "
    Next
    If t$ = "STRING" Then typname2typ& = STRINGTYPE: Exit Function

    If Left$(t$, 9) = "STRING * " Then

        n$ = Right$(t$, Len(t$) - 9)

        'constant check 2011
        hashfound = 0
        hashname$ = n$
        hashchkflags = HASHFLAG_CONSTANT
        hashres = HashFindRev(hashname$, hashchkflags, hashresflags, hashresref)
        Do While hashres
            If constsubfunc(hashresref) = subfuncn Or constsubfunc(hashresref) = 0 Then
                If constdefined(hashresref) Then
                    hashfound = 1
                    Exit Do
                End If
            End If
            If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
        Loop
        If hashfound Then
            i2 = hashresref
            t = consttype(i2)
            If t And ISSTRING Then Give_Error "Expected STRING * numeric-constant": Exit Function
            'convert value to general formats
            If t And ISFLOAT Then
                v## = constfloat(i2)
                v&& = v##
                v~&& = v&&
            Else
                If t And ISUNSIGNED Then
                    v~&& = constuinteger(i2)
                    v&& = v~&&
                    v## = v&&
                Else
                    v&& = constinteger(i2)
                    v## = v&&
                    v~&& = v&&
                End If
            End If
            If v&& < 1 Or v&& > 9999999999 Then Give_Error "STRING * out-of-range constant": Exit Function
            b = v&&
            GoTo constantlenstr
        End If

        If isuinteger(n$) = 0 Or Len(n$) > 10 Then Give_Error "Invalid number/constant after STRING * type": Exit Function
        b = Val(n$)
        If b = 0 Or Len(n$) > 10 Then Give_Error "Invalid number after STRING * type": Exit Function
        constantlenstr:
        typname2typsize = b
        typname2typ& = STRINGTYPE + ISFIXEDLENGTH
        Exit Function
    End If

    If t$ = "SINGLE" Then typname2typ& = SINGLETYPE: Exit Function
    If t$ = "DOUBLE" Then typname2typ& = DOUBLETYPE: Exit Function
    If t$ = "_FLOAT" Then typname2typ& = FLOATTYPE: Exit Function
    If Left$(t$, 10) = "_UNSIGNED " Then
        u = 1
        t$ = Mid$(t$, InStr(t$, Chr$(32)) + 1)
    End If
    If Left$(t$, 4) = "_BIT" Then
        If t$ = "_BIT" Then
            If u Then typname2typ& = UBITTYPE Else typname2typ& = BITTYPE
            Exit Function
        End If
        If Left$(t$, 7) <> "_BIT * " Then Give_Error "Expected _BIT * number": Exit Function

        n$ = Right$(t$, Len(t$) - 7)
        If isuinteger(n$) = 0 Then Give_Error "Invalid size after " + qb64prefix$ + "BIT *": Exit Function
        b = Val(n$)
        If b = 0 Or b > 64 Then Give_Error "Invalid size after " + qb64prefix$ + "BIT *": Exit Function
        t = BITTYPE - 1 + b: If u Then t = t + ISUNSIGNED
        typname2typ& = t
        Exit Function
    End If

    t = 0
    If t$ = "_BYTE" Then t = BYTETYPE
    If t$ = "INTEGER" Then t = INTEGERTYPE
    If t$ = "LONG" Then t = LONGTYPE
    If t$ = "_INTEGER64" Then t = INTEGER64TYPE
    If t$ = "_OFFSET" Then t = OFFSETTYPE
    If t Then
        If u Then t = t + ISUNSIGNED
        typname2typ& = t
        Exit Function
    End If
    If u Then Exit Function '_UNSIGNED (nothing)

    'UDT?
    For i = 1 To lasttype
        If t$ = RTrim$(udtxname(i)) Then
            typname2typ& = ISUDT + ISPOINTER + i
            Exit Function
        End If
    Next

    'return 0 (failed)
End Function

Function uniquenumber&
    uniquenumbern = uniquenumbern + 1
    uniquenumber& = uniquenumbern
End Function

Function validlabel (LABEL2$)
    create = CreatingLabel: CreatingLabel = 0
    validlabel = 0
    If Len(LABEL2$) = 0 Then Exit Function
    clabel$ = LABEL2$
    label$ = UCase$(LABEL2$)

    n = numelements(label$)

    If n = 1 Then

        'Note: Reserved words and internal sub/function names are invalid
        hashres = HashFind(label$, HASHFLAG_RESERVED + HASHFLAG_SUB + HASHFLAG_FUNCTION, hashresflags, hashresref)
        Do While hashres
            If hashresflags And (HASHFLAG_SUB + HASHFLAG_FUNCTION) Then
                If ids(hashresref).internal_subfunc Then Exit Function

                If hashresflags And HASHFLAG_SUB Then 'could be a label or a sub call!

                    'analyze format
                    If Asc(ids(hashresref).specialformat) = 32 Then
                        If ids(hashresref).args = 0 Then onecommandsub = 1 Else onecommandsub = 0
                    Else
                        If Asc(ids(hashresref).specialformat) <> 91 Then '"["
                            onecommandsub = 0
                        Else
                            onecommandsub = 1
                            a$ = RTrim$(ids(hashresref).specialformat)
                            b = 1
                            For x = 2 To Len(a$)
                                a = Asc(a$, x)
                                If a = 91 Then b = b + 1
                                If a = 93 Then b = b - 1
                                If b = 0 And x <> Len(a$) Then onecommandsub = 0: Exit For
                            Next
                        End If
                    End If
                    If create <> 0 And onecommandsub = 1 Then
                        If InStr(SubNameLabels$, sp + UCase$(label$) + sp) = 0 Then PossibleSubNameLabels$ = PossibleSubNameLabels$ + UCase$(label$) + sp: Exit Function 'treat as sub call
                    End If

                End If 'sub name

            Else
                'reserved
                Exit Function
            End If
            If hashres <> 1 Then hashres = HashFindCont(hashresflags, hashresref) Else hashres = 0
        Loop

        'Numeric label?
        'quasi numbers are possible, but:
        'a) They may only have one decimal place
        'b) They must be typed with the exact same characters to match
        t$ = label$
        'numeric?
        a = Asc(t$)
        If (a >= 48 And a <= 57) Or a = 46 Then

            'refer to original formatting if possible (eg. 1.10 not 1.1)
            x = InStr(t$, Chr$(44))
            If x Then
                t$ = Right$(t$, Len(t$) - x)
            End If

            'note: The symbols ! and # are valid trailing symbols in QBASIC, regardless of the number's size,
            '      so they are allowed in QB64 for compatibility reasons
            addsymbol$ = removesymbol$(t$)
            If Error_Happened Then Exit Function
            If Len(addsymbol$) Then
                If InStr(addsymbol$, "$") Then Exit Function
                If addsymbol$ <> "#" And addsymbol$ <> "!" Then addsymbol$ = ""
            End If

            If a = 46 Then dp = 1
            For x = 2 To Len(t$)
                a = Asc(Mid$(t$, x, 1))
                If a = 46 Then dp = dp + 1
                If (a < 48 Or a > 57) And a <> 46 Then Exit Function 'not numeric
            Next x
            If dp > 1 Then Exit Function 'too many decimal points
            If dp = 1 And Len(t$) = 1 Then Exit Function 'cant have '.' as a label

            tlayout$ = t$ + addsymbol$

            i = InStr(t$, "."): If i Then Mid$(t$, i, 1) = "p"
            If addsymbol$ = "#" Then t$ = t$ + "d"
            If addsymbol$ = "!" Then t$ = t$ + "s"

            If Len(t$) > 40 Then Exit Function

            LABEL2$ = t$
            validlabel = 1
            Exit Function
        End If 'numeric

    End If 'n=1

    'Alpha-numeric label?
    'Build label

    'structure check (???.???.???.???)
    If (n And 1) = 0 Then Exit Function 'must be an odd number of elements
    For nx = 2 To n - 1 Step 2
        a$ = getelement$(LABEL2$, nx)
        If a$ <> "." Then Exit Function 'every 2nd element must be a period
    Next

    'cannot begin with numeric
    c = Asc(clabel$): If c >= 48 And c <= 57 Then Exit Function

    'elements check
    label3$ = ""
    For nx = 1 To n Step 2
        label$ = getelement$(clabel$, nx)

        'alpha-numeric?
        For x = 1 To Len(label$)
            If alphanumeric(Asc(label$, x)) = 0 Then Exit Function
        Next

        'build label
        If label3$ = "" Then label3$ = UCase$(label$): tlayout$ = label$ Else label3$ = label3$ + fix046$ + UCase$(label$): tlayout$ = tlayout$ + "." + label$
    Next nx

    validlabel = 1
    LABEL2$ = label3$
End Function

Sub xend
    Print #12, "sub_end();"
End Sub

Sub xfileprint (a$, ca$, n)
    u$ = str2$(uniquenumber)
    Print #12, "tab_spc_cr_size=2;"
    If n = 2 Then Give_Error "Expected # ... , ...": Exit Sub
    a3$ = ""
    b = 0
    For i = 3 To n
        a2$ = getelement$(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If a2$ = "," And b = 0 Then
            If a3$ = "" Then Give_Error "Expected # ... , ...": Exit Sub
            GoTo printgotfn
        End If
        If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
    Next
    Give_Error "Expected # ... ,": Exit Sub
    printgotfn:
    e$ = fixoperationorder$(a3$)
    If Error_Happened Then Exit Sub
    l$ = SCase$("Print") + sp + "#" + sp2 + tlayout$ + sp2 + ","
    e$ = evaluatetotyp(e$, 64&)
    If Error_Happened Then Exit Sub
    Print #12, "tab_fileno=tmp_fileno=" + e$ + ";"
    Print #12, "if (new_error) goto skip" + u$ + ";"
    i = i + 1

    'PRINT USING? (file)
    If n >= i Then
        If getelement(a$, i) = "USING" Then
            'get format string
            fpujump:
            l$ = l$ + sp + SCase$("Using")
            e$ = "": b = 0: puformat$ = ""
            For i = i + 1 To n
                a2$ = getelement(ca$, i)
                If a2$ = "(" Then b = b + 1
                If a2$ = ")" Then b = b - 1
                If b = 0 Then
                    If a2$ = "," Then Give_Error "Expected PRINT USING #filenumber, formatstring ; ...": Exit Sub
                    If a2$ = ";" Then
                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then Exit Sub
                        l$ = l$ + sp + tlayout$ + sp2 + ";"
                        e$ = evaluate(e$, typ)
                        If Error_Happened Then Exit Sub
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then Exit Sub
                        If (typ And ISSTRING) = 0 Then Give_Error "Expected PRINT USING #filenumber, formatstring ; ...": Exit Sub
                        puformat$ = e$
                        Exit For
                    End If ';
                End If 'b
                If Len(e$) Then e$ = e$ + sp + a2$ Else e$ = a2$
            Next
            If puformat$ = "" Then Give_Error "Expected PRINT USING #filenumber, formatstring ; ...": Exit Sub
            If i = n Then Give_Error "Expected PRINT USING #filenumber, formatstring ; ...": Exit Sub
            'create build string
            Print #12, "tqbs=qbs_new(0,0);"
            'set format start/index variable
            Print #12, "tmp_long=0;" 'scan format from beginning
            'create string to hold format in for multiple references
            puf$ = "print_using_format" + u$
            If subfunc = "" Then
                Print #13, "static qbs *" + puf$ + ";"
            Else
                Print #13, "qbs *" + puf$ + ";"
            End If
            Print #12, puf$ + "=qbs_new(0,0); qbs_set(" + puf$ + "," + puformat$ + ");"
            Print #12, "if (new_error) goto skip" + u$ + ";"
            'print expressions
            b = 0
            e$ = ""
            last = 0
            For i = i + 1 To n
                a2$ = getelement(ca$, i)
                If a2$ = "(" Then b = b + 1
                If a2$ = ")" Then b = b - 1
                If b = 0 Then
                    If a2$ = ";" Or a2$ = "," Then
                        fprintulast:
                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then Exit Sub
                        If last Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp + tlayout$ + sp2 + a2$
                        e$ = evaluate(e$, typ)
                        If Error_Happened Then Exit Sub
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then Exit Sub
                        If typ And ISSTRING Then

                            If Left$(e$, 9) = "func_tab(" Or Left$(e$, 9) = "func_spc(" Then

                                'TAB/SPC exception
                                'note: position in format-string must be maintained
                                '-print any string up until now
                                Print #12, "sub_file_print(tmp_fileno,tqbs,0,0,0);"
                                '-print e$
                                Print #12, "qbs_set(tqbs," + e$ + ");"
                                Print #12, "if (new_error) goto skip_pu" + u$ + ";"
                                Print #12, "sub_file_print(tmp_fileno,tqbs,0,0,0);"
                                '-set length of tqbs to 0
                                Print #12, "tqbs->len=0;"

                            Else

                                'regular string
                                Print #12, "tmp_long=print_using(" + puf$ + ",tmp_long,tqbs," + e$ + ");"

                            End If

                        Else 'not a string
                            If typ And ISFLOAT Then
                                If (typ And 511) = 32 Then Print #12, "tmp_long=print_using_single(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                If (typ And 511) = 64 Then Print #12, "tmp_long=print_using_double(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                If (typ And 511) > 64 Then Print #12, "tmp_long=print_using_float(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                            Else
                                If ((typ And 511) = 64) And (typ And ISUNSIGNED) <> 0 Then
                                    Print #12, "tmp_long=print_using_uinteger64(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                Else
                                    Print #12, "tmp_long=print_using_integer64(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                End If
                            End If
                        End If 'string/not string
                        Print #12, "if (new_error) goto skip_pu" + u$ + ";"
                        e$ = ""
                        If last Then Exit For
                        GoTo fprintunext
                    End If
                End If
                If Len(e$) Then e$ = e$ + sp + a2$ Else e$ = a2$
                fprintunext:
            Next
            If e$ <> "" Then a2$ = "": last = 1: GoTo fprintulast
            Print #12, "skip_pu" + u$ + ":"
            'check for errors
            Print #12, "if (new_error){"
            Print #12, "g_tmp_long=new_error; new_error=0; sub_file_print(tmp_fileno,tqbs,0,0,0); new_error=g_tmp_long;"
            Print #12, "}else{"
            If a2$ = "," Or a2$ = ";" Then nl = 0 Else nl = 1 'note: a2$ is set to the last element of a$
            Print #12, "sub_file_print(tmp_fileno,tqbs,0,0," + str2$(nl) + ");"
            Print #12, "}"
            Print #12, "qbs_free(tqbs);"
            Print #12, "qbs_free(" + puf$ + ");"
            Print #12, "skip" + u$ + ":"
            Print #12, cleanupstringprocessingcall$ + "0);"
            Print #12, "tab_spc_cr_size=1;"
            tlayout$ = l$
            Exit Sub
        End If
    End If
    'end of print using code

    If i > n Then
        Print #12, "sub_file_print(tmp_fileno,nothingstring,0,0,1);"
        GoTo printblankline
    End If
    b = 0
    e$ = ""
    last = 0
    For i = i To n
        a2$ = getelement(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If b = 0 Then
            If a2$ = ";" Or a2$ = "," Or UCase$(a2$) = "USING" Then
                printfilelast:

                If UCase$(a2$) = "USING" Then
                    If e$ <> "" Then gotofpu = 1 Else GoTo fpujump
                End If

                If a2$ = "," Then usetab = 1 Else usetab = 0
                If last = 1 Then newline = 1 Else newline = 0
                extraspace = 0

                If Len(e$) Then
                    ebak$ = e$
                    pnrtnum = 0
                    printfilenumber:
                    e$ = fixoperationorder$(e$)
                    If Error_Happened Then Exit Sub
                    If pnrtnum = 0 Then
                        If last Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp + tlayout$ + sp2 + a2$
                    End If
                    e$ = evaluate(e$, typ)
                    If Error_Happened Then Exit Sub
                    If (typ And ISSTRING) = 0 Then
                        e$ = "STR$" + sp + "(" + sp + ebak$ + sp + ")"
                        extraspace = 1
                        pnrtnum = 1
                        GoTo printfilenumber 'force re-evaluation
                    End If
                    If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                    If Error_Happened Then Exit Sub
                    'format: string, (1/0) extraspace, (1/0) tab, (1/0)begin a new line
                    Print #12, "sub_file_print(tmp_fileno," + e$ + ","; extraspace; ","; usetab; ","; newline; ");"
                Else 'len(e$)=0
                    If a2$ = "," Then l$ = l$ + sp + a2$
                    If a2$ = ";" Then
                        If Right$(l$, 1) <> ";" Then l$ = l$ + sp + a2$ 'concat ;; to ;
                    End If
                    If usetab Then Print #12, "sub_file_print(tmp_fileno,nothingstring,0,1,0);"
                End If 'len(e$)
                Print #12, "if (new_error) goto skip" + u$ + ";"

                e$ = ""
                If gotofpu Then GoTo fpujump
                If last Then Exit For
                GoTo printfilenext
            End If ', or ;
        End If 'b=0
        If e$ <> "" Then e$ = e$ + sp + a2$ Else e$ = a2$
        printfilenext:
    Next
    If e$ <> "" Then a2$ = "": last = 1: GoTo printfilelast
    printblankline:
    Print #12, "skip" + u$ + ":"
    Print #12, cleanupstringprocessingcall$ + "0);"
    Print #12, "tab_spc_cr_size=1;"
    tlayout$ = l$
End Sub

Sub xfilewrite (ca$, n)
    l$ = SCase$("Write") + sp + "#"
    u$ = str2$(uniquenumber)
    Print #12, "tab_spc_cr_size=2;"
    If n = 2 Then Give_Error "Expected # ...": Exit Sub
    a3$ = ""
    b = 0
    For i = 3 To n
        a2$ = getelement$(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If a2$ = "," And b = 0 Then
            If a3$ = "" Then Give_Error "Expected # ... , ...": Exit Sub
            GoTo writegotfn
        End If
        If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
    Next
    Give_Error "Expected # ... ,": Exit Sub
    writegotfn:
    e$ = fixoperationorder$(a3$)
    If Error_Happened Then Exit Sub
    l$ = l$ + sp2 + tlayout$ + sp2 + ","
    e$ = evaluatetotyp(e$, 64&)
    If Error_Happened Then Exit Sub
    Print #12, "tab_fileno=tmp_fileno=" + e$ + ";"
    Print #12, "if (new_error) goto skip" + u$ + ";"
    i = i + 1
    If i > n Then
        Print #12, "sub_file_print(tmp_fileno,nothingstring,0,0,1);"
        GoTo writeblankline
    End If
    b = 0
    e$ = ""
    last = 0
    For i = i To n
        a2$ = getelement(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If b = 0 Then
            If a2$ = "," Then
                writefilelast:
                If last = 1 Then newline = 1 Else newline = 0
                ebak$ = e$
                reevaled = 0
                writefilenumber:
                e$ = fixoperationorder$(e$)
                If Error_Happened Then Exit Sub
                If reevaled = 0 Then
                    l$ = l$ + sp + tlayout$
                    If last = 0 Then l$ = l$ + sp2 + ","
                End If
                e$ = evaluate(e$, typ)
                If Error_Happened Then Exit Sub
                If reevaled = 0 Then
                    If (typ And ISSTRING) = 0 Then
                        e$ = "LTRIM$" + sp + "(" + sp + "STR$" + sp + "(" + sp + ebak$ + sp + ")" + sp + ")"
                        If last = 0 Then e$ = e$ + sp + "+" + sp + Chr$(34) + "," + Chr$(34) + ",1"
                        reevaled = 1
                        GoTo writefilenumber 'force re-evaluation
                    Else
                        e$ = Chr$(34) + "\042" + Chr$(34) + ",1" + sp + "+" + sp + ebak$ + sp + "+" + sp + Chr$(34) + "\042" + Chr$(34) + ",1"
                        If last = 0 Then e$ = e$ + sp + "+" + sp + Chr$(34) + "," + Chr$(34) + ",1"
                        reevaled = 1
                        GoTo writefilenumber 'force re-evaluation
                    End If
                End If
                If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                If Error_Happened Then Exit Sub
                'format: string, (1/0) extraspace, (1/0) tab, (1/0)begin a new line
                Print #12, "sub_file_print(tmp_fileno," + e$ + ",0,0,"; newline; ");"
                Print #12, "if (new_error) goto skip" + u$ + ";"
                e$ = ""
                If last Then Exit For
                GoTo writefilenext
            End If ',
        End If 'b=0
        If e$ <> "" Then e$ = e$ + sp + a2$ Else e$ = a2$
        writefilenext:
    Next
    If e$ <> "" Then a2$ = ",": last = 1: GoTo writefilelast
    writeblankline:
    'print #12, "}"'new_error
    Print #12, "skip" + u$ + ":"
    Print #12, cleanupstringprocessingcall$ + "0);"
    Print #12, "tab_spc_cr_size=1;"
    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
End Sub

Sub xgosub (ca$)
    a2$ = getelement(ca$, 2)
    If validlabel(a2$) = 0 Then Give_Error "Invalid label": Exit Sub

    v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
    x = 1
    labchk200:
    If v Then
        s = Labels(r).Scope
        If s = subfuncn Or s = -1 Then 'same scope?
            If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
            x = 0 'already defined
            tlayout$ = RTrim$(Labels(r).cn)
        Else
            If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk200
        End If
    End If
    If x Then
        'does not exist
        nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
        Labels(nLabels) = Empty_Label
        HashAdd a2$, HASHFLAG_LABEL, nLabels
        r = nLabels
        Labels(r).State = 0
        Labels(r).cn = tlayout$
        Labels(r).Scope = subfuncn
        Labels(r).Error_Line = linenumber
    End If 'x

    l$ = SCase$("GoSub") + sp + tlayout$
    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
    'note: This code fragment also used by ON ... GOTO/GOSUB
    'assume label is reachable (revise)
    Print #12, "return_point[next_return_point++]=" + str2(gosubid) + ";"
    Print #12, "if (next_return_point>=return_points) more_return_points();"
    Print #12, "goto LABEL_" + a2$ + ";"
    'add return point jump
    Print #15, "case " + str2(gosubid) + ":"
    Print #15, "goto RETURN_" + str2(gosubid) + ";"
    Print #15, "break;"
    Print #12, "RETURN_" + str2(gosubid) + ":;"
    gosubid = gosubid + 1
End Sub

Sub xongotogosub (a$, ca$, n)
    If n < 4 Then Give_Error "Expected ON expression GOTO/GOSUB label,label,...": Exit Sub
    l$ = SCase$("On")
    b = 0
    For i = 2 To n
        e2$ = getelement$(a$, i)
        If e2$ = "(" Then b = b + 1
        If e2$ = ")" Then b = b - 1
        If e2$ = "GOTO" Or e2$ = "GOSUB" Then Exit For
    Next
    If i >= n Or i = 2 Then Give_Error "Expected ON expression GOTO/GOSUB label,label,...": Exit Sub
    e$ = getelements$(ca$, 2, i - 1)

    g = 0: If e2$ = "GOSUB" Then g = 1
    e$ = fixoperationorder(e$)
    If Error_Happened Then Exit Sub
    l$ = l$ + sp + tlayout$
    e$ = evaluate(e$, typ)
    If Error_Happened Then Exit Sub
    If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
    If Error_Happened Then Exit Sub
    If (typ And ISSTRING) Then Give_Error "Expected numeric expression": Exit Sub
    If (typ And ISFLOAT) Then
        e$ = "qbr_float_to_long(" + e$ + ")"
    End If
    l$ = l$ + sp + e2$
    u$ = str2$(uniquenumber)
    Print #13, "static int32 ongo_" + u$ + "=0;"
    Print #12, "ongo_" + u$ + "=" + e$ + ";"
    ln = 1
    labelwaslast = 0
    For i = i + 1 To n
        e$ = getelement$(ca$, i)
        If e$ = "," Then
            l$ = l$ + sp2 + ","
            If i = n Then Give_Error "Trailing , invalid": Exit Sub
            ln = ln + 1
            labelwaslast = 0
        Else
            If labelwaslast Then Give_Error "Expected ,": Exit Sub
            If validlabel(e$) = 0 Then Give_Error "Invalid label!": Exit Sub

            v = HashFind(e$, HASHFLAG_LABEL, ignore, r)
            x = 1
            labchk507:
            If v Then
                s = Labels(r).Scope
                If s = subfuncn Or s = -1 Then 'same scope?
                    If s = -1 Then Labels(r).Scope = subfuncn 'acquire scope
                    x = 0 'already defined
                    tlayout$ = RTrim$(Labels(r).cn)
                Else
                    If v = 2 Then v = HashFindCont(ignore, r): GoTo labchk507
                End If
            End If
            If x Then
                'does not exist
                nLabels = nLabels + 1: If nLabels > Labels_Ubound Then Labels_Ubound = Labels_Ubound * 2: ReDim _Preserve Labels(1 To Labels_Ubound) As Label_Type
                Labels(nLabels) = Empty_Label
                HashAdd e$, HASHFLAG_LABEL, nLabels
                r = nLabels
                Labels(r).State = 0
                Labels(r).cn = tlayout$
                Labels(r).Scope = subfuncn
                Labels(r).Error_Line = linenumber
            End If 'x

            l$ = l$ + sp + tlayout$
            If g Then 'gosub
                lb$ = e$
                Print #12, "if (ongo_" + u$ + "==" + str2$(ln) + "){"
                'note: This code fragment also used by ON ... GOTO/GOSUB
                'assume label is reachable (revise)
                Print #12, "return_point[next_return_point++]=" + str2(gosubid) + ";"
                Print #12, "if (next_return_point>=return_points) more_return_points();"
                Print #12, "goto LABEL_" + lb$ + ";"
                'add return point jump
                Print #15, "case " + str2(gosubid) + ":"
                Print #15, "goto RETURN_" + str2(gosubid) + ";"
                Print #15, "break;"
                Print #12, "RETURN_" + str2(gosubid) + ":;"
                gosubid = gosubid + 1
                Print #12, "goto ongo_" + u$ + "_skip;"
                Print #12, "}"
            Else 'goto
                Print #12, "if (ongo_" + u$ + "==" + str2$(ln) + ") goto LABEL_" + e$ + ";"
            End If
            labelwaslast = 1
        End If
    Next
    Print #12, "if (ongo_" + u$ + "<0) error(5);"
    If g = 1 Then Print #12, "ongo_" + u$ + "_skip:;"
    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
End Sub

Sub xprint (a$, ca$, n)
    u$ = str2$(uniquenumber)

    l$ = SCase$("Print")
    If Asc(a$) = 76 Then lp = 1: lp$ = "l": l$ = SCase$("LPrint"): Print #12, "tab_LPRINT=1;": DEPENDENCY(DEPENDENCY_PRINTER) = 1 '"L"

    'PRINT USING?
    If n >= 2 Then
        If getelement(a$, 2) = "USING" Then
            'get format string
            i = 3
            pujump:
            l$ = l$ + sp + SCase$("Using")
            e$ = "": b = 0: puformat$ = ""
            For i = i To n
                a2$ = getelement(ca$, i)
                If a2$ = "(" Then b = b + 1
                If a2$ = ")" Then b = b - 1
                If b = 0 Then
                    If a2$ = "," Then Give_Error "Expected PRINT USING formatstring ; ...": Exit Sub
                    If a2$ = ";" Then
                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then Exit Sub
                        l$ = l$ + sp + tlayout$ + sp2 + ";"
                        e$ = evaluate(e$, typ)
                        If Error_Happened Then Exit Sub
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then Exit Sub
                        If (typ And ISSTRING) = 0 Then Give_Error "Expected PRINT USING formatstring ; ...": Exit Sub
                        puformat$ = e$
                        Exit For
                    End If ';
                End If 'b
                If Len(e$) Then e$ = e$ + sp + a2$ Else e$ = a2$
            Next
            If puformat$ = "" Then Give_Error "Expected PRINT USING formatstring ; ...": Exit Sub
            If i = n Then Give_Error "Expected PRINT USING formatstring ; ...": Exit Sub
            'create build string
            If TQBSset = 0 Then
                Print #12, "tqbs=qbs_new(0,0);"
            Else
                Print #12, "qbs_set(tqbs,qbs_new_txt_len(" + Chr$(34) + Chr$(34) + ",0));"
            End If
            'set format start/index variable
            Print #12, "tmp_long=0;" 'scan format from beginning


            'create string to hold format in for multiple references
            puf$ = "print_using_format" + u$
            If subfunc = "" Then
                Print #13, "static qbs *" + puf$ + ";"
            Else
                Print #13, "qbs *" + puf$ + ";"
            End If
            Print #12, puf$ + "=qbs_new(0,0); qbs_set(" + puf$ + "," + puformat$ + ");"
            Print #12, "if (new_error) goto skip_pu" + u$ + ";"

            'print expressions
            b = 0
            e$ = ""
            last = 0
            For i = i + 1 To n
                a2$ = getelement(ca$, i)
                If a2$ = "(" Then b = b + 1
                If a2$ = ")" Then b = b - 1
                If b = 0 Then
                    If a2$ = ";" Or a2$ = "," Then
                        printulast:
                        e$ = fixoperationorder$(e$)
                        If Error_Happened Then Exit Sub
                        If last Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp + tlayout$ + sp2 + a2$
                        e$ = evaluate(e$, typ)
                        If Error_Happened Then Exit Sub
                        If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                        If Error_Happened Then Exit Sub
                        If typ And ISSTRING Then

                            If Left$(e$, 9) = "func_tab(" Or Left$(e$, 9) = "func_spc(" Then

                                'TAB/SPC exception
                                'note: position in format-string must be maintained
                                '-print any string up until now
                                Print #12, "qbs_" + lp$ + "print(tqbs,0);"
                                '-print e$
                                Print #12, "qbs_set(tqbs," + e$ + ");"
                                Print #12, "if (new_error) goto skip_pu" + u$ + ";"
                                If lp Then Print #12, "lprint_makefit(tqbs);" Else Print #12, "makefit(tqbs);"
                                Print #12, "qbs_" + lp$ + "print(tqbs,0);"
                                '-set length of tqbs to 0
                                Print #12, "tqbs->len=0;"

                            Else

                                'regular string
                                Print #12, "tmp_long=print_using(" + puf$ + ",tmp_long,tqbs," + e$ + ");"

                            End If



                        Else 'not a string
                            If typ And ISFLOAT Then
                                If (typ And 511) = 32 Then Print #12, "tmp_long=print_using_single(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                If (typ And 511) = 64 Then Print #12, "tmp_long=print_using_double(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                If (typ And 511) > 64 Then Print #12, "tmp_long=print_using_float(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                            Else
                                If ((typ And 511) = 64) And (typ And ISUNSIGNED) <> 0 Then
                                    Print #12, "tmp_long=print_using_uinteger64(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                Else
                                    Print #12, "tmp_long=print_using_integer64(" + puf$ + "," + e$ + ",tmp_long,tqbs);"
                                End If
                            End If
                        End If 'string/not string
                        Print #12, "if (new_error) goto skip_pu" + u$ + ";"
                        e$ = ""
                        If last Then Exit For
                        GoTo printunext
                    End If
                End If
                If Len(e$) Then e$ = e$ + sp + a2$ Else e$ = a2$
                printunext:
            Next
            If e$ <> "" Then a2$ = "": last = 1: GoTo printulast
            Print #12, "skip_pu" + u$ + ":"
            'check for errors
            Print #12, "if (new_error){"
            Print #12, "g_tmp_long=new_error; new_error=0; qbs_" + lp$ + "print(tqbs,0); new_error=g_tmp_long;"
            Print #12, "}else{"
            If a2$ = "," Or a2$ = ";" Then nl = 0 Else nl = 1 'note: a2$ is set to the last element of a$
            Print #12, "qbs_" + lp$ + "print(tqbs," + str2$(nl) + ");"
            Print #12, "}"
            Print #12, "qbs_free(tqbs);"
            Print #12, "qbs_free(" + puf$ + ");"
            Print #12, "skip" + u$ + ":"
            Print #12, cleanupstringprocessingcall$ + "0);"
            If lp Then Print #12, "tab_LPRINT=0;"
            tlayout$ = l$
            Exit Sub
        End If
    End If
    'end of print using code

    b = 0
    e$ = ""
    last = 0
    Print #12, "tqbs=qbs_new(0,0);" 'initialize the temp string
    TQBSset = -1 'set the temporary flag so we don't create a temp string twice, in case USING comes after something
    For i = 2 To n
        a2$ = getelement(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If b = 0 Then
            If a2$ = ";" Or a2$ = "," Or UCase$(a2$) = "USING" Then
                printlast:

                If UCase$(a2$) = "USING" Then
                    If e$ <> "" Then gotopu = 1 Else i = i + 1: GoTo pujump
                End If

                If Len(e$) Then
                    ebak$ = e$
                    pnrtnum = 0
                    printnumber:
                    e$ = fixoperationorder$(e$)
                    If Error_Happened Then Exit Sub
                    If pnrtnum = 0 Then
                        If last Then l$ = l$ + sp + tlayout$ Else l$ = l$ + sp + tlayout$ + sp2 + a2$
                    End If
                    e$ = evaluate(e$, typ)
                    If Error_Happened Then Exit Sub
                    If (typ And ISSTRING) = 0 Then
                        'not a string expresion!
                        e$ = "STR$" + sp + "(" + sp + ebak$ + sp + ")" + sp + "+" + sp + Chr$(34) + " " + Chr$(34)
                        pnrtnum = 1
                        GoTo printnumber
                    End If
                    If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                    If Error_Happened Then Exit Sub
                    Print #12, "qbs_set(tqbs," + e$ + ");"
                    Print #12, "if (new_error) goto skip" + u$ + ";"
                    If lp Then Print #12, "lprint_makefit(tqbs);" Else Print #12, "makefit(tqbs);"
                    Print #12, "qbs_" + lp$ + "print(tqbs,0);"
                Else
                    If a2$ = "," Then l$ = l$ + sp + a2$
                    If a2$ = ";" Then
                        If Right$(l$, 1) <> ";" Then l$ = l$ + sp + a2$ 'concat ;; to ;
                    End If
                End If 'len(e$)
                If a2$ = "," Then Print #12, "tab();"
                e$ = ""

                If gotopu Then i = i + 1: GoTo pujump

                If last Then
                    Print #12, "qbs_" + lp$ + "print(nothingstring,1);" 'go to new line
                    Exit For
                End If

                GoTo printnext
            End If 'a2$
        End If 'b=0

        If Len(e$) Then e$ = e$ + sp + a2$ Else e$ = a2$
        printnext:
    Next
    If Len(e$) Then a2$ = "": last = 1: GoTo printlast
    If n = 1 Then Print #12, "qbs_" + lp$ + "print(nothingstring,1);"
    Print #12, "skip" + u$ + ":"
    Print #12, "qbs_free(tqbs);"
    Print #12, cleanupstringprocessingcall$ + "0);"
    If lp Then Print #12, "tab_LPRINT=0;"
    tlayout$ = l$
End Sub




Sub xread (ca$, n)
    l$ = SCase$("Read")
    If n = 1 Then Give_Error "Expected variable": Exit Sub
    i = 2
    If i > n Then Give_Error "Expected , ...": Exit Sub
    a3$ = ""
    b = 0
    For i = i To n
        a2$ = getelement$(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If (a2$ = "," And b = 0) Or i = n Then
            If i = n Then
                If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
            End If
            If a3$ = "" Then Give_Error "Expected , ...": Exit Sub
            e$ = fixoperationorder$(a3$)
            If Error_Happened Then Exit Sub
            l$ = l$ + sp + tlayout$: If i <> n Then l$ = l$ + sp2 + ","
            e$ = evaluate(e$, t)
            If Error_Happened Then Exit Sub
            If (t And ISREFERENCE) = 0 Then Give_Error "Expected variable": Exit Sub

            If (t And ISSTRING) Then
                e$ = refer(e$, t, 0)
                If Error_Happened Then Exit Sub
                Print #12, "sub_read_string(data,&data_offset,data_size," + e$ + ");"
                stringprocessinghappened = 1
            Else
                'numeric variable
                If (t And ISFLOAT) <> 0 Or (t And 511) <> 64 Then
                    If (t And ISOFFSETINBITS) Then
                        setrefer e$, t, "((int64)func_read_float(data,&data_offset,data_size," + str2(t) + "))", 1
                        If Error_Happened Then Exit Sub
                    Else
                        setrefer e$, t, "func_read_float(data,&data_offset,data_size," + str2(t) + ")", 1
                        If Error_Happened Then Exit Sub
                    End If
                Else
                    If t And ISUNSIGNED Then
                        setrefer e$, t, "func_read_uint64(data,&data_offset,data_size)", 1
                        If Error_Happened Then Exit Sub
                    Else
                        setrefer e$, t, "func_read_int64(data,&data_offset,data_size)", 1
                        If Error_Happened Then Exit Sub
                    End If
                End If
            End If 'string/numeric
            If i = n Then Exit For
            a3$ = "": a2$ = ""
        End If
        If a3$ = "" Then a3$ = a2$ Else a3$ = a3$ + sp + a2$
    Next
    If stringprocessinghappened Then Print #12, cleanupstringprocessingcall$ + "0);"
    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
End Sub

Sub xwrite (ca$, n)
    l$ = SCase$("Write")
    u$ = str2$(uniquenumber)
    If n = 1 Then
        Print #12, "qbs_print(nothingstring,1);"
        GoTo writeblankline2
    End If
    b = 0
    e$ = ""
    last = 0
    For i = 2 To n
        a2$ = getelement(ca$, i)
        If a2$ = "(" Then b = b + 1
        If a2$ = ")" Then b = b - 1
        If b = 0 Then
            If a2$ = "," Then
                writelast:
                If last = 1 Then newline = 1 Else newline = 0
                ebak$ = e$
                reevaled = 0
                writechecked:
                e$ = fixoperationorder$(e$)
                If Error_Happened Then Exit Sub
                If reevaled = 0 Then
                    l$ = l$ + sp + tlayout$
                    If last = 0 Then l$ = l$ + sp2 + ","
                End If
                e$ = evaluate(e$, typ)
                If Error_Happened Then Exit Sub
                If reevaled = 0 Then
                    If (typ And ISSTRING) = 0 Then
                        e$ = "LTRIM$" + sp + "(" + sp + "STR$" + sp + "(" + sp + ebak$ + sp + ")" + sp + ")"
                        If last = 0 Then e$ = e$ + sp + "+" + sp + Chr$(34) + "," + Chr$(34) + ",1"
                        reevaled = 1
                        GoTo writechecked 'force re-evaluation
                    Else
                        e$ = Chr$(34) + "\042" + Chr$(34) + ",1" + sp + "+" + sp + ebak$ + sp + "+" + sp + Chr$(34) + "\042" + Chr$(34) + ",1"
                        If last = 0 Then e$ = e$ + sp + "+" + sp + Chr$(34) + "," + Chr$(34) + ",1"
                        reevaled = 1
                        GoTo writechecked 'force re-evaluation
                    End If
                End If
                If (typ And ISREFERENCE) Then e$ = refer(e$, typ, 0)
                If Error_Happened Then Exit Sub
                'format: string, (1/0) extraspace, (1/0) tab, (1/0)begin a new line
                Print #12, "qbs_print(" + e$ + ","; newline; ");"
                Print #12, "if (new_error) goto skip" + u$ + ";"
                e$ = ""
                If last Then Exit For
                GoTo writenext
            End If ',
        End If 'b=0
        If e$ <> "" Then e$ = e$ + sp + a2$ Else e$ = a2$
        writenext:
    Next
    If e$ <> "" Then a2$ = ",": last = 1: GoTo writelast
    writeblankline2:
    Print #12, "skip" + u$ + ":"
    Print #12, cleanupstringprocessingcall$ + "0);"
    layoutdone = 1: If Len(layout$) Then layout$ = layout$ + sp + l$ Else layout$ = l$
End Sub

Function evaluateconst$ (a2$, t As Long)
    a$ = a2$

    Dim block(1000) As String
    Dim status(1000) As Integer
    '0=unprocessed (can be "")
    '1=processed
    Dim btype(1000) As Long 'for status=1 blocks

    'put a$ into blocks
    n = numelements(a$)
    For i = 1 To n
        block(i) = getelement$(a$, i)
    Next

    evalconstevalbrack:

    'find highest bracket level
    l = 0
    b = 0
    For i = 1 To n
        If block(i) = "(" Then b = b + 1
        If block(i) = ")" Then b = b - 1
        If b > l Then l = b
    Next

    'if brackets exist, evaluate that item first
    If l Then

        b = 0
        e$ = ""
        For i = 1 To n

            If block(i) = ")" Then
                If b = l Then block(i) = "": Exit For
                b = b - 1
            End If

            If b >= l Then
                If Len(e$) = 0 Then e$ = block(i) Else e$ = e$ + sp + block(i)
                block(i) = ""
            End If

            If block(i) = "(" Then
                b = b + 1
                If b = l Then i2 = i: block(i) = ""
            End If

        Next i

        status(i) = 1
        block(i) = evaluateconst$(e$, btype(i))
        If Error_Happened Then Exit Function
        GoTo evalconstevalbrack

    End If 'l

    'linear equation remains with some pre-calculated & non-pre-calc blocks

    'problem: type QBASIC assumes and type required to store calc. value may
    '         differ dramatically. in qbasic, this would have caused an overflow,
    '         but in qb64 it MUST work. eg. 32767% * 32767%
    'solution: all interger calc. will be performed using a signed _INTEGER64
    '          all float calc. will be performed using a _FLOAT

    'convert non-calc block numbers into binary form with QBASIC-like type
    For i = 1 To n
        If status(i) = 0 Then
            If Len(block(i)) Then

                a = Asc(block(i))
                If (a = 45 And Len(block(i)) > 1) Or (a >= 48 And a <= 57) Then 'number?

                    'integers
                    e$ = Right$(block(i), 3)
                    If e$ = "~&&" Then btype(i) = UINTEGER64TYPE - ISPOINTER: GoTo gotconstblkityp
                    If e$ = "~%%" Then btype(i) = UBYTETYPE - ISPOINTER: GoTo gotconstblkityp
                    e$ = Right$(block(i), 2)
                    If e$ = "&&" Then btype(i) = INTEGER64TYPE - ISPOINTER: GoTo gotconstblkityp
                    If e$ = "%%" Then btype(i) = BYTETYPE - ISPOINTER: GoTo gotconstblkityp
                    If e$ = "~%" Then btype(i) = UINTEGERTYPE - ISPOINTER: GoTo gotconstblkityp
                    If e$ = "~&" Then btype(i) = ULONGTYPE - ISPOINTER: GoTo gotconstblkityp
                    e$ = Right$(block(i), 1)
                    If e$ = "%" Then btype(i) = INTEGERTYPE - ISPOINTER: GoTo gotconstblkityp
                    If e$ = "&" Then btype(i) = LONGTYPE - ISPOINTER: GoTo gotconstblkityp

                    'ubit-type?
                    If InStr(block(i), "~`") Then
                        x = InStr(block(i), "~`")
                        If x = Len(block(i)) - 1 Then block(i) = block(i) + "1"
                        btype(i) = UBITTYPE - ISPOINTER - 1 + Val(Right$(block(i), Len(block(i)) - x - 1))
                        block(i) = _MK$(_Integer64, Val(Left$(block(i), x - 1)))
                        status(i) = 1
                        GoTo gotconstblktyp
                    End If

                    'bit-type?
                    If InStr(block(i), "`") Then
                        x = InStr(block(i), "`")
                        If x = Len(block(i)) Then block(i) = block(i) + "1"
                        btype(i) = BITTYPE - ISPOINTER - 1 + Val(Right$(block(i), Len(block(i)) - x))
                        block(i) = _MK$(_Integer64, Val(Left$(block(i), x - 1)))
                        status(i) = 1
                        GoTo gotconstblktyp
                    End If

                    'floats
                    If InStr(block(i), "E") Then
                        block(i) = _MK$(_Float, Val(block(i)))
                        btype(i) = SINGLETYPE - ISPOINTER
                        status(i) = 1
                        GoTo gotconstblktyp
                    End If
                    If InStr(block(i), "D") Then
                        block(i) = _MK$(_Float, Val(block(i)))
                        btype(i) = DOUBLETYPE - ISPOINTER
                        status(i) = 1
                        GoTo gotconstblktyp
                    End If
                    If InStr(block(i), "F") Then
                        block(i) = _MK$(_Float, Val(block(i)))
                        btype(i) = FLOATTYPE - ISPOINTER
                        status(i) = 1
                        GoTo gotconstblktyp
                    End If

                    Give_Error "Invalid CONST expression.1": Exit Function

                    gotconstblkityp:
                    block(i) = Left$(block(i), Len(block(i)) - Len(e$))
                    block(i) = _MK$(_Integer64, Val(block(i)))
                    status(i) = 1
                    gotconstblktyp:

                End If 'a

                If a = 34 Then 'string?
                    'no changes need to be made to block(i) which is of format "CHARACTERS",size
                    btype(i) = STRINGTYPE - ISPOINTER
                    status(i) = 1
                End If

            End If 'len<>0
        End If 'status
    Next

    'remove NULL blocks
    n2 = 0
    For i = 1 To n
        If block(i) <> "" Then
            n2 = n2 + 1
            block(n2) = block(i)
            status(n2) = status(i)
            btype(n2) = btype(i)
        End If
    Next
    n = n2

    'only one block?
    If n = 1 Then
        If status(1) = 0 Then Give_Error "Invalid CONST expression.2": Exit Function
        t = btype(1)
        evaluateconst$ = block(1)
        Exit Function
    End If 'n=1

    'evaluate equation (equation cannot contain any STRINGs)

    '[negation/not][variable]
    e$ = block(1)
    If status(1) = 0 Then
        If n <> 2 Then Give_Error "Invalid CONST expression.4": Exit Function
        If status(2) = 0 Then Give_Error "Invalid CONST expression.5": Exit Function
        If btype(2) And ISSTRING Then Give_Error "Invalid CONST expression.6": Exit Function
        o$ = block(1)

        If o$ = Chr$(241) Then
            If btype(2) And ISFLOAT Then
                r## = -_CV(_Float, block(2))
                evaluateconst$ = _MK$(_Float, r##)
            Else
                r&& = -_CV(_Integer64, block(2))
                evaluateconst$ = _MK$(_Integer64, r&&)
            End If
            t = btype(2)
            Exit Function
        End If

        If UCase$(o$) = "NOT" Then
            If btype(2) And ISFLOAT Then
                r&& = _CV(_Float, block(2))
            Else
                r&& = _CV(_Integer64, block(2))
            End If
            r&& = Not r&&
            t = btype(2)
            If t And ISFLOAT Then t = LONGTYPE - ISPOINTER 'markdown to LONG
            evaluateconst$ = _MK$(_Integer64, r&&)
            Exit Function
        End If

        Give_Error "Invalid CONST expression.7": Exit Function
    End If

    '[variable][bool-operator][variable]...

    'get first variable
    et = btype(1)
    ev$ = block(1)

    i = 2

    evalconstequ:

    'get operator
    If i >= n Then Give_Error "Invalid CONST expression.8": Exit Function
    o$ = UCase$(block(i))
    i = i + 1
    If isoperator(o$) = 0 Then Give_Error "Invalid CONST expression.9": Exit Function
    If i > n Then Give_Error "Invalid CONST expression.10": Exit Function

    'string/numeric mismatch?
    If (btype(i) And ISSTRING) <> (et And ISSTRING) Then Give_Error "Invalid CONST expression.11": Exit Function

    If et And ISSTRING Then
        If o$ <> "+" Then Give_Error "Invalid CONST expression.12": Exit Function
        'concat strings
        s1$ = Right$(ev$, Len(ev$) - 1)
        s1$ = Left$(s1$, InStr(s1$, Chr$(34)) - 1)
        s1size = Val(Right$(ev$, Len(ev$) - Len(s1$) - 3))
        s2$ = Right$(block(i), Len(block(i)) - 1)
        s2$ = Left$(s2$, InStr(s2$, Chr$(34)) - 1)
        s2size = Val(Right$(block(i), Len(block(i)) - Len(s2$) - 3))
        ev$ = Chr$(34) + s1$ + s2$ + Chr$(34) + "," + str2$(s1size + s2size)
        GoTo econstmarkedup
    End If

    'prepare left and right values
    If et And ISFLOAT Then
        linteger = 0
        l## = _CV(_Float, ev$)
        l&& = l##
    Else
        linteger = 1
        l&& = _CV(_Integer64, ev$)
        l## = l&&
    End If
    If btype(i) And ISFLOAT Then
        rinteger = 0
        r## = _CV(_Float, block(i))
        r&& = r##
    Else
        rinteger = 1
        r&& = _CV(_Integer64, block(i))
        r## = r&&
    End If

    If linteger = 1 And rinteger = 1 Then
        If o$ = "+" Then r&& = l&& + r&&: GoTo econstmarkupi
        If o$ = "-" Then r&& = l&& - r&&: GoTo econstmarkupi
        If o$ = "*" Then r&& = l&& * r&&: GoTo econstmarkupi
        If o$ = "^" Then r## = l&& ^ r&&: GoTo econstmarkupf
        If o$ = "/" Then r## = l&& / r&&: GoTo econstmarkupf
        If o$ = "\" Then r&& = l&& \ r&&: GoTo econstmarkupi
        If o$ = "MOD" Then r&& = l&& Mod r&&: GoTo econstmarkupi
        If o$ = "=" Then r&& = l&& = r&&: GoTo econstmarkupi16
        If o$ = ">" Then r&& = l&& > r&&: GoTo econstmarkupi16
        If o$ = "<" Then r&& = l&& < r&&: GoTo econstmarkupi16
        If o$ = ">=" Then r&& = l&& >= r&&: GoTo econstmarkupi16
        If o$ = "<=" Then r&& = l&& <= r&&: GoTo econstmarkupi16
        If o$ = "<>" Then r&& = l&& <> r&&: GoTo econstmarkupi16
        If o$ = "IMP" Then r&& = l&& Imp r&&: GoTo econstmarkupi
        If o$ = "EQV" Then r&& = l&& Eqv r&&: GoTo econstmarkupi
        If o$ = "XOR" Then r&& = l&& Xor r&&: GoTo econstmarkupi
        If o$ = "OR" Then r&& = l&& Or r&&: GoTo econstmarkupi
        If o$ = "AND" Then r&& = l&& And r&&: GoTo econstmarkupi
    End If

    If o$ = "+" Then r## = l## + r##: GoTo econstmarkupf
    If o$ = "-" Then r## = l## - r##: GoTo econstmarkupf
    If o$ = "*" Then r## = l## * r##: GoTo econstmarkupf
    If o$ = "^" Then r## = l## ^ r##: GoTo econstmarkupf
    If o$ = "/" Then r## = l## / r##: GoTo econstmarkupf
    If o$ = "\" Then r&& = l## \ r##: GoTo econstmarkupi32
    If o$ = "MOD" Then r&& = l## Mod r##: GoTo econstmarkupi32
    If o$ = "=" Then r&& = l## = r##: GoTo econstmarkupi16
    If o$ = ">" Then r&& = l## > r##: GoTo econstmarkupi16
    If o$ = "<" Then r&& = l## < r##: GoTo econstmarkupi16
    If o$ = ">=" Then r&& = l## >= r##: GoTo econstmarkupi16
    If o$ = "<=" Then r&& = l## <= r##: GoTo econstmarkupi16
    If o$ = "<>" Then r&& = l## <> r##: GoTo econstmarkupi16
    If o$ = "IMP" Then r&& = l## Imp r##: GoTo econstmarkupi32
    If o$ = "EQV" Then r&& = l## Eqv r##: GoTo econstmarkupi32
    If o$ = "XOR" Then r&& = l## Xor r##: GoTo econstmarkupi32
    If o$ = "OR" Then r&& = l## Or r##: GoTo econstmarkupi32
    If o$ = "AND" Then r&& = l## And r##: GoTo econstmarkupi32

    Give_Error "Invalid CONST expression.13": Exit Function

    econstmarkupi16:
    et = INTEGERTYPE - ISPOINTER
    ev$ = _MK$(_Integer64, r&&)
    GoTo econstmarkedup

    econstmarkupi32:
    et = LONGTYPE - ISPOINTER
    ev$ = _MK$(_Integer64, r&&)
    GoTo econstmarkedup

    econstmarkupi:
    If et <> btype(i) Then
        'keep unsigned?
        u = 0: If (et And ISUNSIGNED) <> 0 And (btype(i) And ISUNSIGNED) <> 0 Then u = 1
        lb = et And 511: rb = btype(i) And 511
        ob = 0
        If lb = rb Then
            If (et And ISOFFSETINBITS) <> 0 And (btype(i) And ISOFFSETINBITS) <> 0 Then ob = 1
            b = lb
        End If
        If lb > rb Then
            If (et And ISOFFSETINBITS) <> 0 Then ob = 1
            b = lb
        End If
        If lb < rb Then
            If (btype(i) And ISOFFSETINBITS) <> 0 Then ob = 1
            b = rb
        End If
        et = b
        If ob Then et = et + ISOFFSETINBITS
        If u Then et = et + ISUNSIGNED
    End If
    ev$ = _MK$(_Integer64, r&&)
    GoTo econstmarkedup

    econstmarkupf:
    lfb = 0: rfb = 0
    lib = 0: rib = 0
    If et And ISFLOAT Then lfb = et And 511 Else lib = et And 511
    If btype(i) And ISFLOAT Then rfb = btype(i) And 511 Else rib = btype(i) And 511
    f = 32
    If lib > 16 Or rib > 16 Then f = 64
    If lfb > 32 Or rfb > 32 Then f = 64
    If lib > 32 Or rib > 32 Then f = 256
    If lfb > 64 Or rfb > 64 Then f = 256
    et = ISFLOAT + f
    ev$ = _MK$(_Float, r##)

    econstmarkedup:

    i = i + 1

    If i <= n Then GoTo evalconstequ

    t = et
    evaluateconst$ = ev$

End Function

Function typevalue2symbol$ (t)

    If t And ISSTRING Then
        If t And ISFIXEDLENGTH Then Give_Error "Cannot convert expression type to symbol": Exit Function
        typevalue2symbol$ = "$"
        Exit Function
    End If

    s$ = ""

    If t And ISUNSIGNED Then s$ = "~"

    b = t And 511

    If t And ISOFFSETINBITS Then
        If b > 1 Then s$ = s$ + "`" + str2$(b) Else s$ = s$ + "`"
        typevalue2symbol$ = s$
        Exit Function
    End If

    If t And ISFLOAT Then
        If b = 32 Then s$ = "!"
        If b = 64 Then s$ = "#"
        If b = 256 Then s$ = "##"
        typevalue2symbol$ = s$
        Exit Function
    End If

    If b = 8 Then s$ = s$ + "%%"
    If b = 16 Then s$ = s$ + "%"
    If b = 32 Then s$ = s$ + "&"
    If b = 64 Then s$ = s$ + "&&"
    typevalue2symbol$ = s$

End Function


Function id2fulltypename$
    t = id.t
    If t = 0 Then t = id.arraytype
    size = id.tsize
    bits = t And 511
    If t And ISUDT Then
        a$ = RTrim$(udtxcname(t And 511))
        id2fulltypename$ = a$: Exit Function
    End If
    If t And ISSTRING Then
        If t And ISFIXEDLENGTH Then a$ = "STRING * " + str2(size) Else a$ = "STRING"
        id2fulltypename$ = a$: Exit Function
    End If
    If t And ISOFFSETINBITS Then
        If bits > 1 Then a$ = qb64prefix$ + "BIT * " + str2(bits) Else a$ = qb64prefix$ + "BIT"
        If t And ISUNSIGNED Then a$ = qb64prefix$ + "UNSIGNED " + a$
        id2fulltypename$ = a$: Exit Function
    End If
    If t And ISFLOAT Then
        If bits = 32 Then a$ = "SINGLE"
        If bits = 64 Then a$ = "DOUBLE"
        If bits = 256 Then a$ = qb64prefix$ + "FLOAT"
    Else 'integer-based
        If bits = 8 Then a$ = qb64prefix$ + "BYTE"
        If bits = 16 Then a$ = "INTEGER"
        If bits = 32 Then a$ = "LONG"
        If bits = 64 Then a$ = qb64prefix$ + "INTEGER64"
        If t And ISUNSIGNED Then a$ = qb64prefix$ + "UNSIGNED " + a$
    End If
    If t And ISOFFSET Then
        a$ = qb64prefix$ + "OFFSET"
        If t And ISUNSIGNED Then a$ = qb64prefix$ + "UNSIGNED " + a$
    End If
    id2fulltypename$ = a$
End Function

Function id2shorttypename$
    t = id.t
    If t = 0 Then t = id.arraytype
    size = id.tsize
    bits = t And 511
    If t And ISUDT Then
        a$ = RTrim$(udtxcname(t And 511))
        id2shorttypename$ = a$: Exit Function
    End If
    If t And ISSTRING Then
        If t And ISFIXEDLENGTH Then a$ = "STRING" + str2(size) Else a$ = "STRING"
        id2shorttypename$ = a$: Exit Function
    End If
    If t And ISOFFSETINBITS Then
        If t And ISUNSIGNED Then a$ = "_U" Else a$ = "_"
        If bits > 1 Then a$ = a$ + "BIT" + str2(bits) Else a$ = a$ + "BIT1"
        id2shorttypename$ = a$: Exit Function
    End If
    If t And ISFLOAT Then
        If bits = 32 Then a$ = "SINGLE"
        If bits = 64 Then a$ = "DOUBLE"
        If bits = 256 Then a$ = "_FLOAT"
    Else 'integer-based
        If bits = 8 Then
            If (t And ISUNSIGNED) Then a$ = "_UBYTE" Else a$ = "_BYTE"
        End If
        If bits = 16 Then
            If (t And ISUNSIGNED) Then a$ = "UINTEGER" Else a$ = "INTEGER"
        End If
        If bits = 32 Then
            If (t And ISUNSIGNED) Then a$ = "ULONG" Else a$ = "LONG"
        End If
        If bits = 64 Then
            If (t And ISUNSIGNED) Then a$ = "_UINTEGER64" Else a$ = "_INTEGER64"
        End If
    End If
    id2shorttypename$ = a$
End Function

Function symbol2fulltypename$ (s2$)
    'note: accepts both symbols and type names
    s$ = s2$

    If Left$(s$, 1) = "~" Then
        u = 1
        If Len(typ$) = 1 Then Give_Error "Expected ~...": Exit Function
        s$ = Right$(s$, Len(s$) - 1)
        u$ = qb64prefix$ + "UNSIGNED "
    End If

    If s$ = "%%" Then t$ = u$ + qb64prefix$ + "BYTE": GoTo gotsym2typ
    If s$ = "%" Then t$ = u$ + "INTEGER": GoTo gotsym2typ
    If s$ = "&" Then t$ = u$ + "LONG": GoTo gotsym2typ
    If s$ = "&&" Then t$ = u$ + qb64prefix$ + "INTEGER64": GoTo gotsym2typ
    If s$ = "%&" Then t$ = u$ + qb64prefix$ + "OFFSET": GoTo gotsym2typ

    If Left$(s$, 1) = "`" Then
        If Len(s$) = 1 Then
            t$ = u$ + qb64prefix$ + "BIT * 1"
            GoTo gotsym2typ
        End If
        n$ = Right$(s$, Len(s$) - 1)
        If isuinteger(n$) = 0 Then Give_Error "Expected number after symbol `": Exit Function
        t$ = u$ + qb64prefix$ + "BIT * " + n$
        GoTo gotsym2typ
    End If

    If u = 1 Then Give_Error "Expected type symbol after ~": Exit Function

    If s$ = "!" Then t$ = "SINGLE": GoTo gotsym2typ
    If s$ = "#" Then t$ = "DOUBLE": GoTo gotsym2typ
    If s$ = "##" Then t$ = qb64prefix$ + "FLOAT": GoTo gotsym2typ
    If s$ = "$" Then t$ = "STRING": GoTo gotsym2typ

    If Left$(s$, 1) = "$" Then
        n$ = Right$(s$, Len(s$) - 1)
        If isuinteger(n$) = 0 Then Give_Error "Expected number after symbol $": Exit Function
        t$ = "STRING * " + n$
        GoTo gotsym2typ
    End If

    t$ = s$

    gotsym2typ:

    If Right$(" " + t$, 5) = " _BIT" Then t$ = t$ + " * 1" 'clarify (_UNSIGNED) _BIT as (_UNSIGNED) _BIT * 1

    For i = 1 To Len(t$)
        If Asc(t$, i) = Asc(sp) Then Asc(t$, i) = 32
    Next

    symbol2fulltypename$ = t$

End Function

Sub lineinput3load (f$)
    Open f$ For Binary As #1
    l = LOF(1)
    lineinput3buffer$ = Space$(l)
    Get #1, , lineinput3buffer$
    If Len(lineinput3buffer$) Then If Right$(lineinput3buffer$, 1) = Chr$(26) Then lineinput3buffer$ = Left$(lineinput3buffer$, Len(lineinput3buffer$) - 1)
    Close #1
    lineinput3index = 1
End Sub

Function lineinput3$
    'returns CHR$(13) if no more lines are available
    l = Len(lineinput3buffer$)
    If lineinput3index > l Then lineinput3$ = Chr$(13): Exit Function
    c13 = InStr(lineinput3index, lineinput3buffer$, Chr$(13))
    c10 = InStr(lineinput3index, lineinput3buffer$, Chr$(10))
    If c10 = 0 And c13 = 0 Then
        lineinput3$ = Mid$(lineinput3buffer$, lineinput3index, l - lineinput3index + 1)
        lineinput3index = l + 1
        Exit Function
    End If
    If c10 = 0 Then c10 = 2147483647
    If c13 = 0 Then c13 = 2147483647
    If c10 < c13 Then
        '10 before 13
        lineinput3$ = Mid$(lineinput3buffer$, lineinput3index, c10 - lineinput3index)
        lineinput3index = c10 + 1
        If lineinput3index <= l Then
            If Asc(Mid$(lineinput3buffer$, lineinput3index, 1)) = 13 Then lineinput3index = lineinput3index + 1
        End If
    Else
        '13 before 10
        lineinput3$ = Mid$(lineinput3buffer$, lineinput3index, c13 - lineinput3index)
        lineinput3index = c13 + 1
        If lineinput3index <= l Then
            If Asc(Mid$(lineinput3buffer$, lineinput3index, 1)) = 10 Then lineinput3index = lineinput3index + 1
        End If
    End If
End Function

Function getfilepath$ (f$)
    For i = Len(f$) To 1 Step -1
        a$ = Mid$(f$, i, 1)
        If a$ = "/" Or a$ = "\" Then
            getfilepath$ = Left$(f$, i)
            Exit Function
        End If
    Next
    getfilepath$ = ""
End Function

Function eleucase$ (a$)
    'this function upper-cases all elements except for quoted strings
    'check first element
    If Len(a$) = 0 Then Exit Function
    i = 1
    If Asc(a$) = 34 Then
        i2 = InStr(a$, sp)
        If i2 = 0 Then eleucase$ = a$: Exit Function
        a2$ = Left$(a$, i2 - 1)
        i = i2
    End If
    'check other elements
    sp34$ = sp + Chr$(34)
    If i < Len(a$) Then
        Do While InStr(i, a$, sp34$)
            i2 = InStr(i, a$, sp34$)
            a2$ = a2$ + UCase$(Mid$(a$, i, i2 - i + 1)) 'everything prior including spacer
            i3 = InStr(i2 + 1, a$, sp): If i3 = 0 Then i3 = Len(a$) Else i3 = i3 - 1
            a2$ = a2$ + Mid$(a$, i2 + 1, i3 - (i2 + 1) + 1) 'everything from " to before next spacer or end
            i = i3 + 1
            If i > Len(a$) Then Exit Do
        Loop
    End If
    a2$ = a2$ + UCase$(Mid$(a$, i, Len(a$) - i + 1))
    eleucase$ = a2$
End Function


Sub SetDependency (requirement)
    If requirement Then
        DEPENDENCY(requirement) = 1
    End If
End Sub

Sub Build (path$)
    previous_dir$ = _CWD$

    'Count the separators in the path
    depth = 1
    For x = 1 To Len(path$)
        If Asc(path$, x) = 92 Or Asc(path$, x) = 47 Then depth = depth + 1
    Next
    ChDir path$

    return_path$ = ".."
    For x = 2 To depth
        return_path$ = return_path$ + "\.."
    Next

    bfh = FreeFile
    Open "build" + BATCHFILE_EXTENSION For Binary As #bfh
    Do Until EOF(bfh)
        Line Input #bfh, c$
        use = 0
        If Len(c$) Then use = 1
        If c$ = "pause" Then use = 0
        If Left$(c$, 1) = "#" Then use = 0 'eg. #!/bin/sh
        If Left$(c$, 13) = "cd " + Chr$(34) + "$(dirname" Then use = 0 'eg. cd "$(dirname "$0")"
        If InStr(LCase$(c$), "press any key") Then Exit Do
        c$ = GDB_Fix$(c$)
        If use Then
            Shell _Hide c$ + " 2>> " + QuotedFilename$(previous_dir$ + "/" + compilelog$)
        End If
    Loop
    Close #bfh

    ChDir previous_dir$
End Sub

Function GDB_Fix$ (g_command$) 'edit a gcc/g++ command line to include debugging info
    c$ = g_command$
    If Include_GDB_Debugging_Info Then
        If Left$(c$, 4) = "gcc " Or Left$(c$, 4) = "g++ " Then
            c$ = Left$(c$, 4) + " -g " + Right$(c$, Len(c$) - 4)
            GoTo added_gdb_flag
        End If
        For o = 1 To 6
            If o = 1 Then o$ = "\g++ "
            If o = 2 Then o$ = "/g++ "
            If o = 3 Then o$ = "\gcc "
            If o = 4 Then o$ = "/gcc "
            If o = 5 Then o$ = " gcc "
            If o = 6 Then o$ = " g++ "
            x = InStr(UCase$(c$), UCase$(o$))
            'note: -g adds debug symbols
            If x Then c$ = Left$(c$, x - 1) + o$ + " -g " + Right$(c$, Len(c$) - x - (Len(o$) - 1)): Exit For
        Next
        added_gdb_flag:
        'note: -s strips all debug symbols which is good for size but not for debugging
        x = InStr(c$, " -s "): If x Then c$ = Left$(c$, x - 1) + " " + Right$(c$, Len(c$) - x - 3)
    End If
    GDB_Fix$ = c$
End Function


Sub PATH_SLASH_CORRECT (a$)
    For x = 1 To Len(a$)
        If Asc(a$, x) = 92 Then Asc(a$, x) = 47
    Next
End Sub

'Steve Subs/Functins for _MATH support with CONST
Function Evaluate_Expression$ (e$)
    t$ = e$ 'So we preserve our original data, we parse a temp copy of it
    PreParse t$


    If Left$(t$, 5) = "ERROR" Then Evaluate_Expression$ = t$: Exit Function

    'Deal with brackets first
    exp$ = "(" + t$ + ")" 'Starting and finishing brackets for our parse routine.

    Do
        Eval_E = InStr(exp$, ")")
        If Eval_E > 0 Then
            c = 0
            Do Until Eval_E - c <= 0
                c = c + 1
                If Eval_E Then
                    If Mid$(exp$, Eval_E - c, 1) = "(" Then Exit Do
                End If
            Loop
            s = Eval_E - c + 1
            If s < 1 Then Evaluate_Expression$ = "ERROR -- BAD () Count": Exit Function
            eval$ = " " + Mid$(exp$, s, Eval_E - s) + " " 'pad with a space before and after so the parser can pick up the values properly.

            ParseExpression eval$
            eval$ = LTrim$(RTrim$(eval$))
            If Left$(eval$, 5) = "ERROR" Then Evaluate_Expression$ = eval$: Exit Function
            exp$ = DWD(Left$(exp$, s - 2) + eval$ + Mid$(exp$, Eval_E + 1))
            If Mid$(exp$, 1, 1) = "N" Then Mid$(exp$, 1) = "-"
        End If
    Loop Until Eval_E = 0
    c = 0
    Do
        c = c + 1
        Select Case Mid$(exp$, c, 1)
            Case "0" To "9", ".", "-" 'At this point, we should only have number values left.
            Case Else: Evaluate_Expression$ = "ERROR - Unknown Diagnosis: (" + exp$ + ") ": Exit Function
        End Select
    Loop Until c >= Len(exp$)

    Evaluate_Expression$ = exp$
End Function



Sub ParseExpression (exp$)
    Dim num(10) As String
    'PRINT exp$
    exp$ = DWD(exp$)
    'We should now have an expression with no () to deal with

    For J = 1 To 250
        lowest = 0
        Do Until lowest = Len(exp$)
            lowest = Len(exp$): OpOn = 0
            For P = 1 To UBound(OName)
                'Look for first valid operator
                If J = PL(P) Then 'Priority levels match
                    If Left$(exp$, 1) = "-" Then startAt = 2 Else startAt = 1
                    op = InStr(startAt, exp$, OName(P))
                    If op > 0 And op < lowest Then lowest = op: OpOn = P
                End If
            Next
            If OpOn = 0 Then Exit Do 'We haven't gotten to the proper PL for this OP to be processed yet.
            If Left$(exp$, 1) = "-" Then startAt = 2 Else startAt = 1
            op = InStr(startAt, exp$, OName(OpOn))

            numset = 0

            '*** SPECIAL OPERATION RULESETS
            If OName(OpOn) = "-" Then 'check for BOOLEAN operators before the -
                Select Case Mid$(exp$, op - 3, 3)
                    Case "NOT", "XOR", "AND", "EQV", "IMP"
                        Exit Do 'Not an operator, it's a negative
                End Select
                If Mid$(exp$, op - 3, 2) = "OR" Then Exit Do 'Not an operator, it's a negative
            End If

            If op Then
                c = Len(OName(OpOn)) - 1
                Do
                    Select Case Mid$(exp$, op + c + 1, 1)
                        Case "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", ".", "N": numset = -1 'Valid digit
                        Case "-" 'We need to check if it's a minus or a negative
                            If OName(OpOn) = "_PI" Or numset Then Exit Do
                        Case ",": numset = 0
                        Case Else 'Not a valid digit, we found our separator
                            Exit Do
                    End Select
                    c = c + 1
                Loop Until op + c >= Len(exp$)
                E = op + c

                c = 0
                Do
                    c = c + 1
                    Select Case Mid$(exp$, op - c, 1)
                        Case "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", ".", "N" 'Valid digit
                        Case "-" 'We need to check if it's a minus or a negative
                            c1 = c
                            bad = 0
                            Do
                                c1 = c1 + 1
                                Select Case Mid$(exp$, op - c1, 1)
                                    Case "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "."
                                        bad = -1
                                        Exit Do 'It's a minus sign
                                    Case Else
                                        'It's a negative sign and needs to count as part of our numbers
                                End Select
                            Loop Until op - c1 <= 0
                            If bad Then Exit Do 'We found our seperator
                        Case Else 'Not a valid digit, we found our separator
                            Exit Do
                    End Select
                Loop Until op - c <= 0
                s = op - c
                num(1) = Mid$(exp$, s + 1, op - s - 1) 'Get our first number
                num(2) = Mid$(exp$, op + Len(OName(OpOn)), E - op - Len(OName(OpOn)) + 1) 'Get our second number
                If Mid$(num(1), 1, 1) = "N" Then Mid$(num(1), 1) = "-"
                If Mid$(num(2), 1, 1) = "N" Then Mid$(num(2), 1) = "-"
                If num(1) = "-" Then
                    num(3) = "N" + EvaluateNumbers(OpOn, num())
                Else
                    num(3) = EvaluateNumbers(OpOn, num())
                End If
                If Mid$(num(3), 1, 1) = "-" Then Mid$(num(3), 1) = "N"
                If Left$(num(3), 5) = "ERROR" Then exp$ = num(3): Exit Sub
                exp$ = LTrim$(N2S(DWD(Left$(exp$, s) + RTrim$(LTrim$(num(3))) + Mid$(exp$, E + 1))))
            End If
            op = 0
        Loop
    Next

End Sub



Sub Set_OrderOfOperations
    'PL sets our priortity level. 1 is highest to 65535 for the lowest.
    'I used a range here so I could add in new priority levels as needed.
    'OName ended up becoming the name of our commands, as I modified things.... Go figure!  LOL!
    ReDim OName(10000) As String, PL(10000) As Integer
    'Constants get evaluated first, with a Priority Level of 1

    i = i + 1: OName(i) = "C_UOF": PL(i) = 5 'convert to unsigned offset
    i = i + 1: OName(i) = "C_OF": PL(i) = 5 'convert to offset
    i = i + 1: OName(i) = "C_UBY": PL(i) = 5 'convert to unsigned byte
    i = i + 1: OName(i) = "C_BY": PL(i) = 5 'convert to byte
    i = i + 1: OName(i) = "C_UIN": PL(i) = 5 'convert to unsigned integer
    i = i + 1: OName(i) = "C_IN": PL(i) = 5 'convert to integer
    i = i + 1: OName(i) = "C_UIF": PL(i) = 5 'convert to unsigned int64
    i = i + 1: OName(i) = "C_IF": PL(i) = 5 'convert to int64
    i = i + 1: OName(i) = "C_ULO": PL(i) = 5 'convert to unsigned long
    i = i + 1: OName(i) = "C_LO": PL(i) = 5 'convert to long
    i = i + 1: OName(i) = "C_SI": PL(i) = 5 'convert to single
    i = i + 1: OName(i) = "C_FL": PL(i) = 5 'convert to float
    i = i + 1: OName(i) = "C_DO": PL(i) = 5 'convert to double
    i = i + 1: OName(i) = "C_UBI": PL(i) = 5 'convert to unsigned bit
    i = i + 1: OName(i) = "C_BI": PL(i) = 5 'convert to bit

    'Then Functions with PL 10
    i = i + 1:: OName(i) = "_PI": PL(i) = 10
    i = i + 1: OName(i) = "_ACOS": PL(i) = 10
    i = i + 1: OName(i) = "_ASIN": PL(i) = 10
    i = i + 1: OName(i) = "_ARCSEC": PL(i) = 10
    i = i + 1: OName(i) = "_ARCCSC": PL(i) = 10
    i = i + 1: OName(i) = "_ARCCOT": PL(i) = 10
    i = i + 1: OName(i) = "_SECH": PL(i) = 10
    i = i + 1: OName(i) = "_CSCH": PL(i) = 10
    i = i + 1: OName(i) = "_COTH": PL(i) = 10
    i = i + 1: OName(i) = "COS": PL(i) = 10
    i = i + 1: OName(i) = "SIN": PL(i) = 10
    i = i + 1: OName(i) = "TAN": PL(i) = 10
    i = i + 1: OName(i) = "LOG": PL(i) = 10
    i = i + 1: OName(i) = "EXP": PL(i) = 10
    i = i + 1: OName(i) = "ATN": PL(i) = 10
    i = i + 1: OName(i) = "_D2R": PL(i) = 10
    i = i + 1: OName(i) = "_D2G": PL(i) = 10
    i = i + 1: OName(i) = "_R2D": PL(i) = 10
    i = i + 1: OName(i) = "_R2G": PL(i) = 10
    i = i + 1: OName(i) = "_G2D": PL(i) = 10
    i = i + 1: OName(i) = "_G2R": PL(i) = 10
    i = i + 1: OName(i) = "ABS": PL(i) = 10
    i = i + 1: OName(i) = "SGN": PL(i) = 10
    i = i + 1: OName(i) = "INT": PL(i) = 10
    i = i + 1: OName(i) = "_ROUND": PL(i) = 10
    i = i + 1: OName(i) = "_CEIL": PL(i) = 10
    i = i + 1: OName(i) = "FIX": PL(i) = 10
    i = i + 1: OName(i) = "_SEC": PL(i) = 10
    i = i + 1: OName(i) = "_CSC": PL(i) = 10
    i = i + 1: OName(i) = "_COT": PL(i) = 10
    i = i + 1: OName(i) = "ASC": PL(i) = 10
    i = i + 1: OName(i) = "C_RG": PL(i) = 10 '_RGB32 converted
    i = i + 1: OName(i) = "C_RA": PL(i) = 10 '_RGBA32 converted
    i = i + 1: OName(i) = "_RGB": PL(i) = 10
    i = i + 1: OName(i) = "_RGBA": PL(i) = 10
    i = i + 1: OName(i) = "C_RX": PL(i) = 10 '_RED32 converted
    i = i + 1: OName(i) = "C_GR": PL(i) = 10 ' _GREEN32 converted
    i = i + 1: OName(i) = "C_BL": PL(i) = 10 '_BLUE32 converted
    i = i + 1: OName(i) = "C_AL": PL(i) = 10 '_ALPHA32 converted
    i = i + 1: OName(i) = "_RED": PL(i) = 10
    i = i + 1: OName(i) = "_GREEN": PL(i) = 10
    i = i + 1: OName(i) = "_BLUE": PL(i) = 10
    i = i + 1: OName(i) = "_ALPHA": PL(i) = 10

    'Exponents with PL 20
    i = i + 1: OName(i) = "^": PL(i) = 20
    i = i + 1: OName(i) = "SQR": PL(i) = 20
    i = i + 1: OName(i) = "ROOT": PL(i) = 20
    'Multiplication and Division PL 30
    i = i + 1: OName(i) = "*": PL(i) = 30
    i = i + 1: OName(i) = "/": PL(i) = 30
    'Integer Division PL 40
    i = i + 1: OName(i) = "\": PL(i) = 40
    'MOD PL 50
    i = i + 1: OName(i) = "MOD": PL(i) = 50
    'Addition and Subtraction PL 60
    i = i + 1: OName(i) = "+": PL(i) = 60
    i = i + 1: OName(i) = "-": PL(i) = 60

    'Relational Operators =, >, <, <>, <=, >=   PL 70
    i = i + 1: OName(i) = "<>": PL(i) = 70 'These next three are just reversed symbols as an attempt to help process a common typo
    i = i + 1: OName(i) = "><": PL(i) = 70
    i = i + 1: OName(i) = "<=": PL(i) = 70
    i = i + 1: OName(i) = ">=": PL(i) = 70
    i = i + 1: OName(i) = "=<": PL(i) = 70 'I personally can never keep these things straight.  Is it < = or = <...
    i = i + 1: OName(i) = "=>": PL(i) = 70 'Who knows, check both!
    i = i + 1: OName(i) = ">": PL(i) = 70
    i = i + 1: OName(i) = "<": PL(i) = 70
    i = i + 1: OName(i) = "=": PL(i) = 70
    'Logical Operations PL 80+
    i = i + 1: OName(i) = "NOT": PL(i) = 80
    i = i + 1: OName(i) = "AND": PL(i) = 90
    i = i + 1: OName(i) = "OR": PL(i) = 100
    i = i + 1: OName(i) = "XOR": PL(i) = 110
    i = i + 1: OName(i) = "EQV": PL(i) = 120
    i = i + 1: OName(i) = "IMP": PL(i) = 130
    i = i + 1: OName(i) = ",": PL(i) = 1000

    ReDim _Preserve OName(i) As String, PL(i) As Integer
End Sub

Function EvaluateNumbers$ (p, num() As String)
    Dim n1 As _Float, n2 As _Float, n3 As _Float
    'PRINT "EVALNUM:"; OName(p), num(1), num(2)

    If _Trim$(num(1)) = "" Then num(1) = "0"

    If PL(p) >= 20 And (Len(_Trim$(num(1))) = 0 Or Len(_Trim$(num(2))) = 0) Then
        EvaluateNumbers$ = "ERROR - Missing operand": Exit Function
    End If

    If InStr(num(1), ",") Then
        EvaluateNumbers$ = "ERROR - Invalid comma (" + num(1) + ")": Exit Function
    End If
    l2 = InStr(num(2), ",")
    If l2 Then
        Select Case OName(p) 'only certain commands should pass a comma value
            Case "C_RG", "C_RA", "_RGB", "_RGBA", "_RED", "_GREEN", "C_BL", "_ALPHA"
            Case Else
                C$ = Mid$(num(2), l2)
                num(2) = Left$(num(2), l2 - 1)
        End Select
    End If

    Select Case PL(p) 'divide up the work so we want do as much case checking
        Case 5 'Type conversions
            'Note, these are special cases and work with the number BEFORE the command and not after
            Select Case OName(p) 'Depending on our operator..
                Case "C_UOF": n1~%& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~%&)))
                Case "C_ULO": n1%& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1%&)))
                Case "C_UBY": n1~%% = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~%%)))
                Case "C_UIN": n1~% = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~%)))
                Case "C_BY": n1%% = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1%%)))
                Case "C_IN": n1% = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1%)))
                Case "C_UIF": n1~&& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~&&)))
                Case "C_OF": n1~& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~&)))
                Case "C_IF": n1&& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1&&)))
                Case "C_LO": n1& = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1&)))
                Case "C_UBI": n1~` = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1~`)))
                Case "C_BI": n1` = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1`)))
                Case "C_FL": n1## = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1##)))
                Case "C_DO": n1# = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1#)))
                Case "C_SI": n1! = Val(num(1)): EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1!)))
            End Select
            Exit Function
        Case 10 'functions
            Select Case OName(p) 'Depending on our operator..
                Case "_PI"
                    n1 = 3.14159265358979323846264338327950288## 'Future compatable in case something ever stores extra digits for PI
                    If num(2) <> "" Then n1 = n1 * Val(num(2))
                Case "_ACOS": n1 = _Acos(Val(num(2)))
                Case "_ASIN": n1 = _Asin(Val(num(2)))
                Case "_ARCSEC": n1 = _Arcsec(Val(num(2)))
                Case "_ARCCSC": n1 = _Arccsc(Val(num(2)))
                Case "_ARCCOT": n1 = _Arccot(Val(num(2)))
                Case "_SECH": n1 = _Sech(Val(num(2)))
                Case "_CSCH": n1 = _Csch(Val(num(2)))
                Case "_COTH": n1 = _Coth(Val(num(2)))
                Case "C_RG"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null _RGB32": Exit Function
                    c1 = InStr(n$, ",")
                    If c1 Then c2 = InStr(c1 + 1, n$, ",")
                    If c2 Then c3 = InStr(c2 + 1, n$, ",")
                    If c3 Then c4 = InStr(c3 + 1, n$, ",")
                    If c1 = 0 Then 'there's no comma in the command to parse.  It's a grayscale value
                        n = Val(num(2))
                        n1 = _RGB32(n, n, n)
                    ElseIf c2 = 0 Then 'there's one comma and not 2.  It's grayscale with alpha.
                        n = Val(Left$(num(2), c1))
                        n2 = Val(Mid$(num(2), c1 + 1))
                        n1 = _RGBA32(n, n, n, n2)
                    ElseIf c3 = 0 Then 'there's two commas.  It's _RGB values
                        n = Val(Left$(num(2), c1))
                        n2 = Val(Mid$(num(2), c1 + 1))
                        n3 = Val(Mid$(num(2), c2 + 1))
                        n1 = _RGB32(n, n2, n3)
                    ElseIf c4 = 0 Then 'there's three commas.  It's _RGBA values
                        n = Val(Left$(num(2), c1))
                        n2 = Val(Mid$(num(2), c1 + 1))
                        n3 = Val(Mid$(num(2), c2 + 1))
                        n4 = Val(Mid$(num(2), c3 + 1))
                        n1 = _RGBA32(n, n2, n3, n4)
                    Else 'we have more than three commas.  I have no idea WTH type of values got passed here!
                        EvaluateNumbers$ = "ERROR - Invalid comma count (" + num(2) + ")": Exit Function
                    End If
                Case "C_RA"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null _RGBA32": Exit Function
                    c1 = InStr(n$, ",")
                    If c1 Then c2 = InStr(c1 + 1, n$, ",")
                    If c2 Then c3 = InStr(c2 + 1, n$, ",")
                    If c3 Then c4 = InStr(c3 + 1, n$, ",")
                    If c3 = 0 Or c4 <> 0 Then EvaluateNumbers$ = "ERROR - Invalid comma count (" + num(2) + ")": Exit Function
                    'we have to have 3 commas; not more, not less.
                    n = Val(Left$(num(2), c1))
                    n2 = Val(Mid$(num(2), c1 + 1))
                    n3 = Val(Mid$(num(2), c2 + 1))
                    n4 = Val(Mid$(num(2), c3 + 1))
                    n1 = _RGBA32(n, n2, n3, n4)
                Case "_RGB"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null _RGB": Exit Function
                    c1 = InStr(n$, ",")
                    If c1 Then c2 = InStr(c1 + 1, n$, ",")
                    If c2 Then c3 = InStr(c2 + 1, n$, ",")
                    If c3 Then c4 = InStr(c3 + 1, n$, ",")
                    If c3 = 0 Or c4 <> 0 Then EvaluateNumbers$ = "ERROR - Invalid comma count (" + num(2) + "). _RGB requires 4 parameters for Red, Green, Blue, ScreenMode.": Exit Function
                    'we have to have 3 commas; not more, not less.
                    n = Val(Left$(num(2), c1))
                    n2 = Val(Mid$(num(2), c1 + 1))
                    n3 = Val(Mid$(num(2), c2 + 1))
                    n4 = Val(Mid$(num(2), c3 + 1))
                    Select Case n4
                        Case 0 To 2, 7 To 13, 256, 32 'these are the good screen values
                        Case Else
                            EvaluateNumbers$ = "ERROR - Invalid Screen Mode (" + Str$(n4) + ")": Exit Function
                    End Select
                    t = _NewImage(1, 1, n4)
                    n1 = _RGB(n, n2, n3, t)
                    _FreeImage t
                Case "_RGBA"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null _RGBA": Exit Function
                    c1 = InStr(n$, ",")
                    If c1 Then c2 = InStr(c1 + 1, n$, ",")
                    If c2 Then c3 = InStr(c2 + 1, n$, ",")
                    If c3 Then c4 = InStr(c3 + 1, n$, ",")
                    If c4 Then c5 = InStr(c4 + 1, n$, ",")
                    If c4 = 0 Or c5 <> 0 Then EvaluateNumbers$ = "ERROR - Invalid comma count (" + num(2) + "). _RGBA requires 5 parameters for Red, Green, Blue, Alpha, ScreenMode.": Exit Function
                    'we have to have 4 commas; not more, not less.
                    n = Val(Left$(num(2), c1))
                    n2 = Val(Mid$(num(2), c1 + 1))
                    n3 = Val(Mid$(num(2), c2 + 1))
                    n4 = Val(Mid$(num(2), c3 + 1))
                    n5 = Val(Mid$(num(2), c4 + 1))
                    Select Case n5
                        Case 0 To 2, 7 To 13, 256, 32 'these are the good screen values
                        Case Else
                            EvaluateNumbers$ = "ERROR - Invalid Screen Mode (" + Str$(n5) + ")": Exit Function
                    End Select
                    t = _NewImage(1, 1, n5)
                    n1 = _RGBA(n, n2, n3, n4, t)
                    _FreeImage t
                Case "_RED", "_GREEN", "_BLUE", "_ALPHA"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null " + OName(p): Exit Function
                    c1 = InStr(n$, ",")
                    If c1 = 0 Then EvaluateNumbers$ = "ERROR - " + OName(p) + " requires 2 parameters for Color, ScreenMode.": Exit Function
                    If c1 Then c2 = InStr(c1 + 1, n$, ",")
                    If c2 Then EvaluateNumbers$ = "ERROR - " + OName(p) + " requires 2 parameters for Color, ScreenMode.": Exit Function
                    n = Val(Left$(num(2), c1))
                    n2 = Val(Mid$(num(2), c1 + 1))
                    Select Case n2
                        Case 0 To 2, 7 To 13, 256, 32 'these are the good screen values
                        Case Else
                            EvaluateNumbers$ = "ERROR - Invalid Screen Mode (" + Str$(n2) + ")": Exit Function
                    End Select
                    t = _NewImage(1, 1, n4)
                    Select Case OName(p)
                        Case "_RED": n1 = _Red(n, t)
                        Case "_BLUE": n1 = _Blue(n, t)
                        Case "_GREEN": n1 = _Green(n, t)
                        Case "_ALPHA": n1 = _Alpha(n, t)
                    End Select
                    _FreeImage t
                Case "C_RX", "C_GR", "C_BL", "C_AL"
                    n$ = num(2)
                    If n$ = "" Then EvaluateNumbers$ = "ERROR - Invalid null " + OName(p): Exit Function
                    n = Val(num(2))
                    Select Case OName(p)
                        Case "C_RX": n1 = _Red32(n)
                        Case "C_BL": n1 = _Blue32(n)
                        Case "C_GR": n1 = _Green32(n)
                        Case "C_AL": n1 = _Alpha32(n)
                    End Select
                Case "COS": n1 = Cos(Val(num(2)))
                Case "SIN": n1 = Sin(Val(num(2)))
                Case "TAN": n1 = Tan(Val(num(2)))
                Case "LOG": n1 = Log(Val(num(2)))
                Case "EXP": n1 = Exp(Val(num(2)))
                Case "ATN": n1 = Atn(Val(num(2)))
                Case "_D2R": n1 = 0.0174532925 * (Val(num(2)))
                Case "_D2G": n1 = 1.1111111111 * (Val(num(2)))
                Case "_R2D": n1 = 57.2957795 * (Val(num(2)))
                Case "_R2G": n1 = 0.015707963 * (Val(num(2)))
                Case "_G2D": n1 = 0.9 * (Val(num(2)))
                Case "_G2R": n1 = 63.661977237 * (Val(num(2)))
                Case "ABS": n1 = Abs(Val(num(2)))
                Case "SGN": n1 = Sgn(Val(num(2)))
                Case "INT": n1 = Int(Val(num(2)))
                Case "_ROUND": n1 = _Round(Val(num(2)))
                Case "_CEIL": n1 = _Ceil(Val(num(2)))
                Case "FIX": n1 = Fix(Val(num(2)))
                Case "_SEC": n1 = _Sec(Val(num(2)))
                Case "_CSC": n1 = _Csc(Val(num(2)))
                Case "_COT": n1 = _Cot(Val(num(2)))
            End Select
        Case 20 To 60 'Math Operators
            Select Case OName(p) 'Depending on our operator..
                Case "^": n1 = Val(num(1)) ^ Val(num(2))
                Case "SQR": n1 = Sqr(Val(num(2)))
                Case "ROOT"
                    n1 = Val(num(1)): n2 = Val(num(2))
                    If n2 = 1 Then EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1))): Exit Function
                    If n1 < 0 And n2 >= 1 Then sign = -1: n1 = -n1 Else sign = 1
                    n3 = 1## / n2
                    If n3 <> Int(n3) And n2 < 1 Then sign = Sgn(n1): n1 = Abs(n1)
                    n1 = sign * (n1 ^ n3)
                Case "*": n1 = Val(num(1)) * Val(num(2))
                Case "/"
                    If Val(num(2)) <> 0 Then
                        n1 = Val(num(1)) / Val(num(2))
                    Else
                        EvaluateNumbers$ = "ERROR - Division By Zero"
                        Exit Function
                    End If
                Case "\"
                    If Val(num(2)) <> 0 Then
                        n1 = Val(num(1)) \ Val(num(2))
                    Else
                        EvaluateNumbers$ = "ERROR - Division By Zero"
                        Exit Function
                    End If
                Case "MOD"
                    If Val(num(2)) <> 0 Then
                        n1 = Val(num(1)) Mod Val(num(2))
                    Else
                        EvaluateNumbers$ = "ERROR - Division By Zero"
                        Exit Function
                    End If
                Case "+": n1 = Val(num(1)) + Val(num(2))
                Case "-":
                    n1 = Val(num(1)) - Val(num(2))
            End Select
        Case 70 'Relational Operators =, >, <, <>, <=, >=
            Select Case OName(p) 'Depending on our operator..
                Case "=": n1 = Val(num(1)) = Val(num(2))
                Case ">": n1 = Val(num(1)) > Val(num(2))
                Case "<": n1 = Val(num(1)) < Val(num(2))
                Case "<>", "><": n1 = Val(num(1)) <> Val(num(2))
                Case "<=", "=<": n1 = Val(num(1)) <= Val(num(2))
                Case ">=", "=>": n1 = Val(num(1)) >= Val(num(2))
            End Select
        Case Else 'a value we haven't processed elsewhere
            Select Case OName(p) 'Depending on our operator..
                Case "NOT": n1 = Not Val(num(2))
                Case "AND": n1 = Val(num(1)) And Val(num(2))
                Case "OR": n1 = Val(num(1)) Or Val(num(2))
                Case "XOR": n1 = Val(num(1)) Xor Val(num(2))
                Case "EQV": n1 = Val(num(1)) Eqv Val(num(2))
                Case "IMP": n1 = Val(num(1)) Imp Val(num(2))
            End Select
    End Select

    EvaluateNumbers$ = RTrim$(LTrim$(Str$(n1))) + C$
End Function

Function DWD$ (exp$) 'Deal With Duplicates
    'To deal with duplicate operators in our code.
    'Such as --  becomes a +
    '++ becomes a +
    '+- becomes a -
    '-+ becomes a -
    t$ = exp$
    Do
        bad = 0
        Do
            l = InStr(t$, "++")
            If l Then t$ = Left$(t$, l - 1) + "+" + Mid$(t$, l + 2): bad = -1
        Loop Until l = 0
        Do
            l = InStr(t$, "+-")
            If l Then t$ = Left$(t$, l - 1) + "-" + Mid$(t$, l + 2): bad = -1
        Loop Until l = 0
        Do
            l = InStr(t$, "-+")
            If l Then t$ = Left$(t$, l - 1) + "-" + Mid$(t$, l + 2): bad = -1
        Loop Until l = 0
        Do
            l = InStr(t$, "--")
            If l Then t$ = Left$(t$, l - 1) + "+" + Mid$(t$, l + 2): bad = -1
        Loop Until l = 0
    Loop Until Not bad
    DWD$ = t$
End Function

Sub PreParse (e$)
    Dim f As _Float
    Static TotalPrefixedPP_TypeMod As Long, TotalPP_TypeMod As Long

    If PP_TypeMod(0) = "" Then
        ReDim PP_TypeMod(100) As String, PP_ConvertedMod(100) As String 'Large enough to hold all values to begin with
        PP_TypeMod(0) = "Initialized" 'Set so we don't do this section over and over, as we keep the values in shared memory.
        'and the below is a conversion list so symbols don't get cross confused.
        i = i + 1: PP_TypeMod(i) = "~`": PP_ConvertedMod(i) = "C_UBI" 'unsigned bit
        i = i + 1: PP_TypeMod(i) = "~%%": PP_ConvertedMod(i) = "C_UBY" 'unsigned byte
        i = i + 1: PP_TypeMod(i) = "~%&": PP_ConvertedMod(i) = "C_UOF" 'unsigned offset
        i = i + 1: PP_TypeMod(i) = "~%": PP_ConvertedMod(i) = "C_UIN" 'unsigned integer
        i = i + 1: PP_TypeMod(i) = "~&&": PP_ConvertedMod(i) = "C_UIF" 'unsigned integer64
        i = i + 1: PP_TypeMod(i) = "~&": PP_ConvertedMod(i) = "C_ULO" 'unsigned long
        i = i + 1: PP_TypeMod(i) = "`": PP_ConvertedMod(i) = "C_BI" 'bit
        i = i + 1: PP_TypeMod(i) = "%%": PP_ConvertedMod(i) = "C_BY" 'byte
        i = i + 1: PP_TypeMod(i) = "%&": PP_ConvertedMod(i) = "C_OF" 'offset
        i = i + 1: PP_TypeMod(i) = "%": PP_ConvertedMod(i) = "C_IN" 'integer
        i = i + 1: PP_TypeMod(i) = "&&": PP_ConvertedMod(i) = "C_IF" 'integer64
        i = i + 1: PP_TypeMod(i) = "&": PP_ConvertedMod(i) = "C_LO" 'long
        i = i + 1: PP_TypeMod(i) = "!": PP_ConvertedMod(i) = "C_SI" 'single
        i = i + 1: PP_TypeMod(i) = "##": PP_ConvertedMod(i) = "C_FL" 'float
        i = i + 1: PP_TypeMod(i) = "#": PP_ConvertedMod(i) = "C_DO" 'double
        i = i + 1: PP_TypeMod(i) = "_RGB32": PP_ConvertedMod(i) = "C_RG" 'rgb32
        i = i + 1: PP_TypeMod(i) = "_RGBA32": PP_ConvertedMod(i) = "C_RA" 'rgba32
        i = i + 1: PP_TypeMod(i) = "_RED32": PP_ConvertedMod(i) = "C_RX" 'red32
        i = i + 1: PP_TypeMod(i) = "_GREEN32": PP_ConvertedMod(i) = "C_GR" 'green32
        i = i + 1: PP_TypeMod(i) = "_BLUE32": PP_ConvertedMod(i) = "C_BL" 'blue32
        i = i + 1: PP_TypeMod(i) = "_ALPHA32": PP_ConvertedMod(i) = "C_AL" 'alpha32
        TotalPrefixedPP_TypeMod = i
        i = i + 1: PP_TypeMod(i) = "RGB32": PP_ConvertedMod(i) = "C_RG" 'rgb32
        i = i + 1: PP_TypeMod(i) = "RGBA32": PP_ConvertedMod(i) = "C_RA" 'rgba32
        i = i + 1: PP_TypeMod(i) = "RED32": PP_ConvertedMod(i) = "C_RX" 'red32
        i = i + 1: PP_TypeMod(i) = "GREEN32": PP_ConvertedMod(i) = "C_GR" 'green32
        i = i + 1: PP_TypeMod(i) = "BLUE32": PP_ConvertedMod(i) = "C_BL" 'blue32
        i = i + 1: PP_TypeMod(i) = "ALPHA32": PP_ConvertedMod(i) = "C_AL" 'alpha32
        TotalPP_TypeMod = i
        ReDim _Preserve PP_TypeMod(i) As String, PP_ConvertedMod(i) As String 'And then resized to just contain the necessary space in memory
    End If
    t$ = e$

    'First strip all spaces
    t$ = ""
    For i = 1 To Len(e$)
        If Mid$(e$, i, 1) <> " " Then t$ = t$ + Mid$(e$, i, 1)
    Next

    t$ = UCase$(t$)
    If t$ = "" Then e$ = "ERROR -- NULL string; nothing to evaluate": Exit Sub

    'ERROR CHECK by counting our brackets
    l = 0
    Do
        l = InStr(l + 1, t$, "("): If l Then c = c + 1
    Loop Until l = 0
    l = 0
    Do
        l = InStr(l + 1, t$, ")"): If l Then c1 = c1 + 1
    Loop Until l = 0
    If c <> c1 Then e$ = "ERROR -- Bad Parenthesis:" + Str$(c) + "( vs" + Str$(c1) + ")": Exit Sub

    'replace existing CONST values
    sep$ = "()+-*/\><=^"
    For i2 = 0 To constlast
        thisConstName$ = constname(i2)
        For replaceConstPass = 1 To 2
            found = 0
            Do
                found = InStr(found + 1, UCase$(t$), thisConstName$)
                If found Then
                    If found > 1 Then
                        If InStr(sep$, Mid$(t$, found - 1, 1)) = 0 Then _Continue
                    End If
                    If found + Len(thisConstName$) <= Len(t$) Then
                        If InStr(sep$, Mid$(t$, found + Len(thisConstName$), 1)) = 0 Then _Continue
                    End If
                    t = consttype(i2)
                    If t And ISSTRING Then
                        r$ = conststring(i2)
                        i4 = _InStrRev(r$, ",")
                        r$ = Left$(r$, i4 - 1)
                    Else
                        If t And ISFLOAT Then
                            r$ = Str$(constfloat(i2))
                            r$ = N2S(r$)
                        Else
                            If t And ISUNSIGNED Then r$ = Str$(constuinteger(i2)) Else r$ = Str$(constinteger(i2))
                        End If
                    End If
                    t$ = Left$(t$, found - 1) + _Trim$(r$) + Mid$(t$, found + Len(thisConstName$))
                End If
            Loop Until found = 0
            thisConstName$ = constname(i2) + constnamesymbol(i2)
        Next
    Next

    'Modify so that NOT will process properly
    l = 0
    Do
        l = InStr(l + 1, t$, "NOT ")
        If l Then
            'We need to work magic on the statement so it looks pretty.
            ' 1 + NOT 2 + 1 is actually processed as 1 + (NOT 2 + 1)
            'Look for something not proper
            l1 = InStr(l + 1, t$, "AND")
            If l1 = 0 Or (InStr(l + 1, t$, "OR") > 0 And InStr(l + 1, t$, "OR") < l1) Then l1 = InStr(l + 1, t$, "OR")
            If l1 = 0 Or (InStr(l + 1, t$, "XOR") > 0 And InStr(l + 1, t$, "XOR") < l1) Then l1 = InStr(l + 1, t$, "XOR")
            If l1 = 0 Or (InStr(l + 1, t$, "EQV") > 0 And InStr(l + 1, t$, "EQV") < l1) Then l1 = InStr(l + 1, t$, "EQV")
            If l1 = 0 Or (InStr(l + 1, t$, "IMP") > 0 And InStr(l + 1, t$, "IMP") < l1) Then l1 = InStr(l + 1, t$, "IMP")
            If l1 = 0 Then l1 = Len(t$) + 1
            t$ = Left$(t$, l - 1) + "(" + Mid$(t$, l, l1 - l) + ")" + Mid$(t$, l + l1 - l)
            l = l + 3
            'PRINT t$
        End If
    Loop Until l = 0

    uboundPP_TypeMod = TotalPrefixedPP_TypeMod

    For j = 1 To uboundPP_TypeMod
        l = 0
        Do
            l = InStr(l + 1, t$, PP_TypeMod(j))
            If l = 0 Then Exit Do
            i = 0: l1 = 0: l2 = 0: lo = Len(PP_TypeMod(j))
            Do
                If PL(i) > 10 Then
                    l2 = _InStrRev(l, t$, OName$(i))
                    If l2 > 0 And l2 > l1 Then l1 = l2
                End If
                i = i + lo
            Loop Until i > UBound(PL)
            l$ = Left$(t$, l1)
            m$ = Mid$(t$, l1 + 1, l - l1 - 1)
            r$ = PP_ConvertedMod(j) + Mid$(t$, l + lo)
            If j > 15 Then
                t$ = l$ + m$ + r$ 'replacement routine for commands which might get confused with others, like _RGB and _RGB32
            Else
                'the first 15 commands need to properly place the parenthesis around the value we want to convert.
                t$ = l$ + "(" + m$ + ")" + r$
            End If
            l = l + 2 + Len(PP_TypeMod(j)) 'move forward from the length of the symbol we checked + the new "(" and  ")"
        Loop
    Next

    'Check for bad operators before a ( bracket
    l = 0
    Do
        l = InStr(l + 1, t$, "(")
        If l > 0 And l > 2 Then 'Don't check the starting bracket; there's nothing before it.
            good = 0
            For i = 1 To UBound(OName)
                m$ = Mid$(t$, l - Len(OName(i)), Len(OName(i)))
                If m$ = OName(i) Then
                    good = -1: Exit For 'We found an operator after our ), and it's not a CONST (like PI)
                End If
            Next
            If Not good Then e$ = "ERROR - Improper operations before (.": Exit Sub
            l = l + 1
        End If
    Loop Until l = 0

    'Check for bad operators after a ) bracket
    l = 0
    Do
        l = InStr(l + 1, t$, ")")
        If l > 0 And l < Len(t$) Then
            good = 0
            For i = 1 To UBound(OName)
                m$ = Mid$(t$, l + 1, Len(OName(i)))
                If m$ = OName(i) Then
                    good = -1: Exit For 'We found an operator after our ), and it's not a CONST (like PI
                End If
            Next
            If Mid$(t$, l + 1, 1) = ")" Then good = -1
            If Not good Then e$ = "ERROR - Improper operations after ).": Exit Sub
            l = l + 1
        End If
    Loop Until l = 0 Or l = Len(t$) 'last symbol is a bracket

    'Turn all &H (hex) numbers into decimal values for the program to process properly
    l = 0
    Do
        l = InStr(t$, "&H")
        If l Then
            E = l + 1: finished = 0
            Do
                E = E + 1
                comp$ = Mid$(t$, E, 1)
                Select Case comp$
                    Case "0" To "9", "A" To "F" 'All is good, our next digit is a number, continue to add to the hex$
                    Case Else
                        good = 0
                        For i = 1 To UBound(OName)
                            If Mid$(t$, E, Len(OName(i))) = OName(i) And PL(i) > 1 And PL(i) <= 250 Then good = -1: Exit For 'We found an operator after our ), and it's not a CONST (like PI)
                        Next
                        If Not good Then e$ = "ERROR - Improper &H value. (" + comp$ + ")": Exit Sub
                        E = E - 1
                        finished = -1
                End Select
            Loop Until finished Or E = Len(t$)
            t$ = Left$(t$, l - 1) + LTrim$(RTrim$(Str$(Val(Mid$(t$, l, E - l + 1))))) + Mid$(t$, E + 1)
        End If
    Loop Until l = 0

    'Turn all &B (binary) numbers into decimal values for the program to process properly
    l = 0
    Do
        l = InStr(t$, "&B")
        If l Then
            E = l + 1: finished = 0
            Do
                E = E + 1
                comp$ = Mid$(t$, E, 1)
                Select Case comp$
                    Case "0", "1" 'All is good, our next digit is a number, continue to add to the hex$
                    Case Else
                        good = 0
                        For i = 1 To UBound(OName)
                            If Mid$(t$, E, Len(OName(i))) = OName(i) And PL(i) > 1 And PL(i) <= 250 Then good = -1: Exit For 'We found an operator after our ), and it's not a CONST (like PI)
                        Next
                        If Not good Then e$ = "ERROR - Improper &B value. (" + comp$ + ")": Exit Sub
                        E = E - 1
                        finished = -1
                End Select
            Loop Until finished Or E = Len(t$)
            bin$ = Mid$(t$, l + 2, E - l - 1)
            For i = 1 To Len(bin$)
                If Mid$(bin$, i, 1) = "1" Then f = f + 2 ^ (Len(bin$) - i)
            Next
            t$ = Left$(t$, l - 1) + LTrim$(RTrim$(Str$(f))) + Mid$(t$, E + 1)
        End If
    Loop Until l = 0


    't$ = N2S(t$)
    VerifyString t$
    e$ = t$
End Sub



Sub VerifyString (t$)
    'ERROR CHECK for unrecognized operations
    j = 1
    Do
        comp$ = Mid$(t$, j, 1)
        Select Case comp$
            Case "0" To "9", ".", "(", ")", ",": j = j + 1
            Case Else
                good = 0
                extrachar = 0
                For i = 1 To UBound(OName)
                    If Mid$(t$, j, Len(OName(i))) = OName(i) Then
                        good = -1: Exit For 'We found an operator after our ), and it's not a CONST (like PI)
                    End If
                Next
                If Not good Then t$ = "ERROR - Bad Operational value. (" + comp$ + ")": Exit Sub
                j = j + (Len(OName(i)) - extrachar)
        End Select
    Loop Until j > Len(t$)
End Sub

Function N2S$ (exp$) 'scientific Notation to String

    t$ = LTrim$(RTrim$(exp$))
    If Left$(t$, 1) = "-" Or Left$(t$, 1) = "N" Then sign$ = "-": t$ = Mid$(t$, 2)

    dp = InStr(t$, "D+"): dm = InStr(t$, "D-")
    ep = InStr(t$, "E+"): em = InStr(t$, "E-")
    check1 = Sgn(dp) + Sgn(dm) + Sgn(ep) + Sgn(em)
    If check1 < 1 Or check1 > 1 Then N2S = exp$: Exit Function 'If no scientic notation is found, or if we find more than 1 type, it's not SN!

    Select Case l 'l now tells us where the SN starts at.
        Case Is < dp: l = dp
        Case Is < dm: l = dm
        Case Is < ep: l = ep
        Case Is < em: l = em
    End Select

    l$ = Left$(t$, l - 1) 'The left of the SN
    r$ = Mid$(t$, l + 1): r&& = Val(r$) 'The right of the SN, turned into a workable long


    If InStr(l$, ".") Then 'Location of the decimal, if any
        If r&& > 0 Then
            r&& = r&& - Len(l$) + 2
        Else
            r&& = r&& + 1
        End If
        l$ = Left$(l$, 1) + Mid$(l$, 3)
    End If

    Select Case r&&
        Case 0 'what the heck? We solved it already?
            'l$ = l$
        Case Is < 0
            For i = 1 To -r&&
                l$ = "0" + l$
            Next
            l$ = "0." + l$
        Case Else
            For i = 1 To r&&
                l$ = l$ + "0"
            Next
    End Select

    N2S$ = sign$ + l$
End Function

Function QuotedFilename$ (f$)
    QuotedFilename$ = "'" + f$ + "'"
    Exit Function
End Function

Function HashValue& (a$) 'returns the hash table value of a string
    '[5(first)][5(second)][5(last)][5(2nd-last)][3(length AND 7)][1(first char is underscore)]
    l = Len(a$)
    If l = 0 Then Exit Function 'an (invalid) NULL string equates to 0
    a = Asc(a$)
    If a <> 95 Then 'does not begin with underscore
        Select Case l
            Case 1
                HashValue& = hash1char(a) + 1048576
                Exit Function
            Case 2
                HashValue& = hash2char(CVI(a$)) + 2097152
                Exit Function
            Case 3
                HashValue& = hash2char(CVI(a$)) + hash1char(Asc(a$, 3)) * 1024 + 3145728
                Exit Function
            Case Else
                HashValue& = hash2char(CVI(a$)) + hash2char(Asc(a$, l) + Asc(a$, l - 1) * 256) * 1024 + (l And 7) * 1048576
                Exit Function
        End Select
    Else 'does begin with underscore
        Select Case l
            Case 1
                HashValue& = (1048576 + 8388608): Exit Function 'note: underscore only is illegal in QB64 but supported by hash
            Case 2
                HashValue& = hash1char(Asc(a$, 2)) + (2097152 + 8388608)
                Exit Function
            Case 3
                HashValue& = hash2char(Asc(a$, 2) + Asc(a$, 3) * 256) + (3145728 + 8388608)
                Exit Function
            Case 4
                HashValue& = hash2char((CVL(a$) And &HFFFF00) \ 256) + hash1char(Asc(a$, 4)) * 1024 + (4194304 + 8388608)
                Exit Function
            Case Else
                HashValue& = hash2char((CVL(a$) And &HFFFF00) \ 256) + hash2char(Asc(a$, l) + Asc(a$, l - 1) * 256) * 1024 + (l And 7) * 1048576 + 8388608
                Exit Function
        End Select
    End If
End Function

Sub HashAdd (a$, flags, reference)

    'find the index to use
    If HashListFreeLast > 0 Then
        'take from free list
        i = HashListFree(HashListFreeLast)
        HashListFreeLast = HashListFreeLast - 1
    Else
        If HashListNext > HashListSize Then
            'double hash list size
            HashListSize = HashListSize * 2
            ReDim _Preserve HashList(1 To HashListSize) As HashListItem
            ReDim _Preserve HashListName(1 To HashListSize) As String * 256
        End If
        i = HashListNext
        HashListNext = HashListNext + 1
    End If

    'setup links to index
    x = HashValue(a$)
    i2 = HashTable(x)
    If i2 Then
        i3 = HashList(i2).LastItem
        HashList(i2).LastItem = i
        HashList(i3).NextItem = i
        HashList(i).PrevItem = i3
    Else
        HashTable(x) = i
        HashList(i).PrevItem = 0
        HashList(i).LastItem = i
    End If
    HashList(i).NextItem = 0

    'set common hashlist values
    HashList(i).Flags = flags
    HashList(i).Reference = reference
    HashListName(i) = UCase$(a$)

End Sub

Function HashFind (a$, searchflags, resultflags, resultreference)
    '(0,1,2)z=hashfind[rev]("RUMI",Hashflag_label,resflag,resref)
    '0=doesn't exist
    '1=found, no more items to scan
    '2=found, more items still to scan
    i = HashTable(HashValue(a$))
    If i Then
        ua$ = UCase$(a$) + Space$(256 - Len(a$))
        hashfind_next:
        f = HashList(i).Flags
        If searchflags And f Then 'flags in common
            If HashListName(i) = ua$ Then
                resultflags = f
                resultreference = HashList(i).Reference
                i2 = HashList(i).NextItem
                If i2 Then
                    HashFind = 2
                    HashFind_NextListItem = i2
                    HashFind_Reverse = 0
                    HashFind_SearchFlags = searchflags
                    HashFind_Name = ua$
                    HashRemove_LastFound = i
                    Exit Function
                Else
                    HashFind = 1
                    HashRemove_LastFound = i
                    Exit Function
                End If
            End If
        End If
        i = HashList(i).NextItem
        If i Then GoTo hashfind_next
    End If
End Function

Function HashFindRev (a$, searchflags, resultflags, resultreference)
    '(0,1,2)z=hashfind[rev]("RUMI",Hashflag_label,resflag,resref)
    '0=doesn't exist
    '1=found, no more items to scan
    '2=found, more items still to scan
    i = HashTable(HashValue(a$))
    If i Then
        i = HashList(i).LastItem
        ua$ = UCase$(a$) + Space$(256 - Len(a$))
        hashfindrev_next:
        f = HashList(i).Flags
        If searchflags And f Then 'flags in common
            If HashListName(i) = ua$ Then
                resultflags = f
                resultreference = HashList(i).Reference
                i2 = HashList(i).PrevItem
                If i2 Then
                    HashFindRev = 2
                    HashFind_NextListItem = i2
                    HashFind_Reverse = 1
                    HashFind_SearchFlags = searchflags
                    HashFind_Name = ua$
                    HashRemove_LastFound = i
                    Exit Function
                Else
                    HashFindRev = 1
                    HashRemove_LastFound = i
                    Exit Function
                End If
            End If
        End If
        i = HashList(i).PrevItem
        If i Then GoTo hashfindrev_next
    End If
End Function

Function HashFindCont (resultflags, resultreference)
    '(0,1,2)z=hashfind[rev](resflag,resref)
    '0=no more items exist
    '1=found, no more items to scan
    '2=found, more items still to scan
    If HashFind_Reverse Then

        i = HashFind_NextListItem
        hashfindrevc_next:
        f = HashList(i).Flags
        If HashFind_SearchFlags And f Then 'flags in common
            If HashListName(i) = HashFind_Name Then
                resultflags = f
                resultreference = HashList(i).Reference
                i2 = HashList(i).PrevItem
                If i2 Then
                    HashFindCont = 2
                    HashFind_NextListItem = i2
                    HashRemove_LastFound = i
                    Exit Function
                Else
                    HashFindCont = 1
                    HashRemove_LastFound = i
                    Exit Function
                End If
            End If
        End If
        i = HashList(i).PrevItem
        If i Then GoTo hashfindrevc_next
        Exit Function

    Else

        i = HashFind_NextListItem
        hashfindc_next:
        f = HashList(i).Flags
        If HashFind_SearchFlags And f Then 'flags in common
            If HashListName(i) = HashFind_Name Then
                resultflags = f
                resultreference = HashList(i).Reference
                i2 = HashList(i).NextItem
                If i2 Then
                    HashFindCont = 2
                    HashFind_NextListItem = i2
                    HashRemove_LastFound = i
                    Exit Function
                Else
                    HashFindCont = 1
                    HashRemove_LastFound = i
                    Exit Function
                End If
            End If
        End If
        i = HashList(i).NextItem
        If i Then GoTo hashfindc_next
        Exit Function

    End If
End Function

Sub HashRemove

    i = HashRemove_LastFound

    'add to free list
    HashListFreeLast = HashListFreeLast + 1
    If HashListFreeLast > HashListFreeSize Then
        HashListFreeSize = HashListFreeSize * 2
        ReDim _Preserve HashListFree(1 To HashListFreeSize) As Long
    End If
    HashListFree(HashListFreeLast) = i

    'unlink
    i1 = HashList(i).PrevItem
    If i1 Then
        'not first item in list
        i2 = HashList(i).NextItem
        If i2 Then
            '(not first and) not last item
            HashList(i1).NextItem = i2
            HashList(i2).LastItem = i1
        Else
            'last item
            x = HashTable(HashValue(HashListName$(i)))
            HashList(x).LastItem = i1
            HashList(i1).NextItem = 0
        End If
    Else
        'first item in list
        x = HashTable(HashValue(HashListName$(i)))
        i2 = HashList(i).NextItem
        If i2 Then
            '(first item but) not last item
            HashTable(x) = i2
            HashList(i2).PrevItem = 0
            HashList(i2).LastItem = HashList(i).LastItem
        Else
            '(first and) last item
            HashTable(x) = 0
        End If
    End If

End Sub

Sub HashDump 'used for debugging purposes
    fh = FreeFile
    Open "hashdump.txt" For Output As #fh
    b$ = "12345678901234567890123456789012}"
    For x = 0 To 16777215
        If HashTable(x) Then

            Print #fh, "START HashTable("; x; "):"
            i = HashTable(x)

            'validate
            lasti = HashList(i).LastItem
            If HashList(i).LastItem = 0 Or HashList(i).PrevItem <> 0 Or HashValue(HashListName(i)) <> x Then GoTo corrupt

            Print #fh, "  HashList("; i; ").LastItem="; HashList(i).LastItem
            hashdumpnextitem:
            x$ = "  [" + Str$(i) + "]" + HashListName(i)

            f = HashList(i).Flags
            x$ = x$ + ",.Flags=" + Str$(f) + "{"
            For z = 1 To 32
                Asc(b$, z) = (f And 1) + 48
                f = f \ 2
            Next
            x$ = x$ + b$

            x$ = x$ + ",.Reference=" + Str$(HashList(i).Reference)

            Print #fh, x$

            'validate
            i1 = HashList(i).PrevItem
            i2 = HashList(i).NextItem
            If i1 Then
                If HashList(i1).NextItem <> i Then GoTo corrupt
            End If
            If i2 Then
                If HashList(i2).PrevItem <> i Then GoTo corrupt
            End If
            If i2 = 0 Then
                If lasti <> i Then GoTo corrupt
            End If

            i = HashList(i).NextItem
            If i Then GoTo hashdumpnextitem

            Print #fh, "END HashTable("; x; ")"
        End If
    Next
    Close #fh

    Exit Sub
    corrupt:
    Print #fh, "HASH TABLE CORRUPT!" 'should never happen
    Close #fh

End Sub

Sub HashClear 'clear entire hash table

    HashListSize = 65536
    HashListNext = 1
    HashListFreeSize = 1024
    HashListFreeLast = 0
    ReDim HashList(1 To HashListSize) As HashListItem
    ReDim HashListName(1 To HashListSize) As String * 256
    ReDim HashListFree(1 To HashListFreeSize) As Long
    ReDim HashTable(16777215) As Long '64MB lookup table with indexes to the hashlist

    HashFind_NextListItem = 0
    HashFind_Reverse = 0
    HashFind_SearchFlags = 0
    HashFind_Name = ""
    HashRemove_LastFound = 0

End Sub

Function removecast$ (a$)
    removecast$ = a$
    If InStr(a$, "  )") Then
        removecast$ = Right$(a$, Len(a$) - InStr(a$, "  )") - 2)
    End If
End Function

Function converttabs$ (a2$)
    If ideautoindent Then s = ideautoindentsize Else s = 4
    a$ = a2$
    Do While InStr(a$, CHR_TAB)
        x = InStr(a$, CHR_TAB)
        a$ = Left$(a$, x - 1) + Space$(s - ((x - 1) Mod s)) + Right$(a$, Len(a$) - x)
    Loop
    converttabs$ = a$
End Function


Function NewByteElement$
    a$ = "byte_element_" + str2$(uniquenumber)
    NewByteElement$ = a$
    If use_global_byte_elements Then
        Print #18, "byte_element_struct *" + a$ + "=(byte_element_struct*)malloc(12);"
    Else
        Print #13, "byte_element_struct *" + a$ + "=NULL;"
        Print #13, "if (!" + a$ + "){"
        Print #13, "if ((mem_static_pointer+=12)<mem_static_limit) " + a$ + "=(byte_element_struct*)(mem_static_pointer-12); else " + a$ + "=(byte_element_struct*)mem_static_malloc(12);"
        Print #13, "}"
    End If
End Function

Function validname (a$)
    'notes:
    '1) '_1' is invalid because it has no alphabet letters
    '2) 'A_' is invalid because it has a trailing _
    '3) '_1A' is invalid because it contains a number before the first alphabet letter
    '4) names cannot be longer than 40 characters
    l = Len(a$)

    If l = 0 Or l > 40 Then
        If l = 0 Then Exit Function
        'Note: variable names with periods need to be obfuscated, and this affects their length
        i = InStr(a$, fix046$)
        Do While i
            l = l - Len(fix046$) + 1
            i = InStr(i + 1, a$, fix046$)
        Loop
        If l > 40 Then Exit Function
        l = Len(a$)
    End If

    'check for single, leading underscore
    If l >= 2 Then
        If Asc(a$, 1) = 95 And Asc(a$, 2) <> 95 Then Exit Function
    End If

    For i = 1 To l
        a = Asc(a$, i)
        If alphanumeric(a) = 0 Then Exit Function
        If isnumeric(a) Then
            trailingunderscore = 0
            If alphabetletter = 0 Then Exit Function
        Else
            If a = 95 Then
                trailingunderscore = 1
            Else
                alphabetletter = 1
                trailingunderscore = 0
            End If
        End If
    Next
    If trailingunderscore Then Exit Function
    validname = 1
End Function

Function str_nth$ (x)
    If x = 1 Then str_nth$ = "1st": Exit Function
    If x = 2 Then str_nth$ = "2nd": Exit Function
    If x = 3 Then str_nth$ = "3rd": Exit Function
    str_nth$ = str2(x) + "th"
End Function

Sub Give_Error (a$)
    Error_Happened = 1
    Error_Message = a$
End Sub

Sub WriteConfigSetting (section$, item$, value$)
    WriteSetting ConfigFile$, section$, item$, value$
End Sub

Function ReadConfigSetting (section$, item$, value$)
    value$ = ReadSetting$(ConfigFile$, section$, item$)
    ReadConfigSetting = (Len(value$) > 0)
End Function

Function VRGBS~& (text$, DefaultColor As _Unsigned Long)
    'Value of RGB String = VRGBS without a ton of typing
    'A function to get the RGB value back from a string such as _RGB32(255,255,255)
    'text$ is the string that we send to check for a value
    'DefaultColor is the value we send back if the string isn't in the proper format

    VRGBS~& = DefaultColor 'A return the default value if we can't parse the string properly
    If UCase$(Left$(text$, 4)) = "_RGB" Then
        rpos = InStr(text$, "(")
        gpos = InStr(rpos, text$, ",")
        bpos = InStr(gpos + 1, text$, ",")
        If rpos <> 0 And bpos <> 0 And gpos <> 0 Then
            red = Val(_Trim$(Mid$(text$, rpos + 1)))
            green = Val(_Trim$(Mid$(text$, gpos + 1)))
            blue = Val(_Trim$(Mid$(text$, bpos + 1)))
            VRGBS~& = _RGB32(red, green, blue)
        End If
    End If
End Function

Function rgbs$ (c As _Unsigned Long)
    rgbs$ = "_RGB32(" + _Trim$(Str$(_Red32(c))) + ", " + _Trim$(Str$(_Green32(c))) + ", " + _Trim$(Str$(_Blue32(c))) + ")"
End Function

Function EvalPreIF (text$, err$)
    temp$ = text$ 'so we don't corrupt the string sent to us for evaluation
    err$ = "" 'null the err message to begin with
    'first order of business is to solve for <>=
    Dim PC_Op(3) As String
    PC_Op(1) = "="
    PC_Op(2) = "<"
    PC_Op(3) = ">"
    Do
        'look for the existence of the first symbol if there is any
        firstsymbol$ = "": first = 0
        For i = 1 To UBound(PC_Op)
            temp = InStr(temp$, PC_Op(i))
            If first = 0 Then first = temp: firstsymbol$ = PC_Op(i)
            If temp <> 0 And temp < first Then first = temp: firstsymbol$ = PC_Op(i)
        Next
        If firstsymbol$ <> "" Then 'we've got = < >; let's see if we have a combination of them
            secondsymbol = 0: second = 0
            For i = first + 1 To Len(temp$)
                a$ = Mid$(temp$, i, 1)
                Select Case a$
                    Case " " 'ignore spaces
                    Case "=", "<", ">"
                        If a$ = firstsymbol$ Then err$ = "Duplicate operator (" + a$ + ")": Exit Function
                        second = i: secondsymbol$ = a$
                    Case Else 'we found a symbol we don't recognize
                        Exit For
                End Select
            Next
        End If
        If first Then 'we found a symbol
            l$ = RTrim$(Left$(temp$, first - 1))
            If second Then rightstart = second + 1 Else rightstart = first + 1

            r$ = LTrim$(Mid$(temp$, rightstart))
            symbol$ = Mid$(temp$, first, 1) + Mid$(temp$, second, 1)
            'now we check for spaces to separate this segment from any other AND/OR conditions and such
            For i = Len(l$) To 1 Step -1
                If Asc(l$, i) = 32 Then Exit For
            Next
            leftside$ = RTrim$(Left$(temp$, i))
            l$ = LTrim$(RTrim$(Mid$(temp$, i + 1, Len(l$) - i)))
            If validname(l$) = 0 Then err$ = "Invalid flag name": Exit Function
            rightstop = Len(r$)
            For i = 1 To Len(r$)
                If Asc(r$, i) = 32 Then Exit For
            Next
            rightside$ = LTrim$(Mid$(r$, i + 1))
            r$ = LTrim$(RTrim$(Left$(r$, i - 1)))
            If symbol$ = "=<" Then symbol$ = "<="
            If symbol$ = "=>" Then symbol$ = ">="
            If symbol$ = "><" Then symbol$ = "<>"
            result$ = " 0 "
            If symbol$ = "<>" Then 'check to see if we're NOT equal in any case with <>
                For i = 0 To UserDefineCount
                    If UserDefine(0, i) = l$ And UserDefine(1, i) <> r$ Then result$ = " -1 ": GoTo finishedcheck
                Next
            End If
            If InStr(symbol$, "=") Then 'check to see if we're equal in any case with =
                UserFound = 0
                For i = 0 To UserDefineCount
                    If UserDefine(0, i) = l$ Then
                        UserFound = -1
                        If UserDefine(1, i) = r$ Then result$ = " -1 ": GoTo finishedcheck
                    End If
                Next
                If UserFound = 0 And LTrim$(RTrim$(r$)) = "UNDEFINED" Then result$ = " -1 ": GoTo finishedcheck
                If UserFound = -1 And LTrim$(RTrim$(r$)) = "DEFINED" Then result$ = " -1 ": GoTo finishedcheck
            End If

            If InStr(symbol$, ">") Then 'check to see if we're greater than in any case with >
                For i = 0 To UserDefineCount
                    If VerifyNumber(r$) And VerifyNumber(UserDefine(1, i)) Then 'we're comparing numeric values
                        If UserDefine(0, i) = l$ And Val(UserDefine(1, i)) > Val(r$) Then result$ = " -1 ": GoTo finishedcheck
                    Else
                        If UserDefine(0, i) = l$ And UserDefine(1, i) > r$ Then result$ = " -1 ": GoTo finishedcheck
                    End If
                Next
            End If
            If InStr(symbol$, "<") Then 'check to see if we're less than in any case with <
                For i = 0 To UserDefineCount
                    If VerifyNumber(r$) And VerifyNumber(UserDefine(1, i)) Then 'we're comparing numeric values
                        If UserDefine(0, i) = l$ And Val(UserDefine(1, i)) < Val(r$) Then result$ = " -1 ": GoTo finishedcheck
                    Else
                        If UserDefine(0, i) = l$ And UserDefine(1, i) < r$ Then result$ = " -1 ": GoTo finishedcheck
                    End If
                Next
            End If

            finishedcheck:
            temp$ = leftside$ + result$ + rightside$
        End If
    Loop Until first = 0

    'And at this point we should now be down to a statement with nothing but AND/OR/XORS in it

    PC_Op(1) = " AND "
    PC_Op(2) = " OR "
    PC_Op(3) = " XOR "

    Do
        first = 0
        For i = 1 To UBound(PC_Op)
            If PC_Op(i) <> "" Then
                t = InStr(temp$, PC_Op(i))
                If first <> 0 Then
                    If t < first And t <> 0 Then first = t: firstsymbol = i
                Else
                    first = t: firstsymbol = i
                End If
            End If
        Next
        If first = 0 Then Exit Do
        leftside$ = RTrim$(Left$(temp$, first - 1))
        symbol$ = Mid$(temp$, first, Len(PC_Op(firstsymbol)))
        t$ = Mid$(temp$, first + Len(PC_Op(firstsymbol)))
        t = InStr(t$, " ") 'the first space we come to
        If t Then
            m$ = LTrim$(RTrim$(Left$(t$, t - 1)))
            rightside$ = LTrim$(Mid$(t$, t))
        Else
            m$ = LTrim$(Mid$(t$, t))
            rightside$ = ""
        End If
        leftresult = 0
        If VerifyNumber(leftside$) Then
            If Val(leftside$) <> 0 Then leftresult = -1
        Else
            For i = 0 To UserDefineCount
                If UserDefine(0, i) = leftside$ Then
                    t$ = LTrim$(RTrim$(UserDefine(1, i)))
                    If t$ <> "0" And t$ <> "" Then leftresult = -1: Exit For
                End If
            Next
        End If
        rightresult = 0
        If VerifyNumber(m$) Then
            If Val(m$) <> 0 Then rightresult = -1
        Else
            For i = 0 To UserDefineCount
                If UserDefine(0, i) = m$ Then
                    t$ = LTrim$(RTrim$(UserDefine(1, i)))
                    If t$ <> "0" And t$ <> "" Then rightresult = -1: Exit For
                End If
            Next
        End If
        Select Case LTrim$(RTrim$(symbol$))
            Case "AND"
                If leftresult <> 0 And rightresult <> 0 Then result$ = " -1 " Else result$ = " 0 "
            Case "OR"
                If leftresult <> 0 Or rightresult <> 0 Then result$ = " -1 " Else result$ = " 0 "
            Case "XOR"
                If leftresult <> rightresult Then result$ = " -1 " Else result$ = " 0 "
        End Select
        temp$ = result$ + rightside$
    Loop

    If VerifyNumber(temp$) Then
        EvalPreIF = Val(temp$)
    Else
        If InStr(temp$, " ") Then err$ = "Invalid Resolution of $IF; check statements" 'If we've got more than 1 statement, it's invalid
        For i = 0 To UserDefineCount
            If UserDefine(0, i) = temp$ Then
                t$ = LTrim$(RTrim$(UserDefine(1, i)))
                If t$ <> "0" And t$ <> "" Then EvalPreIF = -1: Exit For
            End If
        Next
    End If

End Function

Function VerifyNumber (text$)
    t$ = LTrim$(RTrim$(text$))
    v = Val(t$)
    t1$ = LTrim$(Str$(v))
    If t$ = t1$ Then VerifyNumber = -1
End Function

Sub initialise_udt_varstrings (n$, udt, file, base_offset)
    If Not udtxvariable(udt) Then Exit Sub
    element = udtxnext(udt)
    offset = 0
    Do While element
        If udtetype(element) And ISSTRING Then
            If (udtetype(element) And ISFIXEDLENGTH) = 0 Then
                Print #file, "*(qbs**)(((char*)" + n$ + ")+" + Str$(base_offset + offset) + ") = qbs_new(0,0);"
            End If
        ElseIf udtetype(element) And ISUDT Then
            initialise_udt_varstrings n$, udtetype(element) And 511, file, offset
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub

Sub free_udt_varstrings (n$, udt, file, base_offset)
    If Not udtxvariable(udt) Then Exit Sub
    element = udtxnext(udt)
    offset = 0
    Do While element
        If udtetype(element) And ISSTRING Then
            If (udtetype(element) And ISFIXEDLENGTH) = 0 Then
                Print #file, "qbs_free(*((qbs**)(((char*)" + n$ + ")+" + Str$(base_offset + offset) + ")));"
            End If
        ElseIf udtetype(element) And ISUDT Then
            initialise_udt_varstrings n$, udtetype(element) And 511, file, offset
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub

Sub clear_udt_with_varstrings (n$, udt, file, base_offset)
    If Not udtxvariable(udt) Then Exit Sub
    element = udtxnext(udt)
    offset = 0
    Do While element
        If udtetype(element) And ISSTRING Then
            If (udtetype(element) And ISFIXEDLENGTH) = 0 Then
                Print #file, "(*(qbs**)(((char*)" + n$ + ")+" + Str$(base_offset + offset) + "))->len=0;"
            Else
                Print #file, "memset((char*)" + n$ + "+" + Str$(base_offset + offset) + ",0," + Str$(udtesize(element) \ 8) + ");"
            End If
        Else
            If udtetype(element) And ISUDT Then
                clear_udt_with_varstrings n$, udtetype(element) And 511, file, base_offset + offset
            Else
                Print #file, "memset((char*)" + n$ + "+" + Str$(base_offset + offset) + ",0," + Str$(udtesize(element) \ 8) + ");"
            End If
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub


Sub initialise_array_udt_varstrings (n$, udt, base_offset, bytesperelement$, acc$)
    If Not udtxvariable(udt) Then Exit Sub
    offset = base_offset
    element = udtxnext(udt)
    Do While element
        If udtetype(element) And ISSTRING Then
            If (udtetype(element) And ISFIXEDLENGTH) = 0 Then
                acc$ = acc$ + Chr$(13) + Chr$(10) + "*(qbs**)(" + n$ + "[0]+(" + bytesperelement$ + "-1)*tmp_long+" + Str$(offset) + ")=qbs_new(0,0);"
            End If
        ElseIf udtetype(element) And ISUDT Then
            initialise_array_udt_varstrings n$, udtetype(element) And 511, offset, bytesperelement$, acc$
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub

Sub free_array_udt_varstrings (n$, udt, base_offset, bytesperelement$, acc$)
    If Not udtxvariable(udt) Then Exit Sub
    offset = base_offset
    element = udtxnext(udt)
    Do While element
        If udtetype(element) And ISSTRING Then
            If (udtetype(element) And ISFIXEDLENGTH) = 0 Then
                acc$ = acc$ + Chr$(13) + Chr$(10) + "qbs_free(*(qbs**)(" + n$ + "[0]+(" + bytesperelement$ + "-1)*tmp_long+" + Str$(offset) + "));"
            End If
        ElseIf udtetype(element) And ISUDT Then
            free_array_udt_varstrings n$, udtetype(element) And 511, offset, bytesperelement$, acc$
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub

Sub copy_full_udt (dst$, src$, file, base_offset, udt)
    If Not udtxvariable(udt) Then
        Print #file, "memcpy(" + dst$ + "+" + Str$(base_offset) + "," + src$ + "+" + Str$(base_offset) + "," + Str$(udtxsize(udt) \ 8) + ");"
        Exit Sub
    End If
    offset = base_offset
    element = udtxnext(udt)
    Do While element
        If ((udtetype(element) And ISSTRING) > 0) And (udtetype(element) And ISFIXEDLENGTH) = 0 Then
            Print #file, "qbs_set(*(qbs**)(" + dst$ + "+" + Str$(offset) + "), *(qbs**)(" + src$ + "+" + Str$(offset) + "));"
        ElseIf ((udtetype(element) And ISUDT) > 0) Then
            copy_full_udt dst$, src$, 12, offset, udtetype(element) And 511
        Else
            Print #file, "memcpy((" + dst$ + "+" + Str$(offset) + "),(" + src$ + "+" + Str$(offset) + ")," + Str$(udtesize(element) \ 8) + ");"
        End If
        offset = offset + udtesize(element) \ 8
        element = udtenext(element)
    Loop
End Sub

Sub dump_udts
    f = FreeFile
    Open "types.txt" For Output As #f
    Print #f, "Name   Size   Align? Next   Var?"
    For i = 1 To lasttype
        Print #f, RTrim$(udtxname(i)), udtxsize(i), udtxbytealign(i), udtxnext(i), udtxvariable(i)
    Next i
    Print #f, "Name   Size   Align? Next   Type   Tsize  Arr"
    For i = 1 To lasttypeelement
        Print #f, RTrim$(udtename(i)), udtesize(i), udtebytealign(i), udtenext(i), udtetype(i), udtetypesize(i), udtearrayelements(i)
    Next i
    Close #f
End Sub

Sub addWarning (whichLineNumber As Long, includeLevel As Long, incLineNumber As Long, incFileName$, header$, text$)
    warningsissued = -1
    totalWarnings = totalWarnings + 1

    If idemode = 0 And ShowWarnings Then
        thissource$ = getfilepath$(CMDLineFile)
        thissource$ = Mid$(CMDLineFile, Len(thissource$) + 1)
        thisincname$ = getfilepath$(incFileName$)
        thisincname$ = Mid$(incFileName$, Len(thisincname$) + 1)

        If Not MonochromeLoggingMode Then Color 15
        If includeLevel > 0 And incLineNumber > 0 Then
            Print thisincname$; ":";
            Print str2$(incLineNumber); ": ";
        Else
            Print thissource$; ":";
            Print str2$(whichLineNumber); ": ";
        End If

        If Not MonochromeLoggingMode Then Color 13
        Print "warning: ";
        If Not MonochromeLoggingMode Then Color 7
        Print header$

        If Len(text$) > 0 Then
            If Not MonochromeLoggingMode Then Color 2
            Print Space$(4); text$
            If Not MonochromeLoggingMode Then Color 7
        End If
    ElseIf idemode Then
        If Not IgnoreWarnings Then
            If whichLineNumber > maxLineNumber Then maxLineNumber = whichLineNumber
            If lastWarningHeader <> header$ Then
                lastWarningHeader = header$
                GoSub increaseWarningCount
                warning$(warningListItems) = header$
                warningLines(warningListItems) = 0
            End If

            GoSub increaseWarningCount
            warning$(warningListItems) = text$
            warningLines(warningListItems) = whichLineNumber
            If includeLevel > 0 Then
                thisincname$ = getfilepath$(incFileName$)
                thisincname$ = Mid$(incFileName$, Len(thisincname$) + 1)
                warningIncLines(warningListItems) = incLineNumber
                warningIncFiles(warningListItems) = thisincname$
            Else
                warningIncLines(warningListItems) = 0
                warningIncFiles(warningListItems) = ""
            End If
        End If
    End If
    Exit Sub
    increaseWarningCount:
    warningListItems = warningListItems + 1
    If warningListItems > UBound(warning$) Then
        ReDim _Preserve warning$(warningListItems + 999)
        ReDim _Preserve warningLines(warningListItems + 999) As Long
        ReDim _Preserve warningIncLines(warningListItems + 999) As Long
        ReDim _Preserve warningIncFiles(warningListItems + 999) As String
    End If
    Return
End Sub

Function SCase$ (t$)
    If ideautolayoutkwcapitals Then SCase$ = UCase$(t$) Else SCase$ = t$
End Function

Function SCase2$ (t$)
    separator$ = sp
    If ideautolayoutkwcapitals Then
        SCase2$ = UCase$(t$)
    Else
        newWord = -1
        temp$ = ""
        For i = 1 To Len(t$)
            s$ = Mid$(t$, i, 1)
            If newWord Then
                If s$ = "_" Or s$ = separator$ Then
                    temp$ = temp$ + s$
                Else
                    temp$ = temp$ + UCase$(s$)
                    newWord = 0
                End If
            Else
                If s$ = separator$ Then
                    temp$ = temp$ + separator$
                    newWord = -1
                Else
                    temp$ = temp$ + LCase$(s$)
                End If
            End If
        Next
        SCase2$ = temp$
    End If
End Function

Sub increaseUDTArrays
    x = UBound(udtxname)
    ReDim _Preserve udtxname(x + 1000) As String * 256
    ReDim _Preserve udtxcname(x + 1000) As String * 256
    ReDim _Preserve udtxsize(x + 1000) As Long
    ReDim _Preserve udtxbytealign(x + 1000) As Integer 'first element MUST be on a byte alignment & size is a multiple of 8
    ReDim _Preserve udtxnext(x + 1000) As Long
    ReDim _Preserve udtxvariable(x + 1000) As Integer 'true if the udt contains variable length elements
    'elements
    ReDim _Preserve udtename(x + 1000) As String * 256
    ReDim _Preserve udtecname(x + 1000) As String * 256
    ReDim _Preserve udtebytealign(x + 1000) As Integer
    ReDim _Preserve udtesize(x + 1000) As Long
    ReDim _Preserve udtetype(x + 1000) As Long
    ReDim _Preserve udtetypesize(x + 1000) As Long
    ReDim _Preserve udtearrayelements(x + 1000) As Long
    ReDim _Preserve udtenext(x + 1000) As Long
End Sub

'
' String manipulation functions
'

Function StrRemove$ (myString$, whatToRemove$) 'noncase sensitive
    Dim a$, b$
    Dim As Long i

    a$ = myString$
    b$ = LCase$(whatToRemove$)
    i = InStr(LCase$(a$), b$)
    Do While i
        a$ = Left$(a$, i - 1) + Right$(a$, Len(a$) - i - Len(b$) + 1)
        i = InStr(LCase$(a$), b$)
    Loop
    StrRemove$ = a$
End Function

Function StrReplace$ (myString$, find$, replaceWith$) 'noncase sensitive
    Dim a$, b$
    Dim As Long basei, i
    If Len(myString$) = 0 Then Exit Function
    a$ = myString$
    b$ = LCase$(find$)
    basei = 1
    i = InStr(basei, LCase$(a$), b$)
    Do While i
        a$ = Left$(a$, i - 1) + replaceWith$ + Right$(a$, Len(a$) - i - Len(b$) + 1)
        basei = i + Len(replaceWith$)
        i = InStr(basei, LCase$(a$), b$)
    Loop
    StrReplace$ = a$
End Function

Function gl2qb_type_convert$ (a$, symbol$, typ, ctyp$)
    symbol$ = ""

    'unsigned int
    If a$ = "GLenum" Then b$ = "_UNSIGNED LONG": symbol$ = "~&": typ = ULONGTYPE - ISPOINTER: ctyp$ = "uint32"
    If a$ = "GLbitfield" Then b$ = "_UNSIGNED LONG": symbol$ = "~&": typ = ULONGTYPE - ISPOINTER: ctyp$ = "uint32"
    If a$ = "GLuint" Then b$ = "_UNSIGNED LONG": symbol$ = "~&": typ = ULONGTYPE - ISPOINTER: ctyp$ = "uint32"

    'int
    If a$ = "GLint" Then b$ = "LONG": symbol$ = "&": typ = LONGTYPE - ISPOINTER: ctyp$ = "int32"
    If a$ = "GLsizei" Then b$ = "LONG": symbol$ = "&": typ = LONGTYPE - ISPOINTER: ctyp$ = "int32"

    'unsigned char
    If a$ = "GLboolean" Then b$ = "_UNSIGNED _BYTE": symbol$ = "~%%": typ = UBYTETYPE - ISPOINTER: ctyp$ = "uint8"
    If a$ = "GLubyte" Then b$ = "_UNSIGNED _BYTE": symbol$ = "~%%": typ = UBYTETYPE - ISPOINTER: ctyp$ = "uint8"

    'char
    If a$ = "GLbyte" Then b$ = "_BYTE": symbol$ = "%%": typ = BYTETYPE - ISPOINTER: ctyp$ = "int8"

    'unsigned short
    If a$ = "GLushort" Then b$ = "_UNSIGNED INTEGER": symbol$ = "~%": typ = UINTEGERTYPE - ISPOINTER: ctyp$ = "uint16"

    'short
    If a$ = "GLshort" Then b$ = "INTEGER": symbol$ = "%": typ = INTEGERTYPE - ISPOINTER: ctyp$ = "int16"

    'float
    If a$ = "GLfloat" Then b$ = "SINGLE": symbol$ = "!": typ = SINGLETYPE - ISPOINTER: ctyp$ = "float"
    If a$ = "GLclampf" Then b$ = "SINGLE": symbol$ = "!": typ = SINGLETYPE - ISPOINTER: ctyp$ = "float"

    'double
    If a$ = "GLdouble" Then b$ = "DOUBLE": symbol$ = "#": typ = DOUBLETYPE - ISPOINTER: ctyp$ = "double"
    If a$ = "GLclampd" Then b$ = "DOUBLE": symbol$ = "#": typ = DOUBLETYPE - ISPOINTER: ctyp$ = "double"

    'void
    If a$ = "GLvoid" Then b$ = "_OFFSET": symbol$ = "%&": typ = OFFSETTYPE - ISPOINTER: ctyp$ = "ptrszint"

    'typedef unsigned int GLenum;
    'typedef unsigned char GLboolean;
    'typedef unsigned int GLbitfield;
    'typedef signed char GLbyte;
    'typedef short GLshort;
    'typedef int GLint;
    'typedef int GLsizei;
    'typedef unsigned char GLubyte;
    'typedef unsigned short GLushort;
    'typedef unsigned int GLuint;
    'typedef float GLfloat;
    'typedef float GLclampf;
    'typedef double GLdouble;
    'typedef double GLclampd;
    'typedef void GLvoid;

    If b$ = "" Then Print "Unknown type:" + a$: End
    gl2qb_type_convert$ = b$
End Function

Function readchunk$ (a$, last_character$)
    a$ = LTrim$(RTrim$(a$))
    For x = 1 To Len(a$)
        c = Asc(a$, x)
        If c = 32 Or c = 44 Or c = 40 Or c = 41 Then last_character$ = Chr$(c): readchunk$ = Left$(a$, x - 1): a$ = LTrim$(Right$(a$, Len(a$) - x)): Exit Function
    Next
    readchunk$ = a$: last_character$ = "": a$ = ""
End Function


Sub gl_scan_header

    If GL_KIT Then hk = FreeFile: Open "internal\c\parts\core\gl_header_for_parsing\temp\gl_kit.bas" For Output As #hk
    If GL_KIT Then Print #hk, "DECLARE LIBRARY"

    d = 0: a2$ = ""
    h = FreeFile
    Open "internal\c\parts\core\gl_header_for_parsing\gl.h" For Binary As #h
    Do Until EOF(h)
        Line Input #h, a$
        If Len(a$) Then
            a$ = LTrim$(RTrim$(a$))
            If Left$(a$, 8) = "#define " Then
                a2$ = ""
                a$ = a$ + " "
                For x = 1 To Len(a$)
                    c = Asc(a$, x)
                    If c = 32 Then
                        For x2 = 1 To Len(a2$)
                            c2 = Asc(a2$, x2)
                            If c2 >= 65 And c2 <= 90 Then GoTo define_ok
                            If c2 >= 48 And c2 <= 57 And x2 <> 1 Then GoTo define_ok
                            If c2 = 95 Then GoTo define_ok
                            GoTo define_not_ok
                            define_ok:
                        Next
                        value$ = LTrim$(RTrim$(Right$(a$, Len(a$) - x)))
                        If Len(value$) = 0 Then GoTo define_not_ok

                        If Left$(value$, 2) = "0x" Then
                            value&& = Val("&H" + Right$(value$, Len(value$) - 2) + "&&")
                            'PRINT a2$, value&&
                            d = d + 1: GL_DEFINES(d) = a2$: GL_DEFINES_VALUE(d) = value&&
                        ElseIf Asc(value$) >= 48 And Asc(value$) <= 57 Then
                            value&& = Val(value$)
                            'PRINT a2$, value&&
                            d = d + 1: GL_DEFINES(d) = a2$: GL_DEFINES_VALUE(d) = value&&
                        Else
                            'PRINT a2$, value$, "?"
                            For i = 1 To d
                                If GL_DEFINES(i) = value$ Then
                                    d = d + 1: GL_DEFINES(d) = a2$: GL_DEFINES_VALUE(d) = GL_DEFINES_VALUE(i)
                                    'PRINT a2$, GL_DEFINES_VALUE(i)
                                    Exit For
                                End If
                            Next
                        End If
                        GoTo got_define
                        define_not_ok:
                        a2$ = ""
                    Else
                        a2$ = a2$ + Chr$(c)
                    End If
                Next
                got_define:
            End If '#define


            If Right$(a$, 1) = ";" Then
                a2$ = readchunk(a$, l$): If a2$ <> "WINGDIAPI" GoTo discard
                ret_type$ = readchunk(a$, l$)
                If ret_type$ = "const" Then ret_type$ = readchunk(a$, l$)

                is_func = 0: If ret_type$ <> "void" Then is_func = 1

                a2$ = readchunk(a$, l$)
                If a2$ = "*APIENTRY" Then ret_type$ = ret_type$ + "*": a2$ = "APIENTRY"
                If a2$ <> "APIENTRY" Then GoTo discard

                GL_COMMANDS_LAST = GL_COMMANDS_LAST + 1
                c = GL_COMMANDS_LAST

                hc$ = ""
                hd$ = ""
                need_helper_function = 0

                If is_func Then
                    GL_COMMANDS(c).subfunc = 1
                    If GL_KIT Then Print #hk, "FUNCTION ";
                Else
                    GL_COMMANDS(c).subfunc = 2
                    If GL_KIT Then Print #hk, "SUB ";
                End If

                proc_name$ = readchunk(a$, l$)

                GL_COMMANDS(c).cn = "_" + proc_name$: If GL_KIT Then Print #hk, proc_name$;
                GL_COMMANDS(c).callname = proc_name$

                GL_COMMANDS(c).ret = 0
                If is_func Then
                    pointer = 0: If Right$(ret_type$, 1) = "*" Then pointer = 1
                    If pointer Then
                        t$ = "_OFFSET": s$ = "&&"
                        GL_COMMANDS(c).ret = OFFSETTYPE - ISPOINTER
                        hd$ = hd$ + "ptrszint "
                        need_helper_function = 1
                    Else
                        t$ = gl2qb_type_convert(ret_type$, s$, typ, ctyp$)
                        GL_COMMANDS(c).ret = typ
                        hd$ = hd$ + ctyp$ + " "
                    End If
                    If GL_KIT Then Print #hk, s$;
                    hc$ = hc$ + "return (" + ctyp$ + ")(" + ret_type$ + ")"
                Else
                    hd$ = hd$ + "void "
                End If

                If GL_KIT Then Print #hk, "(";

                hc$ = hc$ + proc_name$ + "("
                hd$ = hd$ + "call_" + proc_name$ + "("


                GL_COMMANDS(c).args = 0
                GL_COMMANDS(c).arg = ""

                Do

                    var_type$ = readchunk(a$, l$)
                    If var_type$ = "" And l$ = "(" Then var_type$ = readchunk(a$, l$) 'space between fun name and "("?
                    If var_type$ = "const" Then var_type$ = readchunk(a$, l$)
                    If var_type$ = "void" Or var_type$ = "" Then GoTo no_arguments
                    If l$ <> "," And l$ <> ")" Then
                        var_name$ = readchunk(a$, l$)
                        If Left$(var_name$, 1) = "*" Then var_type$ = var_type$ + "*": var_name$ = Right$(var_name$, Len(var_name$) - 1)
                        If Left$(var_name$, 1) = "*" Then var_type$ = var_type$ + "*": var_name$ = Right$(var_name$, Len(var_name$) - 1)
                        'Note: could be a poiner to a pointer
                    Else
                        var_name$ = "no_name"
                    End If

                    var_type_backup$ = var_type$

                    pointer = 0

                    If Right$(var_type$, 1) = "*" Then
                        var_type$ = Left$(var_type$, Len(var_type$) - 1)
                        pointer = 1
                    End If
                    If Right$(var_type$, 1) = "*" Then
                        var_type$ = Left$(var_type$, Len(var_type$) - 1)
                        pointer = 2
                    End If

                    If pointer = 2 Then
                        qb_type$ = "_OFFSET" 'it's the offset of an offset
                    Else
                        qb_type$ = gl2qb_type_convert$(var_type$, s$, typ, ctyp$)
                    End If

                    'IF pointer THEN need_helper_function = 1
                    need_helper_function = 1

                    If GL_KIT Then
                        If pointer = 0 Then Print #hk, "BYVAL ";
                        Print #hk, var_name$ + " AS " + qb_type$;
                        If l$ <> ")" Then Print #hk, ",";
                    End If

                    If pointer = 0 Then
                        arg$ = MKL$(typ)
                    End If
                    If pointer = 1 Then 'all pointers convert to BYVAL _OFFSET
                        arg$ = MKL$(OFFSETTYPE - ISPOINTER)
                        ctyp$ = "ptrszint"
                    End If
                    If pointer = 2 Then 'all pointers-to-pointers convert to xxx"BYREF"xxx BYVAL _OFFSET
                        arg$ = MKL$(OFFSETTYPE - ISPOINTER)
                        ctyp$ = "ptrszint"
                        '***this is important or you lose the ability to specify any offset, only the offset of a variable of type
                        '   _OFFSET
                        '                   arg$ = MKL$(OFFSETTYPE)
                        '                    ctyp$ = "ptrszint*"
                    End If

                    GL_COMMANDS(c).args = GL_COMMANDS(c).args + 1

                    Mid$(GL_COMMANDS(c).arg, (GL_COMMANDS(c).args - 1) * 4 + 1, 4) = arg$
                    'z$ = GL_COMMANDS(c).arg
                    'MID$(z$, (GL_COMMANDS(c).args - 1) * 4 + 1, 4) = arg$
                    'GL_COMMANDS(c).arg = z$

                    letter$ = Chr$(96 + GL_COMMANDS(c).args)

                    hc$ = hc$ + "(" + var_type_backup$ + ")" + letter$
                    hd$ = hd$ + ctyp$ + " " + letter$



                    If l$ <> ")" Then hc$ = hc$ + ",": hd$ = hd$ + ","

                Loop Until l$ = ")"
                no_arguments:


                hd$ = hd$ + "){"
                hc$ = hc$ + ");"
                If GL_KIT Then Print #hk, ")"
                h$ = hd$ + CRLF + "if (!sub_gl_called) error(270);" + CRLF + hc$ + CRLF + "}" + CRLF

                If need_helper_function Then 'do we need the helper function for this command?
                    GL_HELPER_CODE = GL_HELPER_CODE + h$
                    GL_COMMANDS(c).callname = "call_" + proc_name$
                End If


                If proc_name$ = "glGetString" Then
                    GL_COMMANDS(c).ret = STRINGTYPE
                    GL_COMMANDS(c).callname = "(  char*  )" + RTrim$(GL_COMMANDS(c).callname)
                End If




            End If

        End If





        discard:
    Loop
    Close #h

    If GL_KIT Then Print #hk, "END DECLARE"

    GL_DEFINES_LAST = d
    ReDim _Preserve GL_DEFINES(d) As String
    'PRINT "Defines:"; GL_DEFINES_LAST

    ReDim _Preserve GL_COMMANDS(GL_COMMANDS_LAST) As GL_idstruct
    'PRINT "Commands:"; GL_COMMANDS_LAST

    If GL_KIT Then
        For i = 1 To GL_DEFINES_LAST
            Print #hk, "CONST " + GL_DEFINES(i) + "="; GL_DEFINES_VALUE(i)
        Next
    End If

    'FOR i = 1 TO GL_COMMANDS_LAST
    '    PRINT ".cn="; GL_COMMANDS(i).cn
    '    PRINT ".callname="; GL_COMMANDS(i).callname
    '    PRINT ".subfunc="; GL_COMMANDS(i).subfunc
    '    PRINT ".args="; GL_COMMANDS(i).args
    '    _CONTROLCHR OFF
    '    PRINT ".arg=[" + RTRIM$(GL_COMMANDS(i).arg) + "]"
    '    _CONTROLCHR ON
    '    PRINT ".ret="; GL_COMMANDS(i).ret
    'NEXT

    If GL_KIT Then Close #hk


    fh = FreeFile
    Open "internal\c\parts\core\gl_header_for_parsing\temp\gl_helper_code.h" For Output As #fh
    Print #fh, GL_HELPER_CODE
    Close #fh


End Sub

Sub gl_include_content

    'add constants
    For d = 1 To GL_DEFINES_LAST
        'IF ASC(GL_DEFINES(d)) <> 95 THEN
        '    GL_DEFINES(d) = "_" + GL_DEFINES(d)
        'END IF
        constlast = constlast + 1
        If constlast > constmax Then
            constmax = constmax * 2
            ReDim _Preserve constname(constmax) As String
            ReDim _Preserve constcname(constmax) As String
            ReDim _Preserve constnamesymbol(constmax) As String 'optional name symbol
            ReDim _Preserve consttype(constmax) As Long 'variable type number
            ReDim _Preserve constinteger(constmax) As _Integer64
            ReDim _Preserve constuinteger(constmax) As _Unsigned _Integer64
            ReDim _Preserve constfloat(constmax) As _Float
            ReDim _Preserve conststring(constmax) As String
            ReDim _Preserve constsubfunc(constmax) As Long
            ReDim _Preserve constdefined(constmax) As Long
        End If
        i = constlast
        constname(i) = qb64prefix$ + GL_DEFINES(d)
        constcname(i) = qb64prefix$ + GL_DEFINES(d)
        constnamesymbol(i) = "&&"
        consttype(i) = INTEGER64TYPE - ISPOINTER
        constinteger(i) = GL_DEFINES_VALUE(d)
        constsubfunc(i) = 0 'global
        constdefined(i) = 1
        'add to hash table
        HashAdd constcname(i), HASHFLAG_CONSTANT, i
    Next


    'add subs/functions
    For c = 1 To GL_COMMANDS_LAST
        Dim g As GL_idstruct
        g = GL_COMMANDS(c)

        reginternalsubfunc = 1
        clearid
        id.ccall = 1 '*** important for handling string returns correctly ***
        id.n = RTrim$(g.cn)
        s = g.subfunc
        id.subfunc = s
        id.callname = RTrim$(g.callname)
        id.args = g.args
        id.arg = g.arg
        id.ret = g.ret
        regid
        reginternalsubfunc = 0
    Next

    'add inline function definitions

    'SUB gluPerspective (BYVAL fovy#, BYVAL aspect#, BYVAL zNear#, BYVAL zFar#)
    reginternalsubfunc = 1
    clearid
    id.n = qb64prefix$ + "gluPerspective"
    id.subfunc = 2 'sub
    id.callname = "gluPerspective"
    id.args = 4
    id.arg = MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER) + MKL$(DOUBLETYPE - ISPOINTER)
    regid
    reginternalsubfunc = 0

End Sub

'INI Manager v1.01
'Fellippe Heitor, 2017-2021 - fellippe@qb64.org - @fellippeheitor

Sub IniCommit
    Shared currentIniFileName$, IniWholeFile$, currentIniFileLOF As _Unsigned Long
    Shared IniNewFile$, IniDisableAutoCommit, IniCODE

    If currentIniFileName$ = "" Then IniCODE = 18: Exit Sub

    IniWholeFile$ = IniNewFile$
    currentIniFileLOF = Len(IniNewFile$)

    If Not IniDisableAutoCommit Then
        Dim fileNum As Integer

        fileNum = FreeFile
        Open currentIniFileName$ For Binary As #fileNum

        If Len(IniWholeFile$) < LOF(fileNum) Then
            Close fileNum
            Open currentIniFileName$ For Output As #fileNum: Close #fileNum
            Open currentIniFileName$ For Binary As #fileNum
        End If

        Put #fileNum, 1, IniNewFile$
        Close #fileNum 'flush
    End If
End Sub

Function IniGetSection$ (__section$)
    Shared IniPosition As _Unsigned Long, IniCODE, currentIniFileName$
    Shared IniLF$, IniWholeFile$, currentIniFileLOF As _Unsigned Long

    If currentIniFileName$ = "" Then IniCODE = 18: Exit Function
    If currentIniFileLOF = 0 Or Len(LTrim$(RTrim$(IniWholeFile$))) = 0 Then IniCODE = 17: Exit Function

    IniCODE = 0

    Dim section$, foundSection As _Unsigned Long, endSection As _Unsigned Long
    Dim i As _Unsigned Long, Bracket1 As _Unsigned Long, sectionStart As _Unsigned Long
    Dim inQuote As _Byte

    section$ = IniFormatSection$(__section$)
    If IniCODE Then Exit Function

    If section$ = "[]" Then
        'fetch the "global" section, if present
        sectionStart = InStr(IniWholeFile$, "[")
        If sectionStart = 0 Then IniGetSection$ = IniWholeFile$: Exit Function

        For i = sectionStart - 1 To 1 Step -1
            If Asc(IniWholeFile$, i) = 10 Then foundSection = i + 1: Exit For
            If Asc(IniWholeFile$, i) <> 32 Then Exit For
        Next

        If i = 0 Then foundSection = 1

        IniGetSection$ = Left$(IniWholeFile$, foundSection - 1)
    Else
        Do
            sectionStart = InStr(sectionStart + 1, LCase$(IniWholeFile$), LCase$(section$))
            If sectionStart = 0 Then IniCODE = 14: Exit Do

            'make sure it's a valid section header
            foundSection = 0
            For i = sectionStart - 1 To 1 Step -1
                If Asc(IniWholeFile$, i) = 10 Then foundSection = i + 1: Exit For
                If Asc(IniWholeFile$, i) <> 32 Then Exit For
            Next

            If i = 0 Then foundSection = 1

            If foundSection > 0 Then
                'we found it; time to identify where this section ends
                '(either another [section] or the end of the file
                Bracket1 = sectionStart
                checkAgain:
                Bracket1 = InStr(Bracket1 + 1, IniWholeFile$, "[")

                If Bracket1 > 0 Then
                    'found a bracket; check if it's inside quotes
                    inQuote = 0
                    For i = 1 To Bracket1 - 1
                        If Asc(IniWholeFile$, i) = 34 Then inQuote = Not inQuote
                    Next
                    If inQuote Then GoTo checkAgain

                    For i = Bracket1 - 1 To 1 Step -1
                        If Asc(IniWholeFile$, i) = 10 Then endSection = i + 1 - Len(IniLF$): Exit For
                        If Asc(IniWholeFile$, i) = 61 Then GoTo checkAgain 'bracket is inside a key's value
                        If i <= foundSection Then Exit For
                    Next
                    IniGetSection$ = Mid$(IniWholeFile$, foundSection, endSection - foundSection)
                Else
                    IniGetSection$ = Mid$(IniWholeFile$, foundSection)
                End If
                Exit Function
            End If
        Loop
    End If
End Function

Function IniFormatSection$ (__section$)
    Shared IniCODE

    Dim section$

    section$ = LTrim$(RTrim$(__section$))

    'sections are in the format [section name] - add brackets if not passed
    If Left$(section$, 1) <> "[" Then section$ = "[" + section$
    If Right$(section$, 1) <> "]" Then section$ = section$ + "]"

    If InStr(Mid$(section$, 2, Len(section$) - 3), "[") Or InStr(Mid$(section$, 2, Len(section$) - 3), "]") Then
        IniCODE = 15
        Exit Function
    End If

    IniFormatSection$ = section$
End Function

Function ReadSetting$ (file$, __section$, __key$)
    Shared IniLastSection$, IniLastKey$, IniWholeFile$, IniLF$
    Shared IniPosition As _Unsigned Long, IniSectionData$
    Shared IniCODE, IniAllowBasicComments
    Shared currentIniFileLOF As _Unsigned Long

    IniLoad file$
    If IniCODE Then Exit Function

    If currentIniFileLOF = 0 Or Len(LTrim$(RTrim$(IniWholeFile$))) = 0 Then IniCODE = 17: Exit Function

    Dim Equal As _Unsigned Long, tempValue$, key$, section$
    Dim Quote As _Unsigned Long, Comment As _Unsigned Long
    Dim i As Long, FoundLF As _Unsigned Long

    section$ = IniFormatSection(__section$)
    If IniCODE Then Exit Function

    'fetch the desired section$
    IniSectionData$ = IniGetSection(section$)
    If IniCODE > 0 And IniCODE <> 17 Then Exit Function

    If Len(IniSectionData$) = 0 And section$ <> "[]" Then IniCODE = 14: Exit Function

    IniLastSection$ = section$

    IniPosition = 0

    key$ = LTrim$(RTrim$(__key$))
    IniLastKey$ = ""
    If key$ = "" Then IniCODE = 12: Exit Function

    If Left$(key$, 1) = ";" Or Left$(key$, 1) = "'" Or InStr(key$, "[") > 0 Or InStr(key$, "]") > 0 Or InStr(key$, "=") > 0 Then
        IniCODE = 12
        Exit Function
    End If

    IniLastKey$ = key$

    If IniPosition > 0 Then Equal = IniPosition: GoTo KeyFound
    CheckKey:
    IniPosition = InStr(IniPosition + 1, LCase$(IniSectionData$), LCase$(key$))

    If IniPosition > 0 Then
        'identify if this occurrence is actually a key and not part of a key name/value
        For i = IniPosition - 1 To 1 Step -1
            If Asc(IniSectionData$, i) = 10 Then Exit For
            If Asc(IniSectionData$, i) <> 10 And Asc(IniSectionData$, i) <> 32 Then
                'not a key
                GoTo CheckKey
            End If
        Next

        'check if there's nothing but an equal sign ahead
        For i = IniPosition + Len(key$) To Len(IniSectionData$)
            If Asc(IniSectionData$, i) = Asc("=") Then Exit For
            If Asc(IniSectionData$, i) <> Asc("=") And Asc(IniSectionData$, i) <> 32 Then
                'not the key
                GoTo CheckKey
            End If
        Next

        'so far so good; check if there is an assignment
        Equal = InStr(IniPosition, IniSectionData$, "=")
        KeyFound:
        FoundLF = InStr(IniPosition, IniSectionData$, IniLF$)

        If FoundLF > 0 Then
            If Equal > FoundLF Then GoTo CheckKey
        Else
            FoundLF = Len(IniSectionData$) + 1
            If Equal = 0 Then GoTo CheckKey
        End If

        tempValue$ = LTrim$(RTrim$(Mid$(IniSectionData$, Equal + 1, FoundLF - Equal - 1)))

        If Len(tempValue$) > 0 Then
            If Left$(tempValue$, 1) = Chr$(34) Then
                tempValue$ = Mid$(tempValue$, 2)
                Quote = InStr(tempValue$, Chr$(34))
                If Quote > 0 Then
                    tempValue$ = Left$(tempValue$, Quote - 1)
                End If
            Else
                If IniAllowBasicComments Then Comment = InStr(tempValue$, "'") 'BASIC style comments accepted
                If Comment = 0 Then Comment = InStr(tempValue$, ";")
                If Comment > 0 Then
                    tempValue$ = LTrim$(RTrim$(Left$(tempValue$, Comment - 1)))
                End If
            End If
        Else
            IniCODE = 2
        End If
    Else
        IniCODE = 3
        Exit Function
    End If

    ReadSetting$ = tempValue$
    IniLastSection$ = IniCurrentSection$
End Function

Function IniCurrentSection$
    Shared IniPosition As _Unsigned Long, IniSectionData$, IniWholeFile$

    Dim GlobalPosition As _Unsigned Long, i As _Unsigned Long
    Dim ClosingBracket As _Unsigned Long

    GlobalPosition = InStr(IniWholeFile$, IniSectionData$) + IniPosition - 1

    CheckSection:
    For i = GlobalPosition - 1 To 1 Step -1
        If Asc(IniWholeFile$, i) = Asc("[") Then
            GlobalPosition = i: Exit For
        End If
    Next

    If i = 0 Then IniCurrentSection$ = "[]": Exit Function

    'identify if this occurrence is actually a section header and not something else
    For i = GlobalPosition - 1 To 1 Step -1
        If Asc(IniWholeFile$, i) = 10 Then Exit For
        If Asc(IniWholeFile$, i) <> 10 And Asc(IniWholeFile$, i) <> 32 Then
            'not a section header
            GoTo CheckSection
        End If
    Next

    ClosingBracket = InStr(GlobalPosition, IniWholeFile$, "]")
    If ClosingBracket > 0 Then
        IniCurrentSection$ = Mid$(IniWholeFile$, GlobalPosition, ClosingBracket - GlobalPosition + 1)
    End If
End Function

Sub WriteSetting (file$, __section$, __key$, __value$)
    Shared IniPosition As _Unsigned Long, IniCODE, currentIniFileName$
    Shared IniLF$, IniWholeFile$, IniSectionData$
    Shared IniLastSection$, IniLastKey$, IniNewFile$
    Shared IniDisableAddQuotes

    Dim tempValue$, section$, key$, value$

    IniCODE = 0

    'prepare variables for the write operation
    section$ = IniFormatSection$(__section$)
    If IniCODE Then Exit Sub

    key$ = LTrim$(RTrim$(__key$))
    If key$ = "" Then IniCODE = 12: Exit Sub
    IniLastKey$ = key$

    value$ = LTrim$(RTrim$(__value$))
    If LTrim$(Str$(Val(value$))) <> value$ Then
        If Not IniDisableAddQuotes Then
            'if not a numeric value and value contains spaces, add quotation marks
            If InStr(value$, Chr$(32)) Then value$ = Chr$(34) + value$ + Chr$(34)
        End If
    End If

    'Read the existing key to fill IniPosition
    tempValue$ = ReadSetting$(file$, section$, key$)

    'map IniPosition (set in the section block) to the global file position
    IniPosition = InStr(IniWholeFile$, IniSectionData$) + IniPosition - 1

    If IniCODE = 1 Or IniCODE = 17 Then
        'file not found or empty; create a new one
        If file$ = "" Then file$ = currentIniFileName$
        If file$ = "" Then IniCODE = 21: Exit Sub

        currentIniFileName$ = file$

        If section$ <> "[]" Then
            IniNewFile$ = section$ + IniLF$
        End If

        IniNewFile$ = IniNewFile$ + key$ + "=" + value$

        IniCODE = 0
        IniCommit
        IniLoad file$
        If IniCODE = 0 Then IniCODE = 11
        IniLastSection$ = section$
        Exit Sub
    End If

    If IniCODE = 0 Or IniCODE = 2 Then 'key found and read back; write new value$
        If LCase$(IniLastSection$) = LCase$(section$) Then
            If LTrim$(RTrim$(__value$)) = tempValue$ And Len(LTrim$(RTrim$(__value$))) > 0 Then
                'identical values skip the writing routine
                IniCODE = 8
                Exit Sub
            End If

            Dim nextLine As _Unsigned Long
            nextLine = InStr(IniPosition + 1, IniWholeFile$, IniLF$)

            'create new file contents
            IniNewFile$ = Left$(IniWholeFile$, IniPosition - 1)
            IniNewFile$ = IniNewFile$ + key$ + "=" + value$

            If nextLine > 0 Then
                IniNewFile$ = IniNewFile$ + Mid$(IniWholeFile$, nextLine)
            End If

            IniCommit

            IniCODE = 4
        End If
    ElseIf IniCODE = 3 Or IniCODE = 14 Then 'Key not found, Section not found
        IniCODE = 0
        If LCase$(IniLastSection$) = LCase$(section$) Then
            'find this section$ in the current ini file;
            Dim Bracket1 As _Unsigned Long
            Dim beginSection As _Unsigned Long, endSection As _Unsigned Long
            Dim i As _Unsigned Long

            beginSection = 0
            endSection = 0

            CheckSection:
            beginSection = InStr(beginSection + 1, LCase$(IniWholeFile$), LCase$(section$))
            If beginSection = 0 Then GoTo CreateSection

            'identify if this occurrence is actually the section header and not something else
            For i = beginSection - 1 To 1 Step -1
                If Asc(IniWholeFile$, i) = 10 Then Exit For
                If Asc(IniWholeFile$, i) <> 10 And Asc(IniWholeFile$, i) <> 32 Then
                    'not the section header
                    GoTo CheckSection
                End If
            Next

            'we found it; time to identify where this section ends
            '(either another [section], a blank line or the end of the file
            Bracket1 = InStr(beginSection + 1, IniWholeFile$, "[")
            If Bracket1 > 0 Then
                For i = Bracket1 - 1 To 1 Step -1
                    If Asc(IniWholeFile$, i) = 10 Then endSection = i + 1 - Len(IniLF$): Exit For
                    If i <= beginSection Then Exit For
                Next
            End If

            If endSection > 0 Then
                'add values to the end of the specified section$
                IniNewFile$ = Left$(IniWholeFile$, endSection - 1)
                IniNewFile$ = IniNewFile$ + key$ + "=" + value$ + IniLF$
                If Mid$(IniWholeFile$, endSection, Len(IniLF$)) <> IniLF$ Then IniNewFile$ = IniNewFile$ + IniLF$
                IniNewFile$ = IniNewFile$ + Mid$(IniWholeFile$, endSection)
            Else
                'add values to the end of the file
                IniNewFile$ = IniWholeFile$
                If Right$(IniNewFile$, Len(IniLF$)) = IniLF$ Then
                    IniNewFile$ = IniNewFile$ + key$ + "=" + value$
                Else
                    IniNewFile$ = IniNewFile$ + IniLF$ + key$ + "=" + value$
                End If
            End If

            IniCommit

            If IniCODE = 0 Then IniCODE = 7
            Exit Sub
        Else
            CreateSection:
            IniNewFile$ = IniWholeFile$
            If section$ = "[]" Then GoTo WriteAtTop

            If Right$(IniNewFile$, Len(IniLF$) * 2) = IniLF$ + IniLF$ Then
                IniNewFile$ = IniNewFile$ + section$ + IniLF$ + key$ + "=" + value$ + IniLF$
            ElseIf Right$(IniNewFile$, Len(IniLF$)) = IniLF$ Then
                IniNewFile$ = IniNewFile$ + IniLF$ + section$ + IniLF$ + key$ + "=" + value$ + IniLF$
            Else
                IniNewFile$ = IniNewFile$ + IniLF$ + IniLF$ + section$ + IniLF$ + key$ + "=" + value$ + IniLF$
            End If

            IniCommit

            If IniCODE = 0 Then IniCODE = 9 Else IniCODE = 16
            Exit Sub
        End If

        'if not found, key$=value$ is written to the beginning of the file
        WriteAtTop:
        IniNewFile$ = key$ + "=" + value$ + IniLF$
        If Left$(LTrim$(IniWholeFile$), 1) = "[" Then IniNewFile$ = IniNewFile$ + IniLF$
        IniNewFile$ = IniNewFile$ + IniWholeFile$

        IniCommit

        IniCODE = 5
    End If
End Sub

Sub IniSetAddQuotes (state As _Byte)
    Shared IniDisableAddQuotes
    If state Then
        IniDisableAddQuotes = 0
    Else
        IniDisableAddQuotes = -1
    End If
End Sub

Sub IniSetForceReload (state As _Byte)
    Shared IniForceReload
    If state Then
        IniForceReload = -1
    Else
        IniForceReload = 0
    End If
End Sub

Sub IniSetAllowBasicComments (state As _Byte)
    Shared IniAllowBasicComments
    If state Then
        IniAllowBasicComments = -1
    Else
        IniAllowBasicComments = 0
    End If
End Sub

Sub IniSetAutoCommit (state As _Byte)
    Shared IniDisableAutoCommit
    If state Then
        IniDisableAutoCommit = 0
    Else
        IniDisableAutoCommit = -1
    End If
End Sub

Sub IniLoad (file$)
    Shared IniCODE, currentIniFileName$, IniLF$, IniWholeFile$
    Shared currentIniFileLOF As _Unsigned Long
    Shared IniForceReload
    Dim fileNum As Integer

    'Error messages are returned with IniCODE
    IniCODE = 0

    If file$ <> "" And currentIniFileName$ <> file$ Then currentIniFileName$ = ""

    If IniForceReload And Len(currentIniFileName$) > 0 Then
        file$ = currentIniFileName$
        currentIniFileName$ = ""
    End If

    'Passing an empty file$ is allowed if user already
    'passed a valid file in this session.
    If currentIniFileName$ = "" Then
        'initialization
        If _FileExists(file$) Then
            currentIniFileName$ = file$

            'Load file into memory
            fileNum = FreeFile
            Open currentIniFileName$ For Binary As #fileNum
            currentIniFileLOF = LOF(fileNum)
            IniWholeFile$ = Space$(currentIniFileLOF)
            Get #fileNum, 1, IniWholeFile$
            Close #fileNum

            'Check if this ini file uses CRLF or LF
            If InStr(IniWholeFile$, Chr$(13)) Then IniLF$ = Chr$(13) + Chr$(10) Else IniLF$ = Chr$(10)
        Else
            IniFileNotFound:
            IniCODE = 1
            IniLF$ = Chr$(10)
            Exit Sub
        End If
    ElseIf Not _FileExists(currentIniFileName$) Then
        currentIniFileName$ = ""
        GoTo IniFileNotFound
    End If
End Sub

DefLng A-Z

'-------- Optional IDE Component (2/2) --------

Function ide (ignore)
    'Note: ide is a function which optimizes the interaction between the IDE and compiler (ide2)
    '      by avoiding unnecessary bloat associated with entering the main IDE function 'ide2'
    ignore = ignore 'just to clear warnings of unused variables
    If idecommand$ <> "" Then cmd = Asc(idecommand$)
    If cmd = 3 Then 'request next line (compiler->ide)
        If idecompiledline < iden Then
            If idecompiledline < idesy Or idecompiledline > idesy + (idewy - 9) Then 'off screen?
                If _Exit And 1 Then ideexit = 1
                If ideexit = 0 Then
                    GetInput 'check for new input
                    If iCHANGED = 0 And mB = 0 Then

                        '-------------------- layout considerations --------------------
                        'previous line was OK, so use layout if available
                        If ideautolayout <> 0 Or ideautoindent <> 0 Then
                            If Len(layout$) Then

                                'calculate recommended indent level
                                l = Len(layout$)
                                For i = 1 To l
                                    If Asc(layout$, i) <> 32 Or i = l Then
                                        If Asc(layout$, i) = 32 Then
                                            layout$ = "": indent = i
                                        Else
                                            indent = i - 1
                                            layout$ = Right$(layout$, Len(layout$) - i + 1)
                                        End If
                                        Exit For
                                    End If
                                Next

                                If ideautolayout Then
                                    layout2$ = layout$: i2 = 1
                                    ignoresp = 0
                                    For i = 1 To Len(layout$)
                                        a = Asc(layout$, i)
                                        If a = 34 Then
                                            ignoresp = ignoresp + 1: If ignoresp = 2 Then ignoresp = 0
                                        End If
                                        If ignoresp = 0 Then
                                            If a = sp_asc Then Asc(layout2$, i2) = 32: i2 = i2 + 1: GoTo skipchar
                                            If a = sp2_asc Then GoTo skipchar
                                        End If
                                        Asc(layout2$, i2) = a: i2 = i2 + 1
                                        skipchar:
                                    Next
                                    layout$ = Left$(layout2$, i2 - 1)
                                End If

                                If ideautoindent = 0 Then
                                    'note: can assume auto-format
                                    'calculate old indent (if any)
                                    indent = 0
                                    l = Len(idecompiledline$)
                                    For i = 1 To l
                                        If Asc(idecompiledline$, i) <> 32 Or i = l Then
                                            indent = i - 1
                                            Exit For
                                        End If
                                    Next
                                    indent$ = Space$(indent)
                                Else
                                    indent$ = Space$(indent * ideautoindentsize)
                                End If

                                If ideautolayout = 0 Then
                                    'note: can assume auto-indent
                                    l = Len(idecompiledline$)
                                    layout$ = ""
                                    For i = 1 To l
                                        If Asc(idecompiledline$, i) <> 32 Or i = l Then
                                            layout$ = Right$(idecompiledline$, l - i + 1)
                                            Exit For
                                        End If
                                    Next
                                End If

                                If Len(layout$) Then
                                    layout$ = indent$ + layout$
                                    If idecompiledline$ <> layout$ Then
                                        idesetline idecompiledline, layout$
                                    End If
                                End If 'len(layout$) after modification

                            End If 'len(layout$)

                        End If 'using layout/indent
                        '---------------------------------------------------------------

                        idecompiledline = idecompiledline + 1
                        idecompiledline$ = idegetline(idecompiledline)
                        ide = 4
                        idereturn$ = idecompiledline$

                        'Update compilation progress on the status bar
                        If ideautorun <> 0 Then
                            If prepass Then
                                status.progress$ = str2$(Int((idecompiledline * 100) / (iden * 2)))
                                status.progress$ = String$(3 - Len(status.progress$), 32) + status.progress$ + "%"
                            Else
                                status.progress$ = str2$(Int(((iden + idecompiledline) * 100) / (iden * 2)))
                                status.progress$ = String$(3 - Len(status.progress$), 32) + status.progress$ + "%"
                            End If
                            IdeInfo = Chr$(0) + status.progress$
                            'ELSE
                            '    STATIC p AS _BYTE, lastUpdateDots AS SINGLE
                            '    IF TIMER - lastUpdateDots > .5 THEN
                            '        lastUpdateDots = TIMER
                            '        p = p + 1
                            '        temp$ = STRING$(3, 250) '"..."
                            '        IF p > 3 THEN p = 1
                            '        ASC(temp$, p) = 254
                            '        COLOR 7, 1
                            '        _PRINTSTRING (2, idewy - 3), temp$ 'compilation progress indicator
                            '    END IF
                        End If
                        UpdateIdeInfo

                        Exit Function
                    End If
                    If iCHANGED Then iCHECKLATER = 1
                End If 'ideexit
            End If 'not on screen
        Else
            If IdeSystem <> 3 Or Left$(IdeInfo, 19) <> "Selection length = " Then IdeInfo = ""
            UpdateIdeInfo
        End If 'idecompiledline<iden
    End If

    ide = ide2(0)
End Function

Function ide2 (ignore)
    Static MenuLocations As String
    Static idesystem2.issel As _Byte
    Static idesystem2.sx1 As Long
    Static idesystem2.v1 As Long
    Static AttemptToLoadRecent As _Byte
    Static old.mX, old.mY
    Static last.TBclick#, wholeword.select As _Byte
    Static wholeword.selectx1, wholeword.idecx
    Static wholeword.selecty1, wholeword.idecy
    Static ForceResize, IDECompilationRequested As _Byte
    Static QuickNavHover As _Byte, FindFieldHover As _Byte
    Static VersionInfoHover As _Byte, LineNumberHover As _Byte
    Static waitingForVarList As _Byte

    ignore = ignore 'just to clear warnings of unused variables

    char.sep$ = Chr$(34) + " =<>+-/\^:;,*()."

    c$ = idecommand$

    IDEerrorMessage:
    'report any IDE errors which have occurred
    If ideerror Then
        mustdisplay = 1
        If ideerror = 1 Then errorat$ = "Internal IDE error"
        If ideerror = 2 Then errorat$ = "File not found"
        If ideerror = 3 Then errorat$ = "File access error": Close #150
        If ideerror = 4 Then errorat$ = "Path not found"
        If ideerror = 5 Then errorat$ = "Cannot create folder"
        If ideerror = 6 Then errorat$ = "Cannot save file"
        If ideerror = -1 Then GoTo errorReportDone 'fail quietly - like ON ERROR RESUME NEXT

        qberrorcode = Err
        If qberrorcode Then
            ideerrormessageTITLE$ = "Error " + str2$(qberrorcode)
        Else
            ideerrormessageTITLE$ = "Error"
        End If

        If (ideerror > 1) Then
            'Don't show too much detail if user just tried loading an invalid file
            ideerrormessageTITLE$ = ideerrormessageTITLE$ + " ("
            If _ErrorLine > 0 Or _InclErrorLine > 0 Then
                ideerrormessageTITLE$ = ideerrormessageTITLE$ + str2$(_ErrorLine) + "-" + str2$(_InclErrorLine)
            End If
            If Len(AutoBuildMsg$) Then ideerrormessageTITLE$ = ideerrormessageTITLE$ + "-" + Mid$(AutoBuildMsg$, 10)
            ideerrormessageTITLE$ = ideerrormessageTITLE$ + ")"
            If ideerrormessageTITLE$ = "Error ()" Then ideerrormessageTITLE$ = "Error"
            If AttemptToLoadRecent = -1 Then
                'Offer to cleanup recent file list, removing invalid entries
                PCopy 2, 0
                result = idemessagebox(ideerrormessageTITLE$, errorat$ + "." + Chr$(10) + Chr$(10) + "Remove broken links from recent files?", "#Yes;#No")
                If result = 1 Then
                    GoSub CleanUpRecentList
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo errorReportDone
            End If
        Else
            'a more serious error; let's report something that'll help bug reporting
            inclerrorline = _InclErrorLine
            If inclerrorline Then
                errorat$ = errorat$ + CHR$(10) + " " + CHR$(10) + "(module: " + _
                           RemoveFileExtension$(LEFT$(_INCLERRORFILE$, 60))
                errorat$ = errorat$ + ", on line: " + str2$(inclerrorline)
                If Len(AutoBuildMsg$) Then errorat$ = errorat$ + ", " + Mid$(AutoBuildMsg$, 10)
                errorat$ = errorat$ + ")"
            Else
                errorat$ = errorat$ + Chr$(10) + " " + Chr$(10) + "(on line: " + str2$(_ErrorLine)
                If Len(AutoBuildMsg$) Then errorat$ = errorat$ + ", " + Mid$(AutoBuildMsg$, 10)
                errorat$ = errorat$ + ")"
            End If
        End If

        PCopy 3, 0
        result = idemessagebox(ideerrormessageTITLE$, errorat$, "")
        errorReportDone:
    End If

    ideerror = 1 'unknown IDE error
    AttemptToLoadRecent = 0

    If Left$(c$, 1) = Chr$(12) Then
        f$ = Right$(c$, Len(c$) - 1)
        Locate , , 0
        clearStatusWindow 0

        dummy = DarkenFGBG(1)
        BkpIdeSystem = IdeSystem: IdeSystem = 2: UpdateTitleOfMainWindow: IdeSystem = BkpIdeSystem
        Color 1, 7: _PrintString ((idewx - 8) / 2, idewy - 4), " Status "
        Color 15, 1

        _PrintString (2, idewy - 3), "Creating executable file named " + Chr$(34) + f$ + extension$ + Chr$(34) + "..."

        PCopy 3, 0
        ide2 = 9: idereturn$ = f$
        Exit Function
    End If

    If c$ = Chr$(100) Then 'special call for next line (usually for the purpose of line continuation)
        idecompiledline = idecompiledline + 1 'must increment (to trigger no more lines avail. message later)
        If idecompiledline < iden Then
            idecompiledline$ = idegetline(idecompiledline)
            idereturn$ = idecompiledline$
        Else
            idecompiledline$ = ""
            idereturn$ = idecompiledline$ 'no more lines
        End If
        Exit Function
    End If

    If idelaunched = 0 Then
        idelaunched = 1

        Width idewx, idewy
        If IDE_UseFont8 Then _Font 8 Else _Font 16

        If idecustomfont Then
            idecustomfonthandle = _LoadFont(idecustomfontfile$, idecustomfontheight, "MONOSPACE")
            If idecustomfonthandle = -1 Then
                'failed! - revert to default settings
                idecustomfont = 0: idecustomfontfile$ = "C:\Windows\Fonts\lucon.ttf": idecustomfontheight = 21
            Else
                _Font idecustomfonthandle
            End If
        End If

        m = 1: i = 0
        IdeMakeFileMenu

        m = m + 1: i = 0
        ideeditmenuID = m
        IdeMakeEditMenu

        m = m + 1: i = 0: ViewMenuID = m
        menu$(m, i) = "View": i = i + 1
        menu$(m, i) = "#SUBs...  F2": i = i + 1
        menuDesc$(m, i - 1) = "Displays a list of SUB/FUNCTION procedures"
        menu$(m, i) = "#Line Numbers  " + Chr$(16): i = i + 1
        menuDesc$(m, i - 1) = "Toggles and customizes line numbers (side bar)"
        menu$(m, i) = "-": i = i + 1

        ViewMenuCompilerWarnings = i
        menu$(ViewMenuID, ViewMenuCompilerWarnings) = "Compiler #Warnings...  Ctrl+W": i = i + 1
        menuDesc$(m, i - 1) = "Displays a list of recent code warnings"
        menusize(m) = i - 1

        m = m + 1: i = 0: SearchMenuID = m
        menu$(m, i) = "Search": i = i + 1
        menu$(m, i) = "#Find...  Ctrl+F3": i = i + 1
        menuDesc$(m, i - 1) = "Finds specified text"
        menu$(m, i) = "#Repeat Last Find  (Shift+) F3": i = i + 1
        menuDesc$(m, i - 1) = "Finds next occurrence of text specified in previous search"
        menu$(m, i) = "#Change...  Alt+F3": i = i + 1
        menuDesc$(m, i - 1) = "Finds and changes specified text"
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "Clear Search #History...": i = i + 1
        menuDesc$(m, i - 1) = "Clears history of searched text items"
        menu$(m, i) = "-": i = i + 1

        SearchMenuEnableQuickNav = i
        menu$(m, i) = "#Quick Navigation": i = i + 1
        menuDesc$(m, i - 1) = "Toggles Quick Navigation (back arrow)"
        If EnableQuickNav Then
            menu$(SearchMenuID, SearchMenuEnableQuickNav) = Chr$(7) + menu$(SearchMenuID, SearchMenuEnableQuickNav)
        End If
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "#Go To Line...  Ctrl+G": i = i + 1
        menuDesc$(m, i - 1) = "Jumps to the specified line number"

        menusize(m) = i - 1

        m = m + 1: i = 0: RunMenuID = m
        menu$(m, i) = "Run": i = i + 1
        menu$(m, i) = "#Start  F5": i = i + 1
        menuDesc$(m, i - 1) = "Compiles current program and runs it"
        menu$(m, i) = "Modify #COMMAND$...": i = i + 1
        menuDesc$(m, i - 1) = "Sets string returned by COMMAND$ function"
        menu$(m, i) = "-": i = i + 1

        RunMenuSaveExeWithSource = i
        menu$(m, i) = "Output EXE to Source #Folder": i = i + 1
        menuDesc$(m, i - 1) = "Toggles compiling program to QB64's folder or to source folder"
        If SaveExeWithSource Then
            menu$(RunMenuID, RunMenuSaveExeWithSource) = Chr$(7) + menu$(RunMenuID, RunMenuSaveExeWithSource)
        End If
        menu$(m, i) = "-": i = i + 1

        menu$(m, i) = "Make E#xecutable Only  F11": i = i + 1
        menuDesc$(m, i - 1) = "Compiles current program without running it"
        menusize(m) = i - 1

        m = m + 1: i = 0: OptionsMenuID = m
        menu$(m, i) = "Options": i = i + 1
        menu$(m, i) = "#Display...": i = i + 1
        menuDesc$(m, i - 1) = "Changes screen size and font"
        menu$(m, i) = "IDE C#olors...": i = i + 1
        menuDesc$(m, i - 1) = "Changes or customizes IDE color scheme"
        menu$(m, i) = "#Code Layout...": i = i + 1
        menuDesc$(m, i - 1) = "Changes auto-format features"
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "#Backup/Undo...": i = i + 1
        menuDesc$(m, i - 1) = "Sets size of backup/undo buffer"
        menu$(m, i) = "-": i = i + 1

        OptionsMenuDisableSyntax = i
        menu$(m, i) = "Syntax #Highlighter": i = i + 1
        menuDesc$(m, i - 1) = "Toggles syntax highlighter"
        If Not DisableSyntaxHighlighter Then
            menu$(OptionsMenuID, OptionsMenuDisableSyntax) = Chr$(7) + menu$(OptionsMenuID, OptionsMenuDisableSyntax)
        End If

        OptionsMenuSwapMouse = i
        menu$(m, i) = "#Swap Mouse Buttons": i = i + 1
        menuDesc$(m, i - 1) = "Swaps functionality of left/right mouse buttons"
        If MouseButtonSwapped Then
            menu$(OptionsMenuID, OptionsMenuSwapMouse) = Chr$(7) + menu$(OptionsMenuID, OptionsMenuSwapMouse)
        End If

        OptionsMenuPasteCursor = i
        menu$(m, i) = "Cursor After #Paste": i = i + 1
        menuDesc$(m, i - 1) = "Toggles placing the cursor before/after the pasted content"
        If PasteCursorAtEnd Then
            menu$(OptionsMenuID, OptionsMenuPasteCursor) = Chr$(7) + menu$(OptionsMenuID, OptionsMenuPasteCursor)
        End If

        OptionsMenuShowErrorsImmediately = i
        menu$(m, i) = "Syntax Ch#ecker": i = i + 1
        menuDesc$(m, i - 1) = "Toggles instant syntax checker (status area)"
        If IDEShowErrorsImmediately Then
            menu$(OptionsMenuID, OptionsMenuShowErrorsImmediately) = Chr$(7) + menu$(OptionsMenuID, OptionsMenuShowErrorsImmediately)
        End If

        OptionsMenuIgnoreWarnings = i
        menu$(m, i) = "Ignore #Warnings": i = i + 1
        menuDesc$(m, i - 1) = "Toggles display of warning messages (unused variables, etc)"
        If IgnoreWarnings Then menu$(OptionsMenuID, OptionsMenuIgnoreWarnings) = Chr$(7) + "Ignore #Warnings"

        'OptionsMenuAutoComplete = i
        'menu$(m, i) = "Code Suggest#ions": i = i + 1
        'menuDesc$(m, i - 1) = "Toggles code suggestions/auto-complete"
        'IF IdeAutoComplete THEN menu$(OptionsMenuID, OptionsMenuAutoComplete) = CHR$(7) + "Code Suggest#ions"

        menusize(m) = i - 1

        m = m + 1: i = 0
        menu$(m, i) = "QB64": i = i + 1
        menu$(m, i) = "#About...": i = i + 1
        menuDesc$(m, i - 1) = "Displays the current version of QB64"
        menusize(m) = i - 1

        menus = m

        'Hidden contextual menu (ID is retrieved for later use; allows expansion of the original menu system above):
        m = m + 1
        idecontextualmenuID = m

        'View Menu sub menu for Line Numbers options
        m = m + 1: i = 0
        menu$(m, i) = "ViewMenuShowLineNumbersSubMenu": i = i + 1
        ViewMenuShowLineNumbersSubMenuID = m
        If ShowLineNumbers Then menu$(m, i) = "#Hide Line Numbers" Else menu$(m, i) = "#Show Line Numbers"
        menuDesc$(m, i) = "Toggles displaying line numbers (side bar)"
        i = i + 1
        menu$(m, i) = "#Background Color": If ShowLineNumbersUseBG Then menu$(m, i) = Chr$(7) + menu$(m, i)
        menuDesc$(m, i) = "Toggles displaying a different background (side bar)"
        ViewMenuShowBGID = i
        If ShowLineNumbers = 0 Then menu$(m, i) = "~" + menu$(m, i)
        i = i + 1
        menu$(m, i) = "Sho#w Separator": If ShowLineNumbersSeparator Then menu$(m, i) = Chr$(7) + menu$(m, i)
        menuDesc$(m, i) = "Toggles showing a separator line (side bar)"
        ViewMenuShowSeparatorID = i
        If ShowLineNumbers = 0 Then menu$(m, i) = "~" + menu$(m, i)
        i = i + 1
        menusize(m) = i - 1

        idepathsep$ = "/"

        ideroot$ = idezgetroot$
        idepath$ = _StartDir$

        'new blank text field
        idet$ = MKL$(0) + MKL$(0): idel = 1: ideli = 1: iden = 1: IdeBmkN = 0
        ReDim IdeBreakpoints(iden) As _Byte
        ReDim IdeSkipLines(iden) As _Byte
        backupTypeDefinitions$ = ""

        ideunsaved = -1
        idechangemade = 1

        redraweverything:
        ideselect = 0
        idesx = 1
        idesy = 1
        idecx = 1
        idecy = 1

        redraweverything2:
        GoSub redrawItAll

        If retval = 1 Then GoTo skipload

        'restore autosave?
        'undo/redo
        Open tmpdir$ + "autosave.bin" For Binary As #150
        If LOF(150) = 1 Then
            Close #150
            r$ = iderestore$
            PCopy 3, 0: Screen , , 3, 0
            If r$ = "Y" Then
                'restore
                Open tmpdir$ + "undo2.bin" For Binary As #150
                If LOF(150) Then
                    ideunsaved = 1
                    h$ = Space$(12): Get #150, , h$: p1 = CVL(Mid$(h$, 1, 4)): p2 = CVL(Mid$(h$, 5, 4)): plast = CVL(Mid$(h$, 9, 4))
                    'get backup
                    Seek #150, p2
                    Get #150, , l&
                    Get #150, , idesx: Get #150, , idesy
                    Get #150, , idecx: Get #150, , idecy
                    Get #150, , ideselect: Get #150, , ideselectx1: Get #150, , ideselecty1
                    Get #150, , iden
                    Get #150, , idel
                    Get #150, , ideli
                    'bookmark info [v2]
                    Get #150, , IdeBmkN: ReDim IdeBmk(IdeBmkN + 1) As IdeBmkType
                    For bi = 1 To IdeBmkN: Get #150, , IdeBmk(bi).y: Get #150, , IdeBmk(bi).x: Next
                    Get #150, , x&: idet$ = Space$(x&): Get #150, , idet$
                End If
                Close #150
            End If
        Else
            Close #150
        End If

        If ideunsaved <> 1 Then 'no file restored (takes priority over loading file from command line)
            If Left$(c$, 1) = Chr$(1) Then 'load file
                f$ = Right$(c$, Len(c$) - 1)
                If FileHasExtension(f$) = 0 Then f$ = f$ + ".bas"
                path$ = idezgetfilepath$(ideroot$, f$)
                If ideerror > 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo IDEerrorMessage

                '(copied from ideopen)
                ideerror = 2
                If _FileExists(path$ + idepathsep$ + f$) = 0 Then GoTo IDEerrorMessage
                PCopy 3, 0
                ideerror = 3
                idepath$ = path$
                lineinput3load path$ + idepathsep$ + f$
                idet$ = Space$(Len(lineinput3buffer) * 8)
                i2 = 1
                n = 0
                chrtab$ = Chr$(9)
                space1$ = " ": space2$ = "  ": space3$ = "   ": space4$ = "    "
                chr7$ = Chr$(7): chr11$ = Chr$(11): chr12$ = Chr$(12): chr28$ = Chr$(28): chr29$ = Chr$(29): chr30$ = Chr$(30): chr31$ = Chr$(31)
                Do
                    a$ = lineinput3$
                    l = Len(a$)
                    If l Then asca = Asc(a$) Else asca = -1
                    If asca <> 13 Then
                        If asca <> -1 Then
                            'fix tabs
                            ideopenfixtabsx:
                            x = InStr(a$, chrtab$)
                            If x Then
                                x2 = (x - 1) Mod 4
                                If x2 = 0 Then a$ = Left$(a$, x - 1) + space4$ + Right$(a$, l - x): l = l + 3: GoTo ideopenfixtabsx
                                If x2 = 1 Then a$ = Left$(a$, x - 1) + space3$ + Right$(a$, l - x): l = l + 2: GoTo ideopenfixtabsx
                                If x2 = 2 Then a$ = Left$(a$, x - 1) + space2$ + Right$(a$, l - x): l = l + 1: GoTo ideopenfixtabsx
                                If x2 = 3 Then a$ = Left$(a$, x - 1) + space1$ + Right$(a$, l - x): GoTo ideopenfixtabsx
                            End If
                        End If 'asca<>-1
                        Mid$(idet$, i2, l + 8) = MKL$(l) + a$ + MKL$(l): i2 = i2 + l + 8: n = n + 1
                    End If
                Loop Until asca = 13
                lineinput3buffer = ""
                iden = n: If n = 0 Then idet$ = MKL$(0) + MKL$(0): iden = 1 Else idet$ = Left$(idet$, i2 - 1)
                ReDim IdeBreakpoints(iden) As _Byte
                ReDim IdeSkipLines(iden) As _Byte
                backupTypeDefinitions$ = ""

                If ideStartAtLine > 0 And ideStartAtLine <= iden Then
                    idecy = ideStartAtLine
                    If idecy - 10 >= 1 Then idesy = idecy - 10
                    idegotobox_LastLineNum = ideStartAtLine
                    ideStartAtLine = 0
                End If
                IdeBmkN = 0
                ideerror = 1
                ideprogname = f$: _Title ideprogname + " - " + WindowTitle
                '                IdeImportBookmarks idepath$ + idepathsep$ + ideprogname$
                IdeAddRecent idepath$ + idepathsep$ + ideprogname$
            End If 'message 1

        End If 'no restore

        skipload:

    End If 'idelaunched

    If c$ = Chr$(3) Then
        skipdisplay = 1 'assume .../starting already displayed
        sendnextline = 1

        'previous line was OK, so use layout if available

        If ideautolayout = 0 And ideautoindent = 0 Then

            layout$ = ""
            idelayoutallow = 0

        Else

            If Len(layout$) Then

                'calculate recommended indent level
                For i = 1 To Len(layout$)
                    If Asc(layout$, i) <> 32 Or i = Len(layout$) Then
                        indent = i - 1
                        layout$ = Right$(layout$, Len(layout$) - i + 1)
                        Exit For
                    End If
                Next

                If ideautolayout Then
                    spacelayout:
                    ignoresp = 0
                    For i = 1 To Len(layout$)
                        If Asc(layout$, i) = 34 Then
                            ignoresp = ignoresp + 1: If ignoresp = 2 Then ignoresp = 0
                        End If
                        If ignoresp = 0 Then
                            If Mid$(layout$, i, 1) = sp Then Mid$(layout$, i, 1) = " "
                            If Mid$(layout$, i, 1) = sp2 Then layout$ = Left$(layout$, i - 1) + Right$(layout$, Len(layout$) - i): GoTo spacelayout
                        End If
                    Next
                End If

                If ideautoindent = 0 Then
                    'note: can assume auto-format
                    'calculate old indent (if any)
                    a$ = idecompiledline$
                    indent = 0
                    For i = 1 To Len(a$)
                        If Asc(a$, i) <> 32 Or i = Len(a$) Then
                            indent = i - 1
                            Exit For
                        End If
                    Next
                    indent$ = Space$(indent)
                Else
                    indent$ = Space$(indent * ideautoindentsize)
                End If

                If ideautolayout = 0 Then
                    'note: can assume auto-indent
                    a$ = idecompiledline$
                    layout$ = ""
                    For i = 1 To Len(a$)
                        If Asc(a$, i) <> 32 Or i = Len(a$) Then
                            layout$ = Right$(a$, Len(a$) - i + 1)
                            Exit For
                        End If
                    Next
                End If

                layout$ = indent$ + layout$

                If idecy <> idecompiledline Or idelayoutallow <> 0 Then
                    idelayoutallow = 0

                    If idecompiledline$ <> layout$ Then
                        idesetline idecompiledline, layout$
                        If idecompiledline >= idesy And idecompiledline <= (idesy + 16) Then skipdisplay = 0
                    End If

                Else

                    If idecompiledline$ <> layout$ Then
                        idecurrentlinelayout = layout$
                        idecurrentlinelayouti = idecy
                    End If

                End If

            End If 'len(layout$)

        End If 'using layout/indent

    End If '3

    If c$ = Chr$(6) Then
        idecompiling = 0
        ready = 1
        If ideautorun Then ideautorun = 0: GoTo idemrunspecial
    End If

    If c$ = Chr$(11) Then
        idecompiling = 0
        ready = 1
        ideautorun = 0
        showexecreated = 1
    End If

    If c$ = Chr$(7) Then
        skipdisplay = 1 'assume .../starting already displayed
        idecompiledline = 0
        sendnextline = 1
    End If

    If Left$(c$, 1) = Chr$(8) Then
        idecompiling = 0
        failed = 1
        ideautorun = 0
    End If

    passback = 0
    If Left$(c$, 1) = Chr$(10) Then 'passback
        skipdisplay = 1 'assume .../starting already displayed
        sendnextline = 1
        idecompiledline = idecompiledline - 1
        passback = 1
        passback$ = Right$(c$, Len(c$) - 1)
    End If

    If mustdisplay Then skipdisplay = 0

    If skipdisplay = 0 Then

        Locate , , 0

        If c$ <> Chr$(3) Then
            clearStatusWindow 0
            If ready Then
                If IDEShowErrorsImmediately Then
                    _PrintString (2, idewy - 3), "OK" 'report OK status
                    statusarealink = 0
                    If totalWarnings > 0 And showexecreated = 0 Then
                        Color 11, 1
                        msg$ = " (" + LTrim$(Str$(totalWarnings)) + " warning"
                        If totalWarnings > 1 Then msg$ = msg$ + "s"
                        msg$ = msg$ + " - click here or Ctrl+W to view)"
                        _PrintString (4, idewy - 3), msg$
                        statusarealink = 4
                    End If
                    If waitingForVarList Then GoSub showVarListReady
                End If
            End If
            If showexecreated Then
                showexecreated = 0
                _PrintString (2, idewy - 3), "Executable file created"
                If SaveExeWithSource Then
                    Color 11, 1
                    location$ = lastBinaryGenerated$
                    If path.exe$ = "" Then location$ = _StartDir$ + pathsep$ + location$
                    msg$ = "Location: " + location$
                    If 2 + Len(msg$) > idewx Then
                        msg$ = "Location: " + String$(3, 250) + Right$(location$, idewx - 15)
                    End If
                    _PrintString (2, idewy - 2), msg$
                    statusarealink = 3
                End If

            End If
        End If

    End If 'skipdisplay

    idefocusline = 0

    'main loop
    Do
        ideloop:
        If ShowLineNumbers Then maxLineNumberLength = Len(Str$(iden)) + 1 Else maxLineNumberLength = 0
        idecontextualmenu = 0
        idedeltxt 'removes temporary strings (typically created by guibox commands) by setting an index to 0
        If idesubwindow <> 0 Then _Resize Off Else _Resize On

        If (_Resize Or ForceResize) And timeElapsedSince(QB64_uptime!) > 1.5 Then
            If idesubwindow <> 0 Then 'If there's a subwindow up, don't resize as it screws all sorts of things up.
                ForceResize = -1
            Else
                retval = 0
                ForceResize = 0
                Do
                    tooSmall%% = 0
                    v% = _ResizeWidth \ _FontWidth: If v% < 80 Or v% > 1000 Then v% = 80: tooSmall%% = -1
                    If v% <> idewx Then retval = 1: idewx = v%
                    v% = _ResizeHeight \ _FontHeight: If v% < 25 Or v% > 1000 Then v% = 25: tooSmall%% = -1
                    If v% <> idewy Then retval = 1: idewy = v%

                    tempf& = _Font
                    Width idewx, idewy
                    _Font tempf&

                    _PaletteColor 1, IDEBackgroundColor, 0
                    _PaletteColor 2, _RGB32(84, 84, 84), 0 'dark gray - help system and interface details
                    _PaletteColor 5, IDEBracketHighlightColor, 0
                    _PaletteColor 6, IDEBackgroundColor2, 0
                    _PaletteColor 7, IDEChromaColor, 0
                    _PaletteColor 8, IDENumbersColor, 0
                    _PaletteColor 10, IDEMetaCommandColor, 0
                    _PaletteColor 11, IDECommentColor, 0
                    _PaletteColor 12, IDEKeywordColor, 0
                    _PaletteColor 13, IDETextColor, 0
                    _PaletteColor 14, IDEQuoteColor, 0

                    Screen , , 3, 0
                    'static background
                    Color 0, 7
                    _PrintString (1, 1), Space$(idewx)
                    _PrintString (1, 1), Left$(menubar$, idewx)
                    Color 7, 1: idebox 1, 2, idewx, idewy - 5

                    Color 7, 1: idebox 1, idewy - 4, idewx, 5
                    'edit corners
                    Color 7, 1: _PrintString (1, idewy - 4), Chr$(195): _PrintString (idewx, idewy - 4), Chr$(180)

                    GoSub UpdateSearchBar

                    'status bar
                    Color 0, 3: _PrintString (1, idewy + idesubwindow), Space$(idewx)
                    UpdateIdeInfo
                    q = idevbar(idewx, idewy - 3, 3, 1, 1)
                    q = idevbar(idewx, 3, idewy - 8, 1, 1)
                    q = idehbar(2, idewy - 5, idewx - 2, 1, 1)

                    UpdateTitleOfMainWindow

                    Color 7, 1
                    _PrintString (2, idewy - 3), "Resizing..."
                    If tooSmall%% Then
                        Color 14, 1
                        _PrintString (2, 3), "ERROR: Minimum window size is 80x25"
                    Else
                        ideshowtext
                    End If

                    PCopy 3, 0

                    _Display
                    _Limit 15
                Loop While _Resize

                If retval = 1 Then 'screen dimensions have changed and everything must be redrawn/reapplied
                    WriteConfigSetting windowSettingsSection$, "IDE_Width", Str$(idewx)
                    WriteConfigSetting windowSettingsSection$, "IDE_Height", Str$(idewy)
                End If

                retval = 1
                _AutoDisplay
                GoSub redrawItAll
            End If
        Else
            _AutoDisplay
        End If

        If skipdisplay = 0 Then

            Locate , , 0

            'update title of main window
            UpdateTitleOfMainWindow

            'Draw navigation buttons (QuickNav)
            If EnableQuickNav Then GoSub DrawQuickNav

            'update search bar
            GoSub UpdateSearchBar

            'alter cursor style to match insert mode
            If ideinsert Then Locate , , , 0, 31 Else Locate , , , IDENormalCursorStart, IDENormalCursorEnd

            'display error message (if necessary)
            If failed Then
                If IDEShowErrorsImmediately <> 0 Or IDECompilationRequested <> 0 Or compfailed <> 0 Then
                    If Left$(IdeInfo, 19) <> "Selection length = " Then IdeInfo = ""
                    UpdateIdeInfo

                    clearStatusWindow 0
                    'scrolling unavailable, but may span multiple lines
                    If compfailed Then
                        a$ = Mid$(c$, 2, Len(c$) - 5)
                        x = 2
                        y = idewy - 3
                        printWrapStatus x, y, x, a$
                        statusarealink = 1
                    Else
                        a$ = Mid$(c$, 2, Len(c$) - 5)

                        l = CVL(Right$(c$, 4)): If l <> 0 Then idefocusline = l

                        x = 2
                        y = idewy - 3

                        If l <> 0 And idecy = l Then onCurrentLine = Len(a$): a$ = a$ + Chr$(1) + " on current line"

                        hasReference = InStr(a$, " - Reference: ")
                        If hasReference Then
                            hasReference = hasReference + 13
                            a$ = Left$(a$, hasReference) + Chr$(2) + Mid$(a$, hasReference + 1)
                        Else
                            hasReference = InStr(a$, "Expected ")
                            If hasReference Then
                                hasReference = hasReference + 8
                                a$ = Left$(a$, hasReference) + Chr$(2) + Mid$(a$, hasReference + 1)
                            End If
                        End If

                        printWrapStatus x, y, x, a$

                        If l <> 0 And idecy <> l Then
                            a$ = " on line" + Str$(l) + " (click here or Ctrl+Shift+G to jump there)"
                            Color 11, 1
                            printWrapStatus Pos(0), CsrLin, 2, a$
                            statusarealink = 2
                        End If

                        y = CsrLin
                        If y < idewy - 1 And linefragment <> "[INFORMATION UNAVAILABLE]" Then
                            temp$ = linefragment
                            For i = 1 To Len(temp$)
                                If Mid$(temp$, i, 1) = sp$ Then Mid$(temp$, i, 1) = " "
                            Next
                            temp$ = _Trim$(temp$)
                            If Len(temp$) Then
                                y = y + 1: x = 1
                                temp$ = "Caused by (or after): " + Chr$(1) + temp$

                                Color 7, 1
                                For i = 1 To Len(temp$)
                                    x = x + 1: If x = idewx Then x = 2: y = y + 1
                                    If y > idewy - 1 Then Exit For
                                    If Asc(temp$, i) = 1 Then i = i + 1: Color 11, 1
                                    _PrintString (x, y), Chr$(Asc(temp$, i))
                                Next
                            End If
                        End If

                    End If
                End If
            End If

            If idechangemade Then
                If IDEShowErrorsImmediately Or IDECompilationRequested Then
                    clearStatusWindow 0
                    IdeInfo = ""
                    _PrintString (2, idewy - 3), String$(3, 250) 'assume new compilation will begin "..."
                End If
            End If

            ideshowtext

            If IdeSystem = 2 Then 'override cursor position
                Screen , , 0, 0
                tx = idesystem2.v1
                If Len(idefindtext) > idesystem2.w Then
                    If idesystem2.v1 > idesystem2.w Then
                        tx = idesystem2.w
                    Else
                        tx = idesystem2.v1
                    End If
                End If
                Locate idewy - 4, idewx - (idesystem2.w + 8) + 4 + tx
                Screen , , 3, 0
            End If

            Locate , , 1

            PCopy 3, 0

        End If 'skipdisplay

        If idechangemade Then

            If idelayoutallow Then idelayoutallow = idelayoutallow - 1

            idecurrentlinelayouti = 0 'invalidate
            idefocusline = 0
            idechangemade = 0
            IDECompilationRequested = 0
            compfailed = 0
            If ideunsaved = -1 Then ideunsaved = 0 Else ideunsaved = 1

            If idenoundo = 0 Then

                'undo/redo
                'build data so it can be written in a single write (a backup requirement)
                a$ = ""
                a$ = a$ + MKL$(idesx) + MKL$(idesy) 'screen position
                a$ = a$ + MKL$(idecx) + MKL$(idecy) 'cursor position
                a$ = a$ + MKL$(ideselect) + MKL$(ideselectx1) + MKL$(ideselecty1) 'selection state & position
                a$ = a$ + MKL$(iden) 'number of lines
                a$ = a$ + MKL$(idel) 'selected line in buffer
                a$ = a$ + MKL$(ideli) 'selected line offset in buffer
                'bookmark info [v2]
                a$ = a$ + MKL$(IdeBmkN)
                For bi = 1 To IdeBmkN: a$ = a$ + MKL$(IdeBmk(bi).y) + MKL$(IdeBmk(bi).x): Next
                l& = Len(idet$)
                a$ = a$ + MKL$(l&) 'data size
                a$ = MKL$(l& + Len(a$)) + a$ + idet$ + MKL$(l& + Len(a$)) 'header, data & encapsulation (reverse navigatable list)

                'add undo event

                Open tmpdir$ + "undo2.bin" For Binary As #150
                '[oldest state entry][newest state entry][top-most entry(ignore if no wrapping required)]
                h$ = Space$(12): Get #150, , h$: p1 = CVL(Mid$(h$, 1, 4)): p2 = CVL(Mid$(h$, 5, 4)): plast = CVL(Mid$(h$, 9, 4))

                If idemergeundo Then
                    idemergeundo = 0
                    If p2 <> p1 Then 'can it be moved back?
                        If p2 = 13 Then
                            p2 = plast
                        Else
                            'get offset of previous message
                            Get #150, p2 - 4, pp2l
                            p2 = p2 - 4 - pp2l - 4
                        End If
                    End If
                End If

                If p1 = 0 Then 'not init
                    p1 = 13: p2 = 13
                Else
                    If p2 >= p1 Then
                        'no wrap
                        'should we extend?
                        If p2 >= idebackupsize * 1000000 Then
                            'can't extend
                            'set p2 as top-most
                            plast = p2
                            p2 = 13
                            'can new state (a$) fit before p1?
                            Do While (p2 + Len(a$) - 1) >= p1
                                If p1 = ideundobase Then ideundobase = -1
                                'no, so move p1 to next entry
                                'note: it can be assumed that p1, being near/at beginning, won't have to wrap when being moved forward
                                Get #150, p1, p1l
                                p1 = p1 + 4 + p1l + 4
                            Loop
                            'p1 & p2 ready
                        Else
                            'extend
                            'find size of p2 event
                            Get #150, p2, p2l
                            p2 = p2 + 4 + p2l + 4
                            'p1 & p2 ready
                        End If
                    Else
                        'wrap
                        'find size of p2 event
                        Get #150, p2, p2l
                        op2 = p2
                        p2 = p2 + 4 + p2l + 4
                        'can new state (a$) fit before p1?
                        Do While (p2 + Len(a$) - 1) >= p1
                            If p1 = ideundobase Then ideundobase = -1
                            'no, so move p1 to next entry
                            If p1 = plast Then
                                p1 = 13
                                Exit Do
                            Else
                                Get #150, p1, p1l
                                p1 = p1 + 4 + p1l + 4
                            End If
                        Loop
                        'should we extend?
                        If p2 >= idebackupsize * 1000000 Then
                            'can't extend
                            'set op2 as top-most
                            plast = op2
                            p2 = 13
                            'can new state (a$) fit before p1?
                            Do While (p2 + Len(a$) - 1) >= p1
                                If p1 = ideundobase Then ideundobase = -1
                                'no, so move p1 to next entry
                                'note: it can be assumed that p1, being near/at beginning, won't have to wrap when being moved forward
                                Get #150, p1, p1l
                                p1 = p1 + 4 + p1l + 4
                            Loop
                        End If
                        'p1 & p2 ready
                    End If
                End If

                'update p1,p2,plast
                h$ = MKL$(p1) + MKL$(p2) + MKL$(plast)
                Put #150, 1, h$

                'add new state
                Put #150, p2, a$

                Close #150

                ideundopos = p2
                If ideundobase = 0 Then ideundobase = ideundopos



                'set undo flag once
                If ideundoflag = 0 Then
                    ideundoflag = 1
                    Open tmpdir$ + "autosave.bin" For Binary As #150: a$ = Chr$(1): Put #150, , a$: Close #150 'set flag
                End If

            Else
                idenoundo = 0
            End If

            'begin new compilation
            If IDEBuildModeChanged = 0 Then
                ideautorun = 0
            End If
            IDEBuildModeChanged = 0

            idecompiling = 1
            ide2 = 2
            idecompiledline$ = idegetline(1)
            idereturn$ = idecompiledline$
            idecompiledline = 1
            Exit Function
        End If 'idechangemade


        change = 0
        waitforinput:
        If startPausedPending Then GoTo idemrun
        If idecurrentlinelayouti Then
            If idecy <> idecurrentlinelayouti Then
                idesetline idecurrentlinelayouti, idecurrentlinelayout$
                idecurrentlinelayouti = 0
                change = 1 'simulate a change to force a screen update
            End If
        End If

        exitvalue = _Exit
        If (exitvalue And 1) <> 0 Or ideexit <> 0 Then ideexit = 0: GoTo quickexit

        GetInput
        If iCHANGED Then
            Static mox, moy
            If (mX <> mox Or mY <> moy) And mB <> 0 Then 'dragging mouse
                mox = mX
                moy = mY
                change = 1
            End If
            If mB <> mOB Then change = 1 'button changed
            If mB2 <> mOB2 Then change = 1 'button changed
            If mCLICK <> 0 Or mCLICK2 <> 0 Then change = 1
            If mWHEEL Then change = 1
            If KB Then change = 1
            If KSTATECHANGED Then change = 1
        End If
        If mB <> 0 And idembmonitor = 1 Then change = 1
        If mB = 0 Then idemouseselect = 0: idembmonitor = 0: wholeword.select = 0

        If _Resize Then
            ForceResize = -1: skipdisplay = 0: GoTo ideloop
        End If

        If IDE_AutoPosition Then
            If IDE_TopPosition <> _ScreenY Or IDE_LeftPosition <> _ScreenX Then
                If _ScreenY >= -_Height * _FontHeight And _ScreenX >= -_Width * _FontWidth Then 'Don't record the position if it's off the screen, past the point where we can drag it back into a different position.
                    WriteConfigSetting windowSettingsSection$, "IDE_TopPosition", Str$(_ScreenY)
                    WriteConfigSetting windowSettingsSection$, "IDE_LeftPosition", Str$(_ScreenX)
                    IDE_TopPosition = _ScreenY: IDE_LeftPosition = _ScreenX
                End If
            End If
        End If

        If _TotalDroppedFiles > 0 Then
            If _FileExists(_DroppedFile$(1)) Then
                IdeOpenFile$ = _DroppedFile$(1)
                _FinishDrop
                GoTo ctrlOpen
            End If
            _FinishDrop
        End If

        'Hover/click (QuickNav, "Find" field, version number, line number)
        updateHover = 0
        If QuickNavTotal > 0 Then
            Do Until QuickNavHistory(QuickNavTotal).idecy <= iden
                'make sure that the line number in history still exists
                QuickNavTotal = QuickNavTotal - 1
                If QuickNavTotal = 0 Then Exit Do
            Loop
        End If

        If IdeSystem = 1 And QuickNavTotal > 0 And EnableQuickNav Then
            If mY = 2 Then
                If mX >= 4 And mX <= 6 Then
                    If QuickNavHover = 0 Then
                        QuickNavHover = -1
                        Color 15, 3
                        popup$ = " " + Chr$(17) + " back to line " + str2$(QuickNavHistory(QuickNavTotal).idecy) + " "
                        _PrintString (4, 2), popup$

                        'shadow
                        Color 2, 0
                        For x2 = 6 To 4 + Len(popup$)
                            _PrintString (x2, 3), Chr$(Screen(3, x2))
                        Next
                        updateHover = -1
                    End If

                    If mCLICK Then
                        ideselect = 0
                        idecy = QuickNavHistory(QuickNavTotal).idecy
                        idecx = QuickNavHistory(QuickNavTotal).idecx
                        idesx = QuickNavHistory(QuickNavTotal).idesx
                        idecentercurrentline
                        QuickNavTotal = QuickNavTotal - 1
                        GoTo ideloop
                    End If
                Else
                    GoTo RestoreBGQuickNav
                End If
            Else
                RestoreBGQuickNav:
                If QuickNavHover = -1 Then
                    QuickNavHover = 0
                    UpdateTitleOfMainWindow
                    GoSub DrawQuickNav
                    ideshowtext
                    updateHover = -1
                End If
            End If
        End If

        If mY = idewy - 4 And mX > idewx - (idesystem2.w + 10) And mX <= idewx - (idesystem2.w + 8) + 2 Then '"Find" button
            If FindFieldHover = 0 Then
                'Highlight "Find"
                Color 1, 3
                _PrintString (idewx - (idesystem2.w + 9), idewy - 4), "Find"
                updateHover = -1
                FindFieldHover = -1
            End If
        Else
            If FindFieldHover = -1 Then
                'Restore "Find" bg
                FindFieldHover = 0
                Color 3, 1
                _PrintString (idewx - (idesystem2.w + 9), idewy - 4), "Find"
                updateHover = -1
            End If
        End If

        If mY = idewy + idesubwindow And mX >= idewx - 21 - Len(versionStringStatus$) And mX < idewx - 21 Then
            'Highlight Version Number
            If VersionInfoHover = 0 Then
                Color 13, 6
                _PrintString (idewx - 21 - Len(versionStringStatus$), idewy + idesubwindow), versionStringStatus$
                updateHover = -1
                VersionInfoHover = -1
            End If
            If mCLICK Then PCopy 0, 2: GoTo helpabout
        Else
            If VersionInfoHover = -1 Then
                'Restore "Find" bg
                VersionInfoHover = 0
                Color 2, 3
                _PrintString (idewx - 21 - Len(versionStringStatus$), idewy + idesubwindow), versionStringStatus$
                updateHover = -1
            End If
        End If

        If mY = idewy + idesubwindow And mX >= idewx - 20 And mX <= idewx Then
            'Highlight line number
            If LineNumberHover = 0 Then
                Color 13, 6
                _PrintString (idewx - 20, idewy + idesubwindow), lineNumberStatus$
                LineNumberHover = -1
                updateHover = -1
            End If
            If mCLICK Then
                PCopy 0, 2
                idegotobox
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If
        Else
            If LineNumberHover = -1 Then
                'Restore "Find" bg
                LineNumberHover = 0
                Color 0, 3
                _PrintString (idewx - 20, idewy + idesubwindow), lineNumberStatus$
                updateHover = -1
            End If
        End If

        If KALT Then 'alt held

            If idealthighlight = 0 And KALTPRESS = -1 And Not KCTRL Then
                'highlist first letter of each menu item
                idealthighlight = 1
                Locate , , 0: Color 15, 7: x = 4
                For i = 1 To menus
                    _PrintString (x, 1), Left$(menu$(i, 0), 1)
                    x = x + Len(menu$(i, 0)) + 2
                    If i = menus - 1 Then x = idewx - Len(menu$(menus, 0)) - 1
                Next
                ideentermenu = 1 'alt has just been pressed, so any next keystroke could enter a menu)
                'IF change = 0 THEN
                skipdisplay = 0: GoTo ideloop 'force update so cursor will be restored to correct position
            End If

        Else 'alt not held
            If idealthighlight = 1 Then
                'remove highlight
                idealthighlight = 0
                Locate , , 0: Color 0, 7: _PrintString (1, 1), menubar$
                If ideentermenu = 1 And KCONTROL = 0 Then 'alt was pressed then released
                    If _WindowHasFocus Then
                        Locate , , , IDENormalCursorStart, IDENormalCursorEnd
                        skipdisplay = 0
                        ideentermenu = 0
                        GoTo startmenu
                    End If
                End If
            End If

        End If 'alt not held

        If updateHover Then PCopy 3, 0

        If change = 0 Then

            'continue compilation?
            If idecompiling Then
                If sendnextline Then
                    If idecompiledline < iden Then
                        idecompiledline = idecompiledline + 1
                        ide2 = 4
                        If passback Then
                            idecompiledline$ = passback$
                            idereturn$ = idecompiledline$
                        Else
                            idecompiledline$ = idegetline(idecompiledline)
                            idereturn$ = idecompiledline$
                        End If
                        Exit Function
                    Else
                        'finished compilation
                        ide2 = 5 'end of program reached, what next?
                        'could return:
                        'i) 6 code ready for export/run
                        'ii) 7 repass required (if so send data from the beginning again)
                        Exit Function
                    End If
                End If
            End If

            _Limit 16
            GoTo waitforinput
        End If 'change=0

        ideentermenu = 0

        ideundocombo = ideundocombo - 1
        If ideundocombo < 0 Then ideundocombo = 0

        skipdisplay = 0

        'IdeSystem independent routines

        If mCLICK Then
            If mX >= 2 And mX <= idewx And mY >= idewy - 3 And mY <= idewy - 1 Then
                If Screen(mY, mX, 1) = 11 + 1 * 16 Then 'if the text clicked is in COLOR 11 it's a link
                    'Status area links
                    Select Case statusarealink
                        Case 1
                            '1- Link to compilelog.txt:
                            Shell _DontWait "xdg-open " + QuotedFilename$(compilelog$)
                            GoTo specialchar
                        Case 2
                            '2- Link to the line that has a compiler error:
                            idecx = 1
                            AddQuickNavHistory
                            idecy = idefocusline
                            ideselect = 0
                            GoTo specialchar
                        Case 3
                            '3- Link to the output folder when "Output EXE to source #folder" is checked:
                            Shell _DontWait "xdg-open " + QuotedFilename$(path.exe$)
                            GoTo specialchar
                        Case 4
                            '4- Link to Warnings dialog:
                            retval = idewarningbox
                            'retval is ignored
                            PCopy 3, 0: Screen , , 3, 0
                            GoTo specialchar
                    End Select
                End If
            End If
        End If

        If KB = KEY_F11 Then 'make exe only
            idemexe:
            iderunmode = 2
            GoTo idemrunspecial
        End If

        If KB = KEY_F5 Then 'Note: F5 or SHIFT+F5 accepted
            startPaused = 0
            idemrun:
            startPausedPending = 0
            iderunmode = 1 'run detached; = 0 'standard run
            idemrunspecial:

            IDECompilationRequested = -1

            If ExeToSourceFolderFirstTimeMsg = 0 Then
                If SaveExeWithSource Then
                    result = idemessagebox("Run", "Your program will be compiled to the same folder where your" + CHR$(10) + _
                                           "source code is saved. You can change that by unchecking the" + CHR$(10) + _
                                           "option 'Output EXE to Source Folder' in the Run menu.", "#OK;#Don't show this again;#Cancel")
                Else
                    result = idemessagebox("Run", "Your program will be compiled to your QB64 folder. You can" + CHR$(10) + _
                                         "change that by checking the option 'Output EXE to Source" + CHR$(10) + _
                                         "Folder' in the Run menu.", "#OK;#Don't show this again;#Cancel")
                End If
                If result = 2 Then
                    WriteConfigSetting generalSettingsSection$, "ExeToSourceFolderFirstTimeMsg", "True"
                    ExeToSourceFolderFirstTimeMsg = -1
                ElseIf result = 3 Then
                    PCopy 3, 0: Screen , , 3, 0
                    Locate , , 0
                    clearStatusWindow 0
                    _PrintString (2, idewy - 3), "Compilation request canceled."
                    GoTo specialchar
                End If
            End If
            PCopy 3, 0: Screen , , 3, 0

            'run program
            If ready <> 0 And idechangemade = 0 Then

                Locate , , 0
                clearStatusWindow 0

                If idecompiled Then

                    If iderunmode = 2 And _FileExists(lastBinaryGenerated$) Then
                        _PrintString (2, idewy - 3), "Already created executable file!"
                        Color 11, 1
                        location$ = lastBinaryGenerated$
                        If path.exe$ = "" Then location$ = _StartDir$ + pathsep$ + location$
                        msg$ = "Location: " + location$
                        If 2 + Len(msg$) > idewx Then
                            msg$ = "Location: " + String$(3, 250) + Right$(location$, idewx - 15)
                        End If
                        _PrintString (2, idewy - 2), msg$
                        statusarealink = 3


                        GoTo specialchar
                    ElseIf _FileExists(lastBinaryGenerated$) = 0 Then
                        idecompiled = 0
                        GoTo mustGenerateExe
                    End If

                    dummy = DarkenFGBG(1)
                    BkpIdeSystem = IdeSystem: IdeSystem = 2: UpdateTitleOfMainWindow: IdeSystem = BkpIdeSystem
                    Color 1, 7: _PrintString ((idewx - 8) / 2, idewy - 4), " Status "
                    Color 15, 1
                    _PrintString (2, idewy - 3), "Starting program..."
                Else
                    mustGenerateExe:
                    dummy = DarkenFGBG(1)
                    BkpIdeSystem = IdeSystem: IdeSystem = 2: UpdateTitleOfMainWindow: IdeSystem = BkpIdeSystem
                    Color 1, 7: _PrintString ((idewx - 8) / 2, idewy - 4), " Status "
                    Color 15, 1
                    _PrintString (2, idewy - 3), "Creating executable file..."
                End If
                PCopy 3, 0

                'send run request
                'prepare name
                If ideprogname$ = "" Then
                    f$ = "untitled" + tempfolderindexstr$
                Else
                    f$ = ideprogname$
                    f$ = RemoveFileExtension$(f$)
                End If
                ide2 = 9: idereturn$ = f$
                Exit Function
            End If
            'not ready!
            If failed = 1 Then GoTo specialchar
            'assume still compiling ...
            ideautorun = 1

            'correct status message
            Locate , , 0
            clearStatusWindow 0

            _PrintString (2, idewy - 3), "Checking program... (editing program will cancel request)"

            'must move the cursor back to its correct location
            ideshowtext
            Locate , , 1
            PCopy 3, 0

            GoTo specialchar
        End If

        Locate , , 0
        Locate , , , IDENormalCursorStart, IDENormalCursorEnd

        If (mCLICK Or mCLICK2) And idemouseselect = 0 Then
            If mY = 1 Then
                x = 3
                For i = 1 To menus
                    x2 = Len(menu$(i, 0)) + 2
                    If mX >= x And mX < x + x2 Then
                        m = i
                        GoTo showmenu
                    End If
                    x = x + x2
                    If i = menus - 1 Then x = idewx - Len(menu$(menus, 0)) - 2
                Next
            End If
        End If

        For i = 1 To menus
            a$ = UCase$(Left$(menu$(i, 0), 1))
            If KALT And UCase$(K$) = a$ Then
                m = i
                Color 0, 7: _PrintString (1, 1), menubar$
                PCopy 3, 0
                GoTo showmenu
            End If
        Next

        If KCTRL And UCase$(K$) = "F" Then
            K$ = ""
            IdeSystem = 2
            If Len(idefindtext) Then idesystem2.issel = -1: idesystem2.sx1 = 0: idesystem2.v1 = Len(idefindtext)
            GoTo specialchar
        End If

        If KCTRL And UCase$(K$) = "K" Then
            K$ = ""
        End If

        If KCTRL And KB = KEY_F3 Then
            GoTo idefindjmp
        End If

        If KALT And KB = KEY_F3 Then
            GoTo idefindchangejmp
        End If

        If KB = KEY_F3 Or K$ = Chr$(28) Then
            idemf3:
            If idefindtext <> "" Then
                If IdeSystem = 2 Then
                    idesystem2.sx1 = 0
                    idesystem2.v1 = Len(idefindtext)
                    idesystem2.issel = -1
                End If
                GoSub UpdateSearchBar
                If KSHIFT Then idefindinvert = 1
                IdeAddSearched idefindtext
                idefindagain -1
            Else
                GoTo idefindjmp
            End If
            GoTo specialchar
        End If

        'Scroll bar code goes here
        '1=arrow less, 2=arrow more, 3=dragging 'bit', 4=clicking in space
        'IdeSystem specific code goes here

        If mCLICK Then 'Find [...] search field (IdeSystem = 2)
            If mY = idewy - 4 And mX > idewx - (idesystem2.w + 10) And mX < idewx - 1 Then 'inside text box
                If mX <= idewx - (idesystem2.w + 8) + 2 Then
                    If Len(idefindtext) = 0 Then
                        IdeSystem = 2 'no search string, so begin editing
                        idesystem2.issel = 0: idesystem2.v1 = 0
                    Else
                        IdeAddSearched idefindtext
                        IdeSystem = 1: GoTo idemf3 'F3 functionality
                    End If
                Else
                    If mX = idewx - 3 Then
                        showrecentlysearchedbox:
                        PCopy 0, 3
                        GoSub UpdateSearchBar
                        f$ = idesearchedbox
                        If Len(f$) Then idefindtext = f$
                        PCopy 3, 0: Screen , , 3, 0
                        idealthighlight = 0
                        Locate , , 0: Color 0, 7: _PrintString (1, 1), menubar$
                        IdeSystem = 1
                        If Len(f$) Then GoTo idemf3 'F3 functionality
                        GoTo ideloop
                    Else
                        If IdeSystem = 2 Then
                            If idesystem2.issel Then idesystem2.issel = 0

                            If Len(idefindtext) <= idesystem2.w Then
                                idesystem2.v1 = mX - (idewx - (idesystem2.w + 4))
                            Else
                                If idesystem2.v1 > idesystem2.w Then
                                    idesystem2.v1 = (mX - (idewx - (idesystem2.w + 4))) + (idesystem2.v1 - idesystem2.w)
                                Else
                                    idesystem2.v1 = mX - (idewx - (idesystem2.w + 4))
                                End If
                            End If
                        Else
                            IdeSystem = 2
                            If Len(idefindtext) Then idesystem2.issel = -1: idesystem2.sx1 = 0: idesystem2.v1 = Len(idefindtext)
                        End If
                    End If
                End If
            End If
        End If

        If IdeSystem = 2 Then 'certain keys transfer control
            z = 0
            If (KALT And KB = KEY_UP) Or (KALT And KB = KEY_DOWN) Then GoTo showrecentlysearchedbox
            If KB = KEY_UP Then z = 1
            If KB = KEY_DOWN Then z = 1
            If KB = KEY_PAGEUP Then z = 1
            If KB = KEY_PAGEDOWN Then z = 1
            If mWHEEL Then z = 1
            If z = 1 Then IdeSystem = 1
        End If

        If IdeSystem = 2 Then
            a$ = idefindtext
            If Len(K$) = 1 Or (KB = KEY_INSERT Or KB = KEY_DELETE) Then
                If Len(K$) = 1 Then k = Asc(K$)
                If (KSHIFT And KB = KEY_INSERT) Or (KCONTROL And UCase$(K$) = "V") Then 'paste from clipboard
                    pasteIntoSearchField:
                    clip$ = _Clipboard$ 'read clipboard
                    x = InStr(clip$, Chr$(13))
                    If x Then clip$ = Left$(clip$, x - 1)
                    x = InStr(clip$, Chr$(10))
                    If x Then clip$ = Left$(clip$, x - 1)
                    If Len(clip$) Then
                        If idesystem2.issel Then
                            sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                            If sx1 > sx2 Then Swap sx1, sx2
                            If sx2 - sx1 > 0 Then
                                a$ = Left$(a$, sx1) + clip$ + Right$(a$, Len(a$) - sx2)
                                idesystem2.v1 = sx1
                                If PasteCursorAtEnd Then
                                    idesystem2.v1 = sx1 + Len(clip$)
                                End If
                                idesystem2.issel = 0
                            End If
                        Else
                            a$ = Left$(a$, idesystem2.v1) + clip$ + Right$(a$, Len(a$) - idesystem2.v1)
                            If PasteCursorAtEnd Then idesystem2.v1 = idesystem2.v1 + Len(clip$)
                        End If
                    End If
                    k = 255
                End If

                If (KCONTROL And UCase$(K$) = "A") Then 'select all
                    selectAllInSearchField:
                    If Len(a$) > 0 Then
                        idesystem2.issel = -1
                        idesystem2.sx1 = 0
                        idesystem2.v1 = Len(a$)
                    End If
                    k = 255
                End If

                If ((KCTRL And KB = KEY_INSERT) Or (KCONTROL And UCase$(K$) = "C")) Then 'copy to clipboard
                    copysearchterm2clip:
                    If idesystem2.issel Then
                        sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then _Clipboard$ = Mid$(a$, sx1 + 1, sx2 - sx1)
                    End If
                    k = 255
                End If

                If ((KSHIFT And KB = KEY_DELETE) Or (KCONTROL And UCase$(K$) = "X")) Then 'cut to clipboard
                    cutToClipboardSearchField:
                    If idesystem2.issel Then
                        sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            _Clipboard$ = Mid$(a$, sx1 + 1, sx2 - sx1)
                            'delete selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            idesystem2.v1 = sx1
                            idesystem2.issel = 0
                        End If
                    End If
                    k = 255
                End If

                If k = 8 Then
                    If idesystem2.issel Then
                        sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            'delete selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            idefindtext = a$
                            idesystem2.v1 = sx1
                            idesystem2.issel = 0
                        End If
                    ElseIf idesystem2.v1 > 0 Then
                        a1$ = Left$(a$, idesystem2.v1 - 1)
                        If idesystem2.v1 <= Len(a$) Then a2$ = Right$(a$, Len(a$) - idesystem2.v1) Else a2$ = ""
                        a$ = a1$ + a2$: idesystem2.v1 = idesystem2.v1 - 1
                        idefindtext = a$
                    End If
                End If
                If k = 27 Then
                    IdeSystem = 1
                    GoTo specialchar
                End If
                If k = 9 Then
                    IdeSystem = 1
                    GoTo specialchar
                End If
                If k = 13 Then
                    If Len(idefindtext) Then
                        IdeAddSearched idefindtext
                        GoTo idemf3 'F3 functionality
                    End If
                    GoTo specialchar
                End If
                If k <> 8 And k <> 9 And k <> 0 And k <> 10 And k <> 13 And k <> 26 And k <> 255 Then
                    If idesystem2.issel Then
                        sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            'replace selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            idefindtext = a$
                            idesystem2.issel = 0
                            idesystem2.v1 = sx1
                        End If
                    End If
                    If idesystem2.v1 > 0 Then a1$ = Left$(a$, idesystem2.v1) Else a1$ = ""
                    If idesystem2.v1 <= Len(a$) Then a2$ = Right$(a$, Len(a$) - idesystem2.v1) Else a2$ = ""
                    a$ = a1$ + K$ + a2$: idesystem2.v1 = idesystem2.v1 + 1
                End If
                idefindtext = a$
            End If

            If K$ = Chr$(0) + Chr$(60) Then 'F2
                IdeSystem = 1
                GoTo idesubsjmp
            End If

            If K$ = Chr$(0) + "S" Then 'DEL
                deleteSelectionSearchField:
                If idesystem2.issel Then
                    sx1 = idesystem2.sx1: sx2 = idesystem2.v1
                    If sx1 > sx2 Then Swap sx1, sx2
                    If sx2 - sx1 > 0 Then
                        'delete selection
                        a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                        idefindtext = a$
                        idesystem2.v1 = sx1
                        idesystem2.issel = 0
                    End If
                Else
                    If idesystem2.v1 > 0 Then a1$ = Left$(a$, idesystem2.v1) Else a1$ = ""
                    If idesystem2.v1 < Len(a$) Then a2$ = Right$(a$, Len(a$) - idesystem2.v1 - 1) Else a2$ = ""
                    a$ = a1$ + a2$
                    idefindtext = a$
                End If
            End If

            'cursor control
            If K$ = Chr$(0) + "K" Then GoSub selectcheck: idesystem2.v1 = idesystem2.v1 - 1
            If K$ = Chr$(0) + "M" Then GoSub selectcheck: idesystem2.v1 = idesystem2.v1 + 1
            If K$ = Chr$(0) + "G" Then GoSub selectcheck: idesystem2.v1 = 0
            If K$ = Chr$(0) + "O" Then GoSub selectcheck: idesystem2.v1 = Len(a$)
            If idesystem2.v1 < 0 Then idesystem2.v1 = 0
            If idesystem2.v1 > Len(a$) Then idesystem2.v1 = Len(a$)
            If idesystem2.v1 = idesystem2.sx1 Then idesystem2.issel = 0

            If mCLICK Or mCLICK2 Then
                If mX > 1 And mX < idewx And mY > 2 And mY < (idewy - 5) Then 'inside text box
                    IdeSystem = 1
                    If mCLICK2 Then GoTo invokecontextualmenu Else GoTo ideloop
                End If
            End If

            GoTo specialchar
        End If


        If KALT And KB = KEY_LEFT Then
            bmkremoved = 0
            bmkremove:
            For b = 1 To IdeBmkN
                If IdeBmk(b).y = idecy Then
                    For b2 = b To IdeBmkN - 1
                        IdeBmk(b2) = IdeBmk(b2 + 1)
                    Next
                    IdeBmkN = IdeBmkN - 1
                    bmkremoved = 1
                    ideunsaved = 1
                    GoTo bmkremove
                End If
            Next
            If bmkremoved = 0 Then
                IdeBmkN = IdeBmkN + 1
                If IdeBmkN > UBound(IdeBmk) Then x = UBound(IdeBmk) * 2: ReDim _Preserve IdeBmk(x) As IdeBmkType
                IdeBmk(IdeBmkN).y = idecy
                IdeBmk(IdeBmkN).x = idecx
                IdeBmk(IdeBmkN).reserved = 0: IdeBmk(IdeBmkN).reserved2 = 0
                ideunsaved = 1
            End If
            GoTo specialchar
        End If

        If KALT And (KB = KEY_DOWN Or KB = KEY_UP) Then
            If IdeBmkN = 0 Then
                result = idemessagebox("Bookmarks", "No bookmarks exist (Use Alt+Left to create a bookmark)", "")
                Screen , , 3, 0
                idealthighlight = 0
                Locate , , 0: Color 0, 7: _PrintString (1, 1), menubar$
                GoTo specialchar
            End If
            If IdeBmkN = 1 Then
                If idecy = IdeBmk(1).y Then
                    result = idemessagebox("Bookmarks", "No other bookmarks exist", "")
                    Screen , , 3, 0
                    idealthighlight = 0
                    Locate , , 0: Color 0, 7: _PrintString (1, 1), menubar$
                    GoTo specialchar
                End If
            End If
            l = idecy
            Do
                If KB = KEY_DOWN Then l = l + 1 Else l = l - 1
                If l < 1 Then l = iden
                If l > iden Then l = 1
                For b = 1 To IdeBmkN
                    If IdeBmk(b).y = l Then Exit Do
                Next
            Loop
            AddQuickNavHistory
            idecy = l
            idecx = IdeBmk(b).x
            ideselect = 0
            idecentercurrentline
            GoTo specialchar
        End If

        If KALT And KB = KEY_RIGHT Then
            '***RESERVED***
            GoTo specialchar
        End If


        If KALT And KB >= 48 And KB <= 57 Then GoTo specialchar ' Steve Edit on 07-04-2014 to add support for ALT-numkey combos to produce ASCII codes

        If ideselect = 1 And wholeword.select < 0 And mY = old.mY Then
            'Mouse button has been held down since the last double-click word selection
            'and the user has moved the mouse only horizontally. Attempt to keep
            'selecting words to the left or right.
            If wholeword.select = -2 Then
                'we had a snap selection but moved up or down.
                'now we're back in the same line.
                wholeword.select = -1
                idemouseselect = 0
                ideselectx1 = wholeword.selectx1
                idecx = wholeword.idecx
                ideselecty1 = wholeword.selecty1
                idecy = wholeword.idecy
            End If
            newposition = (mX - 1 + idesx - 1) - maxLineNumberLength
            a$ = idegetline$(idecy)
            If newposition > Len(a$) Then idecx = newposition: GoTo DoneWholeWord
            If newposition = 1 Then ideselectx1 = 1: GoTo DoneWholeWord
            char.clicked$ = Mid$(a$, newposition, 1)
            If Len(char.clicked$) > 0 Then
                If newposition < wholeword.idecx Then
                    'To the left, to the left.
                    For i = newposition To 1 Step -1
                        If InStr(char.sep$, Mid$(a$, i, 1)) Then Exit For
                    Next i
                    ideselectx1 = i + 1
                ElseIf newposition > wholeword.selectx1 Then
                    'To the right.
                    For i = newposition To Len(a$)
                        If InStr(char.sep$, Mid$(a$, i, 1)) Then Exit For
                    Next i
                    idecx = i
                End If
            End If
        ElseIf ideselect = 1 And wholeword.select = -1 And mY <> old.mY Then
            idemouseselect = 1
            wholeword.select = -2
        End If

        If mCLICK Then
            If mX > 1 + maxLineNumberLength And mX < idewx And mY > 2 And mY < (idewy - 5) Then 'inside text box
                If old.mX = mX And old.mY = mY Then
                    If timeElapsedSince(last.TBclick#) > .5 Then GoTo regularTextBox_click
                    'Double-click on text box: attempt to select "word" clicked
                    idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                    idecy = mY - 2 + idesy - 1
                    If idecy > iden Then
                        GoTo regularTextBox_click
                    ElseIf ActiveINCLUDELink > 0 Then
                        'Double-click on an $INCLUDE statement launches that file in
                        'a separate instance of QB64:
                        p$ = idepath$ + pathsep$
                        f$ = p$ + ActiveINCLUDELinkFile
                        If _FileExists(f$) = 0 Then f$ = ActiveINCLUDELinkFile
                        If _FileExists(f$) Then
                            backupIncludeFile = FreeFile
                            Open f$ For Binary As #backupIncludeFile
                            tempInclude1$ = Space$(LOF(backupIncludeFile))
                            Get #backupIncludeFile, 1, tempInclude1$
                            Close #backupIncludeFile

                            Screen , , 3, 0
                            clearStatusWindow 0
                            Color 15, 1
                            _PrintString (2, idewy - 3), "Editing $INCLUDE file..."
                            dummy = DarkenFGBG(1)
                            PCopy 3, 0

                            p$ = QuotedFilename$(Command$(0)) + " " + QuotedFilename$(f$)
                            If errorLineInInclude > 0 And idefocusline = idecy Then
                                p$ = p$ + " -l:" + str2$(errorLineInInclude)
                            ElseIf warningInIncludeLine > 0 And warningInInclude = idecy Then
                                p$ = p$ + " -l:" + str2$(warningInIncludeLine)
                            End If
                            Shell p$

                            Open f$ For Binary As #backupIncludeFile
                            tempInclude2$ = Space$(LOF(backupIncludeFile))
                            Get #backupIncludeFile, 1, tempInclude2$
                            Close #backupIncludeFile

                            dummy = DarkenFGBG(0)
                            clearStatusWindow 0

                            If tempInclude1$ = tempInclude2$ Then
                                If IDEShowErrorsImmediately Then
                                    If idecompiling = 1 Then
                                        _PrintString (2, idewy - 3), String$(3, 250) '"..."
                                    Else
                                        _PrintString (2, idewy - 3), "OK" 'report OK status
                                        statusarealink = 0
                                        If totalWarnings > 0 Then
                                            Color 11, 1
                                            msg$ = " (" + LTrim$(Str$(totalWarnings)) + " warning"
                                            If totalWarnings > 1 Then msg$ = msg$ + "s"
                                            msg$ = msg$ + " - click here or Ctrl+W to view)"
                                            _PrintString (4, idewy - 3), msg$
                                            statusarealink = 4
                                        End If
                                        If waitingForVarList Then GoSub showVarListReady
                                    End If
                                End If
                            Else
                                idechangemade = 1
                                startPausedPending = 0
                            End If

                            PCopy 3, 0

                            tempInclude1$ = ""
                            tempInclude2$ = ""
                        End If
                    Else
                        a$ = idegetline$(idecy)
                        If Len(a$) = 0 Then GoTo regularTextBox_click
                        char.clicked$ = Mid$(a$, idecx, 1)
                        ideselect = 1
                        ideselecty1 = idecy
                        If Len(char.clicked$) > 0 And char.clicked$ <> Chr$(32) Then
                            For i = idecx To 1 Step -1
                                If InStr(char.sep$, Mid$(a$, i, 1)) Then Exit For
                            Next i
                            ideselectx1 = i + 1
                            wholeword.selectx1 = ideselectx1
                            For i = idecx To Len(a$)
                                If InStr(char.sep$, Mid$(a$, i, 1)) Then Exit For
                            Next i
                            idecx = i
                            wholeword.idecx = idecx
                            wholeword.select = -1
                            wholeword.idecy = idecy
                            wholeword.selecty1 = ideselecty1
                        End If
                    End If
                Else
                    regularTextBox_click:
                    old.mX = mX: old.mY = mY: last.TBclick# = Timer
                    ideselect = 1
                    idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                    idecy = mY - 2 + idesy - 1
                    If idecy > iden Then idecy = iden
                    ideselect = 1
                    If (Not KSHIFT) Then ideselectx1 = idecx: ideselecty1 = idecy
                    idemouseselect = 1
                    wholeword.select = 0
                End If
            ELSEIF (mX > 1 AND mX <= 1 + maxLineNumberLength AND mY > 2 AND mY < (idewy - 5) AND ShowLineNumbers) OR _
                   (mX = 1 AND mY > 2 AND mY < (idewy - 5) AND ShowLineNumbers = 0) THEN
                'line numbers are visible and have been clicked or
                'line numbers are hidden and the left border has been clicked
                ideselect = 1
                idecy = mY - 2 + idesy - 1
                If idecy < iden Then
                    If (Not KSHIFT) Then ideselectx1 = 1: ideselecty1 = idecy
                    idecy = idecy + 1
                    idecx = 1
                ElseIf idecy = iden Then
                    a$ = idegetline$(idecy)
                    If (Not KSHIFT) Then ideselectx1 = 1: ideselecty1 = idecy
                    idecx = Len(a$) + 1
                ElseIf idecy > iden Then
                    idecy = iden
                    ideselect = 0
                    idecx = 1
                End If
                wholeword.select = 0
                idemouseselect = 0
            End If
        End If

        DoneWholeWord:

        If mCLICK2 Then 'Second mouse button pressed.
            invokecontextualmenu:
            If mX > 1 + maxLineNumberLength And mX < idewx And mY > 2 And mY < (idewy - 5) Then 'inside text box
                IdeSystem = 1
                If ideselect = 0 Then 'Right click only positions the cursor if no selection is active
                    idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                    idecy = mY - 2 + idesy - 1
                    If idecy > iden Then idecy = iden
                Else 'A selection is reported but it may be that the user only clicked the screen. Let's check:
                    If ideselecty1 = idecy Then 'single line selected
                        a$ = idegetline(idecy)
                        a2$ = ""
                        sx1 = ideselectx1: sx2 = idecx
                        If sx2 < sx1 Then Swap sx1, sx2
                        For x = sx1 To sx2 - 1
                            If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
                        Next
                        If a2$ = "" Then
                            'Told ya.
                            ideselect = 0
                            idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                            idecy = mY - 2 + idesy - 1
                            If idecy > iden Then idecy = iden
                        Else
                            'Ok, there is a selection. But we'll override it if the click was outside it
                            If (mX - 1 + idesx - 1) - maxLineNumberLength < sx1 Or (mX - 1 + idesx - 1) - maxLineNumberLength > sx2 Then
                                ideselect = 0
                                idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                                idecy = mY - 2 + idesy - 1
                                If idecy > iden Then idecy = iden
                            End If
                            If mY - 2 + idesy - 1 < idecy Or mY - 2 + idesy - 1 > idecy Then
                                ideselect = 0
                                idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                                idecy = mY - 2 + idesy - 1
                                If idecy > iden Then idecy = iden
                            End If
                        End If
                    Else 'Multiple lines selected
                        'We'll override the selection if the click was outside it
                        sy1 = ideselecty1
                        sy2 = idecy
                        If sy1 > sy2 Then Swap sy1, sy2
                        If mY - 2 + idesy - 1 < sy1 Or mY - 2 + idesy - 1 > sy2 Then
                            ideselect = 0
                            idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                            idecy = mY - 2 + idesy - 1
                            If idecy > iden Then idecy = iden
                        End If
                    End If
                End If
                ideshowtext
                PCopy 3, 0
                IdeMakeContextualMenu
                idecontextualmenu = 1
                GoTo showmenu
            End If
        End If

        If mCLICK Then
            If mX = idewx Then
                If iden > 1 Then 'take no action if not slider available
                    y = idevbar(idewx, 3, idewy - 8, idecy, iden)
                    If y = mY Then
                        idemouseselect = 2
                        ideselect = 0
                    End If
                End If
            End If
        End If

        If mCLICK Then
            If mY = idewy - 5 Then
                x = idehbar(2, idewy - 5, idewx - 2, idesx, 608)
                If x = mX Then
                    idemouseselect = 3
                    ideselect = 0
                End If
            End If
        End If

        If mB And idemouseselect = 0 Then
            If mX = idewx And mY > 2 And mY < idewy - 5 Then 'inside vbar
                ideselect = 0
                If mY = 3 Then KB = KEY_UP: idewait: idembmonitor = 1
                If mY = idewy - 6 Then KB = KEY_DOWN: idewait: idembmonitor = 1
                If mY > 3 And mY < (idewy - 6) Then
                    'assume not on slider
                    If iden > 1 Then 'take no action if not slider available
                        y = idevbar(idewx, 3, idewy - 8, idecy, iden)
                        If y <> mY Then
                            If mY < y Then
                                KB = KEY_PAGEUP: idewait: idembmonitor = 1
                            Else
                                KB = KEY_PAGEDOWN: idewait: idembmonitor = 1
                            End If
                        End If
                    End If
                End If
            End If
        End If

        If mB And idemouseselect = 0 Then
            If mY = idewy - 5 And mX > 1 And mX < idewx Then 'inside hbar
                ideselect = 0
                If mX = 2 Then KB = KEY_LEFT: idewait: idembmonitor = 1
                If mX = idewx - 1 Then KB = KEY_RIGHT: idewait: idembmonitor = 1
                If mX > 2 And mX < idewx - 1 Then
                    'assume not on slider
                    x = idehbar(2, idewy - 5, idewx - 2, idesx, 608)
                    If x <> mX Then
                        If mX < x Then
                            idecx = idecx - 8
                            If idecx < 1 Then idecx = 1
                            idewait: idembmonitor = 1
                        Else
                            idecx = idecx + 8
                            idewait: idembmonitor = 1
                        End If
                    End If

                End If
            End If
        End If

        If mB And idemouseselect = 2 Then
            'move vbar scroller (idecy) to appropriate position
            If iden > 1 Then
                If mY <= 4 Then idecy = 1
                If mY >= idewy - 7 Then idecy = iden
                If mY > 4 And mY < idewy - 7 Then
                    y = mY
                    p! = y - 3 - 2 + .5
                    p! = p! / ((idewy - 8) - 4)
                    i = p! * (iden - 1) + 1
                    idecy = i
                End If
            End If
        End If

        If mB And idemouseselect = 3 Then
            'move hbar scroller (idecx) to appropriate position
            If mX <= 3 Then idesx = 1: idecx = idesx
            If mX >= idewx - 2 Then idesx = 608: idecx = idesx
            If mX > 3 And mX < idewx - 2 Then
                x = mX
                p! = x - 2 - 2 + .5
                p! = p! / ((idewx - 2) - 4)
                i = p! * (608 - 1) + 1
                idesx = i
                idecx = idesx
            End If
        End If

        If mB And idemouseselect <= 1 Then
            If mX > 1 + maxLineNumberLength And mX < idewx And mY > 2 And mY < idewy - 5 Then 'inside text box
                If idemouseselect = 1 Then
                    idecx = (mX - 1 + idesx - 1) - maxLineNumberLength
                    If idecx < 1 Then idecx = 1
                    idecy = mY - 2 + idesy - 1
                    If idecy > iden Then idecy = iden
                End If
            End If
        End If

        If mB Then
            If ((mX = 1 And ShowLineNumbers = 0) Or (mX <= 1 + maxLineNumberLength And ShowLineNumbers)) Or mX = idewx Or mY <= 2 Or mY >= idewy - 5 Then 'off text window area
                If idemouseselect = 1 Then

                    'scroll window
                    If mY >= idewy - 5 Then idecy = idecy + 1: If idecy > iden Then idecy = iden
                    If mY <= 2 Then idecy = idecy - 1: If idecy < 1 Then idecy = 1
                    If ((mX = 1 And ShowLineNumbers = 0) Or (mX <= 1 + maxLineNumberLength And ShowLineNumbers)) Then idecx = idecx - 1: If idecx < 1 Then idecx = 1
                    If mX = idewx Then idecx = idecx + 1
                    idewait
                End If
            End If
        End If

        If KCONTROL And UCase$(K$) = "A" Then 'select all
            idemselectall:
            ideselect = 1: ideselectx1 = 1: ideselecty1 = 1
            idecy = iden
            a$ = idegetline(idecy)
            idecx = Len(a$) + 1
            GoTo specialchar
        End If

        If KCONTROL And UCase$(K$) = "G" Then 'goto line
            If KSHIFT And idefocusline > 0 Then
                idecx = 1
                AddQuickNavHistory
                idecy = idefocusline
                ideselect = 0
            Else
                idegotobox
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
            End If
            GoTo specialchar
        End If

        If KCONTROL And UCase$(K$) = "N" Then 'File -> #New
            GoTo ctrlNew
        End If

        If KCONTROL And UCase$(K$) = "O" Then 'File -> #Open
            IdeOpenFile$ = ""
            GoTo ctrlOpen
        End If

        If (Not KSHIFT) And KCONTROL And UCase$(K$) = "R" Then 'Comment (add ') - R for REMark
            GoTo ctrlAddComment
        End If

        If (Not KSHIFT) And KCONTROL And UCase$(K$) = "T" Then 'Toggle comment
            GoTo ctrlToggleComment
        End If

        If KSHIFT And KCONTROL And UCase$(K$) = "R" Then 'uncomment (remove ')
            GoTo ctrlRemoveComment
        End If

        If KCONTROL And UCase$(K$) = "S" Then 'File -> #Save
            If ideprogname = "" Then
                ProposedTitle$ = FindProposedTitle$
                If ProposedTitle$ = "" Then
                    a$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                Else
                    a$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                End If
                If ideerror > 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo IDEerrorMessage
            Else
                idesave idepath$ + idepathsep$ + ideprogname$
            End If
            PCopy 3, 0: Screen , , 3, 0: GoTo ideloop
        End If

        If K$ = Chr$(0) + Chr$(60) Then 'F2
            If KCONTROL Then
                If QuickNavTotal > 0 Then
                    ideselect = 0
                    idecy = QuickNavHistory(QuickNavTotal).idecy
                    idecx = QuickNavHistory(QuickNavTotal).idecx
                    idesy = QuickNavHistory(QuickNavTotal).idesy
                    idesx = QuickNavHistory(QuickNavTotal).idesx
                    QuickNavTotal = QuickNavTotal - 1
                    GoTo ideloop
                End If
            Else
                GoTo idesubsjmp
            End If
        End If

        If KCONTROL And UCase$(K$) = "W" Then 'goto line
            If totalWarnings > 0 Then
                retval = idewarningbox
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo specialchar
            Else
                result = idemessagebox("Compilation status", "No warnings to display.", "")
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If
        End If

        If KCONTROL And UCase$(K$) = "Z" Then 'undo (CTRL+Z)
            idemundo:
            If ideundopos Then
                Open tmpdir$ + "undo2.bin" For Binary As #150
                h$ = Space$(12): Get #150, , h$: p1 = CVL(Mid$(h$, 1, 4)): p2 = CVL(Mid$(h$, 5, 4)): plast = CVL(Mid$(h$, 9, 4))

                'does something exist to undo?
                u = 0
                If p2 >= p1 Then
                    'linear
                    If ideundopos > p1 Then
                        Get #150, ideundopos - 4, upl
                        u = ideundopos - 4 - upl - 4
                    End If
                Else
                    'wrapped
                    If ideundopos > p1 Then
                        Get #150, ideundopos - 4, upl
                        u = ideundopos - 4 - upl - 4
                    End If
                    If ideundopos <= p2 Then
                        If ideundopos = 13 Then
                            u = plast
                        Else
                            Get #150, ideundopos - 4, upl
                            u = ideundopos - 4 - upl - 4
                        End If
                    End If
                End If

                If u Then

                    If ideundopos = ideundobase Then
                        'if not untitled, then we MUST switch to a special state
                        'warn
                        PCopy 3, 0
                        what$ = ideyesnobox("Undo", "Undo through previous program content?")
                        PCopy 3, 0: Screen , , 3, 0
                        If what$ = "N" Then
                            Close #150
                            GoTo skipundo
                        End If
                        If ideunsaved = 1 And ideprogname <> "" Then
                            PCopy 3, 0
                            r$ = idesavenow
                            PCopy 3, 0: Screen , , 3, 0
                            If r$ = "C" Then Close #150: GoTo skipundo
                            If r$ = "Y" Then
                                idesave idepath$ + idepathsep$ + ideprogname$
                            End If
                        End If
                        ideunsaved = 1
                        ideprogname$ = ""
                        _Title WindowTitle
                        ideundobase = -1 'release base restriction
                    End If

                    ideundopos = u 'set new current state

                    'get backup
                    Seek #150, u
                    Get #150, , l2& 'should be the same as l&
                    Get #150, , idesx: Get #150, , idesy
                    Get #150, , idecx: Get #150, , idecy
                    Get #150, , ideselect: Get #150, , ideselectx1: Get #150, , ideselecty1
                    Get #150, , iden
                    Get #150, , idel
                    Get #150, , ideli
                    'bookmark info [v2]
                    Get #150, , IdeBmkN: ReDim IdeBmk(IdeBmkN + 1) As IdeBmkType
                    For bi = 1 To IdeBmkN: Get #150, , IdeBmk(bi).y: Get #150, , IdeBmk(bi).x: Next
                    Get #150, , x&: idet$ = Space$(x&): Get #150, , idet$

                    idechangemade = 1: idenoundo = 1: startPausedPending = 0

                End If 'u

                skipundo:
                Close #150
            End If
            GoTo specialchar

        End If


        If KCONTROL And UCase$(K$) = "Y" Then 'redo (CTRL+Y)
            idemredo:
            If ideundopos Then
                Open tmpdir$ + "undo2.bin" For Binary As #150
                h$ = Space$(12): Get #150, , h$: p1 = CVL(Mid$(h$, 1, 4)): p2 = CVL(Mid$(h$, 5, 4)): plast = CVL(Mid$(h$, 9, 4))

                'does something exist to redo?
                u = 0
                If p2 >= p1 Then
                    'linear
                    If ideundopos < p2 Then
                        Get #150, ideundopos, upl
                        u = ideundopos + 4 + upl + 4
                    End If
                Else
                    'wrapped
                    If ideundopos >= p1 Then
                        If ideundopos = plast Then
                            u = 13
                        Else
                            Get #150, ideundopos, upl
                            u = ideundopos + 4 + upl + 4
                        End If
                    Else
                        If ideundopos < p2 Then
                            Get #150, ideundopos, upl
                            u = ideundopos + 4 + upl + 4
                        End If
                    End If
                End If

                If u Then

                    ideundopos = u 'set new current state

                    'get backup
                    Seek #150, u
                    Get #150, , l2& 'should be the same as l&
                    Get #150, , idesx: Get #150, , idesy
                    Get #150, , idecx: Get #150, , idecy
                    Get #150, , ideselect: Get #150, , ideselectx1: Get #150, , ideselecty1
                    Get #150, , iden
                    Get #150, , idel
                    Get #150, , ideli
                    'bookmark info [v2]
                    Get #150, , IdeBmkN: ReDim IdeBmk(IdeBmkN + 1) As IdeBmkType
                    For bi = 1 To IdeBmkN: Get #150, , IdeBmk(bi).y: Get #150, , IdeBmk(bi).x: Next
                    Get #150, , x&: idet$ = Space$(x&): Get #150, , idet$

                    idechangemade = 1: idenoundo = 1: startPausedPending = 0

                End If 'u

                Close #150
            End If
            GoTo specialchar
        End If


        If ((KSHIFT And KB = KEY_DELETE) Or (KCONTROL And UCase$(K$) = "X")) And ideselect = 1 Then 'cut to clipboard
            idemcut:
            idechangemade = 1
            GoTo copy2clip
        End If

        If (KB = KEY_DELETE Or KB = 8) And ideselect = 1 Then 'delete selection
            If ideselecty1 <> idecy Or ideselectx1 <> idecx Then
                idechangemade = 1
                delselect
                GoTo specialchar
            Else
                ideselect = 0
            End If
        End If


        If (KSHIFT And KB = KEY_INSERT) Or (KCONTROL And UCase$(K$) = "V") Then 'paste from clipboard
            idempaste:

            clip$ = _Clipboard$ 'read clipboard

            If Len(clip$) Then
                If InStr(clip$, Chr$(13)) Or InStr(clip$, Chr$(10)) Then

                    'full lines paste
                    If ideselect Then delselect

                    idelayoutallow = 2
                    a$ = clip$
                    x3 = 1 'scan from position
                    i = 0 'lines counter

                    fullpastenextline:

                    x = InStr(x3, a$, Chr$(13))
                    x2 = InStr(x3, a$, Chr$(10))
                    If x = 0 Then x = x2
                    If x2 = 0 Then x2 = x
                    If x2 < x Then Swap x, x2
                    If x2 > x + 1 Then x2 = x 'if seperated by more than one character, they are seperate line terminators
                    'x to x2 is the range of the next line terminator (1 or 2 characters)

                    If x Then
                        ideinsline idecy + i, converttabs$(Mid$(a$, x3, x - x3))
                        i = i + 1
                        x3 = x2 + 1
                    Else
                        ideinsline idecy + i, converttabs$(Mid$(a$, x3, Len(a$) - x3 + 1))
                        i = i + 1
                        x3 = Len(a$) + 1
                    End If

                    If x3 <= Len(a$) GoTo fullpastenextline

                    If PasteCursorAtEnd Then
                        'Place the cursor at the end of the pasted content:
                        idecy = idecy + i - 1
                        idecx = Len(idegetline(idecy)) + 1
                        If Right$(clip$, 1) = Chr$(10) Then
                            idecy = idecy + 1
                            idecx = 1
                        End If
                    End If
                Else
                    'insert single line paste
                    insertAtCursor clip$
                End If

                idechangemade = 1
            End If
            GoTo specialchar
        End If

        If ((KCTRL And KB = KEY_INSERT) Or (KCONTROL And UCase$(K$) = "C")) And ideselect = 1 Then 'copy to clipboard
            copy2clip:
            clip$ = getSelectedText$(-1)
            If clip$ <> "" Then _Clipboard$ = clip$
            If (K$ = Chr$(0) + "S") Or (KSHIFT And KB = KEY_DELETE) Or (KCONTROL And UCase$(K$) = "X") Then delselect
            GoTo specialchar
        End If

        If KB = KEY_INSERT Then 'toggle INSERT mode
            ideinsert = ideinsert + 1
            If ideinsert = 2 Then ideinsert = 0
        End If

        If KB = KEY_UP Then
            If KCONTROL Then 'scroll the window, instead of moving the cursor
                idesy = idesy - 1
                If idesy < 1 Then idesy = 1
                If idecy > idesy + (idewy - 9) Then idecy = idesy + (idewy - 9)
            Else
                GoSub selectcheck
                idecy = idecy - 1
                If idecy < 1 Then idecy = 1
                GoTo specialchar
            End If
        End If

        If KB = KEY_DOWN Then
            If KCONTROL Then 'scroll the window, instead of moving the cursor
                idesy = idesy + 1
                If idesy > iden Then idesy = iden
                If idecy < idesy Then idecy = idesy
            Else
                GoSub selectcheck
                idecy = idecy + 1
                If idecy > iden Then idecy = iden
                GoTo specialchar
            End If
        End If

        If mWHEEL Then
            GoSub selectcheck
            'move relative to top/bottom
            If mWHEEL < 0 Then idecy = idesy
            If mWHEEL > 0 Then idecy = idesy + (idewy - 9)
            idecy = idecy + mWHEEL * 3
            If idecy < 1 Then idecy = 1
            If idecy > iden Then idecy = iden
            GoTo specialchar
        End If

        If KB = KEY_LEFT Then
            GoSub selectcheck

            If KCONTROL Then 'move forward to next beginning alphanumeric

                a$ = idegetline(idecy)
                If idecx > Len(a$) Then idecx = Len(a$) + 1

                skipping = 1
                Do
                    'move
                    idecx = idecx - 1
                    'latch onto prev character
                    If idecx < 1 Then
                        Do
                            If idecy = 1 Then idecx = 1: GoTo specialchar
                            idecy = idecy - 1
                            a$ = idegetline(idecy)
                            idecx = Len(a$) + 1
                        Loop Until Len(a$)
                        GoTo specialchar 'stop at the end of the previous line
                    End If
                    'check character
                    If alphanumeric(Asc(a$, idecx)) Then
                        If idecx = 1 Then GoTo specialchar
                        x = idecx: y = idecy
                        skipping = 0
                    Else
                        If skipping = 0 Then idecx = x: idecy = y: GoTo specialchar
                    End If
                Loop

            Else

                idecx = idecx - 1
                If idecx < 1 Then idecx = 1

            End If

            GoTo specialchar
        End If

        If KB = KEY_RIGHT Then
            GoSub selectcheck

            If KCONTROL Then 'move forward to next beginning alphanumeric

                a$ = idegetline(idecy)
                skipping = 0
                first = 1
                Do
                    'move
                    If first = 0 Then idecx = idecx + 1
                    'latch onto next character
                    If first = 0 And idecx = Len(a$) + 1 Then GoTo specialchar 'stop at the end of the line
                    If idecx > Len(a$) Then
                        Do
                            If idecy = iden Then GoTo specialchar
                            idecy = idecy + 1: idecx = 1
                            a$ = idegetline(idecy)
                        Loop Until Len(a$)
                        skipping = 0
                        first = 0
                    End If
                    'check character
                    If alphanumeric(Asc(a$, idecx)) Then
                        If first Then
                            skipping = 1
                        Else
                            If skipping = 0 Then GoTo specialchar
                        End If
                    Else
                        skipping = 0
                    End If
                    first = 0
                Loop

            Else

                idecx = idecx + 1

            End If

            GoTo specialchar
        End If

        If KCONTROL And KB = KEY_HOME Then
            GoSub selectcheck
            idecx = 1
            idecy = 1
            GoTo specialchar
        End If

        If KCONTROL And KB = KEY_END Then
            GoSub selectcheck
            idecy = iden
            a$ = idegetline(idecy)
            idecx = Len(a$) + 1
            GoTo specialchar
        End If

        If KB = KEY_HOME Then
            GoSub selectcheck
            If idecx <> 1 Then
                idecx = 1
            Else
                a$ = idegetline(idecy)
                idecx = 1
                For x = 1 To Len(a$)
                    If Asc(a$, x) <> 32 Then idecx = x: Exit For
                Next
            End If
            GoTo specialchar
        End If

        If KB = KEY_END Then
            GoSub selectcheck
            a$ = idegetline(idecy)
            idecx = Len(a$) + 1
            GoTo specialchar
        End If

        If KB = KEY_PAGEUP Then
            GoSub selectcheck
            idecy = idecy - (idewy - 9)
            If idecy < 1 Then idecy = 1
            GoTo specialchar
        End If

        If KB = KEY_PAGEDOWN Then
            GoSub selectcheck
            idecy = idecy + (idewy - 9)
            If idecy > iden Then idecy = iden
            GoTo specialchar
        End If

        GoTo skipgosubs

        selectcheck:
        If IdeSystem = 1 Then
            If KSHIFT And ideselect = 0 Then ideselect = 1: ideselectx1 = idecx: ideselecty1 = idecy
            If KSHIFT = 0 Then ideselect = 0
        ElseIf IdeSystem = 2 Then
            If KSHIFT And idesystem2.issel = 0 Then idesystem2.issel = -1: idesystem2.sx1 = idesystem2.v1
            If KSHIFT = 0 Then idesystem2.issel = 0
        End If
        Return

        skipgosubs:

        If K$ = Chr$(13) Then
            If KSHIFT Then
                retval$ = ""
                a$ = idegetline(idecy)
                If EnteringRGB Then 'The "Shift+ENTER" message is being shown
                    oldkeywordHighlight = keywordHighlight
                    keywordHighlight = 0
                    HideBracketHighlight
                    keywordHighlight = oldkeywordHighlight
                    retval$ = idergbmixer$(0)
                Else
                    If ideselect Then
                        If ideselecty1 <> idecy Then GoTo specialchar 'multi line selected
                    End If

                    Found_RGB = 0
                    Found_RGB = Found_RGB + InStr(UCase$(a$), "RGB(")
                    Found_RGB = Found_RGB + InStr(UCase$(a$), "RGB32(")
                    Found_RGB = Found_RGB + InStr(UCase$(a$), "RGBA(")
                    Found_RGB = Found_RGB + InStr(UCase$(a$), "RGBA32(")
                    If Found_RGB Then
                        oldkeywordHighlight = keywordHighlight
                        keywordHighlight = 0
                        HideBracketHighlight
                        keywordHighlight = oldkeywordHighlight
                        retval$ = idergbmixer$(-1)
                    Else
                        GoTo RegularEnter
                    End If
                End If
                If Len(retval$) Then
                    'the mixer dialog could not insert the value, so let's do it here
                    If EnteringRGB Then
                        insertAtCursor Mid$(retval$, InStr(retval$, "(") + 1)
                    Else
                        insertAtCursor retval$
                    End If
                End If
                GoTo specialchar
            Else
                a$ = idegetline(idecy)
                RegularEnter:
                ideselect = 0
                desiredcolumn = 1
                idechangemade = 1
                If idecx > Len(a$) Then
                    ideinsline idecy + 1, ""
                    If Len(a$) = 0 Then
                        desiredcolumn = idecx
                    Else
                        desiredcolumn = Len(a$) - Len(LTrim$(a$)) + 1
                    End If
                Else
                    a2$ = Left$(a$, idecx - 1)
                    idesetline idecy, a2$
                    If Len(LTrim$(a2$)) > 0 Then
                        If idecx > 1 Then desiredcolumn = Len(a$) - Len(LTrim$(a$)) Else desiredcolumn = 0
                        ideinsline idecy + 1, Space$(desiredcolumn) + Right$(a$, Len(a$) - idecx + 1)
                        If desiredcolumn = 0 Then desiredcolumn = 1 Else desiredcolumn = desiredcolumn + 1
                    Else
                        desiredcolumn = idecx
                        ideinsline idecy + 1, Space$(desiredcolumn - 1) + Right$(a$, Len(a$) - idecx + 1)
                    End If
                End If

                If idecx = 1 Then
                    For b = 1 To IdeBmkN
                        If IdeBmk(b).y = idecy Then IdeBmk(b).y = IdeBmk(b).y + 1
                    Next
                End If

                idecy = idecy + 1
                idecx = desiredcolumn
                GoTo specialchar
            End If
        End If

        If KB = KEY_DELETE And KCONTROL = 0 Then
            idechangemade = 1
            a$ = idegetline(idecy)
            If idecx <= Len(a$) Then
                a$ = Left$(a$, idecx - 1) + Right$(a$, Len(a$) - idecx)
                idesetline idecy, a$
            Else
                a$ = a$ + Space$(idecx - Len(a$) - 1)
                a$ = a$ + LTrim$(idegetline(idecy + 1))
                idesetline idecy, a$
                idedelline idecy + 1
            End If
            GoTo specialchar
        End If

        If K$ = Chr$(8) Then 'Regular Backspace
            ideselect = 0
            idechangemade = 1

            'undocombos
            If ideundocombochr <> 8 Then
                ideundocombo = 2
            Else
                ideundocombo = ideundocombo + 1
                If ideundocombo = 2 Then idemergeundo = 1
            End If
            ideundocombochr = 8

            a$ = idegetline(idecy)
            If idecx = 1 Then
                RegularBackspaceIdecx1:
                If idecy > 1 Then
                    a2$ = idegetline(idecy - 1)
                    If Len(a2$) > 0 Then
                        'If the previous line has any content, let's just append this line to it
                        RegularBackupToPrevLine:
                        idesetline idecy - 1, a2$ + a$
                        idedelline idecy
                        idecx = Len(a2$) + 1
                        idecy = idecy - 1
                    Else
                        'Or else, if it's an empty line, let's try to follow the
                        'next line's indentation.
                        'First, get indentation level of next line, if any.
                        If idecy < iden Then
                            a3$ = idegetline(idecy + 1)
                            desiredcolumn = Len(a3$) - Len(LTrim$(a3$))
                            idesetline idecy - 1, Space$(desiredcolumn) + a$
                            idedelline idecy
                            idecx = desiredcolumn + 1
                            idecy = idecy - 1
                        Else
                            GoTo RegularBackupToPrevLine
                        End If
                    End If
                End If
                GoTo specialchar
            End If
            If idecx > Len(a$) + 1 Then
                idecx = Len(a$) + 1
            Else
                CheckSpacesBehind:
                If Len(RTrim$(Mid$(a$, 1, idecx - 1))) = 0 Then
                    'Only spaces behind. If we're on a tab stop, let's go back in tabs.
                    x = 4
                    If ideautoindentsize <> 0 Then x = ideautoindentsize
                    check.tabstop! = (idecx - 1) / x
                    If check.tabstop! = Fix(check.tabstop!) Then
                        If idecx - x < 1 Then x = idecx - 1
                        a$ = Left$(a$, idecx - (x + 1)) + Right$(a$, Len(a$) - idecx + 1)
                        idesetline idecy, a$
                        idecx = idecx - x
                    Else
                        GoTo onebackspace
                    End If
                Else
                    onebackspace:
                    a$ = Left$(a$, idecx - 2) + Right$(a$, Len(a$) - idecx + 1)
                    idesetline idecy, a$
                    idecx = idecx - 1
                End If
            End If
            GoTo specialchar
        End If









        'patch#1
        If Len(K$) <> 1 Then GoTo specialchar
        If K$ = Chr$(9) Then GoTo ideforceinput
        If block_chr(Asc(K$)) Then GoTo specialchar
        ideforceinput:

        If K$ = Chr$(9) Then
            If ideselect Then
                'Block indentation code copied/adapted from block comment/uncomment:
                If KSHIFT Or K$ = Chr$(25) Then
                    IdeBlockDecreaseIndent:
                    BlockIndentLevel = 4
                    If ideautoindentsize <> 0 Then BlockIndentLevel = ideautoindentsize
                    y1 = idecy
                    y2 = ideselecty1

                    If y1 = y2 Then 'single line selected
                        a$ = idegetline(idecy)
                        a2$ = ""
                        sx1 = ideselectx1: sx2 = idecx
                        If sx2 < sx1 Then Swap sx1, sx2
                        For x = sx1 To sx2 - 1
                            If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
                        Next
                        If a2$ = "" Then
                            GoTo SkipBlockIndent
                        End If
                    End If

                    If y1 > y2 Then Swap y1, y2
                    If idecy > ideselecty1 And idecx = 1 Then y2 = y2 - 1
                    'calculate lhs
                    lhs = 10000000
                    For y = y1 To y2
                        a$ = idegetline(y)
                        If Len(a$) Then
                            ta$ = LTrim$(a$)
                            t = Len(a$) - Len(ta$)
                            If t < lhs Then lhs = t
                        End If
                    Next
                    'edit lines
                    'Unless any of the block lines already starts at the beginning of the line
                    If lhs > 0 Then
                        If lhs < BlockIndentLevel Then BlockIndentLevel = lhs
                        For y = y1 To y2
                            a$ = idegetline(y)
                            If Len(a$) Then
                                a$ = Right$(a$, Len(a$) - BlockIndentLevel)
                                idesetline y, a$
                                idechangemade = 1
                            End If
                        Next
                    End If
                    If (y1 = y2) And idechangemade Then
                        ideselectx1 = ideselectx1 - BlockIndentLevel
                        idecx = idecx - BlockIndentLevel
                        If idecx < 1 Then idecx = 1: ideselectx1 = idecx
                    End If
                    PCopy 3, 0: Screen , , 3, 0
                    GoTo ideloop
                Else
                    IdeBlockIncreaseIndent:
                    BlockIndentLevel = 4
                    If ideautoindentsize <> 0 Then BlockIndentLevel = ideautoindentsize
                    y1 = idecy
                    y2 = ideselecty1

                    If y1 = y2 Then 'single line selected
                        a$ = idegetline(idecy)
                        a2$ = ""
                        sx1 = ideselectx1: sx2 = idecx
                        If sx2 < sx1 Then Swap sx1, sx2
                        For x = sx1 To sx2 - 1
                            If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
                        Next
                        If a2$ = "" Then
                            GoTo SkipBlockIndent
                        End If
                    End If

                    If y1 > y2 Then Swap y1, y2
                    If idecy > ideselecty1 And idecx = 1 Then y2 = y2 - 1
                    'calculate lhs
                    lhs = 10000000
                    For y = y1 To y2
                        a$ = idegetline(y)
                        If Len(a$) Then
                            ta$ = LTrim$(a$)
                            t = Len(a$) - Len(ta$)
                            If t < lhs Then lhs = t
                        End If
                    Next
                    'edit lines
                    For y = y1 To y2
                        a$ = idegetline(y)
                        If Len(a$) Then
                            a$ = Left$(a$, lhs) + Space$(BlockIndentLevel) + Right$(a$, Len(a$) - lhs)
                            idesetline y, a$
                            idechangemade = 1
                        End If
                    Next
                    If (y1 = y2) And idechangemade Then
                        ideselectx1 = ideselectx1 + BlockIndentLevel
                        idecx = idecx + BlockIndentLevel
                    End If
                    PCopy 3, 0: Screen , , 3, 0
                    GoTo ideloop
                End If
            Else
                SkipBlockIndent:
                If KSHIFT = 0 Then
                    x = 4
                    If ideautoindentsize <> 0 Then x = ideautoindentsize
                    K$ = Space$(x - ((idecx - 1) Mod x))
                Else
                    K$ = ""
                End If
            End If
        End If

        If K$ = Chr$(27) And Not AltSpecial Then GoTo specialchar 'Steve edit 07-04-2014 to stop ESC from printing chr$(27) in the IDE

        'alt and ctrl combos have already been processed, so skip inserting
        'K$ if these are still held down:
        If KCTRL And Not KALT Then GoTo specialchar
        If KALT And Not KCTRL And Not AltSpecial Then GoTo specialchar

        'standard character
        If ideselect Then delselect
        idechangemade = 1

        'undocombos
        If Len(K$) = 1 Then
            asck = Asc(K$)
            If alphanumeric(asck) Or ideundocombochr = asck Then
                If ideundocombochr = 8 Then ideundocombo = 0
                If ideundocombo = 0 Then
                    ideundocombo = 2
                Else
                    ideundocombo = ideundocombo + 1
                    If ideundocombo = 2 Then idemergeundo = 1
                End If
            End If
            ideundocombochr = asck
        End If

        a$ = idegetline(idecy)
        If Len(a$) < idecx - 1 Then a$ = a$ + Space$(idecx - 1 - Len(a$))

        If ideinsert Then
            a2$ = Right$(a$, Len(a$) - idecx + 1)
            If Len(a2$) Then a2$ = Right$(a$, Len(a$) - idecx)
            a$ = Left$(a$, idecx - 1) + K$ + a2$
        Else
            a$ = Left$(a$, idecx - 1) + K$ + Right$(a$, Len(a$) - idecx + 1)
        End If

        idesetline idecy, a$
        idecx = idecx + Len(K$)
        specialchar:
        'In case there is a selection, let's show the number of
        'selected characters on the status bar:
        If (IdeInfo = "" Or Left$(IdeInfo, 19) = "Selection length = ") Then
            If idecy = ideselecty1 Then 'selection is in only one line
                sx1 = ideselectx1: sx2 = idecx
                If sx1 > sx2 Then Swap sx1, sx2
                If ideselect = 1 And (sx2 - sx1) > 0 Then
                    If sx2 - sx1 > 0 Then
                        a$ = idegetline(idecy)
                        ideCurrentSingleLineSelection = Mid$(a$, sx1, sx2 - sx1)
                        For i = 1 To Len(ideCurrentSingleLineSelection)
                            If InStr(char.sep$, Mid$(ideCurrentSingleLineSelection, i, 1)) > 0 Then
                                'separators in selection don't trigger multi-highlight
                                If Mid$(ideCurrentSingleLineSelection, i, 1) <> "." Then
                                    ideCurrentSingleLineSelection = ""
                                    Exit For
                                End If
                            End If
                        Next i
                    End If
                    IdeInfo = "Selection length = " + str2$(sx2 - sx1) + " character" + Left$("s", Abs(sx2 - sx1 > 1))
                    UpdateIdeInfo
                Else
                    IdeInfo = ""
                    ideCurrentSingleLineSelection = ""
                    UpdateIdeInfo
                End If
            Else
                If ideselect Then
                    sy1 = ideselecty1
                    sy2 = idecy
                    If sy1 > sy2 Or idecx > 1 Then
                        IdeInfo = "Selection length = " + str2$(Abs(sy2 - sy1) + 1) + " line" + Left$("s", Abs((Abs(sy2 - sy1) + 1) > 1))
                    Else
                        IdeInfo = "Selection length = " + str2$(sy2 - sy1) + " line" + Left$("s", Abs(sy2 - sy1 > 1))
                    End If
                Else
                    IdeInfo = ""
                End If
                ideCurrentSingleLineSelection = ""
                UpdateIdeInfo
            End If
        End If

        If AltSpecial Then
            AltSpecial = 0
            ideentermenu = 0
            KALT = 0
            Color 0, 7: _PrintString (1, 1), menubar$
        End If
    Loop

    '--------------------------------------------------------------------------------

    startmenu:
    m = 1
    oldmx = mX: oldmy = mY
    startmenu2:
    altheld = 1
    If IdeSystem = 2 Then IdeSystem = 1: GoSub UpdateSearchBar

    Do

        Locate 1, 3
        For i = 1 To menus
            If m = i Then Color 15, 0 Else Color 15, 7
            Print " " + Left$(menu$(i, 0), 1);
            If m = i Then Color 7, 0 Else Color 0, 7
            Print Right$(menu$(i, 0), Len(menu$(i, 0)) - 1) + " ";
            If i = menus - 1 Then Locate 1, idewx - Len(menu$(menus, 0)) - 2
        Next

        PCopy 3, 0
        Do

            lastaltheld = altheld

            GetInput
            If oldmx <> mX Or oldmy <> mY Then
                If mY = 1 And idecontextualmenu <> 1 Then 'Check if we're hovering on menu bar
                    lastm = m
                    For i = 1 To menus
                        x = CVI(Mid$(MenuLocations, i * 2 - 1, 2))
                        x2 = CVI(Mid$(MenuLocations, i * 2 - 1, 2)) + Len(menu$(i, 0))
                        If mX >= x And mX < x2 Then
                            m = i
                            If m <> lastm Then Exit Do 'Update the menu bar to reflect the current mouse hover
                        End If
                    Next
                End If
                oldmx = mX: oldmy = mY
            End If
            If iCHANGED = 0 Then _Limit 100

            If KALT Then altheld = 1 Else altheld = 0

            If altheld <> 0 And lastaltheld = 0 Then
                Do
                    _Limit 100
                    GetInput

                    If _Resize Then
                        ForceResize = -1: skipdisplay = 0: GoTo ideloop
                    End If
                Loop Until KALT = 0
                KB = KEY_ESC
            End If

            If _Resize Then
                ForceResize = -1: skipdisplay = 0: GoTo ideloop
            End If

            If mCLICK Or mCLICK2 Then
                If mY = 1 Then
                    For i = 1 To menus
                        x = CVI(Mid$(MenuLocations, i * 2 - 1, 2))
                        x2 = CVI(Mid$(MenuLocations, i * 2 - 1, 2)) + Len(menu$(i, 0))
                        If mX >= x And mX < x2 Then
                            m = i
                            Color 0, 7: _PrintString (1, 1), menubar$
                            PCopy 3, 0
                            GoTo showmenu
                        End If
                    Next
                End If 'my=1
                KB = KEY_ESC 'exit menu selection
            End If

            If _Exit Then ideexit = 1: KB = KEY_ESC
        Loop Until KB

        K$ = UCase$(K$)
        If Len(K$) > 0 And KCTRL Then
            'ctrl+key combos are not valid while a menu is active
            Color 0, 7: _PrintString (1, 1), menubar$
            Screen , , 3, 0: PCopy 3, 0
            GoTo ideloop
        End If

        For i = 1 To menus
            a$ = UCase$(Left$(menu$(i, 0), 1))
            If K$ = a$ Then
                m = i
                Color 0, 7: _PrintString (1, 1), menubar$
                PCopy 3, 0
                GoTo showmenu
            End If
        Next

        If KB = KEY_LEFT Then m = m - 1
        If KB = KEY_RIGHT Then m = m + 1
        If KB = KEY_ESC Then
            Color 0, 7: _PrintString (1, 1), menubar$
            IdeInfo = ""
            GoTo ideloop
        End If
        If m < 1 Then m = menus
        If m > menus And idecontextualmenu = 0 Then m = 1
        If KB = KEY_UP Or KB = KEY_DOWN Or KB = KEY_ENTER Then
            Color 0, 7: _PrintString (1, 1), menubar$
            PCopy 3, 0
            GoTo showmenu
        End If

        'possible ALT+??? code?
        If KB > 0 And KB <= 255 Then
            If KALT = 0 Then
                iCHECKLATER = 1
                Color 0, 7: _PrintString (1, 1), menubar$
                GoTo ideloop
            End If
        End If

    Loop

    '--------------------------------------------------------------------------------

    showmenu:
    altheld = 1
    If IdeSystem = 2 Then IdeSystem = 1: GoSub UpdateSearchBar
    PCopy 0, 2
    Screen , , 1, 0
    parentMenuR = r
    r = 1
    s = 0
    parentMenu = 0
    parentMenuSetup%% = 0
    Select Case idecontextualmenu
        Case 1
            'right-click on text area
            idectxmenuX = mX
            idectxmenuY = mY
            m = idecontextualmenuID
        Case 2
            'line numbers menu item in View menu
            idectxmenuX = xx + w + 3
            idectxmenuY = yy + r
            parentMenu = m
            m = ViewMenuShowLineNumbersSubMenuID
    End Select

    IdeMakeEditMenu

    If totalWarnings = 0 Then
        menu$(ViewMenuID, ViewMenuCompilerWarnings) = "~Compiler #Warnings...  Ctrl+W"
    Else
        menu$(ViewMenuID, ViewMenuCompilerWarnings) = "Compiler #Warnings...  Ctrl+W"
    End If

    oldmy = mY: oldmx = mX
    Do
        PCopy 2, 1

        If idecontextualmenu = 0 Then
            'find pos of menu m
            x = 4: For i = 1 To m - 1: x = x + Len(menu$(i, 0)) + 2
                If i = menus - 1 Then x = idewx - Len(menu$(menus, 0)) - 1
            Next: xx = x
            Color 7, 0: _PrintString (xx - 1, 1), " " + menu$(m, 0) + " "
        Else
            If parentMenu > 0 And parentMenuSetup%% = 0 Then
                parentMenuSetup%% = -1
                backToParent.x1 = xx - 1
                backToParent.x2 = xx + w
                backToParent.y1 = 3
                backToParent.y2 = backToParent.y1 + menusize(parentMenu)
            End If
        End If
        'calculate menu width
        w = 0
        For i = 1 To menusize(m)
            m$ = menu$(m, i)
            l = Len(m$)
            If InStr(m$, "#") Then l = l - 1
            If Left$(m$, 1) = "~" Then l = l - 1
            If Left$(m$, 1) = Chr$(7) Then l = l - 1
            If InStr(m$, "  ") Then l = l + 2 'min 4 spacing
            If l > w Then w = l
        Next
        yy = 2
        If idecontextualmenu > 0 Then
            actual.idewy = idewy
            If idesubwindow <> 0 Then
                actual.idewy = idewy + idesubwindow
            End If
            xx = idectxmenuX
            If xx < 3 Then xx = 3
            yy = idectxmenuY
            If yy + menusize(m) + 2 > actual.idewy Then yy = actual.idewy - 2 - menusize(m)
        End If
        If xx > idewx - w - 3 Then xx = idewx - w - 3

        '        UpdateMenuHelpLine menuDesc$(m, r)

        Color 0, 7
        ideboxshadow xx - 2, yy, w + 4, menusize(m) + 2

        'draw menu items
        For i = 1 To menusize(m)
            m$ = menu$(m, i)
            If m$ = "-" Then
                Color 0, 7: _PrintString (xx - 2, i + yy), Chr$(195) + String$(w + 2, Chr$(196)) + Chr$(180)
            ElseIf Left$(m$, 1) = "~" Then
                m$ = Right$(m$, Len(m$) - 1) 'Remove the tilde before printing
                If r = i Then Color 7, 0: _PrintString (xx - 1, i + yy), Space$(w + 2)
                If Left$(m$, 1) = Chr$(7) Then Locate i + yy, xx - 1 Else Locate i + yy, xx
                h = -1: x = InStr(m$, "#"): If x Then h = x: m$ = Left$(m$, x - 1) + Right$(m$, Len(m$) - x)
                x = InStr(m$, "  "): If x Then m1$ = Left$(m$, x - 1): m2$ = Right$(m$, Len(m$) - x - 1): m$ = m1$ + Space$(w - Len(m1$) - Len(m2$)) + m2$
                For x = 1 To Len(m$)
                    If r = i Then Color 2, 0 Else Color 2, 7
                    Print Mid$(m$, x, 1);
                Next
            Else
                If r = i Then Color 7, 0: _PrintString (xx - 1, i + yy), Space$(w + 2)
                If Left$(m$, 1) = Chr$(7) Then Locate i + yy, xx - 1 Else Locate i + yy, xx
                h = -1: x = InStr(m$, "#"): If x Then h = x: m$ = Left$(m$, x - 1) + Right$(m$, Len(m$) - x)
                x = InStr(m$, "  "): If x Then m1$ = Left$(m$, x - 1): m2$ = Right$(m$, Len(m$) - x - 1): m$ = m1$ + Space$(w - Len(m1$) - Len(m2$)) + m2$
                For x = 1 To Len(m$)
                    If x = h Then
                        If r = i Then Color 15, 0 Else Color 15, 7
                    Else
                        If r = i Then Color 7, 0 Else Color 0, 7
                    End If
                    Print Mid$(m$, x, 1);
                Next
            End If
        Next

        PCopy 1, 0

        If s Then GoTo menuChoiceMade

        updateMenuPanel%% = 0
        change = 0
        Do
            mousedown = 0: mouseup = 0
            GetInput
            lastaltheld = altheld: If KALT Then altheld = 1 Else altheld = 0
            If iCHANGED Then
                If KB Then change = 1
                If mCLICK Then change = 1: mousedown = 1
                If mCLICK2 Then change = 1
                If mRELEASE Then change = 1: mouseup = 1
                If mWHEEL Then change = 1
                If mX Then change = 1
                If mY Then change = 1
            End If
            If mB Then change = 1
            'revert to previous menuwhen alt pressed again
            If altheld <> 0 And lastaltheld = 0 Then
                Do
                    _Limit 100
                    GetInput

                    If (_Resize <> 0) Then
                        ForceResize = -1: skipdisplay = 0: GoTo ideloop
                    End If
                Loop Until KALT = 0 'wait till alt is released
                PCopy 3, 0: Screen , , 3, 0
                GoTo startmenu2
            End If
            If _Exit Then
                ideexit = 1: GoTo ideloop
            End If
            If (_Resize <> 0) Then
                ForceResize = -1: skipdisplay = 0: GoTo ideloop
            End If
            _Limit 100
        Loop Until change

        s = 0

        If mWHEEL Then
            PCopy 3, 0: Screen , , 3, 0
            GoTo ideloop
        End If

        If mCLICK2 And idecontextualmenu = 1 Then 'A new right click in the text area repositions the contextual menu
            IF (mX > 1 AND mX < idewx AND mY > 2 AND mY < (idewy - 5)) OR _
                (mY >= idewy AND mY < idewy + idesubwindow) THEN
                PCopy 3, 0: Screen , , 3, 0
                GoTo invokecontextualmenu
            Else
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If
        End If

        'mouse selection
        If mouseup Then
            If mX >= xx - 2 And mX < xx - 2 + w + 4 Then
                If mY > yy And mY <= menusize(m) + yy Then
                    y = mY - yy
                    If menu$(m, y) <> "-" And Left$(menu$(m, y), 1) <> "~" Then
                        s = r
                    End If
                End If
            End If

            IF parentMenu > 0 AND _
               mX >= backToParent.x1 AND mX =< backToParent.x2 AND _
               mY >= backToParent.y1 AND mY =< backToParent.y2 THEN
                m = parentMenu
                r = parentMenuR
                parentMenu = 0
                parentMenuR = 0
                idecontextualmenu = 0
                PCopy 3, 2
                _Continue
            End If

            If mX < xx - 2 Or mX >= xx - 2 + w + 4 Or mY > yy + menusize(m) + 1 Or (mY < yy And idecontextualmenu = 1) Then
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If
        End If

        If Not mouseup And Not mousedown Then 'Check if we're hovering on menu options
            IF parentMenu > 0 AND oldmy <> mY AND oldmx <> mX AND _
               mX >= backToParent.x1 AND mX =< backToParent.x2 AND _
               mY >= backToParent.y1 AND mY =< backToParent.y2 THEN
                m = parentMenu
                r = parentMenuR
                parentMenu = 0
                parentMenuR = 0
                idecontextualmenu = 0
                PCopy 3, 2
                _Continue
            End If
            If oldmy <> mY Then
                If mX >= xx - 2 And mX < xx - 2 + w + 4 Then
                    If mY > yy And mY <= menusize(m) + yy Then
                        y = mY - yy
                        If menu$(m, y) <> "-" Then
                            r = y
                        End If
                    End If
                Else
                    If mY = 1 Then GoTo checkmenubarhover
                End If
                oldmy = mY
            End If
            If oldmx <> mX Then
                checkmenubarhover:
                If mY = 1 And idecontextualmenu <> 1 Then 'Check if we're hovering on menu bar
                    lastm = m
                    For i = 1 To menus
                        x = CVI(Mid$(MenuLocations, i * 2 - 1, 2))
                        x2 = CVI(Mid$(MenuLocations, i * 2 - 1, 2)) + Len(menu$(i, 0))
                        If mX >= x And mX < x2 Then
                            m = i
                            r = 1
                            parentMenuR = 0
                            parentMenu = 0
                            If idecontextualmenu > 1 Then idecontextualmenu = 0: PCopy 3, 2
                            Exit For
                        End If
                    Next
                End If
                oldmx = mX
            End If
        End If

        If mB Then

            'top row
            If mY = 1 Then
                lastm = m
                x = 3
                For i = 1 To menus
                    x2 = Len(menu$(i, 0)) + 2
                    If mX >= x And mX < x + x2 Then
                        m = i
                        r = 1
                        If lastm = m And mousedown = 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo ideloop
                        idecontextualmenu = 0
                        Exit For
                    End If
                    x = x + x2
                    If i = menus - 1 Then x = idewx - Len(menu$(menus, 0)) - 2
                Next
            End If

            'uses pre-calc xx & w
            If mX >= xx - 2 And mX < xx - 2 + w + 4 Then
                If mY > yy And mY <= menusize(m) + yy Then
                    y = mY - yy
                    If menu$(m, y) <> "-" Then r = y
                End If
            End If

        End If 'mb

        If KB = KEY_LEFT And idecontextualmenu = 0 Then
            m = m - 1: r = 1
        ElseIf KB = KEY_LEFT And idecontextualmenu > 1 Then
            idecontextualmenu = 0
            PCopy 3, 2
            m = parentMenu
            r = parentMenuR
            parentMenu = 0
        End If
        If KB = KEY_RIGHT And idecontextualmenu = 0 Then
            If Right$(menu$(m, r), 1) = Chr$(16) Then
                Select Case Left$(menu$(m, r), Len(menu$(m, r)) - 3)
                    Case "#Line Numbers"
                        idecontextualmenu = 2
                        GoTo showmenu
                End Select
            Else
                m = m + 1: r = 1
            End If
        ElseIf KB = KEY_RIGHT And idecontextualmenu > 1 Then
            idecontextualmenu = 0
            PCopy 3, 2
            m = parentMenu + 1
            r = 1
        End If
        If m < 1 Then m = menus
        If m > menus And idecontextualmenu = 0 Then m = 1
        If KB = KEY_ESC Then
            PCopy 3, 0: Screen , , 3, 0
            GoTo ideloop
        End If
        If KB = KEY_DOWN Then
            r = r + 1
            If menu$(m, r) = "-" Then r = r + 1
            If r > menusize(m) Then r = 1
        End If

        If KB = KEY_UP Then
            r = r - 1
            If menu$(m, r) = "-" Then r = r - 1
            If r < 1 Then r = menusize(m)
        End If

        'select?

        'with enter
        If KB = KEY_ENTER Then
            If Left$(menu$(m, r), 1) <> "~" Then s = r
        End If

        'with hotkey
        K$ = UCase$(K$)
        If Len(K$) > 0 And Not KCTRL Then
            For r2 = 1 To menusize(m)
                x = InStr(menu$(m, r2), "#")
                If x Then
                    a$ = UCase$(Mid$(menu$(m, r2), x + 1, 1))
                    If K$ = a$ And Left$(menu$(m, r2), 1) <> "~" Then
                        s = r2
                        updateMenuPanel%% = -1
                        Exit For
                    ElseIf K$ = a$ And Left$(menu$(m, r2), 1) = "~" Then
                        updateMenuPanel%% = -1
                        Exit For
                    End If
                End If
            Next
            If updateMenuPanel%% Then r = r2: _Continue
        End If

        If s Then
            menuChoiceMade:
            If KALT Then idehl = 1 Else idehl = 0 'set idehl, a shared variable used by various dialogue boxes

            If menu$(m, s) = "Add Co#mment (')  Ctrl+R" Then
                ctrlAddComment:
                y1 = idecy: y2 = y1
                If ideselect = 1 Then
                    y1 = ideselecty1
                    If idecy > ideselecty1 And idecx = 1 Then y2 = y2 - 1
                    If y1 > y2 Then Swap y1, y2
                End If
                'calculate lhs
                lhs = 10000000
                For y = y1 To y2
                    a$ = idegetline(y)
                    If Len(a$) Then
                        ta$ = LTrim$(a$)
                        t = Len(a$) - Len(ta$)
                        If t < lhs Then lhs = t
                    End If
                Next
                'edit lines
                For y = y1 To y2
                    a$ = idegetline(y)
                    If Len(a$) Then
                        a$ = Left$(a$, lhs) + "'" + Right$(a$, Len(a$) - lhs)
                        idesetline y, a$
                        idechangemade = 1
                    End If
                Next
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "Remove Comme#nt (')  Ctrl+Shift+R" Then
                ctrlRemoveComment:
                PCopy 3, 0: Screen , , 3, 0
                y1 = idecy: y2 = y1
                If ideselect = 1 Then
                    y1 = ideselecty1
                    If idecy > ideselecty1 And idecx = 1 Then y2 = y2 - 1
                    If y1 > y2 Then Swap y1, y2
                End If
                'edit lines
                For y = y1 To y2
                    a$ = idegetline(y)
                    If Len(a$) Then
                        a2$ = LTrim$(a$)
                        If Len(a2$) Then
                            If Asc(a2$, 1) = 39 Then
                                a$ = Space$(Len(a$) - Len(a2$)) + Right$(a2$, Len(a2$) - 1)
                                idesetline y, a$
                                idechangemade = 1
                            End If
                        End If
                    End If
                Next
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "To#ggle Comment  Ctrl+T" Then
                ctrlToggleComment:
                PCopy 3, 0: Screen , , 3, 0
                y1 = idecy: y2 = y1
                If ideselect = 1 Then
                    y1 = ideselecty1
                    If idecy > ideselecty1 And idecx = 1 Then y2 = y2 - 1
                    If y1 > y2 Then Swap y1, y2
                End If
                'calculate lhs
                lhs = 10000000
                For y = y1 To y2
                    a$ = idegetline(y)
                    If Len(a$) Then
                        ta$ = LTrim$(a$)
                        t = Len(a$) - Len(ta$)
                        If t < lhs Then lhs = t
                    End If
                Next
                'edit lines
                For y = y1 To y2
                    a$ = idegetline(y)
                    If Len(a$) Then
                        a2$ = LTrim$(a$)
                        If Len(a2$) Then
                            If Asc(a2$, 1) = 39 Then
                                a$ = Space$(Len(a$) - Len(a2$)) + Right$(a2$, Len(a2$) - 1)
                                idesetline y, a$
                                idechangemade = 1
                            Else
                                a$ = Left$(a$, lhs) + "'" + Right$(a$, Len(a$) - lhs)
                                idesetline y, a$
                                idechangemade = 1
                            End If
                        End If
                    End If
                Next
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Increase Indent  TAB" Then
                If ideselect Then GoTo IdeBlockIncreaseIndent
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 16) = "#Decrease Indent" Then
                If ideselect Then GoTo IdeBlockDecreaseIndent
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Display..." Then
                PCopy 2, 0
                retval = idedisplaybox
                If retval = 1 Then
                    'screen dimensions have changed and everything must be redrawn/reapplied
                    Width idewx, idewy + idesubwindow
                    If idecustomfont Then
                        _Font idecustomfonthandle
                    Else
                        If IDE_UseFont8 Then _Font 8 Else _Font 16
                    End If
                    skipdisplay = 0
                    GoSub redrawItAll
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "IDE C#olors..." Then
                PCopy 2, 0
                HideBracketHighlight
                retval = idechoosecolorsbox 'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Advanced (C++)..." Then
                PCopy 2, 0
                retval = ideadvancedbox
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "Purge C++ #Libraries" Then
                PCopy 2, 0
                purgeprecompiledcontent
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If


            If Right$(menu$(m, s), 19) = "#Swap Mouse Buttons" Then
                PCopy 2, 0
                MouseButtonSwapped = Not MouseButtonSwapped
                If MouseButtonSwapped Then
                    WriteConfigSetting mouseSettingsSection$, "SwapMouseButton", "True"
                    menu$(OptionsMenuID, OptionsMenuSwapMouse) = Chr$(7) + "#Swap Mouse Buttons"
                Else
                    WriteConfigSetting mouseSettingsSection$, "SwapMouseButton", "False"
                    menu$(OptionsMenuID, OptionsMenuSwapMouse) = "#Swap Mouse Buttons"
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 19) = "Syntax #Highlighter" Then
                PCopy 2, 0
                DisableSyntaxHighlighter = Not DisableSyntaxHighlighter
                If DisableSyntaxHighlighter Then
                    WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "True"
                    menu$(OptionsMenuID, OptionsMenuDisableSyntax) = "Syntax #Highlighter"
                Else
                    WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "False"
                    menu$(OptionsMenuID, OptionsMenuDisableSyntax) = Chr$(7) + "Syntax #Highlighter"
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 19) = "Cursor After #Paste" Then
                PCopy 2, 0
                PasteCursorAtEnd = Not PasteCursorAtEnd
                If PasteCursorAtEnd Then
                    WriteConfigSetting generalSettingsSection$, "PasteCursorAtEnd", "True"
                    menu$(OptionsMenuID, OptionsMenuPasteCursor) = Chr$(7) + "Cursor After #Paste"
                Else
                    WriteConfigSetting generalSettingsSection$, "PasteCursorAtEnd", "False"
                    menu$(OptionsMenuID, OptionsMenuPasteCursor) = "Cursor After #Paste"
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 15) = "Syntax Ch#ecker" Then
                PCopy 2, 0
                IDEShowErrorsImmediately = Not IDEShowErrorsImmediately
                If IDEShowErrorsImmediately Then
                    WriteConfigSetting generalSettingsSection$, "ShowErrorsImmediately", "True"
                    menu$(OptionsMenuID, OptionsMenuShowErrorsImmediately) = Chr$(7) + "Syntax Ch#ecker"
                Else
                    WriteConfigSetting generalSettingsSection$, "ShowErrorsImmediately", "False"
                    menu$(OptionsMenuID, OptionsMenuShowErrorsImmediately) = "Syntax Ch#ecker"
                End If
                idechangemade = 1
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 16) = "Ignore #Warnings" Then
                PCopy 2, 0
                If IgnoreWarnings = 0 Then
                    IgnoreWarnings = -1
                    WriteConfigSetting generalSettingsSection$, "IgnoreWarnings", "True"
                    menu$(OptionsMenuID, OptionsMenuIgnoreWarnings) = Chr$(7) + "Ignore #Warnings"
                Else
                    IgnoreWarnings = 0
                    WriteConfigSetting generalSettingsSection$, "IgnoreWarnings", "False"
                    menu$(OptionsMenuID, OptionsMenuIgnoreWarnings) = "Ignore #Warnings"
                End If
                idechangemade = 1
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 28) = "Output EXE to Source #Folder" Then
                PCopy 2, 0
                SaveExeWithSource = Not SaveExeWithSource
                If SaveExeWithSource Then
                    WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "True"
                    menu$(RunMenuID, RunMenuSaveExeWithSource) = Chr$(7) + "Output EXE to Source #Folder"
                Else
                    WriteConfigSetting generalSettingsSection$, "SaveExeWithSource", "False"
                    menu$(RunMenuID, RunMenuSaveExeWithSource) = "Output EXE to Source #Folder"
                End If
                PCopy 3, 0: Screen , , 3, 0
                idecompiled = 0
                GoTo ideloop
            End If

            If Mid$(menu$(m, s), 1, 17) = "#Quick Navigation" Or Mid$(menu$(m, s), 2, 17) = "#Quick Navigation" Then
                PCopy 2, 0
                EnableQuickNav = Not EnableQuickNav
                If EnableQuickNav Then
                    WriteConfigSetting generalSettingsSection$, "EnableQuickNav", "True"
                    menu$(SearchMenuID, SearchMenuEnableQuickNav) = Chr$(7) + "#Quick Navigation"
                Else
                    WriteConfigSetting generalSettingsSection$, "EnableQuickNav", "False"
                    menu$(SearchMenuID, SearchMenuEnableQuickNav) = "#Quick Navigation"
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Code Layout..." Then
                PCopy 2, 0
                retval = idelayoutbox
                If retval Then idechangemade = 1: idelayoutallow = 2 'recompile if options changed
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Go To Line...  Ctrl+G" Then
                PCopy 2, 0
                idegotobox
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Backup/Undo..." Then
                PCopy 2, 0
                retval = idebackupbox
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#About..." Then
                helpabout:
                PCopy 2, 0
                m$ = "QB64 Version " + Version$ + Chr$(10) + DevChannel$
                If Len(AutoBuildMsg$) Then m$ = m$ + Chr$(10) + AutoBuildMsg$
                result = idemessagebox("About", m$, "")
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 10) = "#Go To SUB" Or Left$(menu$(m, s), 15) = "#Go To FUNCTION" Then 'Contextual menu Goto
                PCopy 3, 0: Screen , , 3, 0
                AddQuickNavHistory
                idecy = CVL(Mid$(SubFuncLIST(1), 1, 4))
                idesy = idecy
                idecx = 1
                idesx = 1
                ideselect = 0
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 12) = "Go To #Label" Then 'Contextual menu Goto label
                PCopy 3, 0: Screen , , 3, 0
                AddQuickNavHistory
                idecy = CVL(Mid$(SubFuncLIST(UBound(SubFuncLIST)), 1, 4))
                idesy = idecy
                idecx = 1
                idesx = 1
                ideselect = 0
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 8) = "New #SUB" Then
                PCopy 2, 0
                idenewsf "SUB"
                ideselect = 0
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If
            If Left$(menu$(m, s), 13) = "New #FUNCTION" Then
                PCopy 2, 0
                idenewsf "FUNCTION"
                ideselect = 0
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#SUBs...  F2" Or menu$(m, s) = "SUBs...  F2" Then
                PCopy 2, 0
                idesubsjmp:
                r$ = idesubs
                If r$ <> "C" Then ideselect = 0
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Line Numbers  " + Chr$(16) Then
                idecontextualmenu = 2
                GoTo showmenu
            End If

            If menu$(m, s) = "#Show Line Numbers" Then
                PCopy 2, 0
                ShowLineNumbers = -1
                WriteConfigSetting generalSettingsSection$, "ShowLineNumbers", "True"
                menu$(m, s) = "#Hide Line Numbers"
                menu$(m, ViewMenuShowBGID) = Mid$(menu$(m, ViewMenuShowBGID), 2)
                menu$(m, ViewMenuShowSeparatorID) = Mid$(menu$(m, ViewMenuShowSeparatorID), 2)
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Hide Line Numbers" Then
                PCopy 2, 0
                ShowLineNumbers = 0
                WriteConfigSetting generalSettingsSection$, "ShowLineNumbers", "False"
                menu$(m, s) = "#Show Line Numbers"
                menu$(m, ViewMenuShowBGID) = "~" + menu$(m, ViewMenuShowBGID)
                menu$(m, ViewMenuShowSeparatorID) = "~" + menu$(m, ViewMenuShowSeparatorID)
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If Right$(menu$(m, s), 17) = "#Background Color" Then
                If Left$(menu$(m, s), 1) <> "~" Then
                    PCopy 2, 0
                    ShowLineNumbersUseBG = Not ShowLineNumbersUseBG
                    If ShowLineNumbersUseBG Then
                        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersUseBG", "True"
                        menu$(m, s) = Chr$(7) + "#Background Color"
                    Else
                        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersUseBG", "False"
                        menu$(m, s) = "#Background Color"
                    End If
                    PCopy 3, 0: Screen , , 3, 0
                    GoTo ideloop
                End If
            End If

            If Right$(menu$(m, s), 15) = "Sho#w Separator" Then
                If Left$(menu$(m, s), 1) <> "~" Then
                    PCopy 2, 0
                    ShowLineNumbersSeparator = Not ShowLineNumbersSeparator
                    If ShowLineNumbersSeparator Then
                        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersSeparator", "True"
                        menu$(m, s) = Chr$(7) + "Sho#w Separator"
                    Else
                        WriteConfigSetting generalSettingsSection$, "ShowLineNumbersSeparator", "False"
                        menu$(m, s) = "Sho#w Separator"
                    End If
                    PCopy 3, 0: Screen , , 3, 0
                    GoTo ideloop
                End If
            End If

            If menu$(m, s) = "Compiler #Warnings...  Ctrl+W" Then
                PCopy 2, 0
                retval = idewarningbox
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Find...  Ctrl+F3" Then
                PCopy 2, 0
                idefindjmp:
                r$ = idefind
                PCopy 3, 0: Screen , , 3, 0
                '...
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 6) = "Find '" Then 'Contextual menu Find
                idefindtext = idecontextualSearch$
                IdeAddSearched idefindtext
                PCopy 3, 0: Screen , , 3, 0
                GoTo idemf3
            End If

            If menu$(m, s) = "#Change...  Alt+F3" Then
                PCopy 2, 0
                idefindchangejmp:
                r$ = idechange
                PCopy 3, 0: Screen , , 3, 0
                idealthighlight = 0
                Locate , , 0: Color 0, 7: _PrintString (1, 1), menubar$
                If r$ = "C" Or r$ = "" Then GoTo ideloop
                'assume "V", verify changes
                IdeAddSearched idefindtext

                oldcx = idecx: oldcy = idecy
                found = 0: looped = 0
                changed = 0

                s$ = idefindtext$
                If idefindcasesens = 0 Then s$ = UCase$(s$)
                start = idecy: y = start
                startx = idecx: x1 = startx
                first = 1
                idefindnext2:

                l$ = idegetline(y)
                If idefindcasesens = 0 Then l$ = UCase$(l$)

                If first = 1 Then
                    first = 0
                Else
                    x1 = 1
                    If idefindbackwards Then
                        x1 = Len(l$) - Len(s$) + 1
                    End If
                End If
                If x1 < 0 Then x1 = 0

                idefindagain2:

                If idefindbackwards Then
                    x = 0
                    For xx = x1 To 1 Step -1
                        If Asc(l$, xx) = Asc(s$) Then 'first char
                            xxo = xx - 1
                            For xx2 = xx To xx + Len(s$) - 1
                                If Asc(l$, xx2) <> Asc(s$, xx2 - xxo) Then Exit For
                            Next
                            If xx2 = xx + Len(s$) Then
                                'matched!
                                x = xx
                                Exit For
                            End If
                        End If 'first char
                    Next
                    If y = start And looped = 1 And x <= startx Then x = 0
                Else
                    x = InStr(x1, l$, s$)
                    If y = start And looped = 1 And x >= startx Then x = 0
                End If

                If x Then
                    If idefindwholeword Then
                        whole = 1
                        If x > 1 Then
                            c = Asc(UCase$(Mid$(l$, x - 1, 1)))
                            If c >= 65 And c <= 90 Then whole = 0
                            If c >= 48 And c <= 57 Then whole = 0
                        End If
                        If x + Len(s$) <= Len(l$) Then
                            c = Asc(UCase$(Mid$(l$, x + Len(s$), 1)))
                            If c >= 65 And c <= 90 Then whole = 0
                            If c >= 48 And c <= 57 Then whole = 0
                        End If
                        If whole = 0 Then
                            x1 = x + 1: If idefindbackwards Then x1 = x - 1
                            x = 0
                            If x1 > 0 And x1 <= Len(l$) Then GoTo idefindagain2
                        End If
                    End If
                End If

                Dim comment As _Byte, quote As _Byte
                If x Then
                    FindQuoteComment l$, x, comment, quote
                    If idefindnocomments <> 0 And comment Then x = 0
                    If idefindnostrings <> 0 And quote Then x = 0
                    If idefindonlycomments <> 0 And comment = 0 Then x = 0
                    If idefindonlystrings <> 0 And quote = 0 Then x = 0
                End If

                If x Then
                    ideselect = 1
                    idecx = x: idecy = y
                    idecentercurrentline
                    ideselectx1 = x + Len(s$): ideselecty1 = y

                    found = 1
                    ideshowtext
                    Screen , , 0, 0: Locate , , 1: Screen , , 3, 0
                    PCopy 3, 0
                    r$ = idechangeit
                    idedeltxt
                    PCopy 3, 0: Screen , , 3, 0
                    ideselect = 0
                    If r$ = "C" Then
                        idecx = oldcx: idecy = oldcy
                        If changed Then
                            ideshowtext
                            Screen , , 0, 0: Locate , , 1: Screen , , 3, 0
                            PCopy 3, 0
                            idechanged changed
                        End If
                        GoTo ideloop
                    End If
                    If r$ = "Y" Then
                        l$ = idegetline(idecy)
                        idechangemade = 1
                        If Len(l$) >= ideselectx1 Then
                            l$ = Left$(l$, idecx - 1) + idechangeto$ + Right$(l$, Len(l$) - ideselectx1 + 1)
                        Else
                            l$ = Left$(l$, idecx - 1) + idechangeto$
                        End If
                        idesetline idecy, l$
                        changed = changed + 1
                        If idefindcasesens = 0 Then l$ = UCase$(l$)

                        If idefindbackwards Then
                            If x <= startx And y = start Then startx = startx - Len(s$) + Len(idechangeto$) 'move startx according to the difference
                        Else
                            If x <= startx And y = start And looped = 1 Then startx = startx - Len(s$) + Len(idechangeto$) 'move startx according to the difference
                            x = x + Len(idechangeto$) - 1 'skip changed portion
                        End If
                    Else
                        '"N"
                        '(no action)
                    End If
                    If idefindbackwards Then x1 = x - 1 Else x1 = x + 1
                    GoTo idefindagain2
                End If

                If idefindbackwards Then
                    y = y - 1
                    If y = start - 1 And looped = 1 Then
                        GoTo finishedchange
                    End If
                    If y < 1 Then y = iden: looped = 1
                    GoTo idefindnext2
                Else
                    y = y + 1
                    If y = start + 1 And looped = 1 Then
                        GoTo finishedchange
                    End If
                    If y > iden Then y = 1: looped = 1
                    GoTo idefindnext2
                End If

                '-------------------------------------------------

                finishedchange:
                idecx = oldcx: idecy = oldcy
                If changed Then
                    ideshowtext
                    Screen , , 0, 0: Locate , , 1: Screen , , 3, 0
                    PCopy 3, 0
                    idechanged changed
                ElseIf found Then
                    ideshowtext
                    Screen , , 0, 0: Locate , , 1: Screen , , 3, 0
                    PCopy 3, 0
                    result = idemessagebox("Search complete", "No changes made.", "")
                Else
                    idenomatch -1
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If '#Change...

            If menu$(m, s) = "Clear Search #History..." Then
                PCopy 2, 0
                r$ = ideclearhistory$("SEARCH")
                If r$ = "Y" Then
                    fh = FreeFile
                    Open ".\internal\temp\searched.bin" For Output As #fh: Close #fh
                    idefindtext = ""
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Repeat Last Find  (Shift+) F3" Then
                PCopy 3, 0: Screen , , 3, 0
                GoTo idemf3
            End If

            If menu$(m, s) = "Cl#ear  Del" Then
                PCopy 3, 0: Screen , , 3, 0
                If IdeSystem = 1 And ideselect = 1 Then
                    idechangemade = 1
                    delselect
                ElseIf IdeSystem = 2 Then
                    GoTo deleteSelectionSearchField
                End If
                GoTo ideloop
            End If

            If menu$(m, s) = "#Paste  Shift+Ins or Ctrl+V" Then
                PCopy 3, 0: Screen , , 3, 0
                If IdeSystem = 1 Then GoTo idempaste
                If IdeSystem = 2 Then GoTo pasteIntoSearchField
            End If

            If menu$(m, s) = "#Copy  Ctrl+Ins or Ctrl+C" Then
                PCopy 3, 0: Screen , , 3, 0
                If IdeSystem = 1 And ideselect = 1 Then GoTo copy2clip
                If IdeSystem = 2 Then GoTo copysearchterm2clip
                GoTo ideloop
            End If

            If menu$(m, s) = "Cu#t  Shift+Del or Ctrl+X" Then
                PCopy 3, 0: Screen , , 3, 0
                If IdeSystem = 1 And ideselect = 1 Then
                    K$ = Chr$(0) + "S" 'tricks handler into del after copy
                    GoTo idemcut
                ElseIf IdeSystem = 2 Then
                    GoTo cutToClipboardSearchField
                End If
                GoTo ideloop
            End If

            If menu$(m, s) = "#Undo  Ctrl+Z" Then
                PCopy 3, 0: Screen , , 3, 0
                GoTo idemundo
            End If

            If menu$(m, s) = "#Redo  Ctrl+Y" Then
                PCopy 3, 0: Screen , , 3, 0
                GoTo idemredo
            End If

            If menu$(m, s) = "Select #All  Ctrl+A" Then
                PCopy 3, 0: Screen , , 3, 0
                If IdeSystem = 1 Then GoTo idemselectall
                If IdeSystem = 2 Then GoTo selectAllInSearchField
            End If

            If menu$(m, s) = "#Start  F5" Then
                PCopy 3, 0: Screen , , 3, 0
                startPaused = 0
                GoTo idemrun
            End If

            If menu$(m, s) = "Modify #COMMAND$..." Then
                PCopy 2, 0
                ModifyCOMMAND$ = " " + ideinputbox$("Modify COMMAND$", "#Enter text for COMMAND$", _Trim$(ModifyCOMMAND$), "", 60, 0, 0)
                If _Trim$(ModifyCOMMAND$) = "" Then ModifyCOMMAND$ = ""
                'retval is ignored
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "Make E#XE Only  F11" Or menu$(m, s) = "Make E#xecutable Only  F11" Then
                PCopy 3, 0: Screen , , 3, 0
                GoTo idemexe
            End If

            If menu$(m, s) = "E#xit" Then
                PCopy 2, 0
                quickexit:
                If ideunsaved = 1 Then
                    r$ = idesavenow
                    PCopy 3, 0: Screen , , 3, 0
                    If r$ = "C" Then GoTo ideloop
                    If r$ = "Y" Then
                        If ideprogname = "" Then
                            ProposedTitle$ = FindProposedTitle$
                            If ProposedTitle$ = "" Then
                                r$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                            Else
                                r$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                            End If
                            PCopy 3, 0: Screen , , 3, 0
                            If ideerror > 1 Then GoTo IDEerrorMessage
                            If r$ = "C" Then GoTo ideloop
                        Else
                            idesave idepath$ + idepathsep$ + ideprogname$
                        End If
                    End If

                End If
                fh = FreeFile: Open tmpdir$ + "autosave.bin" For Output As #fh: Close #fh
                System
            End If

            If menu$(m, s) = "#New  Ctrl+N" Then
                PCopy 2, 0
                ctrlNew:
                If ideunsaved = 1 Then
                    r$ = idesavenow
                    PCopy 3, 0: Screen , , 3, 0
                    If r$ = "C" Then GoTo ideloop
                    If r$ = "Y" Then
                        If ideprogname = "" Then
                            ProposedTitle$ = FindProposedTitle$
                            If ProposedTitle$ = "" Then
                                r$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                            Else
                                r$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                            End If
                            PCopy 3, 0: Screen , , 3, 0
                            If ideerror > 1 Then GoTo IDEerrorMessage
                            If r$ = "C" Then GoTo ideloop
                        Else
                            idesave idepath$ + idepathsep$ + ideprogname$
                        End If
                    End If
                End If
                ideunsaved = -1
                'new blank text field
                ReDim IdeBreakpoints(1) As _Byte
                ReDim IdeSkipLines(1) As _Byte
                backupTypeDefinitions$ = ""
                idet$ = MKL$(0) + MKL$(0): idel = 1: ideli = 1: iden = 1: IdeBmkN = 0
                idesx = 1
                idesy = 1
                idecx = 1
                idecy = 1
                ideselect = 0
                ideprogname$ = ""
                listOfCustomKeywords$ = Left$(listOfCustomKeywords$, customKeywordsLength)
                QuickNavTotal = 0
                ModifyCOMMAND$ = ""
                _Title WindowTitle
                idechangemade = 1
                idefocusline = 0
                ideundobase = 0 'reset
                GoTo ideloop
            End If

            AttemptToLoadRecent = 0
            For ml = 1 To UBound(IdeRecentLink, 1)
                If Len(IdeRecentLink(ml, 1)) Then
                    If menu$(m, s) = IdeRecentLink(ml, 1) Then
                        IdeOpenFile$ = IdeRecentLink(ml, 2)
                        AttemptToLoadRecent = -1
                        GoTo directopen
                    End If
                End If
            Next


            If menu$(m, s) = "#Recent..." Then
                PCopy 2, 0
                ideshowrecentbox:
                f$ = iderecentbox
                If f$ = "<C>" Then
                    f$ = ""
                    r$ = ideclearhistory$("FILES")
                    If r$ = "Y" Then
                        fh = FreeFile
                        Open ".\internal\temp\recent.bin" For Output As #fh: Close #fh
                        IdeMakeFileMenu
                        PCopy 3, 0: Screen , , 3, 0
                        GoTo ideloop
                    Else
                        GoTo ideshowrecentbox
                    End If
                ElseIf f$ = "<R>" Then
                    GoSub CleanUpRecentList
                    GoTo ideshowrecentbox
                End If
                If Len(f$) Then
                    IdeOpenFile$ = f$
                    AttemptToLoadRecent = -1
                    GoTo directopen
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Clear Recent..." Then
                PCopy 2, 0
                r$ = ideclearhistory$("FILES")
                If r$ = "Y" Then
                    fh = FreeFile
                    Open ".\internal\temp\recent.bin" For Output As #fh: Close #fh
                    IdeMakeFileMenu
                    PCopy 3, 0: Screen , , 3, 0
                    GoTo ideloop
                End If
                PCopy 3, 0: Screen , , 3, 0
                GoTo ideloop
            End If

            If menu$(m, s) = "#Open...  Ctrl+O" Then
                IdeOpenFile$ = ""
                directopen:
                PCopy 2, 0
                ctrlOpen:
                If ideunsaved Then
                    r$ = idesavenow
                    PCopy 3, 0: Screen , , 3, 0
                    If r$ = "C" Then GoTo ideloop
                    If r$ = "Y" Then
                        If ideprogname = "" Then
                            ProposedTitle$ = FindProposedTitle$
                            If ProposedTitle$ = "" Then
                                r$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                            Else
                                r$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                            End If
                            If ideerror > 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo IDEerrorMessage
                            If r$ = "C" Then GoTo ideloop
                        Else
                            idesave idepath$ + idepathsep$ + ideprogname$
                        End If
                        PCopy 3, 0: Screen , , 3, 0
                    End If '"Y"
                End If 'unsaved
                r$ = idefiledialog$("", 1)
                If ideerror > 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo IDEerrorMessage
                If r$ <> "C" Then ideunsaved = -1: idechangemade = 1: idelayoutallow = 2: ideundobase = 0: QuickNavTotal = 0: ModifyCOMMAND$ = "": idefocusline = 0
                PCopy 3, 0: Screen , , 3, 0
                GoSub redrawItAll: GoTo ideloop
            End If

            If menu$(m, s) = "#Save  Ctrl+S" Then
                PCopy 2, 0
                If ideprogname = "" Then
                    ProposedTitle$ = FindProposedTitle$
                    If ProposedTitle$ = "" Then
                        a$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                    Else
                        a$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                    End If
                    If ideerror > 1 Then PCopy 3, 0: Screen , , 3, 0: GoTo IDEerrorMessage
                Else
                    idesave idepath$ + idepathsep$ + ideprogname$
                End If
                PCopy 3, 0: Screen , , 3, 0: GoTo ideloop
            End If


            If menu$(m, s) = "Save #As..." Then
                PCopy 2, 0
                If ideprogname = "" Then
                    ProposedTitle$ = FindProposedTitle$
                    If ProposedTitle$ = "" Then
                        a$ = idefiledialog$("untitled" + tempfolderindexstr$ + ".bas", 2)
                    Else
                        a$ = idefiledialog$(ProposedTitle$ + ".bas", 2)
                    End If
                Else
                    a$ = idefiledialog$(ideprogname$, 2)
                End If
                PCopy 3, 0: Screen , , 3, 0
                If ideerror > 1 Then GoTo IDEerrorMessage
                GoTo ideloop
            End If

            If Left$(menu$(m, s), 1) = "~" Then 'Ignore disabled items (starting with "~")
                _Continue
            End If

            Screen , , 0, 0
            Cls: Print "MENU ITEM [" + menu$(m, s) + "] NOT IMPLEMENTED!": End
        End If


        _Limit 100

    Loop

    '--------------------------------------------------------------------------------
    Exit Function
    DrawQuickNav:
    If IdeSystem = 1 And QuickNavTotal > 0 Then
        Color 15, 7
        _PrintString (4, 2), " " + Chr$(17) + " "
    Else
        Color 7, 1
        _PrintString (4, 2), String$(3, 196)
    End If
    Return

    UpdateSearchBar:
    Color 7, 1: _PrintString (idewx - (idesystem2.w + 10), idewy - 4), Chr$(180)
    Color 3, 1
    _PrintString (1 + idewx - (idesystem2.w + 10), idewy - 4), "Find[" + Space$(idesystem2.w + 1) + Chr$(18) + "]"
    Color 7, 1: _PrintString (idewx - 2, idewy - 4), Chr$(195)

    'add status title
    Color 7, 1
    a$ = String$(14, 196)
    _PrintString ((idewx - Len(a$)) / 2, idewy - 4), a$
    If IdeSystem = 2 Then Color 1, 7 Else Color 7, 1
    a$ = " Status "
    _PrintString ((idewx - Len(a$)) / 2, idewy - 4), a$

    a$ = idefindtext
    tx = 1
    If Len(a$) > idesystem2.w Then
        If IdeSystem = 2 Then
            tx = idesystem2.v1 - idesystem2.w + 1
            If tx < 1 Then tx = 1
            a$ = Mid$(a$, tx, idesystem2.w)
        Else
            a$ = Left$(a$, idesystem2.w)
        End If
    End If

    sx1 = idesystem2.sx1: sx2 = idesystem2.v1
    If sx1 > sx2 Then Swap sx1, sx2

    x = x + 2
    'apply selection color change if necessary
    If idesystem2.issel = 0 Or IdeSystem <> 2 Then
        Color 3, 1
        _PrintString (idewx - (idesystem2.w + 8) + 4, idewy - 4), a$
    Else
        For ColorCHAR = 1 To Len(a$)
            If ColorCHAR + tx - 2 >= sx1 And ColorCHAR + tx - 2 < sx2 Then Color 1, 3 Else Color 3, 1
            _PrintString (idewx - (idesystem2.w + 8) + 4 - 1 + ColorCHAR, idewy - 4), Mid$(a$, ColorCHAR, 1)
        Next
    End If
    Return

    CleanUpRecentList:
    l$ = "": ln = 0
    ReDim RecentFilesList(0) As String
    fh = FreeFile
    Open ".\internal\temp\recent.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    Close #fh
    a$ = Right$(a$, Len(a$) - 2)
    FoundBrokenLink = 0
    Do While Len(a$)
        ai = InStr(a$, CRLF)
        If ai Then
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            If _FileExists(f$) Then
                ln = ln + 1
                ReDim _Preserve RecentFilesList(1 To ln)
                RecentFilesList(ln) = f$
            Else
                FoundBrokenLink = -1
            End If
        End If
    Loop

    If Not FoundBrokenLink Then
        result = idemessagebox("Remove Broken Links", "All files in the list are accessible.", "#OK")
    End If

    If ln > 0 And FoundBrokenLink Then
        fh = FreeFile
        Open ".\internal\temp\recent.bin" For Output As #fh: Close #fh
        f$ = ""
        For ln = 1 To UBound(RecentFilesList)
            f$ = f$ + CRLF + RecentFilesList(ln) + CRLF
        Next
        fh = FreeFile
        Open ".\internal\temp\recent.bin" For Binary As #fh
        Put #fh, 1, f$
        Close #fh
    End If

    Erase RecentFilesList
    IdeMakeFileMenu
    Return

    redrawItAll:
    menubar$ = "   "
    MenuLocations = ""
    For i = 1 To menus - 1
        MenuLocations = MenuLocations + MKI$(Len(menubar$))
        menubar$ = menubar$ + menu$(i, 0) + "  "
    Next
    menubar$ = menubar$ + Space$(idewx - Len(menubar$) - Len(menu$(i, 0)) - 2)
    MenuLocations = MenuLocations + MKI$(Len(menubar$))
    menubar$ = menubar$ + menu$(i, 0) + "  "


    Screen , , 3, 0
    View Print 1 To idewy + idesubwindow
    'VIEW PRINT 1 TO _HEIGHT(0)



    Locate , , , IDENormalCursorStart, IDENormalCursorEnd

    'static background
    Color 0, 7: _PrintString (1, 1), menubar$
    Color 7, 1: idebox 1, 2, idewx, idewy - 5


    Color 7, 1: idebox 1, idewy - 4, idewx, 5
    'edit corners
    Color 7, 1: _PrintString (1, idewy - 4), Chr$(195): _PrintString (idewx, idewy - 4), Chr$(180)

    GoSub UpdateSearchBar

    'status bar
    Color 0, 3: _PrintString (1, idewy + idesubwindow), Space$(idewx)
    q = idevbar(idewx, idewy - 3, 3, 1, 1)
    q = idevbar(idewx, 3, idewy - 8, 1, 1)
    q = idehbar(2, idewy - 5, idewx - 2, 1, 1)

    UpdateIdeInfo

    UpdateTitleOfMainWindow

    Def Seg = 0
    ideshowtext

    If IDEShowErrorsImmediately Or IDECompilationRequested Then
        clearStatusWindow 0

        IdeInfo = ""

        If idecompiling = 1 Then
            _PrintString (2, idewy - 3), String$(3, 250) '"..."
        Else
            If idefocusline Then
                _PrintString (2, idewy - 3), String$(3, 250) '"..."
            Else
                _PrintString (2, idewy - 3), "OK" 'report OK status
            End If
            statusarealink = 0
            If totalWarnings > 0 Then
                Color 11, 1
                msg$ = " (" + LTrim$(Str$(totalWarnings)) + " warning"
                If totalWarnings > 1 Then msg$ = msg$ + "s"
                msg$ = msg$ + " - click here or Ctrl+W to view)"
                _PrintString (4, idewy - 3), msg$
                statusarealink = 4
            End If
            If waitingForVarList Then GoSub showVarListReady
        End If
    End If
    Return

    showVarListReady:
    waitingForVarList = 0
    Color 14, 1
    _PrintString (2, idewy - 2), "Variable List is now available (F4 to see it)"
    Return
End Function

Sub UpdateTitleOfMainWindow
    sfname$ = FindCurrentSF$(idecy)
    cleanSubName sfname$
    Color 7, 1: _PrintString (2, 2), String$(idewx - 2, Chr$(196))
    If Len(ideprogname) Then a$ = ideprogname Else a$ = "Untitled" + tempfolderindexstr$
    a$ = " " + a$
    If ideunsaved Then a$ = a$ + "*"
    If Len(sfname$) > 0 Then a$ = a$ + ":" + sfname$
    a$ = a$ + " "
    If Len(a$) > idewx - 5 Then a$ = Left$(a$, idewx - 11) + String$(3, 250) + " "
    If IdeSystem = 1 Then Color 1, 7 Else Color 7, 1
    _PrintString (((idewx / 2) - 1) - (Len(a$) - 1) \ 2, 2), a$
End Sub

Function map! (value!, minRange!, maxRange!, newMinRange!, newMaxRange!)
    map! = ((value! - minRange!) / (maxRange! - minRange!)) * (newMaxRange! - newMinRange!) + newMinRange!
End Function

Function multiSearch (__fullText$, __searchString$)
    'Returns -1 if all of the search items in SearchString can be found
    'in FullText$. Returns 0 if any of the search terms cannot be found.
    'Multiple items in SearchString$ must be in the format "term1+term2+..."
    'Not case-sensitive.

    fullText$ = _Trim$(UCase$(__fullText$))
    searchString$ = _Trim$(UCase$(__searchString$))
    If Len(fullText$) = 0 Then Exit Function
    If Len(searchString$) = 0 Then Exit Function

    multiSearch = -1
    findPlus = InStr(searchString$, "+")
    While findPlus
        thisTerm$ = Left$(searchString$, findPlus - 1)
        searchString$ = Mid$(searchString$, findPlus + 1)
        If InStr(fullText$, thisTerm$) = 0 Then multiSearch = 0: Exit Function
        findPlus = InStr(searchString$, "+")
    Wend

    If Len(searchString$) Then
        If InStr(fullText$, searchString$) = 0 Then multiSearch = 0
    End If
End Function

Function formatRange$ (__text$)
    '__text$ is a series of MKL$(values) concatenated
    temp$ = __text$
    v1 = -1
    v2 = -1
    For i = 1 To Len(temp$) \ 4
        v = CVL(Mid$(temp$, i * 4 - 3, 4))
        If v1 = -1 Then
            v1 = v
        Else
            If v = v1 + 1 Or v = v2 + 1 Then
                v2 = v
            Else
                If v2 = -1 Then
                    a2$ = a2$ + LTrim$(Str$(v1)) + ";"
                    v1 = v
                Else
                    a2$ = a2$ + LTrim$(Str$(v1)) + "-" + LTrim$(Str$(v2)) + ";"
                    v1 = v
                    v2 = -1
                End If
            End If
        End If
    Next
    If v1 <> -1 And v2 = -1 Then a2$ = a2$ + LTrim$(Str$(v1))
    If v1 <> -1 And v2 <> -1 Then a2$ = a2$ + LTrim$(Str$(v1)) + "-" + LTrim$(Str$(v2))
    formatRange$ = a2$
End Function

Function expandArray$ (__indexes$, __path$)
    Static thisLevel As Long, returnValue$

    If thisLevel = 0 Then
        returnValue$ = ""
    End If

    thisLevel = thisLevel + 1

    totalIndexes = CVL(Left$(__indexes$, 4))
    indexes$ = Mid$(__indexes$, 5, totalIndexes)
    remainingIndexes$ = Mid$(__indexes$, 5 + totalIndexes)
    totalIndexes = totalIndexes \ 4

    For i = 1 To totalIndexes
        temp$ = __path$ + Mid$(indexes$, i * 4 - 3, 4)
        If Len(remainingIndexes$) Then
            temp$ = expandArray$(remainingIndexes$, temp$)
        End If
        If Len(temp$) Then
            returnValue$ = returnValue$ + MKL$(Len(temp$)) + temp$
        End If
    Next

    thisLevel = thisLevel - 1

    If thisLevel = 0 Then
        expandArray$ = returnValue$
    End If
End Function

Function parseRange$ (__text$)
    '__text$ must contain a valid numeric string (####),
    'a valid interval (####-####) or comma-separated values.
    'Only positive values >= 0 considered.
    'Returns MKL$(value1) + MKL$(value2)... in order

    If Len(_Trim$(__text$)) = 0 Then Exit Function

    Dim zeroIncluded As _Byte

    Filter$ = _Trim$(__text$)
    j = InStr(Filter$, "-") + InStr(Filter$, ";")
    temp$ = Space$(1000)

    If j = 0 Then 'Single number passed
        parseRange$ = MKL$(Val(Filter$))
        Exit Function
    End If

    Reading = 1
    For j = 1 To Len(Filter$)
        v = Asc(Filter$, j)
        Select Case v
            Case 59 ';
                Reading = 1
                GoSub parseIt
            Case 45 'hyphen
                If PrevChar <> 45 Then
                    Reading = Reading + 1
                    If Reading = 2 Then
                        If j = Len(Filter$) Then GoSub parseIt
                    End If
                End If
            Case 48 To 57 '0 to 9
                If Reading = 1 Then
                    v1$ = v1$ + Chr$(v)
                ElseIf Reading = 2 Then
                    v2$ = v2$ + Chr$(v)
                End If
                If j = Len(Filter$) Then GoSub parseIt
        End Select
        PrevChar = v
    Next j

    returnValue$ = ""
    If zeroIncluded Then returnValue$ = MKL$(0)
    For i = 1 To Len(temp$)
        If Asc(temp$, i) = 1 Then returnValue$ = returnValue$ + MKL$(i)
    Next
    parseRange$ = returnValue$

    Exit Function
    parseIt:
    v1 = Val(v1$)
    v2 = Val(v2$)
    If Len(v2$) > 0 Then
        If Len(v1$) > 0 Then
            If v1 > v2 Then Swap v1, v2
            If v2 > Len(temp$) Then temp$ = temp$ + Space$(v2 - Len(temp$))
            If v1 = 0 Then zeroIncluded = -1: v1 = 1
            For i = v1 To v2
                Asc(temp$, i) = 1
            Next
        End If
    Else
        If v1 > Len(temp$) Then temp$ = temp$ + Space$(v1 - Len(temp$))
        If v1 = 0 Then
            zeroIncluded = -1
        Else
            Asc(temp$, v1) = 1
        End If
    End If
    v1$ = ""
    v2$ = ""
    Return
End Function

Sub idebox (x, y, w, h)
    _PrintString (x, y), Chr$(218) + String$(w - 2, 196) + Chr$(191)
    For y2 = y + 1 To y + h - 2
        _PrintString (x, y2), Chr$(179) + Space$(w - 2) + Chr$(179)
    Next
    _PrintString (x, y + h - 1), Chr$(192) + String$(w - 2, 196) + Chr$(217)
End Sub

Sub ideboxshadow (x, y, w, h)
    idebox x, y, w, h

    'shadow
    Color 2, 0
    For y2 = y + 1 To y + h - 1
        For x2 = x + w To x + w + 1
            If x2 <= idewx And y2 <= idewy + idesubwindow Then
                _PrintString (x2, y2), Chr$(Screen(y2, x2))
            End If
        Next
    Next

    y2 = y + h
    If y2 <= idewy + idesubwindow Then
        For x2 = x + 2 To x + w + 1
            If x2 <= idewx Then
                _PrintString (x2, y2), Chr$(Screen(y2, x2))
            End If
        Next
    End If
End Sub

Function idechange$
    ReDim SearchHistory(0) As String

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    'built initial search strings
    If ideselect Then
        If ideselecty1 = idecy Then 'single line selected
            a$ = idegetline(idecy)
            a2$ = ""
            sx1 = ideselectx1: sx2 = idecx
            If sx2 < sx1 Then Swap sx1, sx2
            For x = sx1 To sx2 - 1
                If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
            Next
        End If
    End If
    If a2$ = "" Then
        a2$ = idefindtext
    End If

    'retrieve search history
    ln = 0
    fh = FreeFile
    Open ".\internal\temp\searched.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    Close #fh
    a$ = Right$(a$, Len(a$) - 2)
    Do While Len(a$)
        ai = InStr(a$, CRLF)
        If ai Then
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            ln = ln + 1
            ReDim _Preserve SearchHistory(1 To ln)
            SearchHistory(ln) = f$
        End If
    Loop
    ln = 0

    i = 0
    idepar p, 60, 14, "Change"
    i = i + 1
    PrevFocus = 1
    o(i).typ = 1
    o(i).y = 2
    o(i).nam = idenewtxt("#Find What")
    o(i).txt = idenewtxt(a2$)
    If Len(a2$) > 0 Then
        o(i).issel = -1
        o(i).sx1 = 0
    End If
    o(i).v1 = Len(a2$)

    i = i + 1
    o(i).typ = 1
    o(i).y = 5
    o(i).nam = idenewtxt("Change #To")
    o(i).txt = idenewtxt(idechangeto)
    If Len(idechangeto) > 0 Then
        o(i).issel = -1
        o(i).sx1 = 0
    End If
    o(i).v1 = Len(idechangeto)

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 8
    o(i).nam = idenewtxt("#Match Upper/Lowercase")
    o(i).sel = idefindcasesens
    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 9
    o(i).nam = idenewtxt("#Whole Word")
    o(i).sel = idefindwholeword
    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 10
    o(i).nam = idenewtxt("#Search Backwards")
    o(i).sel = idefindbackwards

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 11
    o(i).nam = idenewtxt("#Ignore 'comments")
    o(i).sel = idefindnocomments

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 29
    o(i).y = 11
    o(i).nam = idenewtxt("#Look only in 'comments")
    o(i).sel = idefindonlycomments

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 12
    o(i).nam = idenewtxt("Ignore " + Chr$(34) + "#strings" + Chr$(34))
    o(i).sel = idefindnostrings

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 29
    o(i).y = 12
    o(i).nam = idenewtxt("Look only in " + Chr$(34) + "st#rings" + Chr$(34))
    o(i).sel = idefindonlystrings

    i = i + 1
    ButtonsID = i
    o(i).typ = 3
    o(i).y = 14
    o(i).txt = idenewtxt("Find and #Verify" + sep + "#Change All" + sep + "Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        GoSub displayDialog
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If focus = 1 Or focus = 2 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        'mutually exclusive options
        If focus = 6 And o(6).sel = 1 Then
            o(7).sel = 0
        ElseIf focus = 7 And o(7).sel = 1 Then
            o(6).sel = 0
            o(8).sel = 0
            o(9).sel = 0
        ElseIf focus = 8 And o(8).sel = 1 Then
            o(9).sel = 0
        ElseIf focus = 9 And o(9).sel = 1 Then
            o(6).sel = 0
            o(7).sel = 0
            o(8).sel = 0
        End If

        If K$ = Chr$(27) Or (focus = 12 And info <> 0) Then
            idechange$ = "C"
            Exit Function
        End If

        If UBound(SearchHistory) > 0 Then
            If K$ = Chr$(0) + Chr$(72) And focus = 1 Then 'Up
                If ln < UBound(SearchHistory) Then
                    ln = ln + 1
                End If
                idetxt(o(1).txt) = SearchHistory(ln)
                o(1).issel = -1: o(1).sx1 = 0: o(1).v1 = Len(idetxt(o(1).txt))
            End If

            If K$ = Chr$(0) + Chr$(80) And focus = 1 Then 'Down
                If ln > 1 Then
                    ln = ln - 1
                Else
                    ln = 1
                End If
                idetxt(o(1).txt) = SearchHistory(ln)
                o(1).issel = -1: o(1).sx1 = 0: o(1).v1 = Len(idetxt(o(1).txt))
            End If
        End If

        If focus = 11 And info <> 0 Then 'change all
            idefindcasesens = o(3).sel
            idefindwholeword = o(4).sel
            idefindbackwards = o(5).sel
            idefindnocomments = o(6).sel
            idefindonlycomments = o(7).sel
            idefindnostrings = o(8).sel
            idefindonlystrings = o(9).sel

            s$ = idetxt(o(1).txt)
            idefindtext$ = s$
            idechangeto$ = idetxt(o(2).txt)
            IdeAddSearched idefindtext

            changed = 0

            s$ = idefindtext$
            If idefindcasesens = 0 Then s$ = UCase$(s$)

            For y = 1 To iden
                Color 0, 7
                maxprogresswidth = p.w - 4
                percentage = Int(y / iden * 100)
                percentagechars = Int(maxprogresswidth * y / iden)
                percentageMsg$ = String$(percentagechars, 219) + String$(maxprogresswidth - percentagechars, 176)
                _PrintString (p.x + 2, p.y + 7), percentageMsg$
                PCopy 1, 0

                l$ = idegetline(y)
                l2$ = ""

                x1 = 1
                idechangeall:
                If idefindcasesens = 0 Then l3$ = UCase$(l$) Else l3$ = l$
                x = InStr(x1, l3$, s$)

                If x Then
                    If idefindwholeword Then
                        whole = 1
                        If x > 1 Then
                            c = Asc(UCase$(Mid$(l$, x - 1, 1)))
                            If c >= 65 And c <= 90 Then whole = 0
                            If c >= 48 And c <= 57 Then whole = 0
                        End If
                        If x + Len(s$) <= Len(l$) Then
                            c = Asc(UCase$(Mid$(l$, x + Len(s$), 1)))
                            If c >= 65 And c <= 90 Then whole = 0
                            If c >= 48 And c <= 57 Then whole = 0
                        End If
                        If whole = 0 Then
                            If x1 <= Len(l$) Then
                                l2$ = l2$ + Mid$(l$, x1, x - x1 + 1)
                                x1 = x + 1
                                GoTo idechangeall
                            End If
                            x = 0
                        End If
                    End If
                End If

                Dim comment As _Byte, quote As _Byte
                If x Then
                    FindQuoteComment l$, x, comment, quote
                    If idefindnocomments <> 0 And comment Then x = 0
                    If idefindnostrings <> 0 And quote Then x = 0
                    If idefindonlycomments <> 0 And comment = 0 Then x = 0
                    If idefindonlystrings <> 0 And quote = 0 Then x = 0
                End If

                If x Then
                    l2$ = l2$ + Mid$(l$, x1, x - x1) + idechangeto$
                    changed = changed + 1
                    x1 = x + Len(s$)
                    If x1 <= Len(l$) Then GoTo idechangeall
                End If

                l2$ = l2$ + Mid$(l$, x1, Len(l$) - x1 + 1)

                If l2$ <> l$ Then idesetline y, l2$

            Next

            Screen , , 3, 0
            clearStatusWindow 0
            idefocusline = 0
            ideshowtext
            PCopy 3, 0
            PCopy 0, 2
            PCopy 0, 1
            Screen , , 1, 0
            GoSub displayDialog
            PCopy 1, 0

            If changed = 0 Then
                idenomatch 0
            Else
                idechanged changed: idechangemade = 1
            End If

            idetxt(o(ButtonsID).txt) = "Find and #Verify" + sep + "#Change All" + sep + "Close"
        End If 'change all

        If (focus = 10 And info <> 0) Or K$ = Chr$(13) Then
            idefindcasesens = o(3).sel
            idefindwholeword = o(4).sel
            idefindbackwards = o(5).sel
            idefindnocomments = o(6).sel
            idefindonlycomments = o(7).sel
            idefindnostrings = o(8).sel
            idefindonlystrings = o(9).sel
            idefindtext$ = idetxt(o(1).txt)
            idechangeto$ = idetxt(o(2).txt)
            idechange$ = "V"
            Exit Function
        End If

        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
    Exit Function
    displayDialog:
    idedrawpar p
    f = 1: cx = 0: cy = 0
    For i = 1 To 100

        If o(i).typ Then

            'prepare object
            o(i).foc = focus - f 'focus offset

            o(i).cx = 0: o(i).cy = 0

            idedrawobj o(i), f 'display object

            If o(i).cx Then cx = o(i).cx: cy = o(i).cy

        End If
    Next i
    Return
End Function

Sub FindQuoteComment (text$, __cursor As Long, c As _Byte, q As _Byte)
    c = 0: q = 0
    cursor = __cursor
    If cursor > Len(text$) Then cursor = Len(text$)
    For find_k = 1 To cursor
        Select Case Mid$(text$, find_k, 1)
            Case Chr$(34): q = Not q
            Case "'": If q = 0 Then c = -1: Exit For
            Case "R", "r"
                If q = 0 Then
                    IF UCASE$(MID$(text$, find_k - 1, 5)) = " REM " OR _
                       UCASE$(MID$(text$, find_k - 1, 5)) = ":REM " OR _
                       (find_k + 2 = LEN(text$) AND UCASE$(MID$(text$, find_k - 1, 4)) = " REM") OR _
                       (find_k + 2 = LEN(text$) AND UCASE$(MID$(text$, find_k - 1, 4)) = ":REM") OR _
                       (find_k = 1 AND UCASE$(LEFT$(text$, 4)) = "REM ") OR _
                       (find_k = 1 AND UCASE$(text$) = "REM") THEN
                        c = -1: Exit For
                    End If
                End If
        End Select
    Next find_k
End Sub

Sub idechanged (totalChanges As Long)
    If totalChanges > 1 Then pl$ = "s"
    result = idemessagebox("Change Complete", LTrim$(Str$(totalChanges)) + " substitution" + pl$ + ".", "")
End Sub

Function idechangeit$

    '-------- generic dialog box header --------
    PCopy 3, 0
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    i = 0
    w = 45
    p.x = 40 - w \ 2
    p.y = idewy - 4
    p.w = w
    p.h = 2
    p.nam = idenewtxt("Change")

    i = i + 1
    o(i).typ = 3
    o(i).y = 2
    o(i).txt = idenewtxt("#Change" + sep + "#Skip" + sep + "Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        If UCase$(K$) = "C" Then altletter$ = "C"
        If UCase$(K$) = "S" Then altletter$ = "S"

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        If K$ = Chr$(27) Then
            idechangeit$ = "C"
            Exit Function
        End If

        If info Then
            If info = 1 Then idechangeit$ = "Y"
            If info = 2 Then idechangeit$ = "N"
            If info = 3 Then idechangeit$ = "C"
            Exit Function
        End If

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop

End Function

Sub idedelline (i)

    For b = 1 To IdeBmkN
        If IdeBmk(b).y >= i Then
            y = IdeBmk(b).y - 1: If y = 0 Then y = 1
            IdeBmk(b).y = y
        End If
    Next

    idegotoline i
    textlen = CVL(Mid$(idet$, ideli, 4))
    idet$ = Left$(idet$, ideli - 1) + Right$(idet$, Len(idet$) - ideli + 1 - 8 - textlen)
    iden = iden - 1

    If i > iden Then idegotoline iden '[2013] if last line was removed, move to previous line

End Sub

Sub idedeltxt
    idetxtlast = 0
End Sub

Sub idedrawobj (o As idedbotype, f)
    Dim sep As String * 1
    sep = Chr$(0)

    '#1: SINGLE LINE TEXT INPUT BOX
    If o.typ = 1 Then
        If o.x = 0 Then o.x = 2
        x = o.par.x + o.x: y = o.par.y + o.y
        Color 0, 7
        If o.nam Then
            a$ = idetxt(o.nam)
            Locate y, x: idehPRINT a$ + ":"
            x = x + idehlen(a$) + 2
        End If
        If o.w = 0 Then x2 = o.par.x + o.par.w - 1: o.w = x2 - x - 3
        idebox x, y - 1, o.w + 4, 3
        If o.txt = 0 Then o.txt = idenewtxt("")
        a$ = idetxt(o.txt)
        If o.v1 > Len(a$) Then o.v1 = Len(a$) 'new
        cx = o.v1

        tx = 1
        If Len(a$) > o.w Then
            If o.foc = 0 Then
                tx = o.v1 - o.w + 1
                If tx < 1 Then tx = 1
                a$ = Mid$(a$, tx, o.w)
                cx = cx - tx + 1
            Else
                a$ = Left$(a$, o.w)
            End If
        End If

        sx1 = o.sx1: sx2 = o.v1
        If sx1 > sx2 Then Swap sx1, sx2

        x = x + 2
        'apply selection color change if necessary
        If o.issel = 0 Or o.foc <> 0 Then
            _PrintString (x, y), a$
        Else
            For ColorCHAR = 1 To Len(a$)
                If ColorCHAR + tx - 2 >= sx1 And ColorCHAR + tx - 2 < sx2 Then Color 7, 0 Else Color 0, 7
                _PrintString (x - 1 + ColorCHAR, y), Mid$(a$, ColorCHAR, 1)
            Next
        End If

        If o.foc = 0 Then o.cx = x + cx: o.cy = y
        f = f + 1
    End If '#1

    '#2: VERTICAL SCROLLING SELECTION BOX
    If o.typ = 2 Then
        If o.x = 0 Then o.x = 2
        If o.w = 0 Then o.w = o.par.w - 2 - o.x
        If o.h = 0 Then o.h = o.par.h - 1 - o.y
        x = o.par.x + o.x: y = o.par.y + o.y
        Color 0, 7
        idebox x, y, o.w + 2, o.h + 2
        If o.nam Then
            a$ = idetxt(o.nam)
            w = o.w + 2
            m = w \ 2: If w And 1 Then m = m + 1
            Locate y, x + m - 1 - ((idehlen(a$) + 2) - 1) \ 2: idehPRINT " " + a$ + " "
        End If 'nam
        'display list items
        If o.sel = 0 Then o.sel = -1
        If o.txt = 0 Then o.txt = idenewtxt("")
        If o.stx = 0 Then o.stx = idenewtxt("")
        If o.v1 = 0 Then o.v1 = 1
        s = Abs(o.sel)
        If s >= o.v1 + o.h Then o.v1 = s - o.h + 1
        If s < o.v1 Then o.v1 = s
        If o.foc <> 0 And o.sel > 0 Then o.sel = -o.sel
        a$ = idetxt(o.txt)
        n = 1
        y = 1
        v1 = o.v1
        a3$ = ""
        For i2 = 1 To Len(a$)
            a2$ = Mid$(a$, i2, 1)
            If a2$ <> sep Then a3$ = a3$ + a2$
            If a2$ = sep Or i2 = Len(a$) Then
                If n < v1 Then
                    'skip
                Else
                    If y <= o.h Then
                        a3$ = " " + RTrim$(a3$)
                        If o.sel = n Then
                            Color 7, 0
                            o.selY = o.par.y + o.y + y
                        Else
                            Color 0, 7
                        End If
                        If (o.sel = n Or -o.sel = n) And o.foc = 0 Then
                            o.cx = o.par.x + o.x + 2: o.cy = o.par.y + o.y + y
                            If Left$(a3$, 2) = Chr$(32) + Chr$(195) Or Left$(a3$, 2) = Chr$(32) + Chr$(192) Then
                                o.cx = o.cx + 2
                            End If
                        End If

                        Locate o.par.y + o.y + y, o.par.x + o.x + 1
                        If InStr(a3$, Chr$(16)) Then
                            'color formatting: CHR$(16) + CHR$(color)
                            '                  CHR$(16) + CHR$(16) restores default
                            '                  CHR$(17) + CHR$(bg color)
                            '                  CHR$(17) + CHR$(17) restores default
                            character = 0
                            rightSideLimit = Pos(1) + o.w - 1
                            cf = Pos(1)
                            Do
                                character = character + 1
                                If character > Len(a3$) Then
                                    Print Space$(o.w - (Pos(1) - (o.par.x + o.x)) + 1);
                                    Exit Do
                                End If
                                If Asc(a3$, character) = 16 And character < Len(a3$) Then
                                    If Asc(a3$, character + 1) >= 0 And Asc(a3$, character + 1) <= 15 Then
                                        Color Asc(a3$, character + 1)
                                        character = character + 1
                                        _Continue
                                    ElseIf Asc(a3$, character + 1) = 16 Then
                                        If o.sel = n Then Color 7 Else Color 0
                                        character = character + 1
                                        _Continue
                                    End If
                                ElseIf Asc(a3$, character) = 17 And character < Len(a3$) Then
                                    If Asc(a3$, character + 1) >= 0 And Asc(a3$, character + 1) <= 15 Then
                                        If o.sel <> n Then Color , Asc(a3$, character + 1)
                                        character = character + 1
                                        _Continue
                                    ElseIf Asc(a3$, character + 1) = 17 Then
                                        If o.sel = n Then Color , 0 Else Color , 7
                                        character = character + 1
                                        _Continue
                                    End If
                                ElseIf character = 1 And (Left$(a3$, 2) = Chr$(32) + Chr$(195) Or Left$(a3$, 2) = Chr$(32) + Chr$(192)) Then
                                    Color 0, 7
                                    Print Left$(a3$, 3);
                                    If o.sel = n Then Color 7, 0 Else Color 0, 7
                                    character = 3
                                    cf = cf + 3
                                    _Continue
                                End If
                                Print Mid$(a3$, character, 1);
                                cf = cf + 1
                            Loop Until cf > rightSideLimit
                            If character < Len(a3$) Then _PrintString (rightSideLimit, CsrLin), Chr$(26)
                            If Pos(1) < rightSideLimit Then
                                Print Space$(rightSideLimit - Pos(1));
                            End If
                        Else
                            If Len(a3$) > o.w Then Mid$(a3$, o.w, 1) = Chr$(26)
                            a3$ = a3$ + Space$(o.w)
                            a3$ = Left$(a3$, o.w)
                            'customization specific for the SUBs list, due to the tree characters:
                            If Left$(a3$, 2) = Chr$(32) + Chr$(195) Or Left$(a3$, 2) = Chr$(32) + Chr$(192) Then
                                Color 0, 7
                                Print Left$(a3$, 3);
                                If o.sel = n Then Color 7, 0 Else Color 0, 7
                                Print Mid$(a3$, 4);
                            Else
                                Print a3$;
                            End If
                        End If
                        'customization specific for the SUBs list, when there are external procedures:
                        If InStr(a3$, Chr$(196) + "*") > 0 Then
                            If o.sel = n Then Color 2, 0 Else Color 2, 7
                            _PrintString (o.par.x + o.x + 4, o.par.y + o.y + y), "*"
                        End If
                        y = y + 1
                    End If
                End If
                n = n + 1
                a3$ = ""
            End If
        Next
        o.num = n - 1

        tnum = o.num
        tsel = Abs(o.sel)

        q = idevbar(o.par.x + o.x + o.w + 1, o.par.y + o.y + 1, o.h, tsel, tnum)

        f = f + 1
    End If '#2

    '#3: ACTION BUTTONS
    If o.typ = 3 Then
        If o.x = 0 Then o.x = 2
        If o.w = 0 Then o.w = o.par.w - o.x 'spanable width
        If o.txt = 0 Then o.txt = idenewtxt("#OK")
        a$ = idetxt(o.txt)
        n = 1
        c = 0
        For i2 = 1 To Len(a$)
            a2$ = Mid$(a$, i2, 1)
            If a2$ = Chr$(0) Then
                n = n + 1
            Else
                If a$ <> "#" Then c = c + 1
            End If
        Next
        w = o.w
        c = c + n * 4 'add characters for bracing < > buttons
        whitespace = w - c
        spacing = whitespace \ (n + 1)
        f2 = o.foc + 1
        If f2 < 1 Or f2 > n Then
            If o.dft Then f2 = o.dft
        End If
        n2 = 1
        a3$ = ""
        Locate o.par.y + o.y, o.par.x + o.x
        x = o.par.x + o.x
        Color 0, 7
        For i2 = 1 To Len(a$)
            a2$ = Mid$(a$, i2, 1)
            If a2$ <> Chr$(0) Then a3$ = a3$ + a2$
            If a2$ = Chr$(0) Or i2 = Len(a$) Then
                Print Space$(spacing);
                x = x + spacing
                If f2 = n2 Then Color 15, 7 Else Color 0, 7
                Print "< ";
                Color 0, 7: idehPRINT a3$
                If f2 = n2 Then Color 15, 7 Else Color 0, 7
                If n2 = o.foc + 1 Then
                    o.cx = x + 2: o.cy = o.par.y + o.y
                End If
                Print " >";
                Color 0, 7
                x = x + idehlen(a3$) + 4
                a3$ = ""
                n2 = n2 + 1
            End If
        Next
        f = f + n
    End If '#3

    '#4: CHECK BOX
    If o.typ = 4 Then
        If o.x = 0 Then o.x = 2
        x = o.par.x + o.x: y = o.par.y + o.y
        Locate y, x
        Color 0, 7
        If o.sel Then
            Print "[X] ";
        Else
            Print "[ ] ";
        End If
        If o.nam Then
            a$ = idetxt(o.nam)
            idehPRINT a$
        End If
        If o.foc = 0 Then o.cx = x + 1: o.cy = y
        f = f + 1
    End If '#4

End Sub

Sub idedrawpar (p As idedbptype)
    Color 0, 7: ideboxshadow p.x, p.y, p.w + 2, p.h + 2
    If p.nam Then
        x = Len(idetxt(p.nam)) + 2
        Color 0, 7: _PrintString (p.x + (p.w \ 2) - (x - 1) \ 2, p.y), " " + idetxt(p.nam) + " "
    End If
End Sub

Function idefileexists$ (f$)
    l = Len(f$)
    Do
        If l < Len(f$) Then
            m$ = "File " + Chr$(34) + String$(3, 250) + Right$(f$, l) + Chr$(34) + " already exists. Overwrite?"
        Else
            m$ = "File " + Chr$(34) + f$ + Chr$(34) + " already exists. Overwrite?"
        End If
        l = l - 1
    Loop Until Len(m$) + 4 < (idewx - 6)

    result = idemessagebox("Save", m$, "#Yes;#No")
    If result = 1 Then idefileexists$ = "Y" Else idefileexists$ = "N"
End Function

Function idefind$

    ReDim SearchHistory(0) As String
    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    'built initial search string
    If ideselect Then
        If ideselecty1 = idecy Then 'single line selected
            a$ = idegetline(idecy)
            a2$ = ""
            sx1 = ideselectx1: sx2 = idecx
            If sx2 < sx1 Then Swap sx1, sx2
            For x = sx1 To sx2 - 1
                If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
            Next
        End If
    End If
    If a2$ = "" Then
        a2$ = idefindtext
    End If

    'retrieve search history
    ln = 0
    fh = FreeFile
    Open ".\internal\temp\searched.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    Close #fh
    a$ = Right$(a$, Len(a$) - 2)
    Do While Len(a$)
        ai = InStr(a$, CRLF)
        If ai Then
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            ln = ln + 1
            ReDim _Preserve SearchHistory(1 To ln)
            SearchHistory(ln) = f$
        End If
    Loop
    ln = 0

    i = 0
    idepar p, 60, 11, "Find"
    i = i + 1
    PrevFocus = 1
    o(i).typ = 1
    o(i).y = 2
    o(i).nam = idenewtxt("#Find What")
    o(i).txt = idenewtxt(a2$)
    If Len(a2$) > 0 Then
        o(i).issel = -1
        o(i).sx1 = 0
    End If
    o(i).v1 = Len(a2$)

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 5
    o(i).nam = idenewtxt("#Match Upper/Lowercase")
    o(i).sel = idefindcasesens

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 6
    o(i).nam = idenewtxt("#Whole Word")
    o(i).sel = idefindwholeword

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 7
    o(i).nam = idenewtxt("#Search Backwards")
    o(i).sel = idefindbackwards

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 8
    o(i).nam = idenewtxt("#Ignore 'comments")
    o(i).sel = idefindnocomments

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 29
    o(i).y = 8
    o(i).nam = idenewtxt("#Look only in 'comments")
    o(i).sel = idefindonlycomments

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 9
    o(i).nam = idenewtxt("Ignore " + Chr$(34) + "s#trings" + Chr$(34))
    o(i).sel = idefindnostrings

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 29
    o(i).y = 9
    o(i).nam = idenewtxt("Look only in " + Chr$(34) + "st#rings" + Chr$(34))
    o(i).sel = idefindonlystrings

    i = i + 1
    o(i).typ = 3
    o(i).y = 11
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If focus = 1 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        If K$ = Chr$(27) Or (focus = 10 And info <> 0) Then
            idefind$ = "C"
            Exit Function
        End If

        'mutually exclusive options
        If focus = 5 And o(5).sel = 1 Then
            o(6).sel = 0
        ElseIf focus = 6 And o(6).sel = 1 Then
            o(5).sel = 0
            o(7).sel = 0
            o(8).sel = 0
        ElseIf focus = 7 And o(7).sel = 1 Then
            o(8).sel = 0
        ElseIf focus = 8 And o(8).sel = 1 Then
            o(5).sel = 0
            o(6).sel = 0
            o(7).sel = 0
        End If

        If K$ = Chr$(13) Or (focus = 9 And info <> 0) Then
            idefindcasesens = o(2).sel
            idefindwholeword = o(3).sel
            idefindbackwards = o(4).sel
            idefindnocomments = o(5).sel
            idefindonlycomments = o(6).sel
            idefindnostrings = o(7).sel
            idefindonlystrings = o(8).sel
            s$ = idetxt(o(1).txt)
            idefindtext$ = s$
            IdeAddSearched idefindtext
            idefindagain 0
            Exit Function
        End If

        If UBound(SearchHistory) > 0 Then
            If K$ = Chr$(0) + Chr$(72) And focus = 1 Then 'Up
                If ln < UBound(SearchHistory) Then
                    ln = ln + 1
                End If
                idetxt(o(1).txt) = SearchHistory(ln)
                o(1).issel = -1: o(1).sx1 = 0: o(1).v1 = Len(idetxt(o(1).txt))
            End If

            If K$ = Chr$(0) + Chr$(80) And focus = 1 Then 'Down
                If ln > 1 Then
                    ln = ln - 1
                Else
                    ln = 1
                End If
                idetxt(o(1).txt) = SearchHistory(ln)
                o(1).issel = -1: o(1).sx1 = 0: o(1).v1 = Len(idetxt(o(1).txt))
            End If
        End If
        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
End Function

Sub idefindagain (showFlags As _Byte)
    Dim comment As _Byte, quote As _Byte

    If idefindinvert Then
        If idefindbackwards = 0 Then idefindbackwards = 1 Else idefindbackwards = 0
    End If

    s$ = idefindtext$
    If idefindcasesens = 0 Then s$ = UCase$(s$)
    start = idecy
    y = start

    idefindnext2:
    l$ = idegetline(y)
    If idefindcasesens = 0 Then l$ = UCase$(l$)

    If y = start Then
        'retrieve the unscanned portion of this line only
        If looped = 1 Then
            If idefindbackwards Then
                If Len(l$) > idecx Then l$ = String$(idecx, 255) + Right$(l$, Len(l$) - idecx) Else l$ = ""
            Else
                If Len(l$) > idecx Then l$ = Left$(l$, idecx)
            End If
        Else
            If idefindbackwards Then
                If Len(l$) > idecx Then l$ = Left$(l$, idecx - 1 + (Len(s$) - 1))
            Else
                If Len(l$) > idecx Then l$ = String$(idecx, 255) + Right$(l$, Len(l$) - idecx) Else l$ = ""
            End If
        End If
    End If

    x1 = 1
    If idefindbackwards Then
        x1 = Len(l$) - Len(s$) + 1
        If x1 < 0 Then x1 = 0
    End If

    idefindagain2:

    If idefindbackwards Then
        x = 0
        For xx = x1 To 1 Step -1
            If Asc(l$, xx) = Asc(s$) Then 'first char
                xxo = xx - 1
                For xx2 = xx To xx + Len(s$) - 1
                    If Asc(l$, xx2) <> Asc(s$, xx2 - xxo) Then Exit For
                Next
                If xx2 = xx + Len(s$) Then
                    'matched!
                    x = xx
                    Exit For
                End If
            End If 'first char
        Next
    Else
        x = InStr(x1, l$, s$)
    End If


    If x Then
        If idefindwholeword Then
            whole = 1
            If x > 1 Then
                c = Asc(UCase$(Mid$(l$, x - 1, 1)))
                If c >= 65 And c <= 90 Then whole = 0
                If c >= 48 And c <= 57 Then whole = 0
            End If
            If x + Len(s$) <= Len(l$) Then
                c = Asc(UCase$(Mid$(l$, x + Len(s$), 1)))
                If c >= 65 And c <= 90 Then whole = 0
                If c >= 48 And c <= 57 Then whole = 0
            End If
            If whole = 0 Then
                x1 = x + 1: If idefindbackwards Then x1 = x - 1
                x = 0
                If x1 > 0 And x1 <= Len(l$) Then GoTo idefindagain2
            End If
        End If
    End If

    If x Then
        FindQuoteComment l$, x, comment, quote
        If idefindnocomments <> 0 And comment Then x = 0
        If idefindnostrings <> 0 And quote Then x = 0
        If idefindonlycomments <> 0 And comment = 0 Then x = 0
        If idefindonlystrings <> 0 And quote = 0 Then x = 0
    End If

    If x Then
        ideselect = 1
        idecx = x: idecy = y
        searchStringFoundOn = idecy
        ideselectx1 = x + Len(s$): ideselecty1 = y

        If idefindinvert Then
            If idefindbackwards = 0 Then idefindbackwards = 1 Else idefindbackwards = 0
            idefindinvert = 0
        End If
        idecentercurrentline
        Exit Sub
    End If

    If idefindbackwards Then
        y = y - 1
        If y = start - 1 And looped = 1 Then
            idenomatch showFlags
            If idefindinvert Then
                If idefindbackwards = 0 Then idefindbackwards = 1 Else idefindbackwards = 0
                idefindinvert = 0
            End If
            Exit Sub
        End If
        If y < 1 Then y = iden: looped = 1
        GoTo idefindnext2
    Else
        y = y + 1
        If y = start + 1 And looped = 1 Then
            idenomatch showFlags
            If idefindinvert Then
                If idefindbackwards = 0 Then idefindbackwards = 1 Else idefindbackwards = 0
                idefindinvert = 0
            End If
            Exit Sub
        End If
        If y > iden Then y = 1: looped = 1
        GoTo idefindnext2
    End If
End Sub

Function idegetline$ (i)
    If i <> -1 Then idegotoline i
    idegetline$ = Mid$(idet$, ideli + 4, CVL(Mid$(idet$, ideli, 4)))
End Function

Sub idecentercurrentline
    If iden <= idewy - 8 Then Exit Sub
    idesy = idecy - (idewy - 8) \ 2
    If idesy < 1 Then idesy = 1
End Sub

Sub idegotoline (i)
    If idel = i Then Exit Sub
    If i < 1 Then i = 1
    'scan backwards
    If i < idel Then
        Do
            idel = idel - 1
            ideli = ideli - CVL(Mid$(idet$, ideli - 4, 4)) - 8
        Loop Until idel = i
        Exit Sub
    End If
    'assume scan forwards
    Do
        If idel = iden Then idet$ = idet$ + MKL$(0) + MKL$(0): iden = iden + 1 'insert blank line at end?
        idel = idel + 1
        ideli = ideli + CVL(Mid$(idet$, ideli, 4)) + 8
    Loop Until idel = i
End Sub

Function idehbar (x, y, h, i2, n2)
    i = i2: n = n2

    'h is size in characters (inc. arrows)

    'draw background & arrows
    Color 0, 7
    _PrintString (x, y), Chr$(27)
    _PrintString (x + h - 1, y), Chr$(26)
    For x2 = x + 1 To x + h - 2
        _PrintString (x2, y), Chr$(176)
    Next

    'draw slider

    If n < 1 Then n = 1
    If i < 1 Then i = 1
    If i > n Then i = n

    If h = 2 Then
        idehbar = x 'not position for slider exists
        Exit Function
    End If

    If h = 3 Then
        idehbar = x + 1 'dummy value
        'no slider
        Exit Function
    End If

    If h = 4 Then
        If n = 1 Then
            idehbar = x + 1 'dummy value
            'no slider required for 1 item
            Exit Function
        Else
            'show whichever is closer of the two positions
            p! = (i - 1) / (n - 1)
            If p! < .5 Then x2 = x + 1 Else x2 = x + 2
            _PrintString (x2, y), Chr$(219)
            idehbar = x2
            Exit Function
        End If
    End If

    If h > 4 Then
        If n = 1 Then
            idehbar = x + h \ 4 'dummy value
            'no slider required for 1 item
            Exit Function
        End If
        If i = 1 Then
            x2 = x + 1
            _PrintString (x2, y), Chr$(219)
            idehbar = x2
            Exit Function
        End If
        If i = n Then
            x2 = x + h - 2
            _PrintString (x2, y), Chr$(219)
            idehbar = x2
            Exit Function
        End If
        'between i=1 and i=n
        p! = (i - 1) / (n - 1)
        p! = p! * (h - 4)
        x2 = x + 2 + Int(p!)
        _PrintString (x2, y), Chr$(219)
        idehbar = x2
        Exit Function
    End If


End Function

Function idehlen (a$)
    If InStr(a$, "#") Then idehlen = Len(a$) - 1 Else idehlen = Len(a$)
End Function

Sub idehPRINT (a$)
    Color 0, 7
    For i = 1 To Len(a$)
        c$ = Mid$(a$, i, 1)
        If c$ = "#" Then
            If idehl Then Color 15, 7
        Else
            Print c$;: Color 0, 7
        End If
    Next
End Sub

Sub ideinsline (i, text$)
    'note: cursor remains on line i

    For b = 1 To IdeBmkN
        If IdeBmk(b).y >= i Then
            y = IdeBmk(b).y + 1
            IdeBmk(b).y = y
        End If
    Next

    text$ = RTrim$(text$)

    If i = -1 Then i = idel
    'if at end, use idesetline
    If i > iden Then
        idesetline i, text$
        Exit Sub
    End If
    idegotoline i
    'insert line
    textlen = Len(text$)
    idet$ = Left$(idet$, ideli - 1) + MKL$(textlen) + text$ + MKL$(textlen) + Right$(idet$, Len(idet$) - ideli + 1)
    iden = iden + 1
End Sub

Function ideinputbox$ (title$, caption$, initialvalue$, validinput$, boxwidth, maxlength, ok)


    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    i = 0
    ok = 0 'will be set to true if "OK" or Enter are used to close the dialog

    idepar p, boxwidth, 5, title$

    i = i + 1
    PrevFocus = 1
    o(i).typ = 1
    o(i).y = 2
    o(i).nam = idenewtxt(caption$)
    o(i).txt = idenewtxt(initialvalue$)
    If Len(initialvalue$) > 0 Then o(i).issel = -1
    o(i).sx1 = 0
    o(i).v1 = Len(initialvalue$)

    i = i + 1
    o(i).typ = 3
    o(i).y = 5
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop


        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If focus = 1 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        If Len(validinput$) Then
            a$ = idetxt(o(1).txt)
            tempA$ = ""
            For i = 1 To Len(a$)
                If InStr(validinput$, Mid$(a$, i, 1)) > 0 Then
                    tempA$ = tempA$ + Mid$(a$, i, 1)
                End If
            Next
            idetxt(o(1).txt) = tempA$
        End If

        If maxlength Then
            idetxt(o(1).txt) = Left$(idetxt(o(1).txt), maxlength)
        End If

        If K$ = Chr$(27) Or (focus = 3 And info <> 0) Then
            ClearMouse
            Exit Function
        End If

        If K$ = Chr$(13) Or (focus = 2 And info <> 0) Then
            ideinputbox$ = idetxt(o(1).txt)
            ok = -1
            ClearMouse
            _KeyClear
            Exit Function
        End If
        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop

End Function

Sub idenewsf (sf As String)
    'build initial name if word selected
    If ideselect Then
        If ideselecty1 = idecy Then 'single line selected
            a$ = idegetline(idecy)
            a2$ = ""
            sx1 = ideselectx1: sx2 = idecx
            If sx2 < sx1 Then Swap sx1, sx2
            For x = sx1 To sx2 - 1
                If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
            Next
        End If
    End If

    newSF$ = ideinputbox$("New " + sf$, "#Name", a2$, "", 60, 40, 0)

    If Len(newSF$) Then
        y = iden
        y = y + 1: idesetline y, ""
        y = y + 1: idesetline y, sf$ + " " + newSF$
        idesy = y
        y = y + 1: idesetline y, ""
        idecy = y
        y = y + 1: idesetline y, "END " + sf$
        idecx = 1: idesx = 1
        idechangemade = 1
    End If
End Sub

Function idenewfolder$ (thispath$)
    newfolder$ = ideinputbox$("New Folder", "#Name", "", "", 60, 0, 0)

    If Len(newfolder$) Then
        If _DirExists(thispath$ + idepathsep$ + newfolder$) Then
            idenewfolder$ = newfolder$
            Exit Function
        End If
        ideerror = 5
        MkDir thispath$ + idepathsep$ + newfolder$
        ideerror = 1
        idenewfolder$ = newfolder$
    End If
End Function


Function idenewtxt (a$)
    idetxtlast = idetxtlast + 1
    idetxt$(idetxtlast) = a$
    idenewtxt = idetxtlast
End Function

Sub idenomatch (showFlags As _Byte)
    msg$ = "Match not found."
    c$ = ", "
    If showFlags Then
        If idefindcasesens Then flags$ = flags$ + "match case": flagset = flagset + 1
        If idefindwholeword Then flags$ = flags$ + Left$(c$, Abs(flagset) * 2) + "whole word": flagset = flagset + 1
        If idefindnocomments Then flags$ = flags$ + Left$(c$, Abs(flagset) * 2) + "no comments": flagset = flagset + 1
        If idefindonlycomments Then flags$ = flags$ + Left$(c$, Abs(flagset) * 2) + "only comments": flagset = flagset + 1
        If idefindnostrings Then flags$ = flags$ + Left$(c$, Abs(flagset) * 2) + "no strings": flagset = flagset + 1
        If idefindonlystrings Then flags$ = flags$ + Left$(c$, Abs(flagset) * 2) + "only strings": flagset = flagset + 1
        If flagset > 1 Then pl$ = "s"
        If flagset Then msg$ = msg$ + "\n(Flag" + pl$ + ": " + flags$ + ")"
    End If
    result = idemessagebox("Search complete", msg$, "")
End Sub

Function idefiledialog$ (programname$, mode As _Byte)
    Static AllFiles

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    path$ = idepath$
    filelist$ = idezfilelist$(path$, AllFiles, "")
    pathlist$ = idezpathlist$(path$)

    i = 0
    If mode = 1 Then
        idepar p, 70, idewy + idesubwindow - 7, "Open"
    ElseIf mode = 2 Then
        idepar p, 70, idewy + idesubwindow - 7, "Save As"
    End If
    i = i + 1
    PrevFocus = 1
    o(i).typ = 1
    o(i).y = 2
    o(i).nam = idenewtxt("File #Name")
    If mode = 2 Then
        o(i).txt = idenewtxt(programname$)
        o(i).issel = -1
        o(i).sx1 = 0
        o(i).v1 = Len(programname$)
    End If

    i = i + 1
    o(i).typ = 2
    o(i).y = 5
    o(i).w = 32: o(i).h = idewy + idesubwindow - 14
    o(i).nam = idenewtxt("#Files")
    o(i).txt = idenewtxt(filelist$): filelist$ = ""
    i = i + 1
    o(i).typ = 2
    o(i).x = 37: o(i).y = 5
    o(i).w = 31: o(i).h = idewy + idesubwindow - 16
    o(i).nam = idenewtxt("#Paths")
    o(i).txt = idenewtxt(pathlist$): pathlist$ = ""
    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 37
    o(i).y = idewy + idesubwindow - 9
    o(i).nam = idenewtxt(".#BAS Only")
    If AllFiles Then o(i).sel = 0 Else o(i).sel = 1
    prevBASOnly = o(i).sel
    i = i + 1
    o(i).typ = 3
    o(i).x = 56
    o(i).y = idewy + idesubwindow - 9
    o(i).txt = idenewtxt("Ne#w Folder")
    i = i + 1
    o(i).typ = 3
    o(i).y = idewy + idesubwindow - 7
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    If mode = 1 And Len(IdeOpenFile) > 0 Then f$ = IdeOpenFile: GoTo DirectLoad

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        Color 0, 7: _PrintString (p.x + 2, p.y + 4), "Path: "
        a$ = path$
        If Len(a$) = 2 And Right$(a$, 1) = ":" Then a$ = a$ + "\"
        w = p.w - 8
        If Len(a$) > w - 3 Then a$ = String$(3, 250) + Right$(a$, w - 3)
        _PrintString (p.x + 2 + 6, p.y + 4), a$
        '-------- end of custom display changes --------


        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt

            If mode = 1 Then
                If _TotalDroppedFiles > 0 Then
                    idetxt(o(1).txt) = _DroppedFile$(1)
                    o(1).v1 = Len(idetxt(o(1).txt))
                    focus = 1
                    _FinishDrop
                    change = 1
                End If
            End If

            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If focus = 1 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        If o(4).sel <> prevBASOnly Then
            prevBASOnly = o(4).sel
            If o(4).sel = 0 Then AllFiles = 1 Else AllFiles = 0
            idetxt(o(2).txt) = idezfilelist$(path$, AllFiles, "")
            o(2).sel = -1
            GoTo ideopenloop
        End If

        If focus = 5 And info <> 0 Then
            'create new folder
            newpath$ = idenewfolder(path$)
            If Len(newpath$) Then
                f$ = removeDoubleSlashes$(newpath$)
                GoTo changepath
            Else
                GoTo ideopenloop
            End If
        End If

        If K$ = Chr$(27) Or (focus = 7 And info <> 0) Then
            idefiledialog$ = "C"
            Exit Function
        End If

        If focus = 2 And o(2).sel <> prevFileBoxSel Then
            prevFileBoxSel = o(2).sel
            idetxt(o(1).txt) = idetxt(o(2).stx)
            o(1).issel = 0
        End If

        If focus = 3 Then
            If (K$ = Chr$(13) Or info = 1) And o(3).sel >= 1 Then
                newpath$ = removeDoubleSlashes$(idetxt(o(3).stx))
                If newpath$ = "" Then
                    newpath$ = ".."
                    f$ = newpath$
                    GoTo changepath
                Else
                    path$ = removeDoubleSlashes$(idezchangepath(path$, newpath$))
                    idetxt(o(2).txt) = idezfilelist$(path$, AllFiles, "")
                    idetxt(o(3).txt) = idezpathlist$(path$)

                    o(2).sel = -1
                    o(3).sel = 1
                    If info = 1 Then o(3).sel = -1
                    GoTo ideopenloop
                End If
            End If
        End If

        'load or save file
        If K$ = Chr$(13) Or (info = 1 And focus = 2) Or (focus = 6 And info <> 0) Then
            f$ = idetxt(o(1).txt)

            If _FileExists(f$) Then GoTo DirectLoad

            If f$ = "" And focus = 1 And K$ = Chr$(13) Then
                'reset filters
                idetxt(o(2).txt) = idezfilelist$(path$, AllFiles, "")
                o(2).sel = -1
                GoTo ideopenloop
            ElseIf f$ = "" And focus = 6 And info <> 0 Then
                GoTo ideopenloop
            End If

            'change path?
            changepath:
            If _DirExists(path$ + idepathsep$ + f$) Then
                'check/acquire file path
                path$ = removeDoubleSlashes$(idezgetfilepath$(path$, f$ + idepathsep$)) 'note: path ending with pathsep needn't contain a file
                If ideerror > 1 Then Exit Function

                If Len(newpath$) = 0 Then
                    idetxt(o(1).txt) = ""
                    focus = 1
                Else
                    newpath$ = ""
                End If
                idetxt(o(2).txt) = idezfilelist$(path$, AllFiles, "")
                o(2).sel = -1
                idetxt(o(3).txt) = idezpathlist$(path$)
                o(3).sel = -1
                GoTo ideopenloop
            End If

            'wildcards search
            If InStr(f$, "?") > 0 Or InStr(f$, "*") > 0 Then
                If InStr(f$, "/") > 0 Or InStr(f$, "\") > 0 Then
                    'path + wildcards
                    path$ = removeDoubleSlashes$(idezgetfilepath$(path$, f$)) 'note: path ending with pathsep needn't contain a file
                    If ideerror > 1 Then Exit Function
                    idetxt(o(3).txt) = idezpathlist$(path$)
                    o(3).sel = -1
                End If
                idetxt(o(1).txt) = f$
                idetxt(o(2).txt) = idezfilelist$(path$, 2, f$)
                o(2).sel = -1
                o(1).v1 = Len(idetxt(o(1).txt))
                o(1).issel = -1
                o(1).sx1 = 0
                If LCase$(Right$(f$, 4)) <> ".bas" Then
                    AllFiles = 0
                    o(4).sel = 0
                    prevBASOnly = o(4).sel
                End If
                GoTo ideopenloop
            End If

            DirectLoad:
            path$ = removeDoubleSlashes$(idezgetfilepath$(path$, f$)) 'repeat in case of DirectLoad
            If ideerror > 1 Then Exit Function

            If mode = 1 Then
                If _FileExists(path$ + idepathsep$ + f$) = 0 Then
                    'add .bas if not given
                    If (LCase$(Right$(f$, 4)) <> ".bas") And AllFiles = 0 Then f$ = f$ + ".bas"
                End If

                'check file exists
                ideerror = 2
                If _FileExists(path$ + idepathsep$ + f$) = 0 Then Exit Function

                'load file
                ideerror = 3
                idet$ = MKL$(0) + MKL$(0): idel = 1: ideli = 1: iden = 1: IdeBmkN = 0
                idesx = 1
                idesy = 1
                idecx = 1
                idecy = 1
                ideselect = 0
                idefocusline = 0
                lineinput3load path$ + idepathsep$ + f$
                idet$ = Space$(Len(lineinput3buffer) * 8)
                i2 = 1
                n = 0
                chrtab$ = Chr$(9)
                space1$ = " ": space2$ = "  ": space3$ = "   ": space4$ = "    "
                chr7$ = Chr$(7): chr11$ = Chr$(11): chr12$ = Chr$(12): chr28$ = Chr$(28): chr29$ = Chr$(29): chr30$ = Chr$(30): chr31$ = Chr$(31)
                Do
                    a$ = lineinput3$
                    l = Len(a$)
                    If l Then asca = Asc(a$) Else asca = -1
                    If asca <> 13 Then
                        If asca <> -1 Then
                            'fix tabs
                            ideopenfixtabs:
                            x = InStr(a$, chrtab$)
                            If x Then
                                x2 = (x - 1) Mod 4
                                If x2 = 0 Then a$ = Left$(a$, x - 1) + space4$ + Right$(a$, l - x): l = l + 3: GoTo ideopenfixtabs
                                If x2 = 1 Then a$ = Left$(a$, x - 1) + space3$ + Right$(a$, l - x): l = l + 2: GoTo ideopenfixtabs
                                If x2 = 2 Then a$ = Left$(a$, x - 1) + space2$ + Right$(a$, l - x): l = l + 1: GoTo ideopenfixtabs
                                If x2 = 3 Then a$ = Left$(a$, x - 1) + space1$ + Right$(a$, l - x): GoTo ideopenfixtabs
                            End If
                        End If 'asca<>-1
                        Mid$(idet$, i2, l + 8) = MKL$(l) + a$ + MKL$(l): i2 = i2 + l + 8: n = n + 1
                    End If
                Loop Until asca = 13
                lineinput3buffer = ""
                iden = n: If n = 0 Then idet$ = MKL$(0) + MKL$(0): iden = 1 Else idet$ = Left$(idet$, i2 - 1)
                ReDim IdeBreakpoints(iden) As _Byte
                ReDim IdeSkipLines(iden) As _Byte
                backupTypeDefinitions$ = ""

                ideerror = 1
                ideprogname = f$: _Title ideprogname + " - " + WindowTitle
                listOfCustomKeywords$ = Left$(listOfCustomKeywords$, customKeywordsLength)
                idepath$ = path$
                IdeAddRecent idepath$ + idepathsep$ + ideprogname$
                Exit Function
            ElseIf mode = 2 Then
                If FileHasExtension(f$) = 0 Then f$ = f$ + ".bas"

                ideerror = 3
                Open path$ + idepathsep$ + f$ For Binary As #150
                ideerror = 1
                If LOF(150) Then
                    Close #150
                    a$ = idefileexists(f$)
                    If a$ = "N" Then
                        idefiledialog$ = "C"
                        Exit Function 'user didn't agree to overwrite
                    End If
                Else
                    Close #150
                End If
                ideprogname$ = f$: _Title ideprogname + " - " + WindowTitle
                idesave path$ + idepathsep$ + f$
                idepath$ = path$
                IdeAddRecent idepath$ + idepathsep$ + ideprogname$

                Exit Function
            End If
        End If

        ideopenloop:

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop
End Function

Sub idepar (par As idedbptype, w, h, title$)
    par.x = (idewx \ 2) - w \ 2
    par.y = ((idewy + idesubwindow) \ 2) - h \ 2
    par.w = w
    par.h = h
    If Len(title$) Then par.nam = idenewtxt(title$)
    _Resize Off
End Sub

Function iderestore$
    PCopy 3, 0
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    result = idemessagebox("Backup found", "Recover program from auto-saved backup?", "#Yes;#No")
    If result = 1 Then iderestore$ = "Y" Else iderestore$ = "N"
End Function

Function ideclearhistory$ (WhichHistory$)
    Select Case WhichHistory$
        Case "SEARCH": t$ = "Clear search history": m$ = "This cannot be undone. Proceed?"
        Case "FILES": t$ = "Clear recent files": m$ = "This cannot be undone. Proceed?"
    End Select
    result = idemessagebox(t$, m$, "#Yes;#No")
    If result = 1 Then ideclearhistory$ = "Y" Else ideclearhistory$ = "N"
End Function

Sub idesave (f$)
    ideerror = 6
    Open f$ For Output As #151
    ideerror = 1
    For i = 1 To iden
        a$ = idegetline(i)
        Print #151, a$
    Next
    Close #151
    ideunsaved = 0
End Sub

Function idesavenow$
    m$ = "Program is not saved. Save it now?"
    result = idemessagebox("", m$, "#Yes;#No;#Cancel")
    Select Case result
        Case 1: idesavenow$ = "Y"
        Case 2: idesavenow$ = "N"
        Case 0, 3: idesavenow$ = "C"
    End Select
End Function

Sub idesetline (i, text$)

    text$ = RTrim$(text$)

    If i <> -1 Then idegotoline i
    textlen = Len(text$)
    idet$ = Left$(idet$, ideli - 1) + MKL$(textlen) + text$ + MKL$(textlen) + Right$(idet$, Len(idet$) - ideli + 1 - CVL(Mid$(idet$, ideli, 4)) - 8)

End Sub

Function timeElapsedSince! (startTime!)
    If startTime! > Timer Then startTime! = startTime! - 86400
    timeElapsedSince! = Timer - startTime!
End Function

Sub ideshowtext

    If ideshowtextBypassColorRestore = 0 Then
        _PaletteColor 1, IDEBackgroundColor, 0
        _PaletteColor 2, _RGB32(84, 84, 84), 0 'dark gray - help system and interface details
        _PaletteColor 5, IDEBracketHighlightColor, 0
        _PaletteColor 6, IDEBackgroundColor2, 0
        _PaletteColor 7, IDEChromaColor, 0
        _PaletteColor 8, IDENumbersColor, 0
        _PaletteColor 10, IDEMetaCommandColor, 0
        _PaletteColor 11, IDECommentColor, 0
        _PaletteColor 12, IDEKeywordColor, 0
        _PaletteColor 13, IDETextColor, 0
        _PaletteColor 14, IDEQuoteColor, 0
    End If
    ideshowtextBypassColorRestore = 0

    char.sep$ = Chr$(34) + " =<>+-/\^:;,*()'"
    initialNum.char$ = "0123456789-.&"
    num.char$ = "0123456789EDed+-.`%&!#~HBOhboACFacf"

    Dim ideshowtext_comment As _Byte, ideshowtext_quote As _Byte

    Static prevListOfCustomWords$, manualList As _Byte
    Dim startTime As Single

    startTime = Timer

    If Not DisableSyntaxHighlighter Then
        If idefocusline <> 0 Then
            'there's an error and compilation is halted,
            'so we'll build the list of subs/functions
            'for proper highlighting:
            If idechangemade Then manualList = 0
            If manualList = 0 Then
                manualList = -1
                listOfCustomKeywords$ = Left$(listOfCustomKeywords$, customKeywordsLength)
                For y = 1 To iden
                    a$ = UCase$(_Trim$(idegetline(y)))
                    sf = 0
                    If Left$(a$, 4) = "SUB " Then sf = 1
                    If Left$(a$, 9) = "FUNCTION " Then sf = 2
                    If sf Then
                        If Right$(a$, 7) = " STATIC" Then
                            a$ = RTrim$(Left$(a$, Len(a$) - 7))
                        End If

                        If sf = 1 Then
                            a$ = Mid$(a$, 5)
                        Else
                            a$ = Mid$(a$, 10)
                        End If

                        a$ = LTrim$(RTrim$(a$))
                        x = InStr(a$, "(")
                        If x Then
                            a$ = RTrim$(Left$(a$, x - 1))
                        Else
                            cleanSubName a$
                        End If
                        listOfCustomKeywords$ = listOfCustomKeywords$ + "@" + removesymbol2$(a$) + "@"
                    End If
                Next
            End If
        Else
            manualList = 0
        End If

        If prevListOfCustomWords$ <> listOfCustomKeywords$ Then
            If manualList = 0 Then
                Do
                    atSign = InStr(atSign + 1, listOfCustomKeywords$, "@")
                    nextAt = InStr(atSign + 1, listOfCustomKeywords$, "@")
                    If nextAt = 0 Then Exit Do
                    If atSign > customKeywordsLength Then
                        checkKeyword$ = removesymbol2$(Mid$(listOfCustomKeywords$, atSign + 1, (nextAt - atSign) - 1))
                        If Len(checkKeyword$) Then
                            hashchkflags = HASHFLAG_RESERVED + HASHFLAG_CONSTANT
                            hashchkflags = hashchkflags + HASHFLAG_FUNCTION
                            hashres1 = HashFind(checkKeyword$, hashchkflags, hashresflags, hashresref)
                            If hashres1 <> 0 Then hashres1 = 1
                            hashchkflags = HASHFLAG_RESERVED + HASHFLAG_CONSTANT
                            hashchkflags = hashchkflags + HASHFLAG_SUB
                            hashres2 = HashFind(checkKeyword$, hashchkflags, hashresflags, hashresref)
                            If hashres2 <> 0 Then hashres2 = 1
                            If hashres1 + hashres2 = 0 Then
                                'remove this custom keyword if not registered
                                Mid$(listOfCustomKeywords$, atSign + 1, (nextAt - atSign) - 1) = String$(Len(checkKeyword$), "@")
                            End If
                        End If
                    End If
                Loop
            End If

            For i = 1 To Len(listOfCustomKeywords$)
                checkChar = Asc(listOfCustomKeywords$, i)
                If checkChar = 64 Then
                    If Right$(tempList$, 1) <> "@" Then tempList$ = tempList$ + "@"
                Else
                    tempList$ = tempList$ + Chr$(checkChar)
                End If
            Next
            listOfCustomKeywords$ = tempList$

            Do While InStr(listOfCustomKeywords$, fix046$)
                x = InStr(listOfCustomKeywords$, fix046$)
                listOfCustomKeywords$ = Left$(listOfCustomKeywords$, x - 1) + "." + Right$(listOfCustomKeywords$, Len(listOfCustomKeywords$) - x + 1 - Len(fix046$))
            Loop

            prevListOfCustomWords$ = listOfCustomKeywords$
        End If
    End If


    cc = -1

    If idecx < idesx Then idesx = idecx
    If idecy < idesy Then idesy = idecy
    If (idecx + maxLineNumberLength) - idesx >= (idewx - 2) Then idesx = (idecx + maxLineNumberLength) - (idewx - 3)
    If idecy - idesy >= (idewy - 8) Then idesy = idecy - (idewy - 9)

    sy1 = ideselecty1
    sy2 = idecy
    If sy1 > sy2 Then Swap sy1, sy2
    sx1 = ideselectx1
    sx2 = idecx
    If sx1 > sx2 Then Swap sx1, sx2

    l = idesy
    EnteringRGB = 0

    If Not DisableSyntaxHighlighter Then
        idecy_multilinestart = 0
        idecy_multilineend = 0
        a$ = idegetline(idecy)
        FindQuoteComment a$, Len(a$), ideshowtext_comment, ideshowtext_quote
        If Right$(a$, 1) = "_" And ideshowtext_comment = 0 Then
            'Find the beginning of the multiline
            For idecy_i = idecy - 1 To 1 Step -1
                b$ = idegetline(idecy_i)
                FindQuoteComment b$, Len(b$), ideshowtext_comment, ideshowtext_quote
                If Right$(b$, 1) <> "_" Or ideshowtext_comment = -1 Then idecy_multilinestart = idecy_i + 1: Exit For
            Next
            If idecy_multilinestart = 0 Then idecy_multilinestart = 1

            'Find the end of the multiline
            For idecy_i = idecy + 1 To iden
                b$ = idegetline(idecy_i)
                FindQuoteComment b$, Len(b$), ideshowtext_comment, ideshowtext_quote
                If Right$(b$, 1) <> "_" Or ideshowtext_comment = -1 Then idecy_multilineend = idecy_i: Exit For
            Next
            If idecy_multilineend = 0 Then idecy_multilinestart = iden
        Else
            If idecy > 1 Then b$ = idegetline(idecy - 1) Else b$ = ""
            FindQuoteComment b$, Len(b$), ideshowtext_comment, ideshowtext_quote
            If Right$(b$, 1) = "_" And ideshowtext_comment = 0 Then
                idecy_multilineend = idecy

                'Find the beginning of the multiline
                For idecy_i = idecy - 1 To 1 Step -1
                    b$ = idegetline(idecy_i)
                    FindQuoteComment b$, Len(b$), ideshowtext_comment, ideshowtext_quote
                    If Right$(b$, 1) <> "_" Or ideshowtext_comment = -1 Then idecy_multilinestart = idecy_i + 1: Exit For
                Next
                If idecy_multilinestart = 0 Then idecy_multilinestart = 1
            End If
        End If

        If idecy > 1 Then b$ = idegetline(idecy - 1) Else b$ = ""

        ActiveINCLUDELink = 0

        For y = 0 To (idewy - 9)
            Color 7, 1
            _PrintString (1, y + 3), Chr$(179) 'clear prev bookmarks from lhs

            GoSub ShowLineNumber

            If (l = idefocusline And idecy <> l) Or (l = idefocusline And idecy = l) Then
                Color 7, 4 'Line with error gets a red background
            ElseIf idecy = l Or (l >= idecy_multilinestart And l <= idecy_multilineend) Then
                If HideCurrentLineHighlight = 0 And IdeSystem = 1 Then Color 7, 6 'Highlight the current line
            Else
                Color 7, 1 'Regular text color
            End If

            If l <= iden Then
                Do Until l < UBound(InValidLine) 'make certain we have enough InValidLine elements to cover us in case someone scrolls QB64
                    ReDim _Preserve InValidLine(UBound(InValidLine) + 1000) As _Byte '   to the end of a program before the IDE has finished
                Loop '                                                      verifying the code and growing the array during the IDE passes.

                a$ = idegetline(l)
                link_idecx = 0
                shiftEnter_idecx = 0
                If l = idecy Then
                    If idecx <= Len(a$) And idecx >= 1 Then
                        cc = Asc(a$, idecx)
                        If cc = 32 Then
                            If LTrim$(Left$(a$, idecx)) = "" Then cc = -1
                        End If
                    End If

                    'Check if the cursor is positioned inside a comment or
                    'quotation marks:
                    FindQuoteComment a$, idecx, ideshowtext_comment, ideshowtext_quote
                    idecx_comment = ideshowtext_comment
                    idecx_quote = ideshowtext_quote

                    'Check if we're on a bracket, to highlight it and its match
                    brackets = 0
                    bracket1 = 0
                    bracket2 = 0
                    If idecx_comment + idecx_quote = 0 And brackethighlight = -1 Then
                        inquote = 0
                        comment = 0
                        If Mid$(a$, idecx, 1) = "(" Then
                            brackets = 1
                            bracket1 = idecx
                            ScanBracket2:
                            For k = bracket1 + 1 To Len(a$)
                                Select Case Mid$(a$, k, 1)
                                    Case Chr$(34)
                                        inquote = Not inquote
                                    Case "'"
                                        If inquote = 0 Then comment = -1: Exit For
                                End Select
                                If Mid$(a$, k, 1) = ")" And inquote = 0 Then
                                    brackets = brackets - 1
                                    If brackets = 0 Then bracket2 = k: Exit For
                                ElseIf Mid$(a$, k, 1) = "(" And inquote = 0 Then
                                    brackets = brackets + 1
                                End If
                            Next
                        ElseIf Mid$(a$, idecx - 1, 1) = "(" And Mid$(a$, idecx, 1) <> Chr$(34) Then
                            brackets = 1
                            bracket1 = idecx - 1
                            GoTo ScanBracket2
                        ElseIf Mid$(a$, idecx, 1) = ")" Then
                            brackets = 1
                            bracket2 = idecx
                            ScanBracket1:
                            For k = bracket2 - 1 To 1 Step -1
                                Select Case Mid$(a$, k, 1)
                                    Case Chr$(34)
                                        inquote = Not inquote
                                End Select
                                If Mid$(a$, k, 1) = "(" And inquote = 0 Then
                                    brackets = brackets - 1
                                    If brackets = 0 Then bracket1 = k: Exit For
                                ElseIf Mid$(a$, k, 1) = ")" And inquote = 0 Then
                                    brackets = brackets + 1
                                End If
                            Next
                        ElseIf Mid$(a$, idecx - 1, 1) = ")" And Mid$(a$, idecx, 1) <> Chr$(34) Then
                            brackets = 1
                            bracket2 = idecx - 1
                            GoTo ScanBracket1
                        End If
                    End If

                    'If the user is typing on the current line and has just inserted
                    'an _RGB(, _RGB32(, _RGBA( or _RGBA32(, we'll offer the RGB
                    'color mixer.
                    a2$ = UCase$(a$)
                    If idecx = Len(a$) + 1 And idecx_comment + idecx_quote = 0 Then
                        IF (RIGHT$(a2$, 5) = "_RGB(" OR _
                           RIGHT$(a2$, 7) = "_RGB32(" OR _
                           RIGHT$(a2$, 6) = "_RGBA(" OR _
                           RIGHT$(a2$, 8) = "_RGBA32(") THEN
                            shiftEnter_idecx = Len(a$)
                            a$ = a$ + " --> Shift+ENTER to open the RGB mixer"
                            EnteringRGB = -1
                        End If
                    ElseIf idecx_comment + idecx_quote = 0 Then
                        IF (MID$(a2$, idecx - 5, 5) = "_RGB(" OR _
                           MID$(a2$, idecx - 7, 7) = "_RGB32(" OR _
                           MID$(a2$, idecx - 6, 6) = "_RGBA(" OR _
                           MID$(a2$, idecx - 8, 8) = "_RGBA32(")  THEN
                            If InStr("0123456789", Mid$(a2$, idecx, 1)) = 0 Then EnteringRGB = -1
                        End If
                    End If

                    FindInclude = _InStrRev(a2$, "$INCLUDE")
                    If FindInclude > 0 Then
                        link_idecx = Len(a$)
                        FindApostrophe1 = InStr(FindInclude + 8, a2$, "'")
                        FindApostrophe2 = InStr(FindApostrophe1 + 1, a2$, "'")
                        ActiveINCLUDELinkFile = Mid$(a$, FindApostrophe1 + 1, FindApostrophe2 - FindApostrophe1 - 1)
                        p$ = idepath$ + pathsep$
                        f$ = p$ + ActiveINCLUDELinkFile
                        If _FileExists(f$) Or _FileExists(ActiveINCLUDELinkFile) Then
                            a$ = a$ + " --> Double-click to open": ActiveINCLUDELink = idecy
                        End If
                    End If
                End If 'l = idecy

                a2$ = Space$(idesx + (idewx - 3))
                Mid$(a2$, 1) = a$
            Else
                a2$ = Space$((idewx - 2))
            End If

            'Syntax highlighter
            inquote = 0
            metacommand = 0
            comment = 0
            isKeyword = 0: oldChar$ = ""
            isCustomKeyword = 0
            multiHighlightLength = 0
            prevBG% = _BackgroundColor

            For m = 1 To Len(a2$) 'print to the screen while checking required color changes
                If timeElapsedSince(startTime) > 1 Then
                    result = idemessagebox("Syntax Highlighter Disabled", "Syntax Highlighter has been disabled to avoid slowing down the IDE.\nYou can reenable the Highlighter in the 'Options' menu.", "")
                    DisableSyntaxHighlighter = -1
                    WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "True"
                    menu$(OptionsMenuID, OptionsMenuDisableSyntax) = "Syntax #Highlighter"
                    GoTo noSyntaxHighlighting
                End If
                If m > idesx + idewx - 2 Then Exit For 'stop printing when off screen
                If ideselect = 1 And Len(ideCurrentSingleLineSelection) > 0 And multiHighlightLength = 0 And multihighlight = -1 Then
                    If LCase$(Mid$(a2$, m, Len(ideCurrentSingleLineSelection))) = LCase$(ideCurrentSingleLineSelection) Then
                        'the current selection was found at this spot. Multi-highlight takes place:
                        If m > 1 Then
                            If InStr(char.sep$, Mid$(a2$, m - 1, 1)) > 0 Then
                                IF m + LEN(ideCurrentSingleLineSelection) < LEN(a2$) AND _
                                    (INSTR(char.sep$, MID$(a2$, m + LEN(ideCurrentSingleLineSelection), 1)) > 0 OR _
                                     MID$(a2$, m + LEN(ideCurrentSingleLineSelection), 1) = ".") THEN
                                    multiHighlightLength = Len(ideCurrentSingleLineSelection)
                                ElseIf m + Len(ideCurrentSingleLineSelection) >= Len(a2$) Then
                                    multiHighlightLength = Len(ideCurrentSingleLineSelection)
                                End If
                            End If
                        Else
                            IF m + LEN(ideCurrentSingleLineSelection) < LEN(a2$) AND _
                                (INSTR(char.sep$, MID$(a2$, m + LEN(ideCurrentSingleLineSelection), 1)) > 0 OR _
                                 MID$(a2$, m + LEN(ideCurrentSingleLineSelection), 1) = ".") THEN
                                multiHighlightLength = Len(ideCurrentSingleLineSelection)
                            ElseIf m + Len(ideCurrentSingleLineSelection) >= Len(a2$) Then
                                multiHighlightLength = Len(ideCurrentSingleLineSelection)
                            End If
                        End If
                    End If
                End If

                thisChar$ = Mid$(a2$, m, 1)

                If comment = 0 Then
                    Select Case thisChar$
                        Case Chr$(34): inquote = Not inquote
                        Case "'": If inquote = 0 Then comment = -1
                    End Select
                End If

                Color 13

                If InValidLine(l) Then Color 7: GoTo SkipSyntaxHighlighter

                If (Len(oldChar$) > 0 Or m = 1) And inquote = 0 And isKeyword = 0 Then
                    If InStr(initialNum.char$, thisChar$) > 0 And oldChar$ <> ")" And (InStr(char.sep$, oldChar$) > 0 Or oldChar$ = "?") Then
                        'a number literal
                        checkKeyword$ = ""
                        is_Number = 0

                        For i = m To Len(a2$)
                            If InStr(num.char$, Mid$(a2$, i, 1)) = 0 Then Exit For
                            checkKeyword$ = checkKeyword$ + Mid$(a2$, i, 1)
                        Next

                        If checkKeyword$ = "-" Or checkKeyword$ = "." Or checkKeyword$ = "&" Then
                            checkKeyword$ = ""
                        Else
                            If isnumber(checkKeyword$) Then
                                is_Number = -1
                                isKeyword = Len(checkKeyword$)
                            ElseIf InStr(UserDefineList, "@" + UCase$(checkKeyword$)) > 0 Then
                                'keep checking
                                For i = i To Len(a2$)
                                    If InStr(char.sep$, Mid$(a2$, i, 1)) > 0 Then right.sep$ = Mid$(a2$, i, 1): GoTo keywordAcquired
                                    checkKeyword$ = checkKeyword$ + Mid$(a2$, i, 1)
                                Next
                                GoTo keywordAcquired
                            End If
                        End If
                        GoTo setOldChar
                    End If

                    If (InStr(char.sep$, oldChar$) > 0 Or oldChar$ = "?") And InStr(char.sep$, thisChar$) = 0 Then
                        'a new "word" begins; check if it's an internal keyword
                        checkKeyword$ = ""
                        right.sep$ = ""
                        For i = m To Len(a2$)
                            If InStr(char.sep$, Mid$(a2$, i, 1)) > 0 Then right.sep$ = Mid$(a2$, i, 1): Exit For
                            checkKeyword$ = checkKeyword$ + Mid$(a2$, i, 1)
                        Next
                        If comment = 0 And Left$(checkKeyword$, 1) = "?" Then isKeyword = 1: GoTo setOldChar
                        keywordAcquired:
                        checkKeyword$ = UCase$(checkKeyword$)
                        If InStr(listOfKeywords$, "@" + checkKeyword$ + "@") > 0 Then
                            'special cases
                            If checkKeyword$ = "$END" Then
                                If UCase$(Mid$(a2$, m, 7)) = "$END IF" Then checkKeyword$ = "$END IF"
                            ELSEIF checkKeyword$ = "THEN" AND _
                                    (UCASE$(LEFT$(LTRIM$(a2$), 3)) = "$IF" OR _
                                    UCASE$(LEFT$(LTRIM$(a2$), 7)) = "$ELSEIF") THEN
                                metacommand = -1
                            ElseIf checkKeyword$ = "$ASSERTS" Then
                                If UCase$(_Trim$(a2$)) = "$ASSERTS:CONSOLE" Then
                                    checkKeyword$ = "$ASSERTS:CONSOLE"
                                End If
                            End If
                            isKeyword = Len(checkKeyword$)
                        ElseIf InStr(listOfCustomKeywords$, "@" + removesymbol2$(checkKeyword$) + "@") > 0 Then
                            isCustomKeyword = -1
                            isKeyword = Len(checkKeyword$)
                        ELSEIF INSTR(UserDefineList, "@" + checkKeyword$ + "@") > 0 AND _
                                (UCASE$(LEFT$(LTRIM$(a2$), 3)) = "$IF" OR _
                                UCASE$(LEFT$(LTRIM$(a2$), 7)) = "$ELSEIF") THEN
                            isCustomKeyword = -1
                            isKeyword = Len(checkKeyword$)
                        End If
                    End If
                End If
                setOldChar:
                oldChar$ = thisChar$

                If isKeyword > 0 And keywordHighlight Then
                    If is_Number Then
                        Color 8
                    ElseIf isCustomKeyword Then
                        Color 10
                    Else
                        Color 12
                    End If
                    If Left$(checkKeyword$, 1) = "$" Then metacommand = -1
                End If

                If comment Then
                    Color 11
                    If metacommand Then
                        Select Case checkKeyword$
                            Case "$INCLUDE"
                                If InStr(m + 1, UCase$(a2$), checkKeyword$) = 0 Then Color 10
                            Case "$DYNAMIC", "$STATIC"
                                If InStr(m + 1, UCase$(a2$), "$DYNAMIC") = 0 And InStr(m + 1, UCase$(a2$), "$STATIC") = 0 Then Color 10
                        End Select
                    End If
                ElseIf metacommand Then
                    Color 10
                ElseIf inquote Or thisChar$ = Chr$(34) Then
                    Color 14
                End If

                SkipSyntaxHighlighter:

                If l = idecy And (link_idecx > 0 And m > link_idecx) Then Color 10
                If (shiftEnter_idecx > 0 And m > shiftEnter_idecx) Then Color 10

                If l = idecy And (m = bracket1 Or m = bracket2) Then
                    Color , 5
                ElseIf multiHighlightLength > 0 And multihighlight = -1 Then
                    multiHighlightLength = multiHighlightLength - 1
                    Color , 5
                Else
                    Color , prevBG%
                End If

                If ShowLineNumbers Then
                    If (2 + m - idesx) + maxLineNumberLength >= 2 + maxLineNumberLength And (2 + m - idesx) + maxLineNumberLength < idewx Then
                        _PrintString ((2 + m - idesx) + maxLineNumberLength, y + 3), thisChar$
                    End If
                Else
                    If 2 + m - idesx >= 2 And 2 + m - idesx < idewx Then
                        _PrintString (2 + m - idesx, y + 3), thisChar$
                    End If
                End If

                'Restore BG color in case a matching bracket was printed with different BG
                If l = idecy Then Color , 6
                If isKeyword > 0 Then isKeyword = isKeyword - 1
                If isKeyword = 0 Then checkKeyword$ = "": metacommand = 0: is_Number = 0: isCustomKeyword = 0
            Next m

            'apply selection color change if necessary
            If (IdeSystem = 1 Or IdeSystem = 2) And ideselect <> 0 Then
                If l >= sy1 And l <= sy2 Then
                    If sy1 = sy2 Then 'single line select
                        Color 1, 7
                        x2 = idesx
                        For x = 2 + maxLineNumberLength To (idewx - 1)
                            If x2 >= sx1 And x2 < sx2 Then
                                a = Screen(y + 3, x)

                                If a = 63 Then '"?"
                                    c = Screen(y + 3, x, 1)
                                Else
                                    c = 1
                                End If
                                If (c And 15) = 0 Then 'black background
                                    Color 0, 7
                                    _PrintString (x, y + 3), "?"
                                    Color 1, 7
                                Else
                                    _PrintString (x, y + 3), Chr$(a)
                                End If


                            End If
                            x2 = x2 + 1
                        Next
                        Color 7, 1
                    Else 'multiline select
                        If idecx = 1 And l = sy2 And idecy > sy1 Then GoTo nofinalselect
                        Locate y + 3, 2 + maxLineNumberLength
                        Color 1, 7

                        For x = idesx To idesx + idewx - (2 + maxLineNumberLength)
                            Print Mid$(a2$, x, 1);
                        Next

                        Color 7, 1
                        nofinalselect:
                    End If
                End If
            End If

            l = l + 1
        Next
    Else
        noSyntaxHighlighting:
        'original SUB ideshowtext routine:
        Color 13, 1
        l = idesy
        For y = 0 To (idewy - 9)
            Color 7, 1
            _PrintString (1, y + 3), Chr$(179) 'clear prev bookmarks from lhs

            GoSub ShowLineNumber

            If l = idefocusline And idecy <> l Then Color 13, 4 Else Color 13, 1

            If l <= iden Then
                a$ = idegetline(l)
                a2$ = Space$(idesx + (idewx - 3) - maxLineNumberLength)
                Mid$(a2$, 1) = a$
                a2$ = Right$(a2$, (idewx - 2) - maxLineNumberLength)
            Else
                a2$ = Space$((idewx - 2) - maxLineNumberLength)
            End If
            _PrintString (2 + maxLineNumberLength, y + 3), a2$

            If l = idecy Then
                If idecx <= Len(a$) And idecx >= 1 Then
                    cc = Asc(a$, idecx)
                    If cc = 32 Then
                        If LTrim$(Left$(a$, idecx)) = "" Then cc = -1
                    End If
                End If
            End If

            'apply selection color change if necessary
            If ideselect Then
                If l >= sy1 And l <= sy2 Then
                    If sy1 = sy2 Then 'single line select
                        Color 1, 7
                        x2 = idesx
                        For x = 2 + maxLineNumberLength To (idewx - 1)
                            If x2 >= sx1 And x2 < sx2 Then
                                a = Screen(y + 3, x): _PrintString (x, y + 3), Chr$(a)
                            End If
                            x2 = x2 + 1
                        Next
                        Color 7, 1
                    Else 'multiline select
                        If idecx = 1 And l = sy2 And idecy > sy1 Then GoTo nofinalselect0
                        Color 1, 7: _PrintString (2 + maxLineNumberLength, y + 3), a2$
                        Color 7, 1
                        nofinalselect0:
                    End If
                End If
            End If

            l = l + 1
        Next
    End If

    Color 7, 1
    For b = 1 To IdeBmkN
        y = IdeBmk(b).y
        If y >= idesy And y <= idesy + (idewy - 9) Then
            _PrintString (1, 3 + y - idesy), Chr$(197)
        End If
    Next

    q = idevbar(idewx, 3, (idewy - 8), idecy, iden)
    q = idehbar(2, (idewy - 5), (idewx - 2), idesx, 608)

    'update cursor pos in status bar
    Color 0, 3
    a$ = Space$(10)
    b$ = ""
    RSet a$ = LTrim$(Str$(idecy))
    If idecx < 100000 Then
        b$ = Space$(10)
        c$ = LTrim$(Str$(idecx))
        If cc <> -1 Then c$ = c$ + "(" + str2$(cc) + ")"
        LSet b$ = c$
    End If
    lineNumberStatus$ = a$ + ":" + b$
    _PrintString (idewx - 20, idewy + idesubwindow), lineNumberStatus$

    Screen , , 0, 0: Locate idecy - idesy + 3, maxLineNumberLength + idecx - idesx + 2: Screen , , 3, 0

    Exit Sub
    ShowLineNumber:
    Do While l > UBound(IdeBreakpoints)
        ReDim _Preserve IdeBreakpoints(UBound(IdeBreakpoints) + 100) As _Byte
    Loop

    Do While l > UBound(IdeSkipLines)
        ReDim _Preserve IdeSkipLines(UBound(IdeSkipLines) + 100) As _Byte
    Loop

    If ShowLineNumbers Then
        If ShowLineNumbersUseBG Then Color , 6
        If (searchStringFoundOn > 0 And searchStringFoundOn = l) Then
            Color 13, 5
            If searchStringFoundOn > 0 And searchStringFoundOn = l Then searchStringFoundOn = 0
        End If
        _PrintString (2, y + 3), Space$(maxLineNumberLength)
        If l <= iden Then
            l2$ = Str$(l)
            If 2 + maxLineNumberLength - (Len(l2$) + 1) >= 2 Then
                _PrintString (2 + maxLineNumberLength - (Len(l2$) + 1), y + 3), l2$
            End If
        End If
        If ShowLineNumbersSeparator Then
            _PrintString (1 + maxLineNumberLength, y + 3), Chr$(179)
        End If
        Color , 1
    End If
    Return
End Sub

Function idesubs$

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '------- identify word or character at current cursor position
    a2$ = UCase$(getWordAtCursor$)
    If Len(a2$) > 1 Then
        Do Until alphanumeric(Asc(Right$(a2$, 1)))
            a2$ = Left$(a2$, Len(a2$) - 1) 'removes sigil, if any
            If Len(a2$) = 0 Then Exit Do
        Loop
    End If

    '-------- init --------

    l$ = ideprogname$
    If l$ = "" Then l$ = "Untitled" + tempfolderindexstr$

    If idewx < 100 Then
        moduleNameLenLimit = 20
    Else
        moduleNameLenLimit = 42
    End If

    maxModuleNameLen = Len(l$)
    If maxModuleNameLen > moduleNameLenLimit + 2 Then
        l$ = Left$(l$, moduleNameLenLimit - 1) + String$(3, 250)
        maxModuleNameLen = moduleNameLenLimit
    ElseIf maxModuleNameLen < 10 Then
        maxModuleNameLen = 10
    End If

    ly$ = MKL$(1)
    lySorted$ = ly$
    CurrentlyViewingWhichSUBFUNC = 1
    PreferCurrentCursorSUBFUNC = 0
    InsideDECLARE = 0
    FoundExternalSUBFUNC = 0
    maxLineCount = 0

    ReDim SortedSubsList(1 To 100) As String * 998
    ReDim CaseBkpSubsList(1 To 100) As String * 998
    ReDim TotalLines(0 To 100) As Long
    ReDim SubNames(0 To 100) As String
    ReDim SubLines(0 To 100) As Long
    ReDim Args(0 To 100) As String
    ReDim SF(0 To 100) As String

    TotalSUBs = 0
    ModuleSize = 0 'in lines
    SortedSubsFlag = idesortsubs
    SubClosed = 0

    For y = 1 To iden
        a$ = idegetline(y)
        If SubClosed = 0 Then ModuleSize = ModuleSize + 1
        a$ = LTrim$(RTrim$(a$))
        sf = 0
        nca$ = UCase$(a$)
        If Left$(nca$, 8) = "DECLARE " And InStr(nca$, " LIBRARY") > 0 Then InsideDECLARE = -1
        If Left$(nca$, 11) = "END DECLARE" Then InsideDECLARE = 0
        If Left$(nca$, 4) = "SUB " Then sf = 1: sf$ = "SUB   "
        If Left$(nca$, 9) = "FUNCTION " Then sf = 2: sf$ = "FUNC  "
        If sf Then
            'Resize SortedSubsList() and helper arrays
            TotalSUBs = TotalSUBs + 1
            If Not InsideDECLARE Then LastOpenSUB = TotalSUBs
            If TotalSUBs > UBound(SortedSubsList) Then
                ReDim _Preserve SortedSubsList(1 To TotalSUBs + 99) As String * 998
                ReDim _Preserve CaseBkpSubsList(1 To TotalSUBs + 99) As String * 998
                ReDim _Preserve TotalLines(0 To TotalSUBs + 99) As Long
                ReDim _Preserve SubNames(0 To TotalSUBs + 99) As String
                ReDim _Preserve SubLines(0 To TotalSUBs + 99) As Long
                ReDim _Preserve Args(0 To TotalSUBs + 99) As String
                ReDim _Preserve SF(0 To TotalSUBs + 99) As String
            End If

            If Right$(nca$, 7) = " STATIC" Then
                a$ = RTrim$(Left$(a$, Len(a$) - 7))
            End If

            'Store line number
            ly$ = ly$ + MKL$(y)

            'Check if the cursor is currently inside this SUB/FUNCTION to position the
            'selection properly in the list.
            If idecy >= y And Not InsideDECLARE Then
                CurrentlyViewingWhichSUBFUNC = (Len(ly$) / 4)
            End If
            'End of current SUB/FUNCTION check

            If sf = 1 Then
                a$ = Right$(a$, Len(a$) - 4)
            Else
                a$ = Right$(a$, Len(a$) - 9)
            End If
            a$ = LTrim$(RTrim$(a$))
            x = InStr(a$, "(")
            Dim comment As _Byte, quote As _Byte
            If x Then FindQuoteComment a$, x, comment, quote
            If x > 0 And comment = 0 And quote = 0 Then
                n$ = RTrim$(Left$(a$, x - 1))
                args$ = Right$(a$, Len(a$) - x + 1)
                x = 1
                For i = 2 To Len(args$)
                    If Asc(args$, i) = 40 Then x = x + 1
                    If Asc(args$, i) = 41 Then x = x - 1
                    If x = 0 Then args$ = Left$(args$, i): Exit For
                Next
            Else
                n$ = a$
                args$ = "()"
            End If
            cleanSubName n$
            If Len(n$) > maxModuleNameLen Then maxModuleNameLen = Len(n$)
            If maxModuleNameLen > moduleNameLenLimit Then maxModuleNameLen = moduleNameLenLimit

            'If the user currently has the cursor over a SUB/FUNC name, let's highlight it
            'instead of the currently in edition, for a quick link functionality:
            n2$ = n$
            If Len(n2$) > 1 Then
                Do Until alphanumeric(Asc(Right$(n2$, 1)))
                    n2$ = Left$(n$, Len(n2$) - 1) 'removes sigil, if any
                Loop
            End If
            If a2$ = UCase$(n2$) Then PreferCurrentCursorSUBFUNC = (Len(ly$) / 4)

            If InsideDECLARE = -1 Then
                n$ = "*" + n$
                FoundExternalSUBFUNC = -1
            Else
                If SubClosed = 0 Then ModuleSize = 0: GoSub AddLineCount
                SubClosed = 0
                ModuleSize = 0
            End If

            'Populate arrays
            SubNames(TotalSUBs) = n$
            SubLines(TotalSUBs) = y
            Args(TotalSUBs) = args$
            SF(TotalSUBs) = sf$
        Else 'no sf
            'remove double spaces
            i = InStr(nca$, "  ")
            Do While i > 0
                nca$ = Left$(nca$, i) + Mid$(nca$, i + 2)
                i = InStr(i, nca$, "  ")
            Loop

            cursor = 0
            LookForENDSUB:
            sf = InStr(cursor + 1, nca$, "END SUB")
            If sf = 0 Then sf = InStr(cursor + 1, nca$, "END FUNCTION")

            If sf Then
                FindQuoteComment nca$, sf, comment, quote
                If comment Or quote Then cursor = sf: GoTo LookForENDSUB
                GoSub AddLineCount
            End If
        End If
    Next

    If SubClosed = 0 Then GoSub AddLineCount

    'fix arrays to remove empty items
    If TotalSUBs > 0 And TotalSUBs < UBound(SortedSubsList) Then
        ReDim _Preserve SortedSubsList(1 To TotalSUBs) As String * 998
        ReDim _Preserve CaseBkpSubsList(1 To TotalSUBs) As String * 998
        ReDim _Preserve TotalLines(0 To TotalSUBs) As Long
        ReDim _Preserve SubNames(0 To TotalSUBs) As String
        ReDim _Preserve SubLines(0 To TotalSUBs) As Long
        ReDim _Preserve Args(0 To TotalSUBs) As String
        ReDim _Preserve SF(0 To TotalSUBs) As String
    End If

    'build headers (normal, sorted, normal with line count, sorted with line count)
    If TotalSUBs > 0 Then
        If Len(LTrim$(Str$(maxLineCount))) <= 10 Then
            maxLineCountSpace = 10
            linesHeader$ = "Line count"
            external$ = "external"
        End If
        If Len(LTrim$(Str$(maxLineCount))) <= 5 Then
            maxLineCountSpace = 5
            linesHeader$ = "Lines"
            external$ = Chr$(196)
        End If

        l$ = l$ + Space$((maxModuleNameLen + 2) - Len(l$))
        lSized$ = l$
        lSortedSized$ = l$
        l$ = l$ + "  Type  Arguments"
        lSorted$ = l$
        lSorted$ = l$
        lSized$ = lSized$ + "  " + linesHeader$ + "  Type  Arguments" + sep
        lSortedSized$ = lSortedSized$ + "  " + linesHeader$ + "  Type  Arguments"
    Else
        l$ = ideprogname$
        If l$ = "" Then l$ = "Untitled" + tempfolderindexstr$
        lSized$ = l$
    End If

    'build lists
    dialogWidth = 50
    argsLength = 2
    For x = 1 To TotalSUBs
        n$ = SubNames(x)
        If Len(n$) > maxModuleNameLen Then
            n$ = Left$(n$, maxModuleNameLen - 3) + String$(3, 250)
        Else
            n$ = n$ + Space$(maxModuleNameLen - Len(n$))
        End If

        args$ = Args(x)
        If Len(args$) > argsLength Then argsLength = Len(args$)
        If Len(args$) <= (idewx - 41) Then
            args$ = args$ + Space$((idewx - 41) - Len(args$))
        Else
            args$ = Left$(args$, (idewx - 44)) + String$(3, 250)
        End If

        sf$ = SF(x)

        l$ = l$ + sep + CHR$(195) + CHR$(196) + n$ + "  " + CHR$(16) + CHR$(2) + _
             sf$ + CHR$(16) + CHR$(16) + args$

        If TotalLines(x) = 0 Then num$ = external$ Else num$ = LTrim$(Str$(TotalLines(x)))
        lSized$ = lSized$ + CHR$(195) + CHR$(196) + n$ + "  " + _
                  CHR$(16) + CHR$(2) + SPACE$(maxLineCountSpace - LEN(num$)) + num$ + "  " _
                  + sf$ + CHR$(16) + CHR$(16) + args$ + sep

        listItem$ = n$ + "  " + Chr$(1) + Chr$(16) + Chr$(2) + sf$ + Chr$(16) + Chr$(16) + args$
        ListItemLength = Len(listItem$)
        SortedSubsList(x) = UCase$(listItem$)
        CaseBkpSubsList(x) = listItem$
        Mid$(CaseBkpSubsList(x), 992, 6) = MKL$(SubLines(x)) + MKI$(ListItemLength)
        Mid$(SortedSubsList(x), 992, 6) = MKL$(SubLines(x)) + MKI$(ListItemLength)
    Next

    Mid$(l$, _InStrRev(l$, Chr$(195)), 1) = Chr$(192)
    Mid$(lSized$, _InStrRev(lSized$, Chr$(195)), 1) = Chr$(192)

    If TotalSUBs > 1 Then
        sort SortedSubsList()

        For x = 1 To TotalSUBs
            ListItemLength = CVI(Mid$(SortedSubsList(x), Len(SortedSubsList(x)) - 2, 2))
            lySorted$ = lySorted$ + Mid$(SortedSubsList(x), Len(SortedSubsList(x)) - 6, 4)
            For RestoreCaseBkp = 1 To TotalSUBs
                If Mid$(SortedSubsList(x), Len(SortedSubsList(x)) - 6, 4) = Mid$(CaseBkpSubsList(RestoreCaseBkp), Len(CaseBkpSubsList(RestoreCaseBkp)) - 6, 4) Then
                    lSorted$ = lSorted$ + sep + Chr$(195) + Chr$(196)
                    temp$ = Left$(CaseBkpSubsList(RestoreCaseBkp), ListItemLength)
                    lSorted$ = lSorted$ + LEFT$(temp$, INSTR(temp$, CHR$(1)) - 1) + _
                               MID$(temp$, INSTR(temp$, CHR$(1)) + 1)

                    num$ = LTrim$(Str$(TotalLines(RestoreCaseBkp)))
                    If Left$(temp$, 1) = "*" Then num$ = external$
                    lSortedSized$ = lSortedSized$ + sep + Chr$(195) + Chr$(196)
                    lSortedSized$ = lSortedSized$ + LEFT$(temp$, INSTR(temp$, CHR$(1)) - 1) + _
                                    SPACE$(maxLineCountSpace - LEN(num$)) + CHR$(16) + CHR$(2) + num$ + "  " + _
                                    MID$(temp$, INSTR(temp$, CHR$(1)) + 1)
                    Exit For
                End If
            Next
        Next

        Mid$(lSorted$, _InStrRev(lSorted$, Chr$(195)), 1) = Chr$(192)
        Mid$(lSortedSized$, _InStrRev(lSortedSized$, Chr$(195)), 1) = Chr$(192)
        SortedSubsFlag = idesortsubs
    Else
        SortedSubsFlag = 0 'Override idesortsubs if the current program doesn't have more than 1 subprocedure
    End If

    '72,19
    i = 0
    dialogHeight = TotalSUBs + 4
    If dialogHeight > idewy + idesubwindow - 6 Then
        dialogHeight = idewy + idesubwindow - 6
    End If

    If argsLength + maxModuleNameLen + maxLineCountSpace + 20 > dialogWidth Then dialogWidth = argsLength + maxModuleNameLen + maxLineCountSpace + 20
    If dialogWidth > idewx - 8 Then dialogWidth = idewx - 8

    idepar p, dialogWidth, dialogHeight, "SUBs"

    i = i + 1
    o(i).typ = 2
    o(i).y = 1
    '68
    o(i).w = dialogWidth - 4: o(i).h = dialogHeight - 3
    If SortedSubsFlag = 0 Then
        If IDESubsLength Then
            o(i).txt = idenewtxt(lSized$)
        Else
            o(i).txt = idenewtxt(l$)
        End If

        If PreferCurrentCursorSUBFUNC <> 0 Then
            o(i).sel = PreferCurrentCursorSUBFUNC
        Else
            o(i).sel = CurrentlyViewingWhichSUBFUNC
        End If
    Else
        idetxt(o(i).txt) = lSorted$
        If IDESubsLength Then
            o(i).txt = idenewtxt(lSortedSized$)
        Else
            o(i).txt = idenewtxt(lSorted$)
        End If
        If PreferCurrentCursorSUBFUNC <> 0 Then
            For x = 1 To TotalSUBs
                If Mid$(ly$, PreferCurrentCursorSUBFUNC * 4 - 3, 4) = Mid$(SortedSubsList(x), Len(SortedSubsList(x)) - 6, 4) Then
                    o(i).sel = x + 1 'The sorted list items array doesn't contain the first line (ideprogname$)
                    Exit For
                End If
            Next
        Else
            For x = 1 To TotalSUBs
                If Mid$(ly$, CurrentlyViewingWhichSUBFUNC * 4 - 3, 4) = Mid$(SortedSubsList(x), Len(SortedSubsList(x)) - 6, 4) Then
                    o(i).sel = x + 1 'The sorted list items array doesn't contain the first line (ideprogname$)
                    Exit For
                End If
            Next
        End If
    End If
    o(i).nam = idenewtxt("Program Items")

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 2
    o(i).y = dialogHeight
    o(i).nam = idenewtxt("#Line Count")
    o(i).sel = IDESubsLength

    i = i + 1
    o(i).typ = 4 'check box
    o(i).x = 18
    o(i).y = dialogHeight
    o(i).nam = idenewtxt("#Sort")
    o(i).sel = SortedSubsFlag

    i = i + 1
    o(i).typ = 3
    o(i).w = 26
    o(i).x = dialogWidth - 22
    o(i).y = dialogHeight
    o(i).txt = idenewtxt("#Edit" + sep + "#Cancel")
    o(i).dft = 1


    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object

                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        If FoundExternalSUBFUNC Then
            Color 2, 7
            _PrintString (p.x + p.w - 32, p.y + p.h), "* external"
        End If
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        If K$ = Chr$(27) Or (focus = 5 And info <> 0) Then
            idesubs$ = "C"
            GoSub SaveSortSettings
            ClearMouse
            Exit Function
        End If

        If K$ = Chr$(13) Or (focus = 4 And info <> 0) Or (info = 1 And focus = 1) Then
            y = o(1).sel
            If y < 1 Then y = -y
            AddQuickNavHistory
            If SortedSubsFlag = 0 Then
                idecy = CVL(Mid$(ly$, y * 4 - 3, 4))
            Else
                idecy = CVL(Mid$(lySorted$, y * 4 - 3, 4))
            End If
            idesy = idecy
            idecx = 1
            idesx = 1

            GoSub SaveSortSettings
            ClearMouse
            Exit Function
        End If

        If o(2).sel <> IDESubsLength Then
            IDESubsLength = o(2).sel
            If IDESubsLength Then
                If o(3).sel Then
                    idetxt(o(1).txt) = lSortedSized$
                Else
                    idetxt(o(1).txt) = lSized$
                End If
            Else
                If o(3).sel Then
                    idetxt(o(1).txt) = lSorted$
                Else
                    idetxt(o(1).txt) = l$
                End If
            End If
            focus = 1
        End If

        If TotalSUBs > 1 Then
            If o(3).sel <> SortedSubsFlag Then
                SortedSubsFlag = o(3).sel

                If SortedSubsFlag = 0 Then
                    'Replace list contents with unsorted version while mantaining current selection.
                    PreviousSelection = -1
                    If o(1).sel > 0 Then
                        TargetSourceLine$ = Mid$(lySorted$, o(1).sel * 4 - 3, 4)
                        For x = 1 To TotalSUBs
                            If Mid$(ly$, x * 4 - 3, 4) = TargetSourceLine$ Then
                                PreviousSelection = x
                            End If
                        Next
                    End If

                    If IDESubsLength Then
                        idetxt(o(1).txt) = lSized$
                    Else
                        idetxt(o(1).txt) = l$
                    End If
                    o(1).sel = PreviousSelection
                    focus = 1
                Else
                    'Replace list contents with sorted version while mantaining current selection.
                    PreviousSelection = -1
                    If o(1).sel > 0 Then
                        TargetSourceLine$ = Mid$(ly$, o(1).sel * 4 - 3, 4)
                        For x = 1 To TotalSUBs
                            If Mid$(lySorted$, x * 4 - 3, 4) = TargetSourceLine$ Then
                                PreviousSelection = x
                            End If
                        Next
                    End If

                    If IDESubsLength Then
                        idetxt(o(1).txt) = lSortedSized$
                    Else
                        idetxt(o(1).txt) = lSorted$
                    End If
                    o(1).sel = PreviousSelection
                    focus = 1
                End If
            End If
        End If

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop

    Exit Function
    SaveSortSettings:
    idesortsubs = SortedSubsFlag
    If idesortsubs Then
        WriteConfigSetting displaySettingsSection$, "IDE_SortSUBs", "True"
    Else
        WriteConfigSetting displaySettingsSection$, "IDE_SortSUBs", "False"
    End If

    If IDESubsLength Then
        WriteConfigSetting displaySettingsSection$, "IDE_SUBsLength", "True"
    Else
        WriteConfigSetting displaySettingsSection$, "IDE_SUBsLength", "False"
    End If
    Return

    AddLineCount:
    ModuleSize = ModuleSize + 1
    TotalLines(LastOpenSUB) = ModuleSize
    If ModuleSize > maxLineCount Then maxLineCount = ModuleSize
    SubClosed = -1
    Return
End Function

Function idewarningbox

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    If Len(ideprogname) Then thisprog$ = ideprogname Else thisprog$ = "Untitled" + tempfolderindexstr$
    maxModuleNameLen = Len(thisprog$)

    'calculate longest module name
    For x = 1 To warningListItems
        If warningLines(x) = 0 Then _Continue

        If warningIncLines(x) > 0 Then
            If Len(warningIncFiles(x)) > maxModuleNameLen Then
                maxModuleNameLen = Len(warningIncFiles(x))
            End If
        End If
    Next

    'build list
    dialogWidth = 60
    For x = 1 To warningListItems
        If warningLines(x) = 0 Then
            l$ = l$ + warning$(x)
            If x > 1 And treeConnection > 0 Then Asc(l$, treeConnection) = 192
        Else
            l3$ = Chr$(16) + Chr$(2) 'dark grey
            If warningIncLines(x) > 0 Then
                num$ = Space$(Len(Str$(maxLineNumber)) + 1)
                RSet num$ = str2$(warningIncLines(x))
                l3$ = l3$ + warningIncFiles(x) + Space$(maxModuleNameLen - Len(warningIncFiles(x))) + ":" + Chr$(16) + Chr$(16) + num$
            Else
                num$ = Space$(Len(Str$(maxLineNumber)) + 1)
                RSet num$ = str2$(warningLines(x))
                l3$ = l3$ + thisprog$ + Space$(maxModuleNameLen - Len(thisprog$)) + ":" + Chr$(16) + Chr$(16) + num$
            End If
            treeConnection = Len(l$) + 1
            text$ = warning$(x)
            If Len(l3$ + text$) + 6 > dialogWidth Then dialogWidth = Len(l3$ + text$) + 6
            If Len(text$) Then
                l$ = l$ + Chr$(195) + Chr$(196) + l3$ + ": " + text$
            Else
                l$ = l$ + Chr$(195) + Chr$(196) + l3$
            End If
        End If
        If x < warningListItems Then l$ = l$ + sep
    Next

    If warningLines(warningListItems) > 0 Then
        Asc(l$, treeConnection) = 192
    End If

    i = 0
    dialogHeight = warningListItems + 4
    If dialogHeight > idewy + idesubwindow - 6 Then
        dialogHeight = idewy + idesubwindow - 6
    End If

    If dialogWidth > idewx - 8 Then dialogWidth = idewx - 8

    idepar p, dialogWidth, dialogHeight, "Compilation status"

    i = i + 1
    o(i).typ = 2
    o(i).y = 2
    o(i).w = dialogWidth - 4: o(i).h = dialogHeight - 4
    o(i).txt = idenewtxt(l$)
    o(i).sel = 1
    o(i).nam = idenewtxt("Warnings (" + LTrim$(Str$(totalWarnings)) + ")")

    i = i + 1
    o(i).typ = 3
    o(i).y = dialogHeight
    o(i).txt = idenewtxt("#Go to" + sep + "#Close")
    o(i).dft = 1





    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        Color 0, 7: _PrintString (p.x + 2, p.y + 1), "Double-click on an item to jump to the line indicated"

        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        If K$ = Chr$(27) Or (focus = 3 And info <> 0) Then
            Exit Function
        End If

        If K$ = Chr$(13) Or (focus = 2 And info <> 0) Or (info = 1 And focus = 1) Then
            y = Abs(o(1).sel)
            If y >= 1 And y <= warningListItems And warningLines(y) > 0 Then
                idegotobox_LastLineNum = warningLines(y)
                AddQuickNavHistory
                idecy = idegotobox_LastLineNum
                idecentercurrentline
                If warningIncLines(y) > 0 Then
                    warningInInclude = idecy
                    warningInIncludeLine = warningIncLines(y)
                End If
                ideselect = 0
                Exit Function
            End If
        End If

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop

    idewarningbox = 0
End Function

Sub ideobjupdate (o As idedbotype, focus, f, focusoffset, kk$, altletter$, mb, mousedown, mouseup, mx, my, info, mw)
    Static LastKeybInput As Single
    Dim sep As String * 1
    sep = Chr$(0)

    t = o.typ
    mouseup = mouseup 'just to clear warnings of unused variables
    If t = 1 Then 'text field
        If mousedown Then
            x1 = o.par.x + o.x: y = o.par.y + o.y
            x2 = x1
            If o.nam Then
                x2 = x2 + idehlen(idetxt(o.nam)) + 2
            End If
            If my >= y - 1 And my <= y + 1 Then
                If mx >= x1 And mx <= x2 + o.w + 3 Then
                    focus = f
                    'change cursor location?
                    If my = y Then
                        If mx > x2 + 1 And mx < x2 + o.w + 2 Then
                            a$ = idetxt(o.txt)
                            x = mx - x2 - 2 '0-?
                            If x = o.v1 And x <> Len(a$) Then 'dbl-click text=clear field text
                                a$ = ""
                                idetxt(o.txt) = a$
                                o.v1 = 0
                            Else
                                If x <= Len(a$) Then o.v1 = x Else o.v1 = Len(a$)
                                o.issel = 0
                            End If
                        End If
                    End If
                End If
            End If
        End If 'mousedown

        a$ = idetxt(o.txt)
        If focusoffset = 0 Then
            If Len(kk$) = 1 Or KB <> 0 Then
                If Len(kk$) = 1 Then k = Asc(kk$)
                If (KSHIFT And KB = KEY_INSERT) Or (KCONTROL And UCase$(kk$) = "V") Then 'paste from clipboard
                    clip$ = _Clipboard$ 'read clipboard
                    x = InStr(clip$, Chr$(13))
                    If x Then clip$ = Left$(clip$, x - 1)
                    x = InStr(clip$, Chr$(10))
                    If x Then clip$ = Left$(clip$, x - 1)
                    If Len(clip$) Then
                        If o.issel Then
                            sx1 = o.sx1: sx2 = o.v1
                            If sx1 > sx2 Then Swap sx1, sx2
                            If sx2 - sx1 > 0 Then
                                a$ = Left$(a$, sx1) + clip$ + Right$(a$, Len(a$) - sx2)
                                o.v1 = sx1
                                If PasteCursorAtEnd Then o.v1 = sx1 + Len(clip$)
                                o.issel = 0
                            End If
                        Else
                            a$ = Left$(a$, o.v1) + clip$ + Right$(a$, Len(a$) - o.v1)
                            If PasteCursorAtEnd Then o.v1 = o.v1 + Len(clip$)
                        End If
                    End If
                    k = 255
                End If

                If (KCONTROL And UCase$(kk$) = "A") Then 'select all
                    If Len(a$) > 0 Then
                        o.issel = -1
                        o.sx1 = 0
                        o.v1 = Len(a$)
                    End If
                    k = 255
                End If

                If ((KCTRL And KB = KEY_INSERT) Or (KCONTROL And UCase$(kk$) = "C")) Then 'copy to clipboard
                    If o.issel Then
                        sx1 = o.sx1: sx2 = o.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then _Clipboard$ = Mid$(a$, sx1 + 1, sx2 - sx1)
                    End If
                    k = 255
                End If

                If ((KSHIFT And KB = KEY_DELETE) Or (KCONTROL And UCase$(kk$) = "X")) Then 'cut to clipboard
                    If o.issel Then
                        sx1 = o.sx1: sx2 = o.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            _Clipboard$ = Mid$(a$, sx1 + 1, sx2 - sx1)
                            'delete selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            o.v1 = sx1
                            o.issel = 0
                        End If
                    End If
                    k = 255
                End If

                If k = 8 And o.v1 > 0 Then
                    If o.issel Then
                        sx1 = o.sx1: sx2 = o.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            'delete selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            o.issel = 0
                        End If
                    Else
                        a1$ = Left$(a$, o.v1 - 1)
                        If o.v1 <= Len(a$) Then a2$ = Right$(a$, Len(a$) - o.v1) Else a2$ = ""
                        a$ = a1$ + a2$: o.v1 = o.v1 - 1
                    End If
                ElseIf k = 8 And o.issel Then
                    sx1 = o.sx1: sx2 = o.v1
                    If sx1 > sx2 Then Swap sx1, sx2
                    If sx2 - sx1 > 0 Then
                        'delete selection
                        a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                        o.issel = 0
                    End If
                End If
                If k <> 8 And k <> 9 And k <> 0 And k <> 10 And k <> 13 And k <> 26 And k <> 255 And ((KALT = 0 And KCTRL = 0) Or (KALT = -1 And KCTRL = -1)) Then
                    If o.issel Then
                        sx1 = o.sx1: sx2 = o.v1
                        If sx1 > sx2 Then Swap sx1, sx2
                        If sx2 - sx1 > 0 Then
                            'replace selection
                            a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                            idetxt(o.txt) = a$
                            o.issel = 0
                            o.v1 = sx1
                        End If
                    End If
                    If o.v1 > 0 Then a1$ = Left$(a$, o.v1) Else a1$ = ""
                    If o.v1 <= Len(a$) Then a2$ = Right$(a$, Len(a$) - o.v1) Else a2$ = ""
                    a$ = a1$ + kk$ + a2$: o.v1 = o.v1 + 1
                End If
                idetxt(o.txt) = a$
            End If
            If kk$ = Chr$(0) + "S" Then 'DEL
                If o.issel Then
                    sx1 = o.sx1: sx2 = o.v1
                    If sx1 > sx2 Then Swap sx1, sx2
                    If sx2 - sx1 > 0 Then
                        'delete selection
                        a$ = Left$(a$, sx1) + Right$(a$, Len(a$) - sx2)
                        idetxt(o.txt) = a$
                        o.v1 = sx1
                        o.issel = 0
                    End If
                Else
                    If o.v1 > 0 Then a1$ = Left$(a$, o.v1) Else a1$ = ""
                    If o.v1 < Len(a$) Then a2$ = Right$(a$, Len(a$) - o.v1 - 1) Else a2$ = ""
                    a$ = a1$ + a2$
                    idetxt(o.txt) = a$
                End If
            End If

            'cursor control
            If kk$ = Chr$(0) + "K" Then GoSub selectcheck: o.v1 = o.v1 - 1
            If kk$ = Chr$(0) + "M" Then GoSub selectcheck: o.v1 = o.v1 + 1
            If kk$ = Chr$(0) + "G" Then GoSub selectcheck: o.v1 = 0
            If kk$ = Chr$(0) + "O" Then GoSub selectcheck: o.v1 = Len(a$)
            If o.v1 < 0 Then o.v1 = 0
            If o.v1 > Len(a$) Then o.v1 = Len(a$)
            If o.v1 = o.sx1 Then o.issel = 0
        End If
        'hot-key focus
        If Len(altletter$) Then
            If o.nam Then
                x = InStr(idetxt(o.nam), "#")
                If x Then
                    If UCase$(Mid$(idetxt(o.nam), x + 1, 1)) = altletter$ Then focus = f
                End If
            End If
        End If
        f = f + 1
    End If '1

    If t = 2 Then 'list box
        idetxt(o.stx) = ""

        'Populate ListBoxITEMS:
        a$ = idetxt(o.txt)
        ReDim ListBoxITEMS(0) As String
        ReDim OriginalListBoxITEMS(0) As String
        If Len(a$) > 0 Then
            n = 0: x = 1
            Do
                x2 = InStr(x, a$, sep)
                If x2 > 0 Then
                    n = n + 1
                    If n > UBound(ListBoxITEMS) Then
                        ReDim _Preserve ListBoxITEMS(1 To n + 999) As String
                        ReDim _Preserve OriginalListBoxITEMS(1 To n + 999) As String
                    End If
                    ListBoxITEMS(n) = _Trim$(Mid$(a$, x, x2 - x))
                    OriginalListBoxITEMS(n) = Mid$(a$, x, x2 - x)
                    If Len(ListBoxITEMS(n)) Then
                        Do While Asc(ListBoxITEMS(n)) < 32 Or Asc(ListBoxITEMS(n)) > 126
                            ListBoxITEMS(n) = Mid$(ListBoxITEMS(n), 2)
                            If Len(ListBoxITEMS(n)) = 0 Then Exit Do
                        Loop
                    End If
                Else
                    n = n + 1
                    If n > UBound(ListBoxITEMS) Then
                        ReDim _Preserve ListBoxITEMS(1 To n + 999) As String
                        ReDim _Preserve OriginalListBoxITEMS(1 To n + 999) As String
                    End If
                    ListBoxITEMS(n) = _Trim$(Right$(a$, Len(a$) - x + 1))
                    OriginalListBoxITEMS(n) = Right$(a$, Len(a$) - x + 1)
                    If Len(ListBoxITEMS(n)) Then
                        Do While Asc(ListBoxITEMS(n)) < 32 Or Asc(ListBoxITEMS(n)) > 126
                            ListBoxITEMS(n) = Mid$(ListBoxITEMS(n), 2)
                            If Len(ListBoxITEMS(n)) = 0 Then Exit Do
                        Loop
                    End If
                    Exit Do
                End If
                x = x2 + 1
            Loop
            ReDim _Preserve ListBoxITEMS(1 To n) As String
            ReDim _Preserve OriginalListBoxITEMS(1 To n) As String
        End If

        If mousedown Then
            x1 = o.par.x + o.x: y1 = o.par.y + o.y
            x2 = x1 + o.w + 1: y2 = y1 + o.h + 1
            If mx >= x1 And mx <= x2 And my >= y1 And my <= y2 Then
                focus = f
                If mx > x1 And mx < x2 And my > y1 And my < y2 Then
                    y = my - y1 - 1
                    y = y + o.v1
                    If o.sel = y Then info = 1
                    o.sel = y
                    If o.sel > o.num Then o.sel = -o.num
                End If
            End If

        End If 'mousedown

        If mb Then
            If focusoffset = 0 Then

                x1 = o.par.x + o.x: y1 = o.par.y + o.y
                x2 = x1 + o.w + 1: y2 = y1 + o.h + 1
                If mx >= x1 And mx <= x2 And my >= y1 And my <= y2 Then

                    If mx = x2 And my > y1 + 1 And my < y2 - 1 Then

                        tsel = Abs(o.sel)
                        tnum = o.num
                        q = idevbar(x2, y1 + 1, o.h, tsel, tnum)

                        If my < q Then
                            kk$ = Chr$(0) + Chr$(73)
                            idewait
                        End If
                        If my > q Then
                            kk$ = Chr$(0) + Chr$(81)
                            idewait
                        End If
                    End If

                    If mx = x2 And my = y1 + 1 Then
                        kk$ = Chr$(0) + Chr$(72)
                        idewait
                    End If
                    If mx = x2 And my = y2 - 1 Then
                        kk$ = Chr$(0) + Chr$(80)
                        idewait
                    End If

                End If
            End If
        End If 'mb

        If focusoffset = 0 Then
            If mw Then
                'move to top or bottom
                If mw < 0 Then
                    If o.sel > o.v1 Then o.sel = o.v1
                Else
                    o.sel = o.v1 + o.h - 1
                End If
                o.sel = o.sel + mw * 3
                If o.sel < 1 Then o.sel = 1
                If o.sel > o.num Then o.sel = o.num
            End If

            If kk$ = Chr$(0) + Chr$(72) Then
                If o.sel < 0 Then
                    o.sel = -o.sel
                Else
                    o.sel = o.sel - 1
                    If o.sel < 1 Then o.sel = 1
                End If
            End If

            If kk$ = Chr$(0) + Chr$(80) Then
                If o.sel < 0 Then
                    o.sel = -o.sel
                Else
                    o.sel = o.sel + 1
                    If o.sel > o.num Then o.sel = o.num
                End If
            End If

            If kk$ = Chr$(0) + Chr$(73) Then
                If o.sel < 0 Then
                    o.sel = -o.sel
                End If
                o.sel = o.sel - o.h + 1
                If o.sel < 1 Then o.sel = 1
            End If

            If kk$ = Chr$(0) + Chr$(81) Then
                If o.sel < 0 Then
                    o.sel = -o.sel
                End If
                o.sel = o.sel + o.h - 1
                If o.sel > o.num Then o.sel = o.num
            End If

            If kk$ = Chr$(0) + "w" Then
                o.sel = 1
            End If

            If kk$ = Chr$(0) + "u" Then
                o.sel = o.num
            End If

            If Len(kk$) = 1 Then
                ResetKeybTimer = 0
                If timeElapsedSince(LastKeybInput) > 1 Then fileDlgSearchTerm$ = "": ResetKeybTimer = -1
                LastKeybInput = Timer
                k = Asc(UCase$(kk$))
                If k < 32 Or k > 126 Then
                    GoTo selected 'Search is not performed if kk$ isn't a printable character
                End If

                fileDlgSearchTerm$ = fileDlgSearchTerm$ + UCase$(kk$)

                If Len(fileDlgSearchTerm$) = 2 And Left$(fileDlgSearchTerm$, 1) = Right$(fileDlgSearchTerm$, 1) Then
                    'if the user is pressing the same letter again, we deduce the search
                    'is only for the initials
                    ResetKeybTimer = -1
                    fileDlgSearchTerm$ = UCase$(kk$)
                End If

                SearchPass = 1
                If Not ResetKeybTimer Then StartSearch = Abs(o.sel) Else StartSearch = Abs(o.sel) + 1
                If StartSearch < 1 Or StartSearch > n Then StartSearch = 1
                retryfind:
                If SearchPass > 2 Then GoTo selected
                For findMatch = StartSearch To n
                    If UCase$(Left$(ListBoxITEMS(findMatch), Len(fileDlgSearchTerm$))) = UCase$(fileDlgSearchTerm$) Then
                        o.sel = findMatch
                        idetxt(o.stx) = OriginalListBoxITEMS(findMatch)
                        GoTo selected
                    End If
                Next findMatch
                'No match, try again:
                StartSearch = 1
                SearchPass = SearchPass + 1
                GoTo retryfind
                selected:
            End If
        End If
        If o.sel > 0 And o.sel <= UBound(OriginalListBoxITEMS) Then idetxt(o.stx) = OriginalListBoxITEMS(o.sel)

        'hot-key focus
        If Len(altletter$) Then
            If o.nam Then
                x = InStr(idetxt(o.nam), "#")
                If x Then
                    If UCase$(Mid$(idetxt(o.nam), x + 1, 1)) = altletter$ Then focus = f
                End If
            End If
        End If
        f = f + 1
    End If '2

    If t = 3 Then 'buttons (eg. OK, Cancel)

        'count buttons & check for hotkey(s)
        a$ = idetxt(o.txt)
        n = 1
        x = 0
        For i2 = 1 To Len(a$)
            a2$ = Mid$(a$, i2, 1)
            If a2$ = Chr$(0) Then n = n + 1
            If x = 1 Then
                If UCase$(a2$) = altletter$ Then
                    focus = f + n - 1
                    info = n
                End If
            End If
            If a2$ = "#" Then x = 1 Else x = 0
        Next

        'check for mouse click on button(s)
        If mousedown Then
            If my = o.par.y + o.y Then
                a$ = idetxt(o.txt)
                n = 1
                c = 0
                For i2 = 1 To Len(a$)
                    a2$ = Mid$(a$, i2, 1)
                    If a2$ = Chr$(0) Then
                        n = n + 1
                    Else
                        If a$ <> "#" Then c = c + 1
                    End If
                Next
                w = o.w
                c = c + n * 4 'add characters for bracing < > buttons
                whitespace = w - c
                spacing = whitespace \ (n + 1)

                n2 = 1
                a3$ = ""

                x = o.par.x + o.x

                For i2 = 1 To Len(a$)
                    a2$ = Mid$(a$, i2, 1)
                    If a2$ <> Chr$(0) Then a3$ = a3$ + a2$
                    If a2$ = Chr$(0) Or i2 = Len(a$) Then

                        x = x + spacing
                        x2 = idehlen(a3$) + 4
                        If mx >= x And mx < x + x2 Then info = n2: focus = f + n2 - 1

                        x = x + x2
                        a3$ = ""
                        n2 = n2 + 1
                    End If
                Next

            End If 'my
        End If 'mousedown

        If focusoffset >= 0 And focusoffset < n Then
            f2 = f + focusoffset
            If kk$ = Chr$(13) Or kk$ = " " Then
                info = focusoffset + 1
            End If
        End If

        f = f + n
    End If '3

    If t = 4 Then 'checkbox

        If mousedown Then
            y = o.par.y + o.y
            x1 = o.par.x + o.x: x2 = x1 + 2
            If o.nam Then
                x2 = x2 + 1 + idehlen(idetxt(o.nam))
            End If
            If my = y Then
                If mx >= x1 And mx <= x2 Then
                    focus = f
                    o.sel = o.sel + 1: If o.sel > 1 Then o.sel = 0 'toggle
                End If
            End If
        End If 'mousedown

        If focusoffset = 0 Then
            If kk$ = Chr$(0) + "H" Then o.sel = 1
            If kk$ = Chr$(0) + "P" Then o.sel = 0
            If kk$ = " " Then
                o.sel = o.sel + 1: If o.sel > 1 Then o.sel = 0 'toggle
            End If
        End If 'in focus

        'hot-key focus
        If Len(altletter$) Then
            If o.nam Then
                x = InStr(idetxt(o.nam), "#")
                If x Then
                    If UCase$(Mid$(idetxt(o.nam), x + 1, 1)) = altletter$ Then focus = f
                End If
            End If
        End If
        f = f + 1
    End If '4

    Exit Sub
    selectcheck:
    If KSHIFT And o.issel = 0 Then o.issel = -1: o.sx1 = o.v1
    If KSHIFT = 0 Then o.issel = 0
    Return
End Sub

Function idevbar (x, y, h, i2, n2)
    i = i2: n = n2

    'h is height in charatcers (inc. arrows)

    'draw background & arrows
    Color 0, 7
    _PrintString (x, y), Chr$(24)
    _PrintString (x, y + h - 1), Chr$(25)
    For y2 = y + 1 To y + h - 2
        _PrintString (x, y2), Chr$(176)
    Next

    'draw slider

    If n < 1 Then n = 1
    If i < 1 Then i = 1
    If i > n Then i = n

    If h = 2 Then
        idevbar = y 'not position for slider exists
        Exit Function
    End If

    If h = 3 Then
        idevbar = y + 1 'dummy value
        'no slider
        Exit Function
    End If

    If h = 4 Then
        If n = 1 Then
            idevbar = y + 1 'dummy value
            'no slider required for 1 item
            Exit Function
        Else
            'show whichever is closer of the two positions
            p! = (i - 1) / (n - 1)
            If p! < .5 Then y2 = y + 1 Else y2 = y + 2
            _PrintString (x, y2), Chr$(219)
            idevbar = y2
            Exit Function
        End If
    End If

    If h > 4 Then
        If n = 1 Then
            idevbar = y + h \ 4 'dummy value
            'no slider required for 1 item
            Exit Function
        End If
        If i = 1 Then
            y2 = y + 1
            _PrintString (x, y2), Chr$(219)
            idevbar = y2
            Exit Function
        End If
        If i = n Then
            y2 = y + h - 2
            _PrintString (x, y2), Chr$(219)
            idevbar = y2
            Exit Function
        End If
        'between i=1 and i=n
        p! = (i - 1) / (n - 1)
        p! = p! * (h - 4)
        y2 = y + 2 + Int(p!)
        _PrintString (x, y2), Chr$(219)
        idevbar = y2
        Exit Function
    End If
End Function

Sub idewait
    '_Delay 0.05
End Sub

Function idezchangepath$ (path$, newpath$)
    idezchangepath$ = path$ 'default (for unsuccessful cases)
    'go back a path
    If newpath$ = ".." Then
        For x = Len(path$) To 1 Step -1
            a$ = Mid$(path$, x, 1)
            If a$ = "/" Then
                idezchangepath$ = Left$(path$, x - 1)
                If x = 1 Then idezchangepath$ = "/" 'root path cannot be ""
                Exit For
            End If
        Next
        Exit Function
    End If
    If path$ = "/" Then idezchangepath$ = "/" + newpath$ Else idezchangepath$ = path$ + "/" + newpath$
    Exit Function
End Function

Function idezfilelist$ (path$, method, mask$) 'method0=*.bas, method1=*.*, method2=custom mask
    Dim sep As String * 1
    sep = Chr$(0)
    filelist$ = ""
    If method = 0 Then
        For i = 1 To 2
            Open "./internal/temp/files.txt" For Output As #150: Close #150
            If i = 1 Then Shell _Hide "find " + QuotedFilename$(path$) + " -maxdepth 1 -type f -name " + Chr$(34) + "*.bas" + Chr$(34) + " | sort >./internal/temp/files.txt"
            If i = 2 Then Shell _Hide "find " + QuotedFilename$(path$) + " -maxdepth 1 -type f -name " + Chr$(34) + "*.BAS" + Chr$(34) + " | sort >./internal/temp/files.txt"
            GoSub AddToList
        Next
    ElseIf method = 1 Then
        Shell _Hide "find " + QuotedFilename$(path$) + " -maxdepth 1 -type f -name " + Chr$(34) + "*" + Chr$(34) + " | sort >./internal/temp/files.txt"
        GoSub AddToList
    ElseIf method = 2 Then
        Shell _Hide "find " + QuotedFilename$(path$) + " -maxdepth 1 -type f -name " + Chr$(34) + mask$ + Chr$(34) + " | sort >./internal/temp/files.txt"
        GoSub AddToList
    End If
    idezfilelist$ = filelist$
    Exit Function

    AddToList:
    Open "./internal/temp/files.txt" For Input As #150
    Do Until EOF(150)
        Line Input #150, a$
        If Len(a$) = 0 Then Exit Do
        For x = Len(a$) To 1 Step -1
            a2$ = Mid$(a$, x, 1)
            If a2$ = "/" Then
                a$ = Right$(a$, Len(a$) - x)
                Exit For
            End If
        Next
        If filelist$ = "" Then filelist$ = a$ Else filelist$ = filelist$ + sep + a$
    Loop
    Close #150
    Return
End Function

Function idezgetroot$
    'note: does NOT including a trailing / or \ on the right
    Shell _Hide "pwd >./internal/temp/root.txt"
    Open "./internal/temp/root.txt" For Input As #150
    Line Input #150, a$
    idezgetroot$ = a$
    Close #150
    Exit Function
End Function

Function idezpathlist$ (path$)
    Dim sep As String * 1
    sep = Chr$(0)
    pathlist$ = ""
    Open "./internal/temp/paths.txt" For Output As #150: Close #150
    Shell _Hide "find " + QuotedFilename$(path$) + " -maxdepth 1 -mindepth 1 -type d >./internal/temp/paths.txt"
    Open "./internal/temp/paths.txt" For Input As #150
    Do Until EOF(150)
        Line Input #150, a$
        If Len(a$) = 0 Then Exit Do
        For x = Len(a$) To 1 Step -1
            a2$ = Mid$(a$, x, 1)
            If a2$ = "/" Then
                a$ = Right$(a$, Len(a$) - x)
                Exit For
            End If
        Next
        If pathlist$ = "" Then pathlist$ = a$ Else pathlist$ = pathlist$ + sep + a$
    Loop
    Close #150
    If path$ <> "/" Then
        a$ = ".."

        If pathlist$ = "" Then pathlist$ = a$ Else pathlist$ = a$ + sep + pathlist$
    End If
    idezpathlist$ = pathlist$
    Exit Function
End Function

Function ideztakepath$ (f$) 'assume f$ contains a filename with an optional path
    p$ = ""

    For i = Len(f$) To 1 Step -1
        a$ = Mid$(f$, i, 1)
        If a$ = "\" Or a$ = "/" Then
            p$ = Left$(f$, i - 1)
            f$ = Right$(f$, Len(f$) - i)
            Exit For
        End If
    Next
    ideztakepath$ = p$
    Exit Function
End Function

'file f$ exists, and may contain a path
'return the FULL path (even if it was passed as a relative path)
'f$ is altered to only contain the name of the actual file
'root$ is the path to apply relative paths to
Function idezgetfilepath$ (root$, f$)
    'step #1: seperate file's name from its path (if any)
    p$ = ideztakepath$(f$) 'note: this is a simple seperation of the string

    'step #2: if path was undefined, set it to root
    If Len(p$) = 0 Then p$ = root$

    'step #3: if path is relative, make it relative to root$
    If _DirExists(root$ + idepathsep$ + p$) Then p$ = root$ + idepathsep$ + p$

    'step #4: attempt a CHDIR to the path to (i)  validate its existance
    '                                      & (ii) allow listing the paths full name
    ideerror = 4 'path not found
    p2$ = p$
    If _DirExists(p2$) = 0 Then Exit Function

    ChDir p2$
    ideerror = 1
    'step #5: get the path's full name (assume success)
    p$ = _CWD$
    'step #6: restore root path (assume success)
    ChDir ideroot$
    'important: no validation of f$ necessary
    idezgetfilepath$ = p$
End Function

Function idelayoutbox

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    i = 0
    idepar p, 60, 9, "Code Layout"

    i = i + 1
    ideautolayoutid = i
    o(i).typ = 4 'check box
    o(i).y = 2
    o(i).nam = idenewtxt("#Auto Spacing & Upper/Lowercase Formatting")
    o(i).sel = ideautolayout

    i = i + 1
    ideautolayoutkwcapitalsid = i
    o(i).typ = 4 'check box
    o(i).y = 3
    o(i).x = 6
    o(i).nam = idenewtxt("#Keywords in CAPITALS")
    o(i).sel = ideautolayoutkwcapitals

    i = i + 1
    ideautoindentID = i
    o(i).typ = 4 'check box
    o(i).y = 5
    o(i).nam = idenewtxt("Auto #Indent -")
    o(i).sel = ideautoindent

    a2$ = str2$(ideautoindentsize)
    i = i + 1
    ideautoindentsizeid = i
    o(i).typ = 1
    o(i).x = 20
    o(i).y = 5
    o(i).nam = idenewtxt("#Spacing")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)

    i = i + 1
    ideindentsubsid = i
    o(i).typ = 4
    o(i).x = 6
    o(i).y = 7
    o(i).nam = idenewtxt("Indent SUBs and #FUNCTIONs")
    o(i).sel = ideindentsubs

    i = i + 1
    buttonsid = i
    o(i).typ = 3
    o(i).y = 9
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If o(focus).typ = 1 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        a$ = idetxt(o(ideautoindentsizeid).txt)
        If Len(a$) > 2 Then a$ = Left$(a$, 2) '2 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
            If a < 48 Or a > 57 Then a$ = "": Exit For
        Next
        If Len(a$) Then
            a = Val(a$)
            If a > 64 Then a$ = "64"
        End If
        idetxt(o(ideautoindentsizeid).txt) = a$

        If focus = ideautolayoutkwcapitalsid And o(ideautolayoutkwcapitalsid).sel = 1 Then
            o(ideautolayoutid).sel = 1
        End If

        If focus = ideindentsubsid And o(ideindentsubsid).sel = 1 Then
            o(ideautoindentID).sel = 1
        End If

        If o(ideautolayoutid).sel = 0 Then o(ideautolayoutkwcapitalsid).sel = 0
        If o(ideautoindentID).sel = 0 Then o(ideindentsubsid).sel = 0

        If K$ = Chr$(27) Or (focus = buttonsid + 1 And info <> 0) Then Exit Function 'cancel
        If K$ = Chr$(13) Or (focus = buttonsid And info <> 0) Then 'ok
            'save changes
            v% = o(ideautolayoutid).sel: If v% <> 0 Then v% = 1 'ideautolayout
            If ideautolayout <> v% Then ideautolayout = v%: idelayoutbox = 1

            v% = o(ideautolayoutkwcapitalsid).sel: If v% <> 0 Then v% = 1 'ideautolayoutkwcapitals
            If ideautolayoutkwcapitals <> v% Then ideautolayoutkwcapitals = v%: idelayoutbox = 1

            v% = o(ideautoindentID).sel: If v% <> 0 Then v% = 1 'ideautoindent
            If ideautoindent <> v% Then ideautoindent = v%: idelayoutbox = 1

            v$ = idetxt(o(ideautoindentsizeid).txt) 'ideautoindentsize
            If v$ = "" Then v$ = "4"
            v% = Val(v$)
            If v% < 0 Or v% > 64 Then v% = 4
            If ideautoindentsize <> v% Then
                ideautoindentsize = v%
                If ideautoindent <> 0 Then idelayoutbox = 1
            End If

            v% = o(ideindentsubsid).sel: If v% <> 0 Then v% = 1 'ideindentsubs
            If ideindentsubs <> v% Then ideindentsubs = v%: idelayoutbox = 1

            If ideautolayout Then
                WriteConfigSetting displaySettingsSection$, "IDE_AutoFormat", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_AutoFormat", "False"
            End If
            If ideautolayoutkwcapitals Then
                WriteConfigSetting displaySettingsSection$, "IDE_KeywordCapital", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_KeywordCapital", "False"
            End If
            If ideautoindent Then
                WriteConfigSetting displaySettingsSection$, "IDE_AutoIndent", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_AutoIndent", "False"
            End If
            WriteConfigSetting displaySettingsSection$, "IDE_IndentSize", Str$(ideautoindentsize)
            If ideindentsubs Then
                WriteConfigSetting displaySettingsSection$, "IDE_IndentSUBs", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_IndentSUBs", "False"
            End If
            Exit Function
        End If

        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
End Function

Function idebackupbox
    a2$ = str2$(idebackupsize)
    v$ = ideinputbox$("Backup/Undo", "#Undo buffer limit (10-2000MB)", a2$, "0123456789", 50, 4, 0)
    If v$ = "" Then Exit Function

    'save changes
    v& = Val(v$)
    If v& < 10 Then v& = 10
    If v& > 2000 Then v& = 2000

    If v& < idebackupsize Then
        Open tmpdir$ + "undo2.bin" For Output As #151: Close #151
        ideundobase = 0
        ideundopos = 0
    End If

    idebackupsize = v&
    WriteConfigSetting generalSettingsSection$, "BackupSize", Str$(v&) + " 'in MB"
    idebackupbox = 1
End Function

Sub idegotobox
    If idegotobox_LastLineNum > 0 Then a2$ = str2$(idegotobox_LastLineNum) Else a2$ = ""
    v$ = ideinputbox$("Go To Line", "#Line", a2$, "0123456789", 30, 8, 0)
    If v$ = "" Then Exit Sub

    v& = Val(v$)
    If v& < 1 Then v& = 1
    If v& > iden Then v& = iden
    idegotobox_LastLineNum = v&
    AddQuickNavHistory
    idecy = v&
    idecentercurrentline
    ideselect = 0
End Sub

Function idegetlinenumberbox (title$, initialValue&)
    a2$ = str2$(initialValue&)
    If a2$ = "0" Then a2$ = ""
    v$ = ideinputbox$(title$, "#Line", a2$, "0123456789", 30, 8, 0)
    If v$ = "" Then Exit Function

    v& = Val(v$)
    If v& < 1 Then v& = 1
    If v& > iden Then v& = iden

    idegetlinenumberbox = v&
End Function

Function ideadvancedbox

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    Dim Direct_Text$(100)

    i = 0

    i = i + 1
    o(i).typ = 3 '
    'o(i).y = y
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1

    y = 2 '2nd blank line

    i = i + 1
    o(i).typ = 4 'check box --- focus=3
    o(i).y = y
    o(i).nam = idenewtxt("Embed C++ debug information into executable")
    o(i).sel = idedebuginfo
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " This setting is not required for $DEBUG mode"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " Use it to investigate crashes/freezes at C++ (not QB64) code level"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " Use internal/temp/debug batch file to debug your executable"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " Increases executable size"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " Makes public the names of variables in your program's code"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " QB64 libraries will be purged then rebuilt"
    y = y + 1: Direct_Text$(y) = "     " + Chr$(254) + " This setting also affects command line compilation"

    y = y + 2

    o(1).y = y 'close button

    '-------- end of init --------

    idepar p, 75, y, "Advanced Options"

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop


        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        For y = 1 To 100
            If Len(Direct_Text$(y)) Then
                Color 0, 7: _PrintString (p.x + 1, p.y + y), Direct_Text$(y)
            End If
        Next
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls

        If K$ = Chr$(27) Or (focus = 2 And info <> 0) Then Exit Function

        If K$ = Chr$(13) Or (focus = 1 And info <> 0) Then 'close
            'save changes

            'update idedebuginfo?
            v% = o(2).sel: If v% <> 0 Then v% = 1
            If v% <> idedebuginfo Then
                idedebuginfo = v%
                If idedebuginfo Then
                    WriteConfigSetting generalSettingsSection$, "DebugInfo", "True" + DebugInfoIniWarning$
                Else
                    WriteConfigSetting generalSettingsSection$, "DebugInfo", "False" + DebugInfoIniWarning$
                End If
                Include_GDB_Debugging_Info = idedebuginfo
                purgeprecompiledcontent
                idechangemade = 1 'force recompilation
            End If

            Exit Function
        End If

        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
    ideadvancedbox = 0
End Function

Function idemessagebox (titlestr$, messagestr$, buttons$)

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    messagestr$ = StrReplace$(messagestr$, "\n", Chr$(10))
    MessageLines = 1
    Dim FullMessage$(1 To 8)
    PrevScan = 1
    Do
        NextScan = InStr(NextScan + 1, messagestr$, Chr$(10))
        If NextScan > 0 Then
            FullMessage$(MessageLines) = Mid$(messagestr$, PrevScan, NextScan - PrevScan)
            tw = Len(FullMessage$(MessageLines)) + 2
            If tw > w Then w = tw
            PrevScan = NextScan + 1
            MessageLines = MessageLines + 1
            If MessageLines > UBound(FullMessage$) Then Exit Do
        Else
            FullMessage$(MessageLines) = Mid$(messagestr$, PrevScan)
            tw = Len(FullMessage$(MessageLines)) + 2
            If tw > w Then w = tw
            Exit Do
        End If
    Loop

    If buttons$ = "" Then buttons$ = "#OK"
    totalButtons = 1
    For i = 1 To Len(buttons$)
        If Asc(buttons$, i) = 59 Then totalButtons = totalButtons + 1
    Next
    buttonsLen = Len(buttons$) + totalButtons * 6

    i = 0
    w2 = Len(titlestr$) + 4
    If w < w2 Then w = w2
    If w < buttonsLen Then w = buttonsLen
    If w > idewx - 4 Then w = idewx - 4
    idepar p, w, 3 + MessageLines, titlestr$

    i = i + 1
    o(i).typ = 3
    o(i).y = 3 + MessageLines
    o(i).txt = idenewtxt(StrReplace$(buttons$, ";", sep))
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        Color 0, 7
        For i = 1 To MessageLines
            If Len(FullMessage$(i)) > p.w - 2 Then
                FullMessage$(i) = Left$(FullMessage$(i), p.w - 5) + String$(3, 250)
            End If
            _PrintString (p.x + (w \ 2 - Len(FullMessage$(i)) \ 2) + 1, p.y + 1 + i), FullMessage$(i)
        Next i
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0

        If UCase$(K$) >= "A" And UCase$(K$) <= "Z" Then altletter$ = UCase$(K$)

        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If K$ = Chr$(27) Then Exit Function

        If K$ = Chr$(13) Or (info <> 0) Then
            idemessagebox = focus
            ClearMouse
            Exit Function
        End If
        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
End Function

Function ideyesnobox$ (titlestr$, messagestr$) 'returns "Y" or "N"
    result = idemessagebox(titlestr$, messagestr$, "#Yes;#No")
    If result = 1 Then ideyesnobox$ = "Y" Else ideyesnobox$ = "N"
End Function 'yes/no box

Function ideactivitybox$ (action$, titlestr$, messagestr$, buttons$) Static

    Select Case LCase$(action$)
        Case "setup"
            '-------- generic dialog box header --------
            PCopy 0, 2
            PCopy 0, 1
            Screen , , 1, 0
            focus = 1
            ReDim p As idedbptype
            ReDim o(1 To 100) As idedbotype
            ReDim sep As String * 1
            sep = Chr$(0)
            '-------- end of generic dialog box header --------

            '-------- init --------
            messagestr$ = StrReplace$(messagestr$, "\n", Chr$(10))
            MessageLines = 1
            ReDim FullMessage$(1 To 8)
            PrevScan = 1
            Do
                NextScan = InStr(NextScan + 1, messagestr$, Chr$(10))
                If NextScan > 0 Then
                    FullMessage$(MessageLines) = Mid$(messagestr$, PrevScan, NextScan - PrevScan)
                    tw = Len(FullMessage$(MessageLines)) + 2
                    If tw > w Then w = tw
                    PrevScan = NextScan + 1
                    MessageLines = MessageLines + 1
                    If MessageLines > UBound(FullMessage$) Then Exit Do
                Else
                    FullMessage$(MessageLines) = Mid$(messagestr$, PrevScan)
                    tw = Len(FullMessage$(MessageLines)) + 2
                    If tw > w Then w = tw
                    Exit Do
                End If
            Loop

            If buttons$ = "" Then buttons$ = "#OK"
            totalButtons = 1
            For i = 1 To Len(buttons$)
                If Asc(buttons$, i) = 59 Then totalButtons = totalButtons + 1
            Next
            buttonsLen = Len(buttons$) + totalButtons * 6

            i = 0
            w2 = Len(titlestr$) + 4
            If w < w2 Then w = w2
            If w < buttonsLen Then w = buttonsLen
            If w > idewx - 4 Then w = idewx - 4
            idepar p, w, 3 + MessageLines, titlestr$

            i = i + 1
            o(i).typ = 3
            o(i).y = 3 + MessageLines
            o(i).txt = idenewtxt(StrReplace$(buttons$, ";", sep))
            o(i).dft = 1
            '-------- end of init --------

            '-------- generic init --------
            For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
            '-------- end of generic init --------
        Case "update"
            '-------- generic display dialog box & objects --------
            idedrawpar p
            f = 1: cx = 0: cy = 0
            For i = 1 To 100
                If o(i).typ Then

                    'prepare object
                    o(i).foc = focus - f 'focus offset
                    o(i).cx = 0: o(i).cy = 0
                    idedrawobj o(i), f 'display object
                    If o(i).cx Then cx = o(i).cx: cy = o(i).cy
                End If
            Next i
            lastfocus = f - 1
            '-------- end of generic display dialog box & objects --------

            '-------- custom display changes --------
            Color 0, 7
            For i = 1 To MessageLines
                If Len(FullMessage$(i)) > p.w - 2 Then
                    FullMessage$(i) = Left$(FullMessage$(i), p.w - 5) + String$(3, 250)
                End If
                _PrintString (p.x + (w \ 2 - Len(FullMessage$(i)) \ 2) + 1, p.y + 1 + i), FullMessage$(i)
            Next i
            '-------- end of custom display changes --------

            'update visual page and cursor position
            PCopy 1, 0
            If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

            '-------- read input --------
            change = 0
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100

            If change Then
                If alt And Not KCTRL Then idehl = 1 Else idehl = 0
                'convert "alt+letter" scancode to letter's ASCII character
                altletter$ = ""
                If alt And Not KCTRL Then
                    If Len(K$) = 1 Then
                        k = Asc(UCase$(K$))
                        If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
                    End If
                End If
                Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
                '-------- end of read input --------

                '-------- generic input response --------
                info = 0

                If UCase$(K$) >= "A" And UCase$(K$) <= "Z" Then altletter$ = UCase$(K$)

                If K$ = "" Then K$ = Chr$(255)
                If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
                If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
                If focus < 1 Then focus = lastfocus
                If focus > lastfocus Then focus = 1
                f = 1
                For i = 1 To 100
                    t = o(i).typ
                    If t Then
                        focusoffset = focus - f
                        ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
                    End If
                Next
                '-------- end of generic input response --------

                'specific post controls
                If K$ = Chr$(27) Then ideactivitybox$ = MKI$(0)

                If K$ = Chr$(13) Or (info <> 0) Then
                    ideactivitybox$ = MKI$(1) + MKL$(focus)
                    ClearMouse
                End If
                'end of custom controls

                mousedown = 0
                mouseup = 0
            End If
    End Select
End Function


Function idedisplaybox

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    i = 0

    'note: manually set window position in case display is set too large by accident
    p.w = 60
    p.h = 18
    p.x = (80 \ 2) - p.w \ 2
    p.y = (25 \ 2) - p.h \ 2
    p.nam = idenewtxt("Display")

    a2$ = str2$(idewx)
    i = i + 1
    PrevFocus = 1
    o(i).typ = 1
    o(i).x = 3
    o(i).y = 2
    o(i).w = 10
    o(i).nam = idenewtxt("Window #width")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)
    If o(i).v1 > 0 Then
        o(i).issel = -1
        o(i).sx1 = 0
    End If

    a2$ = str2$(idewy + idesubwindow)
    i = i + 1
    o(i).typ = 1
    o(i).x = 2
    o(i).y = 5
    o(i).w = 10
    o(i).nam = idenewtxt("Window #height")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 7
    o(i).nam = idenewtxt("#Remember size")
    If IDE_AutoPosition Then o(i).sel = 1

    i = i + 1
    tmpNormalCursorStart = IDENormalCursorStart
    o(i).typ = 1
    o(i).x = 33
    o(i).y = 2
    o(i).nam = idenewtxt("Cursor #start")
    o(i).txt = idenewtxt(str2$(IDENormalCursorStart))
    o(i).v1 = Len(a2$)

    i = i + 1
    tmpNormalCursorEnd = IDENormalCursorEnd
    o(i).typ = 1
    o(i).x = 35
    o(i).y = 5
    o(i).nam = idenewtxt("Cursor #end")
    o(i).txt = idenewtxt(str2$(IDENormalCursorEnd))
    o(i).v1 = Len(a2$)

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 9
    o(i).nam = idenewtxt("#Use _FONT 8")
    o(i).sel = IDE_UseFont8
    prevFont8Setting = o(i).sel

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 10
    o(i).nam = idenewtxt("Use monospace #TTF font:")
    o(i).sel = idecustomfont
    prevCustomFontSetting = o(i).sel

    a2$ = idecustomfontfile$
    prevFontFile$ = a2$
    i = i + 1
    o(i).typ = 1
    o(i).x = 10
    o(i).y = 12
    o(i).nam = idenewtxt("#Font file")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)

    a2$ = str2$(idecustomfontheight)
    prevFontSize$ = a2$
    i = i + 1
    o(i).typ = 1
    o(i).x = 10
    o(i).y = 15
    o(i).nam = idenewtxt("Font size in #pixels")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)

    i = i + 1
    o(i).typ = 3
    o(i).y = p.h
    o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    o(i).dft = 1
    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop


        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        Locate , , , tmpNormalCursorStart, tmpNormalCursorEnd
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls

        If focus <> PrevFocus Then
            'Always start with TextBox values selected upon getting focus
            PrevFocus = focus
            If o(focus).typ = 1 Then
                o(focus).v1 = Len(idetxt(o(focus).txt))
                If o(focus).v1 > 0 Then o(focus).issel = -1
                o(focus).sx1 = 0
            End If
        End If

        'width
        a$ = idetxt(o(1).txt)
        If Len(a$) > 3 Then a$ = Left$(a$, 3) '3 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If a < 48 Or a > 57 Then a$ = "": Exit For
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
        Next
        If focus <> 1 Then
            If Len(a$) Then a = Val(a$) Else a = 0
            If a < 80 Then a$ = "80"
        End If
        idetxt(o(1).txt) = a$

        'height
        a$ = idetxt(o(2).txt)
        If Len(a$) > 3 Then a$ = Left$(a$, 3) '3 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If a < 48 Or a > 57 Then a$ = "": Exit For
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
        Next
        If focus <> 2 Then
            If Len(a$) Then a = Val(a$) Else a = 0
            If a < 25 Then a$ = "25"
        End If
        idetxt(o(2).txt) = a$

        'cursor start
        a$ = idetxt(o(4).txt)
        If Len(a$) > 2 Then a$ = Left$(a$, 2) '2 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If a < 48 Or a > 57 Then a$ = "": Exit For
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
        Next
        If Len(a$) Then a = Val(a$) Else a = 0
        If focus <> 4 Then
            If a < 0 Then a$ = "0"
            If a > 31 Then a$ = "31"
            tmpNormalCursorStart = Val(a$)
        Else
            If a < 0 Then a = 0
            If a > 31 Then a = 31
            tmpNormalCursorStart = a
        End If
        idetxt(o(4).txt) = a$

        'cursor end
        a$ = idetxt(o(5).txt)
        If Len(a$) > 2 Then a$ = Left$(a$, 2) '2 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If a < 48 Or a > 57 Then a$ = "": Exit For
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
        Next
        If Len(a$) Then a = Val(a$) Else a = 0
        If focus <> 5 Then
            If a < 0 Then a$ = "0"
            If a > 31 Then a$ = "31"
            tmpNormalCursorEnd = Val(a$)
        Else
            If a < 0 Then a = 0
            If a > 31 Then a = 31
            tmpNormalCursorEnd = a
        End If
        idetxt(o(5).txt) = a$

        If prevFont8Setting <> o(6).sel Then
            prevFont8Setting = o(6).sel
            If o(6).sel Then o(7).sel = 0: prevCustomFontSetting = 0
        End If

        If prevCustomFontSetting <> o(7).sel Then
            prevCustomFontSetting = o(7).sel
            If o(7).sel Then o(6).sel = 0: prevFont8Setting = 0
        End If

        a$ = idetxt(o(8).txt)
        If Len(a$) > 1024 Then a$ = Left$(a$, 1024)
        idetxt(o(8).txt) = a$
        If a$ <> prevFontFile$ Then
            prevFontFile$ = a$
            If o(7).sel = 0 Then
                o(6).sel = 0: prevFont8Setting = 0
                o(7).sel = 1: prevCustomFontSetting = 1
            End If
        End If

        a$ = idetxt(o(9).txt)
        If Len(a$) > 2 Then a$ = Left$(a$, 2) '2 character limit
        For i = 1 To Len(a$)
            a = Asc(a$, i)
            If a < 48 Or a > 57 Then a$ = "": Exit For
            If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
        Next
        If focus <> 9 Then
            If Len(a$) Then a = Val(a$) Else a = 0
            If a < 8 Then a$ = "8"
        End If
        idetxt(o(9).txt) = a$
        If a$ <> prevFontSize$ Then
            prevFontSize$ = a$
            If o(7).sel = 0 Then
                o(6).sel = 0: prevFont8Setting = 0
                o(7).sel = 1: prevCustomFontSetting = 1
            End If
        End If


        If K$ = Chr$(27) Or (focus = 11 And info <> 0) Then Exit Function
        If K$ = Chr$(13) Or (focus = 10 And info <> 0) Then

            x = 0 'change to custom font

            'get size in v%
            v$ = idetxt(o(9).txt): If v$ = "" Then v$ = "0"
            v% = Val(v$)
            If v% < 8 Then v% = 8
            If v% > 99 Then v% = 99
            If v% <> idecustomfontheight Then x = 1

            If o(6).sel <> IDE_UseFont8 Then
                IDE_UseFont8 = o(6).sel
                idedisplaybox = 1
            End If

            If o(7).sel <> idecustomfont Then
                If o(7).sel = 0 Then
                    If IDE_UseFont8 Then _Font 8 Else _Font 16
                    _FreeFont idecustomfonthandle
                Else
                    x = 1
                End If
            End If


            v$ = idetxt(o(8).txt): If v$ <> idecustomfontfile$ Then x = 1

            If o(7).sel = 1 And x = 1 Then
                oldhandle = idecustomfonthandle
                idecustomfonthandle = _LoadFont(v$, v%, "MONOSPACE")
                If idecustomfonthandle = -1 Then
                    'failed! - revert to default settings
                    o(7).sel = 0: idetxt(o(8).txt) = "C:\Windows\Fonts\lucon.ttf": idetxt(o(9).txt) = "21": If IDE_UseFont8 Then _Font 8 Else _Font 16
                Else
                    _Font idecustomfonthandle
                End If
                If idecustomfont = 1 Then _FreeFont oldhandle
            End If

            'save changes
            v$ = idetxt(o(1).txt): If v$ = "" Then v$ = "0"
            v% = Val(v$)
            If v% < 80 Then v% = 80
            If v% > 999 Then v% = 999
            If v% <> idewx Then idedisplaybox = 1
            idewx = v%


            v$ = idetxt(o(2).txt): If v$ = "" Then v$ = "0"
            v% = Val(v$)
            If v% < 25 Then v% = 25
            If v% > 999 Then v% = 999
            If v% <> idewy Then idedisplaybox = 1
            idewy = v% - idesubwindow

            v% = o(3).sel
            If v% <> 0 Then v% = -1
            IDE_AutoPosition = v%

            v% = o(7).sel
            If v% <> 0 Then v% = 1
            idecustomfont = v%

            v$ = idetxt(o(8).txt)
            If Len(v$) > 1024 Then v$ = Left$(v$, 1024)
            idecustomfontfile$ = v$
            v$ = v$ + Space$(1024 - Len(v$))

            v$ = idetxt(o(9).txt): If v$ = "" Then v$ = "0"
            v% = Val(v$)
            If v% < 8 Then v% = 8
            If v% > 99 Then v% = 99
            idecustomfontheight = v%


            WriteConfigSetting windowSettingsSection$, "IDE_Width", Str$(idewx)
            WriteConfigSetting windowSettingsSection$, "IDE_Height", Str$(idewy)
            If idecustomfont Then
                WriteConfigSetting displaySettingsSection$, "IDE_CustomFont", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_CustomFont", "False"
            End If
            If IDE_UseFont8 Then
                WriteConfigSetting displaySettingsSection$, "IDE_UseFont8", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_UseFont8", "False"
            End If
            If IDE_AutoPosition Then
                WriteConfigSetting displaySettingsSection$, "IDE_AutoPosition", "True"
            Else
                WriteConfigSetting displaySettingsSection$, "IDE_AutoPosition", "False"
            End If
            WriteConfigSetting displaySettingsSection$, "IDE_CustomFont$", idecustomfontfile$
            WriteConfigSetting displaySettingsSection$, "IDE_CustomFontSize", Str$(idecustomfontheight)

            IDENormalCursorStart = tmpNormalCursorStart
            WriteConfigSetting displaySettingsSection$, "IDE_NormalCursorStart", str2$(IDENormalCursorStart)

            IDENormalCursorEnd = tmpNormalCursorEnd
            WriteConfigSetting displaySettingsSection$, "IDE_NormalCursorEnd", str2$(IDENormalCursorEnd)
            Exit Function
        End If

        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop
End Function

Function idechoosecolorsbox
    Dim bkpIDECommentColor As _Unsigned Long, bkpIDEMetaCommandColor As _Unsigned Long
    Dim bkpIDEQuoteColor As _Unsigned Long, bkpIDETextColor As _Unsigned Long
    Dim bkpIDEBackgroundColor As _Unsigned Long, bkpIDEKeywordColor As _Unsigned Long
    Dim bkpIDEBackgroundColor2 As _Unsigned Long, bkpIDENumbersColor As _Unsigned Long
    Dim bkpIDEBracketHighlightColor As _Unsigned Long, bkpIDEChromaColor As _Unsigned Long

    TotalItems = 10
    Dim SelectionIndicator$(1 To TotalItems)
    bkpIDECommentColor = IDECommentColor
    bkpIDEMetaCommandColor = IDEMetaCommandColor
    bkpIDEQuoteColor = IDEQuoteColor
    bkpIDETextColor = IDETextColor
    bkpIDEKeywordColor = IDEKeywordColor
    bkpIDENumbersColor = IDENumbersColor
    bkpIDEBackgroundColor = IDEBackgroundColor
    bkpIDEBackgroundColor2 = IDEBackgroundColor2
    bkpIDEBracketHighlightColor = IDEBracketHighlightColor
    bkpIDEChromaColor = IDEChromaColor

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------
    LoadColorSchemes
    _PaletteColor 5, &HFF00A800, 0 'Original green may have been changed by the Help System, so 5 is now green

    i = 0
    idepar p, 73, 20, "IDE Colors"

    l$ = Chr$(16) + "Normal Text"
    l$ = l$ + sep + " Keywords"
    l$ = l$ + sep + " Numbers"
    l$ = l$ + sep + " Strings"
    l$ = l$ + sep + " Metacommand/custom keywords"
    l$ = l$ + sep + " Comments"
    l$ = l$ + sep + " Background"
    l$ = l$ + sep + " Current line background"
    l$ = l$ + sep + " Bracket/selection highlight"
    l$ = l$ + sep + " Menus and dialogs"
    i = i + 1
    o(i).typ = 2
    o(i).y = 4
    o(i).w = 30: o(i).h = 10
    o(i).txt = idenewtxt(l$)
    o(i).sel = 1
    SelectedITEM = 1
    PrevFocus = 1
    o(i).nam = idenewtxt("#Item:")

    a2$ = str2$(_Red32(IDETextColor))
    i = i + 1
    o(i).typ = 1
    o(i).x = 66
    o(i).y = 5
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)
    o(i).issel = -1
    o(i).sx1 = 0

    a2$ = str2$(_Green32(IDETextColor))
    i = i + 1
    o(i).typ = 1
    o(i).x = 66
    o(i).y = 8
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)
    o(i).issel = -1
    o(i).sx1 = 0

    a2$ = str2$(_Blue32(IDETextColor))
    i = i + 1
    o(i).typ = 1
    o(i).x = 66
    o(i).y = 11
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)
    o(i).issel = -1
    o(i).sx1 = 0

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 16
    o(i).nam = idenewtxt("#Highlight brackets")
    If brackethighlight Then o(i).sel = 1

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 17
    o(i).nam = idenewtxt("#Multi-highlight (selection)")
    If multihighlight Then o(i).sel = 1

    i = i + 1
    o(i).typ = 4 'check box
    o(i).y = 18
    o(i).nam = idenewtxt("Highlight #keywords and numbers")
    If keywordHighlight Then o(i).sel = 1

    i = i + 1
    o(i).typ = 3
    o(i).y = 20
    o(i).txt = idenewtxt("#OK" + sep + "Restore #Defaults" + sep + "#Cancel")
    o(i).dft = 1

    result = ReadConfigSetting(colorSettingsSection$, "SchemeID", value$)
    SchemeID = Val(value$)
    If SchemeID > TotalColorSchemes Then SchemeID = 0

    If SchemeID = 0 Then
        a2$ = "User-defined"
    Else
        'Validate this scheme first
        FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
        If FoundPipe > 0 Then
            If Len(Mid$(ColorSchemes$(SchemeID), FoundPipe + 1)) = 90 Then
                a2$ = Left$(ColorSchemes$(SchemeID), FoundPipe - 1)
            Else
                SchemeID = 0
                a2$ = "User-defined"
            End If
        Else
            SchemeID = 0
            a2$ = "User-defined"
        End If
    End If
    i = i + 1
    o(i).typ = 1
    o(i).x = 9
    o(i).y = 2
    o(i).w = 38
    o(i).nam = idenewtxt("#Scheme")
    o(i).txt = idenewtxt(a2$)
    o(i).v1 = Len(a2$)

    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then

                'prepare object
                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        'Color scheme selection arrows:
        Locate p.y + 2, p.x + 2
        If mY = p.y + 2 And mX >= p.x + 2 And mX <= p.x + 4 Then Color 15, 0 Else Color 15, 2
        If SchemeID <= 1 Then Color 7, 2
        Print " " + Chr$(17) + " ";
        If mY = p.y + 2 And mX >= p.x + 5 And mX <= p.x + 7 Then Color 15, 0 Else Color 15, 2
        If SchemeID = LastValidColorScheme Then Color 7, 2
        Print " " + Chr$(16) + " ";

        'Color scheme Save and Erase buttons:
        Locate p.y + 2, p.x + 60
        If mY = p.y + 2 And mX >= p.x + 60 And mX <= p.x + 65 Then Color 15, 0 Else Color 15, 2
        If SchemeID > 0 And SchemeID <= PresetColorSchemes Then Color 7, 2 'Disable if preset scheme
        Print " Save ";
        If mY = p.y + 2 And mX >= p.x + 66 And mX <= p.x + 72 Then Color 15, 0 Else Color 15, 2
        If SchemeID <= PresetColorSchemes Then Color 7, 2 'Disable if preset scheme or unsaved user-defined
        Print " Erase ";

        Color , 7

        _PaletteColor 1, IDEBackgroundColor, 0
        _PaletteColor 2, _RGB32(84, 84, 84), 0 'dark gray - help system and interface details
        _PaletteColor 6, IDEBackgroundColor2, 0
        _PaletteColor 7, IDEChromaColor, 0
        _PaletteColor 8, IDENumbersColor, 0
        _PaletteColor 10, IDEMetaCommandColor, 0
        _PaletteColor 11, IDECommentColor, 0
        _PaletteColor 12, IDEKeywordColor, 0
        _PaletteColor 13, IDETextColor, 0
        _PaletteColor 14, IDEQuoteColor, 0

        Color 0: Locate p.y + 5, p.x + 36: Print "R: ";
        Color 4: Print String$(26, 196);
        slider$ = Chr$(197)
        T = Val(idetxt(o(2).txt)): r = ((T / 255) * 26)
        If T = 0 Then slider$ = Chr$(195)
        If T = 255 Then slider$ = Chr$(180)
        _PrintString (p.x + 39 + r, p.y + 5), slider$

        Color 0: Locate p.y + 8, p.x + 36: Print "G: ";
        Color 5: Print String$(26, 196);
        slider$ = Chr$(197)
        T = Val(idetxt(o(3).txt)): r = ((T / 255) * 26)
        If T = 0 Then slider$ = Chr$(195)
        If T = 255 Then slider$ = Chr$(180)
        _PrintString (p.x + 39 + r, p.y + 8), slider$

        Color 0: Locate p.y + 11, p.x + 36: Print "B: ";
        Color 9: Print String$(26, 196);
        slider$ = Chr$(197)
        T = Val(idetxt(o(4).txt)): r = ((T / 255) * 26)
        If T = 0 Then slider$ = Chr$(195)
        If T = 255 Then slider$ = Chr$(180)
        _PrintString (p.x + 39 + r, p.y + 11), slider$

        Select EveryCase SelectedITEM
            Case 1 To 9
                Color 7, 1
                _PrintString (p.x + 39, p.y + 13), Chr$(218) + String$(25, 196)
                _PrintString (p.x + 39, p.y + 14), Chr$(179) + Space$(25)
                _PrintString (p.x + 39, p.y + 15), Chr$(179) + Space$(25)
            Case 1: Color 13, 1: SampleText$ = "myVar% = " 'Normal text
            Case 2: Color 12, 1: SampleText$ = "CLS: PRINT" 'Keywords
            Case 3: Color 13, 1: SampleText$ = "myVar% = " 'Normal text
            Case 4: Color 14, 1: SampleText$ = Space$(6) + Chr$(34) + "Hello, world!" + Chr$(34) 'Strings
            Case 5: Color 10, 1: SampleText$ = "'$DYNAMIC" 'Metacommands
            Case 6: Color 11, 1: SampleText$ = "'TODO: review this block" 'Comments
            Case 7: Color 1, 1: SampleText$ = "" 'Background
            Case 8: Color 6, 6: SampleText$ = Space$(25) 'Current line background
            Case 9
                Color 6, 6: SampleText$ = "" 'Bracket highlight
                _PaletteColor 6, IDEBracketHighlightColor, 0
            Case 10
                Color 0, 7
                _PrintString (p.x + 39, p.y + 13), Chr$(218) + String$(24, 196) + Chr$(191)
                _PrintString (p.x + 39, p.y + 14), Chr$(179) + Space$(24) + Chr$(179)
                _PrintString (p.x + 39, p.y + 15), Chr$(192) + String$(24, 196) + Chr$(217)
                SampleText$ = " Open...         Ctrl+O "
        End Select

        _PrintString (p.x + 40, p.y + 14), SampleText$
        If SelectedITEM = 1 Or SelectedITEM = 3 Then
            Color 8, 1
            _PrintString (p.x + 49, p.y + 14), "5"
        ElseIf SelectedITEM = 2 Then
            Color 13, 1
            _PrintString (p.x + 51, p.y + 14), "myVar%"
        ElseIf SelectedITEM = 4 Then
            Color 12, 1
            _PrintString (p.x + 40, p.y + 14), "PRINT"
        ElseIf SelectedITEM = 5 Then
            Color 11, 1
            _PrintString (p.x + 40, p.y + 14), "'"
        ElseIf SelectedITEM = 9 Then
            Locate p.y + 14, p.x + 40
            Color 13, 1: Print "myVar% = ";
            Color 12: Print "INT RND";
            Locate p.y + 14, p.x + 52
            Color 13, 6: Print "(";
            Locate p.y + 14, p.x + 56
            Print ")";
        ElseIf SelectedITEM = 10 Then
            Color 15, 7
            _PrintString (p.x + 41, p.y + 14), "O"
        End If
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            If mX <> prev.mX Or mY <> prev.mY Then change = 1: prev.mX = mX: prev.mY = mY
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            T = o(i).typ
            If T Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'specific post controls
        If focus <> PrevFocus Then
            'Always start with RGB values AND scheme name selected upon getting focus
            PrevFocus = focus
            If (focus >= 2 And focus <= 4) Or focus = 11 Then
                If focus = 11 Then tfocus = 9 Else tfocus = focus
                o(tfocus).v1 = Len(idetxt(o(tfocus).txt))
                If o(tfocus).v1 > 0 Then o(tfocus).issel = -1
                o(tfocus).sx1 = 0
                If (tfocus >= 2 And tfocus <= 4) Then prevTB.value$ = idetxt(o(tfocus).txt)
            End If
        ElseIf focus = PrevFocus Then
            'Check if new values have been entered into textboxes
            If focus >= 2 And focus <= 4 Then
                If prevTB.value$ <> idetxt(o(focus).txt) Then
                    GoSub NewUserScheme
                    prevTB.value$ = idetxt(o(focus).txt)
                End If
            End If
        End If

        'Save and Erase color scheme (Buttons):
        If (SchemeID = 0 Or SchemeID > PresetColorSchemes) And mCLICK Then
            If mY = p.y + 2 And mX >= p.x + 60 And mX <= p.x + 65 Then
                'Save
                If SchemeID = 0 Then
                    SaveNew:
                    SchemeString$ = LTrim$(RTrim$(idetxt(o(9).txt)))
                    If Len(SchemeString$) = 0 Then SchemeString$ = "User-defined"
                    'Find the next free scheme index
                    i = 0
                    Do
                        i = i + 1
                        result = ReadConfigSetting(colorSchemesSection$, "Scheme" + str2$(i) + "$", value$)
                        If value$ = "" Or value$ = "0" Then Exit Do
                    Loop

                    'Build scheme string
                    SchemeString$ = SchemeString$ + "|"
                    For j = 1 To 10
                        Select Case j
                            Case 1: CurrentColor~& = IDETextColor
                            Case 2: CurrentColor~& = IDEKeywordColor
                            Case 3: CurrentColor~& = IDENumbersColor
                            Case 4: CurrentColor~& = IDEQuoteColor
                            Case 5: CurrentColor~& = IDEMetaCommandColor
                            Case 6: CurrentColor~& = IDECommentColor
                            Case 7: CurrentColor~& = IDEBackgroundColor
                            Case 8: CurrentColor~& = IDEBackgroundColor2
                            Case 9: CurrentColor~& = IDEBracketHighlightColor
                            Case 10: CurrentColor~& = IDEChromaColor
                        End Select

                        r$ = str2$(_Red32(CurrentColor~&)): r$ = String$(3 - Len(r$), "0") + r$
                        g$ = str2$(_Green32(CurrentColor~&)): g$ = String$(3 - Len(g$), "0") + g$
                        b$ = str2$(_Blue32(CurrentColor~&)): b$ = String$(3 - Len(b$), "0") + b$
                        SchemeString$ = SchemeString$ + r$ + g$ + b$
                    Next j

                    'Save user scheme
                    WriteConfigSetting colorSchemesSection$, "Scheme" + str2$(i) + "$", SchemeString$
                    LoadColorSchemes
                    SchemeID = PresetColorSchemes + i
                    ChangedScheme = -1
                    GoTo ApplyScheme
                Else
                    FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
                    SchemeString$ = Left$(ColorSchemes$(SchemeID), FoundPipe - 1)

                    If SchemeString$ <> LTrim$(RTrim$(idetxt(o(9).txt))) Then
                        'User wants to save the current SchemeID under a different name
                        GoTo SaveNew
                    End If

                    i = SchemeID - PresetColorSchemes
                    SchemeString$ = SchemeString$ + "|"

                    'Build scheme string
                    For j = 1 To 10
                        Select Case j
                            Case 1: CurrentColor~& = IDETextColor
                            Case 2: CurrentColor~& = IDEKeywordColor
                            Case 3: CurrentColor~& = IDENumbersColor
                            Case 4: CurrentColor~& = IDEQuoteColor
                            Case 5: CurrentColor~& = IDEMetaCommandColor
                            Case 6: CurrentColor~& = IDECommentColor
                            Case 7: CurrentColor~& = IDEBackgroundColor
                            Case 8: CurrentColor~& = IDEBackgroundColor2
                            Case 9: CurrentColor~& = IDEBracketHighlightColor
                            Case 10: CurrentColor~& = IDEChromaColor
                        End Select

                        r$ = str2$(_Red32(CurrentColor~&)): r$ = String$(3 - Len(r$), "0") + r$
                        g$ = str2$(_Green32(CurrentColor~&)): g$ = String$(3 - Len(g$), "0") + g$
                        b$ = str2$(_Blue32(CurrentColor~&)): b$ = String$(3 - Len(b$), "0") + b$
                        SchemeString$ = SchemeString$ + r$ + g$ + b$
                    Next j

                    'Save user scheme
                    WriteConfigSetting colorSchemesSection$, "Scheme" + str2$(i) + "$", SchemeString$
                    LoadColorSchemes
                    SchemeID = PresetColorSchemes + i
                    ChangedScheme = -1
                    GoTo ApplyScheme
                End If
                o(9).v1 = Len(idetxt(o(9).txt))
                o(9).issel = -1
                o(9).sx1 = 0
            ElseIf mY = p.y + 2 And mX >= p.x + 66 And mX <= p.x + 72 Then
                'Erase
                If SchemeID > PresetColorSchemes Then
                    what$ = ideyesnobox("Erase color scheme", "This cannot be undone. Erase scheme?")
                    K$ = ""
                    If what$ = "Y" Then
                        i = SchemeID - PresetColorSchemes
                        WriteConfigSetting colorSchemesSection$, "Scheme" + str2$(i) + "$", "0"
                        LoadColorSchemes
                        SchemeID = SchemeID - 1
                        ChangedScheme = -1
                        SchemeArrow = -1
                        GoTo ValidateScheme
                    End If
                End If
            End If
        End If

        'Scheme selection arrows:
        ChangedScheme = 0
        SchemeArrow = 0
        IF (mCLICK AND mY = p.y + 2 AND mX >= p.x + 2 AND mX <= p.x + 4) OR _
           (K$ = CHR$(0) + CHR$(75) AND (focus = 1)) THEN
            SchemeArrow = -1
            If SchemeID = 0 Then
                ChangedScheme = -1
                GoTo LoadDefaultScheme
            Else
                If SchemeID > 1 Then SchemeID = SchemeID - 1: ChangedScheme = -1
            End If
        ELSEIF (mCLICK AND mY = p.y + 2 AND mX >= p.x + 5 AND mX <= p.x + 7) OR _
               (K$ = CHR$(0) + CHR$(77) AND (focus = 1)) THEN
            SchemeArrow = 1
            If SchemeID = 0 Then
                ChangedScheme = -1
                GoTo LoadDefaultScheme
            Else
                If SchemeID < TotalColorSchemes Then SchemeID = SchemeID + 1: ChangedScheme = -1
            End If
        End If

        If ChangedScheme Then
            'Validate this scheme first
            If SchemeArrow = 0 Then SchemeArrow = 1
            ValidateScheme:
            FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
            If FoundPipe > 0 Then
                If Len(Mid$(ColorSchemes$(SchemeID), FoundPipe + 1)) = 90 Then
                    a2$ = Left$(ColorSchemes$(SchemeID), FoundPipe - 1)
                Else
                    SchemeID = SchemeID + SchemeArrow
                    If SchemeID > TotalColorSchemes Then SchemeID = TotalColorSchemes: SchemeArrow = -1
                    If SchemeID < 1 Then SchemeID = 1
                    GoTo ValidateScheme
                End If
            Else
                SchemeID = SchemeID + SchemeArrow
                If SchemeID > TotalColorSchemes Then SchemeID = TotalColorSchemes: SchemeArrow = -1
                If SchemeID < 1 Then SchemeID = 1
                GoTo ValidateScheme
            End If
            ApplyScheme:
            FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
            idetxt(o(9).txt) = Left$(ColorSchemes$(SchemeID), FoundPipe - 1)
            o(9).v1 = Len(idetxt(o(9).txt))
            o(9).issel = -1
            o(9).sx1 = 0
            ColorData$ = Right$(ColorSchemes$(SchemeID), 90)
            i = 1
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDETextColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEKeywordColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDENumbersColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEQuoteColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEMetaCommandColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDECommentColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEBackgroundColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEBackgroundColor2 = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEBracketHighlightColor = _RGB32(Val(r$), Val(g$), Val(b$))
            r$ = Mid$(ColorData$, i, 3): i = i + 3: g$ = Mid$(ColorData$, i, 3): i = i + 3: b$ = Mid$(ColorData$, i, 3): i = i + 3
            IDEChromaColor = _RGB32(Val(r$), Val(g$), Val(b$))
            GoTo ChangeTextBoxes
        End If

        If mB And mY = p.y + 5 And mX >= p.x + 39 And mX <= p.x + 39 + 26 Then
            newValue = (mX - p.x - 39) * (255 / 26)
            idetxt(o(2).txt) = str2$(newValue)
            If _KeyDown(100305) Or _KeyDown(100306) Then
                idetxt(o(3).txt) = str2$(newValue)
                idetxt(o(4).txt) = str2$(newValue)
            End If
            focus = 2
            o(focus).v1 = Len(idetxt(o(focus).txt))
            o(focus).issel = -1
            o(focus).sx1 = 0
            GoSub NewUserScheme
        End If

        If mB And mY = p.y + 8 And mX >= p.x + 39 And mX <= p.x + 39 + 26 Then
            newValue = (mX - p.x - 39) * (255 / 26)
            idetxt(o(3).txt) = str2$(newValue)
            If _KeyDown(100305) Or _KeyDown(100306) Then
                idetxt(o(2).txt) = str2$(newValue)
                idetxt(o(4).txt) = str2$(newValue)
            End If
            focus = 3
            o(focus).v1 = Len(idetxt(o(focus).txt))
            o(focus).issel = -1
            o(focus).sx1 = 0
            GoSub NewUserScheme
        End If

        If mB And mY = p.y + 11 And mX >= p.x + 39 And mX <= p.x + 39 + 26 Then
            newValue = (mX - p.x - 39) * (255 / 26)
            idetxt(o(4).txt) = str2$(newValue)
            If _KeyDown(100305) Or _KeyDown(100306) Then
                idetxt(o(2).txt) = str2$(newValue)
                idetxt(o(3).txt) = str2$(newValue)
            End If
            focus = 4
            o(focus).v1 = Len(idetxt(o(focus).txt))
            o(focus).issel = -1
            o(focus).sx1 = 0
            GoSub NewUserScheme
        End If

        ChangedWithKeys = 0
        If K$ = Chr$(0) + Chr$(72) And (focus = 2 Or focus = 3 Or focus = 4) Then 'Up
            idetxt(o(focus).txt) = str2$(Val(idetxt(o(focus).txt)) + 1)
            o(focus).issel = -1: o(focus).sx1 = 0: o(focus).v1 = Len(idetxt(o(focus).txt))
            ChangedWithKeys = -1
            GoSub NewUserScheme
        End If

        If K$ = Chr$(0) + Chr$(80) And (focus = 2 Or focus = 3 Or focus = 4) Then 'Down
            idetxt(o(focus).txt) = str2$(Val(idetxt(o(focus).txt)) - 1)
            o(focus).issel = -1: o(focus).sx1 = 0: o(focus).v1 = Len(idetxt(o(focus).txt))
            ChangedWithKeys = -1
            GoSub NewUserScheme
        End If

        If SelectedITEM <> o(1).sel And o(1).sel > 0 Then
            SelectedITEM = o(1).sel
            For i = 1 To 10: SelectionIndicator$(i) = " ": Next i
            SelectionIndicator$(SelectedITEM) = Chr$(16)

            i = 0
            i = i + 1: l$ = SelectionIndicator$(i) + "Normal Text"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Keywords"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Numbers"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Strings"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Metacommand/custom keywords"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Comments"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Background"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Current line background"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Bracket/selection highlight"
            i = i + 1: l$ = l$ + sep + SelectionIndicator$(i) + "Menus and dialogs"
            idetxt(o(1).txt) = l$

            ChangeTextBoxes:
            Select Case SelectedITEM
                Case 1: CurrentColor~& = IDETextColor
                Case 2: CurrentColor~& = IDEKeywordColor
                Case 3: CurrentColor~& = IDENumbersColor
                Case 4: CurrentColor~& = IDEQuoteColor
                Case 5: CurrentColor~& = IDEMetaCommandColor
                Case 6: CurrentColor~& = IDECommentColor
                Case 7: CurrentColor~& = IDEBackgroundColor
                Case 8: CurrentColor~& = IDEBackgroundColor2
                Case 9: CurrentColor~& = IDEBracketHighlightColor
                Case 10: CurrentColor~& = IDEChromaColor
            End Select
            idetxt(o(2).txt) = str2$(_Red32(CurrentColor~&))
            idetxt(o(3).txt) = str2$(_Green32(CurrentColor~&))
            idetxt(o(4).txt) = str2$(_Blue32(CurrentColor~&))
            If focus >= 2 And focus <= 4 And ChangedScheme Then
                prevTB.value$ = idetxt(o(focus).txt)
            End If
        End If

        'Check RGB values range (0-255)
        For checkRGB = 2 To 4
            a$ = idetxt(o(checkRGB).txt)
            If Len(a$) > 3 Then a$ = Left$(a$, 3) '3 character limit
            For i = 1 To Len(a$)
                a = Asc(a$, i)
                If i = 2 And Asc(a$, 1) = 48 Then a$ = "0": Exit For
                If a < 48 Or a > 57 Then a$ = "": Exit For
            Next
            If Len(a$) Then
                a = Val(a$)
                If a > 255 Then a$ = "255"
                If a < 0 Then a$ = "0"
            Else
                If ChangedWithKeys = -1 Then a$ = "0"
            End If
            idetxt(o(checkRGB).txt) = a$
        Next checkRGB

        'Check for valid scheme name
        FoundPipe = InStr(idetxt(o(9).txt), "|")
        If FoundPipe > 0 Then
            a2$ = Left$(idetxt(o(9).txt), FoundPipe - 1) + Mid$(idetxt(o(9).txt), FoundPipe + 1)
            idetxt(o(9).txt) = a2$
            If o(9).v1 >= FoundPipe Then o(9).v1 = o(9).v1 - 1
        End If

        If SchemeID > 0 Then
            FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
            If RTrim$(LTrim$(idetxt(o(9).txt))) <> Left$(ColorSchemes$(SchemeID), FoundPipe - 1) Then
                'A different scheme name is the beginning of editing a new one
                SchemeID = 0
            End If
        End If

        CurrentColor~& = _RGB32(Val(idetxt(o(2).txt)), Val(idetxt(o(3).txt)), Val(idetxt(o(4).txt)))
        Select Case SelectedITEM
            Case 1: IDETextColor = CurrentColor~& 'Normal text
            Case 2: IDEKeywordColor = CurrentColor~& 'Keywords
            Case 3: IDENumbersColor = CurrentColor~& 'Numbers
            Case 4: IDEQuoteColor = CurrentColor~& 'Strings
            Case 5: IDEMetaCommandColor = CurrentColor~& 'Metacommands
            Case 6: IDECommentColor = CurrentColor~& 'Comments
            Case 7: IDEBackgroundColor = CurrentColor~& 'Background
            Case 8: IDEBackgroundColor2 = CurrentColor~& 'Current line background
            Case 9: IDEBracketHighlightColor = CurrentColor~& 'Bracket highlight
            Case 10: IDEChromaColor = CurrentColor~&
        End Select

        If K$ = Chr$(27) Or (focus = 10 And info <> 0) Then
            IDECommentColor = bkpIDECommentColor
            IDEMetaCommandColor = bkpIDEMetaCommandColor
            IDEQuoteColor = bkpIDEQuoteColor
            IDETextColor = bkpIDETextColor
            IDEKeywordColor = bkpIDEKeywordColor
            IDENumbersColor = bkpIDENumbersColor
            IDEBackgroundColor = bkpIDEBackgroundColor
            IDEBackgroundColor2 = bkpIDEBackgroundColor2
            IDEBracketHighlightColor = bkpIDEBracketHighlightColor
            IDEChromaColor = bkpIDEChromaColor
            Exit Function
        End If

        If (focus = 9 And info <> 0) Then
            LoadDefaultScheme:
            GoSub enableHighlighter
            SchemeID = 1
            FoundPipe = InStr(ColorSchemes$(SchemeID), "|")
            idetxt(o(9).txt) = Left$(ColorSchemes$(SchemeID), FoundPipe - 1)
            info = 0
            GoTo ApplyScheme
        End If

    IF (focus = 8 AND info <> 0) OR _
       (focus = 1 AND K$ = CHR$(13)) OR _
       (focus = 2 AND K$ = CHR$(13)) OR _
       (focus = 3 AND K$ = CHR$(13)) OR _
       (focus = 4 AND K$ = CHR$(13)) OR _
       (focus = 5 AND K$ = CHR$(13)) OR _
       (focus = 6 AND K$ = CHR$(13)) OR _
       (focus = 7 AND K$ = CHR$(13)) OR _
       (focus = 11 AND K$ = CHR$(13)) THEN
            'save changes
            GoSub enableHighlighter

            WriteConfigSetting colorSettingsSection$, "SchemeID", str2$(SchemeID)
            For i = 1 To 10
                Select Case i
                    Case 1: CurrentColor~& = IDETextColor: colorid$ = "TextColor"
                    Case 2: CurrentColor~& = IDEKeywordColor: colorid$ = "KeywordColor"
                    Case 3: CurrentColor~& = IDENumbersColor: colorid$ = "NumbersColor"
                    Case 4: CurrentColor~& = IDEQuoteColor: colorid$ = "QuoteColor"
                    Case 5: CurrentColor~& = IDEMetaCommandColor: colorid$ = "MetaCommandColor"
                    Case 6: CurrentColor~& = IDECommentColor: colorid$ = "CommentColor"
                    Case 7: CurrentColor~& = IDEBackgroundColor: colorid$ = "BackgroundColor"
                    Case 8: CurrentColor~& = IDEBackgroundColor2: colorid$ = "BackgroundColor2"
                    Case 9: CurrentColor~& = IDEBracketHighlightColor: colorid$ = "HighlightColor"
                    Case 10: CurrentColor~& = IDEChromaColor: colorid$ = "ChromaColor"
                End Select
                WriteConfigSetting colorSettingsSection$, colorid$, rgbs$(CurrentColor~&)
            Next i

            v% = o(5).sel
            If v% <> 0 Then v% = -1
            brackethighlight = v%

            If brackethighlight Then
                WriteConfigSetting generalSettingsSection$, "BracketHighlight", "True"
            Else
                WriteConfigSetting generalSettingsSection$, "BracketHighlight", "False"
            End If

            v% = o(6).sel
            If v% <> 0 Then v% = -1
            multihighlight = v%

            If multihighlight Then
                WriteConfigSetting generalSettingsSection$, "MultiHighlight", "True"
            Else
                WriteConfigSetting generalSettingsSection$, "MultiHighlight", "False"
            End If

            v% = o(7).sel
            If v% <> 0 Then v% = -1
            keywordHighlight = v%

            If keywordHighlight Then
                WriteConfigSetting generalSettingsSection$, "KeywordHighlight", "True"
            Else
                WriteConfigSetting generalSettingsSection$, "KeywordHighlight", "False"
            End If

            Exit Function
        End If

        'end of custom controls

        mousedown = 0
        mouseup = 0
    Loop

    idechoosecolorsbox = 0

    Exit Function
    NewUserScheme:
    If SchemeID > 0 And SchemeID <= PresetColorSchemes Then
        'If one of the preset schemes is currently selected,
        'create a new one. User-defined types can be freely
        'edited.
        SchemeID = 0
        idetxt(o(9).txt) = "User-defined"
    End If
    Return

    enableHighlighter:
    If DisableSyntaxHighlighter Then
        DisableSyntaxHighlighter = 0
        WriteConfigSetting generalSettingsSection$, "DisableSyntaxHighlighter", "False"
        menu$(OptionsMenuID, OptionsMenuDisableSyntax) = Chr$(7) + "Syntax #Highlighter"
    End If
    Return
End Function

Function CountItems (SearchString$, Item$)
    Do
        Found = InStr(Found + 1, SearchString$, Item$)
        If Found = 0 Then Exit Do
        Total = Total + 1
    Loop
    CountItems = Total
End Function

Sub GetInput
    Static ASCvalue$

    If iCHECKLATER Then iCHECKLATER = 0: Exit Sub
    'Clear/Update immediate return values
    iCHANGED = 0
    KSTATECHANGED = 0
    mCLICK = 0: mCLICK2 = 0: mRELEASE = 0: mRELEASE2 = 0
    mWHEEL = 0
    K$ = "": KB = 0
    mOB = mB: mOB2 = mB2
    KOALT = KALT: KALTPRESS = 0: KALTRELEASE = 0
    'Flush INKEY$ buffer (for good measure)
    Do: Loop Until InKey$ = ""
    'Keyboard event?
    k = _KeyHit

    'Steve Edit on 07-04-2014 to add extended ASCII creation with ALT-plus numkeys
    If (_KeyDown(100307) Or _KeyDown(100308)) And (k >= -57 And k <= -48) Then
        ASCvalue$ = ASCvalue$ + Chr$(-k)
    End If
    If Not _KeyDown(100307) And Not _KeyDown(100308) Then
        If Len(ASCvalue$) Then
            KB = Val(Right$(ASCvalue$, 3))
            If KB > 0 And KB < 256 Then
                K$ = Chr$(KB)
                k = KB
                iCHANGED = -1
                AltSpecial = -1
            End If
            ASCvalue$ = ""
            Exit Sub
        End If
    End If
    'End of Edit

    If k Then
        If k < 0 Then k = -k: release = 1
        'modifiers
        If k = KEY_LSHIFT Or k = KEY_RSHIFT Then
            If release = 1 Then KSHIFT = 0 Else KSHIFT = -1
            iCHANGED = -1: KSTATECHANGED = -1
        End If
        If k = KEY_LALT Or k = KEY_RALT Then
            If release = 1 Then
                KALT = 0: KALTRELEASE = -1
            Else
                KALT = -1: KALTPRESS = -1
            End If
            iCHANGED = -1: KSTATECHANGED = -1
        End If
        If k = KEY_LCTRL Or k = KEY_RCTRL Then
            If release = 1 Then KCTRL = 0: KCONTROL = 0 Else KCTRL = -1: KCONTROL = -1
            iCHANGED = -1: KSTATECHANGED = -1
        End If
        If k = KEY_LAPPLE Or k = KEY_RAPPLE Then
            If release = 1 Then KCONTROL = 0 Else KCONTROL = -1
            iCHANGED = -1: KSTATECHANGED = -1
        End If
        'presses
        If release = 0 Then
            iCHANGED = -1
            If k <= 255 Then K$ = Chr$(k)
            If k >= 256 And k <= 65535 And ((k And 255) = 0) Then K$ = Chr$(0) + Chr$(k \ 256)
            KB = k
        End If
        If iCHANGED Then Exit Sub
    End If
    Do While _MouseInput
        iCHANGED = 1
        If MouseButtonSwapped Then
            mB = _MouseButton(2): mB2 = _MouseButton(1)
        Else
            mB = _MouseButton(1): mB2 = _MouseButton(2)
        End If
        mWHEEL = mWHEEL + _MouseWheel
        mX = _MouseX: mY = _MouseY
        If mB <> 0 And mOB = 0 Then mCLICK = -1: Exit Sub
        If mB2 <> 0 And mOB2 = 0 Then mCLICK2 = -1: Exit Sub
        If mB = 0 And mOB <> 0 Then mRELEASE = -1: Exit Sub
        If mB2 = 0 And mOB2 <> 0 Then mRELEASE2 = -1: Exit Sub
    Loop
End Sub

Sub ClearMouse
    iCHANGED = 0
    mB = 0
    mB2 = 0
    mCLICK = 0
    mRELEASE = 0
    Do While _MouseButton(1) Or _MouseButton(2)
        i = _MouseInput
    Loop
End Sub

Function idesearchedbox$

    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    ln = 0
    l$ = ""
    fh = FreeFile
    Open ".\internal\temp\searched.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    a$ = Right$(a$, Len(a$) - 2)
    Do While Len(a$)
        ai = InStr(a$, CRLF)
        If ai Then
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            If Len(l$) Then l$ = l$ + sep + f$ Else l$ = f$
            ln = ln + 1
        End If
    Loop
    Close #fh

    If ln = 0 Then
        l$ = sep
    End If

    '72,19

    h = idewy + idesubwindow - 9
    If ln < h Then h = ln
    If h < 3 Then h = 3

    i = 0
    idepar p, 20, h, ""
    p.x = idewx - 24
    p.y = idewy - 6 - h
    If p.y < 3 Then
        p.h = p.h - Abs(3 - p.y)
        h = p.h
        p.y = 3
    End If

    i = i + 1
    o(i).typ = 2
    o(i).x = -1: o(i).y = 0

    o(i).w = 22: o(i).h = h
    o(i).txt = idenewtxt(l$)
    o(i).sel = 1
    o(i).nam = idenewtxt("Find")

    'i = i + 1
    'o(i).typ = 3
    'o(i).y = idewy - 6
    'o(i).txt = idenewtxt("#OK" + sep + "#Cancel")
    'o(i).dft = 1

    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object

                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        'quick exit
        If mCLICK Then
            If mX < p.x - 1 Or mY < p.y Or mX > p.x + p.w + 2 Or mY > p.y + p.h + 1 Then
                idesearchedbox$ = ""
                Exit Function
            End If
        End If

        If K$ = Chr$(27) Then
            idesearchedbox$ = ""
            Exit Function
        End If

        If mCLICK Then
            If mX > p.x - 1 And mY > p.y And mX < p.x + p.w + 2 And mY < p.y + p.h + 1 Then
                f$ = idetxt(o(1).stx)
                idesearchedbox$ = f$
                Exit Function
            End If
        End If

        If K$ = Chr$(13) Or (info = 1 And focus = 1) Then
            f$ = idetxt(o(1).stx)
            idesearchedbox$ = f$
            Exit Function
        End If

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop

End Function

Function iderecentbox$
    '-------- generic dialog box header --------
    PCopy 0, 2
    PCopy 0, 1
    Screen , , 1, 0
    focus = 1
    Dim p As idedbptype
    Dim o(1 To 100) As idedbotype
    Dim sep As String * 1
    sep = Chr$(0)
    '-------- end of generic dialog box header --------

    '-------- init --------

    l$ = ""
    dialogWidth = 72
    totalRecent = 0
    fh = FreeFile
    Open ".\internal\temp\recent.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    a$ = Right$(a$, Len(a$) - 2)
    ReDim tempList$(100)
    Do While Len(a$)
        ai = InStr(a$, CRLF)
        If ai Then
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            If Len(f$) + 6 > dialogWidth Then dialogWidth = Len(f$) + 6
            totalRecent = totalRecent + 1
            If totalRecent > UBound(tempList$) Then
                ReDim _Preserve tempList$(UBound(tempList$) + 100)
            End If
            tempList$(totalRecent) = f$
            If Len(l$) Then l$ = l$ + sep + f$ Else l$ = f$
        End If
    Loop
    Close #fh

    '72,19
    i = 0
    dialogHeight = (totalRecent) + 3
    If dialogHeight > idewy + idesubwindow - 6 Then
        dialogHeight = idewy + idesubwindow - 6
    End If

    If dialogWidth > idewx - 8 Then dialogWidth = idewx - 8
    idepar p, dialogWidth, dialogHeight, "Open"

    i = i + 1
    o(i).typ = 2
    o(i).y = 1
    '68
    o(i).w = dialogWidth - 4: o(i).h = dialogHeight - 3
    o(i).txt = idenewtxt(l$)
    o(i).sel = 1
    o(i).nam = idenewtxt("Recent Programs")

    i = i + 1
    o(i).typ = 3
    o(i).y = dialogHeight
    o(i).txt = idenewtxt("#Open" + sep + "#Cancel" + sep + "Clear #list" + sep + "#Remove broken links")
    o(i).dft = 1

    '-------- end of init --------

    '-------- generic init --------
    For i = 1 To 100: o(i).par = p: Next 'set parent info of objects
    '-------- end of generic init --------

    Do 'main loop

        '-------- generic display dialog box & objects --------
        idedrawpar p
        f = 1: cx = 0: cy = 0
        For i = 1 To 100
            If o(i).typ Then
                'prepare object

                o(i).foc = focus - f 'focus offset
                o(i).cx = 0: o(i).cy = 0
                idedrawobj o(i), f 'display object
                If o(i).cx Then cx = o(i).cx: cy = o(i).cy
            End If
        Next i
        lastfocus = f - 1
        '-------- end of generic display dialog box & objects --------

        '-------- custom display changes --------
        '-------- end of custom display changes --------

        'update visual page and cursor position
        PCopy 1, 0
        If cx Then Screen , , 0, 0: Locate cy, cx, 1: Screen , , 1, 0

        '-------- read input --------
        change = 0
        Do
            GetInput
            If mWHEEL Then change = 1
            If KB Then change = 1
            If mCLICK Then mousedown = 1: change = 1
            If mRELEASE Then mouseup = 1: change = 1
            If mB Then change = 1
            alt = KALT: If alt <> oldalt Then change = 1
            oldalt = alt
            _Limit 100
        Loop Until change
        If alt And Not KCTRL Then idehl = 1 Else idehl = 0
        'convert "alt+letter" scancode to letter's ASCII character
        altletter$ = ""
        If alt And Not KCTRL Then
            If Len(K$) = 1 Then
                k = Asc(UCase$(K$))
                If k >= 65 And k <= 90 Then altletter$ = Chr$(k)
            End If
        End If
        Screen , , 0, 0: Locate , , 0: Screen , , 1, 0
        '-------- end of read input --------

        '-------- generic input response --------
        info = 0
        If K$ = "" Then K$ = Chr$(255)
        If KSHIFT = 0 And K$ = Chr$(9) Then focus = focus + 1
        If (KSHIFT And K$ = Chr$(9)) Then focus = focus - 1: K$ = ""
        If focus < 1 Then focus = lastfocus
        If focus > lastfocus Then focus = 1
        f = 1
        For i = 1 To 100
            t = o(i).typ
            If t Then
                focusoffset = focus - f
                ideobjupdate o(i), focus, f, focusoffset, K$, altletter$, mB, mousedown, mouseup, mX, mY, info, mWHEEL
            End If
        Next
        '-------- end of generic input response --------

        If K$ = Chr$(27) Or (focus = 3 And info <> 0) Then
            iderecentbox$ = ""
            Exit Function
        End If

        If (K$ = Chr$(13) And focus = 1) Or (focus = 2 And info <> 0) Or (info = 1 And focus = 1) Then
            f$ = tempList$(Abs(o(1).sel))
            iderecentbox$ = f$
            Exit Function
        End If

        If (K$ = Chr$(13) And focus = 4) Or (focus = 4 And info <> 0) Or (info = 1 And focus = 4) Then
            iderecentbox$ = "<C>"
            Exit Function
        End If

        If (K$ = Chr$(13) And focus = 5) Or (focus = 5 And info <> 0) Or (info = 1 And focus = 5) Then
            iderecentbox$ = "<R>"
            Exit Function
        End If

        'end of custom controls
        mousedown = 0
        mouseup = 0
    Loop
End Function

Sub IdeMakeFileMenu
    m = 1: i = 0
    menu$(m, i) = "File": i = i + 1
    menu$(m, i) = "#New  Ctrl+N": i = i + 1
    menuDesc$(m, i - 1) = "Closes current program and starts a blank one"
    menu$(m, i) = "#Open...  Ctrl+O": i = i + 1
    menuDesc$(m, i - 1) = "Loads a program into memory"
    menu$(m, i) = "#Save  Ctrl+S": i = i + 1
    menuDesc$(m, i - 1) = "Writes current program to a file on disk"
    menu$(m, i) = "Save #As...": i = i + 1
    menuDesc$(m, i - 1) = "Saves current program with specified name"
    fh = FreeFile
    Open ".\internal\temp\recent.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    a$ = Right$(a$, Len(a$) - 2)
    maxRecentInFileMenu = UBound(IdeRecentLink, 1)
    maxLengthRecentFiles = 35
    For r = 1 To maxRecentInFileMenu + 1
        If r <= maxRecentInFileMenu Then IdeRecentLink(r, 1) = ""
        ai = InStr(a$, CRLF)
        If ai Then
            If r = 1 Then menu$(m, i) = "-": i = i + 1
            f$ = Left$(a$, ai - 1): If ai = Len(a$) - 1 Then a$ = "" Else a$ = Right$(a$, Len(a$) - ai - 3)
            If r <= maxRecentInFileMenu Then IdeRecentLink(r, 2) = f$
            'f$ = MID$(f$, _INSTRREV(f$, pathsep$) + 1)
            If Len(f$) > maxLengthRecentFiles Then f$ = String$(3, 250) + Right$(f$, maxLengthRecentFiles - 3)
            f$ = "#" + str2$(r) + " " + f$
            If r = maxRecentInFileMenu + 1 Then f$ = "#Recent..."
            menu$(m, i) = f$
            If r <= maxRecentInFileMenu Then
                IdeRecentLink(r, 1) = f$
                f$ = "Open '" + IdeRecentLink(r, 2) + "'"
                ai = 3
                Do Until Len(f$) <= idewx - 2
                    ai = ai + 1
                    f$ = "Open '" + String$(3, 250) + Mid$(IdeRecentLink(r, 2), ai) + "'"
                Loop
                menuDesc$(m, i) = f$
            End If
            i = i + 1
        End If
    Next
    Close #fh
    If menu$(m, i - 1) <> "#Recent..." And menu$(m, i - 1) <> "Save #As..." Then
        menu$(m, i) = "#Clear Recent...": i = i + 1
        menuDesc$(m, i - 1) = "Clears list of recently loaded files"
    Else
        menuDesc$(m, i - 1) = "Displays a complete list of recently loaded files"
    End If
    menu$(m, i) = "-": i = i + 1
    menu$(m, i) = "E#xit": i = i + 1
    menuDesc$(m, i - 1) = "Exits QB64"
    menusize(m) = i - 1
End Sub

Sub IdeMakeContextualMenu
    ReDim SubFuncLIST(0) As String
    Dim Selection$

    m = idecontextualmenuID: i = 0
    menu$(m, i) = "Contextual": i = i + 1

    If IdeSystem = 1 Or IdeSystem = 2 Then
        'Figure out if the user wants to search for a selected term
        Selection$ = getSelectedText$(0)
        sela2$ = Selection$
        If Len(Selection$) > 0 Then
            idecontextualSearch$ = Selection$

            If Len(sela2$) > 22 Then
                sela2$ = Left$(sela2$, 19) + String$(3, 250)
            End If
            menu$(m, i) = "Find '" + sela2$ + "'": i = i + 1
            menuDesc$(m, i - 1) = "Searches for the text currently selected"
        End If

        'build SUB/FUNCTION list:
        TotalSF = 0
        For y = 1 To iden
            a$ = idegetline(y)
            a$ = LTrim$(RTrim$(a$))
            sf = 0
            nca$ = UCase$(a$)
            If Left$(nca$, 4) = "SUB " Then sf = 1: sf$ = "SUB  "
            If Left$(nca$, 9) = "FUNCTION " Then sf = 2: sf$ = "FUNC "
            If sf Then
                If Right$(nca$, 7) = " STATIC" Then
                    a$ = RTrim$(Left$(a$, Len(a$) - 7))
                End If

                If sf = 1 Then
                    a$ = Right$(a$, Len(a$) - 4)
                Else
                    a$ = Right$(a$, Len(a$) - 9)
                End If

                a$ = LTrim$(RTrim$(a$))
                x = InStr(a$, "(")
                If x Then
                    n$ = RTrim$(Left$(a$, x - 1))
                Else
                    n$ = a$
                    cleanSubName n$
                End If

                n2$ = n$
                If Len(n2$) > 1 Then
                    Do Until alphanumeric(Asc(Right$(n2$, 1)))
                        n2$ = Left$(n$, Len(n2$) - 1) 'removes sigil, if any
                    Loop
                End If

                'Populate SubFuncLIST()
                TotalSF = TotalSF + 1
                ReDim _Preserve SubFuncLIST(1 To TotalSF) As String
                SubFuncLIST(TotalSF) = MKL$(y) + Chr$(sf) + n2$
            End If
        Next

        'identify if word or character at current cursor position is in the help system OR a sub/func
        a2$ = UCase$(getWordAtCursor$)

        'check if cursor is on sub/func/label name
        If Len(LTrim$(RTrim$(Selection$))) > 0 Then
            Do Until alphanumeric(Asc(Right$(Selection$, 1)))
                Selection$ = Left$(Selection$, Len(Selection$) - 1) 'removes sigil, if any
                If Len(Selection$) = 0 Then Exit Do
            Loop
            Selection$ = LTrim$(RTrim$(Selection$))
        End If

        If Right$(a2$, 1) = "$" Then a3$ = Left$(a2$, Len(a2$) - 1) Else a3$ = a2$ 'creates a new version without $

        If Len(a3$) > 0 Or Len(Selection$) > 0 Then

            For CheckSF = 1 To TotalSF
                If a3$ = UCase$(Mid$(SubFuncLIST(CheckSF), 6)) Or UCase$(Selection$) = UCase$(Mid$(SubFuncLIST(CheckSF), 6)) Then
                    CurrSF$ = FindCurrentSF$(idecy)
                    If Len(CurrSF$) = 0 Then GoTo SkipCheckCurrSF

                    Do Until alphanumeric(Asc(Right$(CurrSF$, 1)))
                        CurrSF$ = Left$(CurrSF$, Len(CurrSF$) - 1) 'removes sigil, if any
                        If Len(CurrSF$) = 0 Then Exit Do
                    Loop
                    CurrSF$ = UCase$(CurrSF$)

                    SkipCheckCurrSF:
                    If Asc(SubFuncLIST(CheckSF), 5) = 1 Then
                        CursorSF$ = "SUB "
                    Else
                        CursorSF$ = "FUNCTION "
                    End If
                    CursorSF$ = CursorSF$ + Mid$(SubFuncLIST(CheckSF), 6)

                    If UCase$(CursorSF$) = CurrSF$ Then
                        Exit For
                    Else
                        menu$(m, i) = "#Go To " + CursorSF$: i = i + 1
                        menuDesc$(m, i - 1) = "Jumps to procedure definition"
                        SubFuncLIST(1) = SubFuncLIST(CheckSF)
                        Exit For
                    End If
                End If
            Next CheckSF

            v = 0
            CurrSF$ = FindCurrentSF$(idecy)
            If validname(a2$) Then v = HashFind(a2$, HASHFLAG_LABEL, ignore, r)
            CheckThisLabel:
            If v Then
                LabelLineNumber = Labels(r).SourceLineNumber
                ThisLabelScope$ = FindCurrentSF$(LabelLineNumber)
                If ThisLabelScope$ <> CurrSF$ And v = 2 Then
                    v = HashFindCont(ignore, r)
                    GoTo CheckThisLabel
                End If
                If LabelLineNumber > 0 And LabelLineNumber <> idecy Then
                    menu$(m, i) = "Go To #Label " + RTrim$(Labels(r).cn): i = i + 1
                    menuDesc$(m, i - 1) = "Jumps to label"
                    ReDim _Preserve SubFuncLIST(1 To UBound(SubFuncLIST) + 1) As String
                    SubFuncLIST(UBound(SubFuncLIST)) = MKL$(Labels(r).SourceLineNumber)
                End If
            End If
        End If

        If Len(a2$) > 0 Then
            'check if a2$ is in help links
            lnks = 0
            'l2$ = findHelpTopic$(a2$, lnks, -1)

            If lnks Then
                If Len(l2$) > 15 Then
                    l2$ = Left$(l2$, 12) + String$(3, 250)
                End If
                If InStr(l2$, "PARENTHESIS") = 0 Then
                    menu$(m, i) = "#Help On '" + l2$ + "'": i = i + 1
                    menuDesc$(m, i - 1) = "Opens help article on the selected term"
                End If
            End If
        End If

        If i > 1 Then
            menu$(m, i) = "-": i = i + 1
        End If

        If (ideselect <> 0) Then
            menu$(m, i) = "Cu#t  Shift+Del or Ctrl+X": i = i + 1
            menuDesc$(m, i - 1) = "Deletes selected text and copies it to clipboard"
            menu$(m, i) = "#Copy  Ctrl+Ins or Ctrl+C": i = i + 1
            menuDesc$(m, i - 1) = "Copies selected text to clipboard"
        End If

        clip$ = _Clipboard$ 'read clipboard
        If Len(clip$) Then
            menu$(m, i) = "#Paste  Shift+Ins or Ctrl+V": i = i + 1
            menuDesc$(m, i - 1) = "Inserts clipboard contents at current location"
        End If

        If ideselect Then
            menu$(m, i) = "Cl#ear  Del": i = i + 1
            menuDesc$(m, i - 1) = "Deletes selected text"
        End If
        menu$(m, i) = "Select #All  Ctrl+A": i = i + 1
        menuDesc$(m, i - 1) = "Selects all contents of current program"
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "To#ggle Comment  Ctrl+T": i = i + 1
        menuDesc$(m, i - 1) = "Toggles comment (') on the current selection"
        menu$(m, i) = "Add Co#mment (')  Ctrl+R": i = i + 1
        menuDesc$(m, i - 1) = "Adds comment marker (') to the current selection"
        menu$(m, i) = "Remove Comme#nt (')  Ctrl+Shift+R": i = i + 1
        menuDesc$(m, i - 1) = "Removes comment marker (') from the current selection"
        If ideselect Then
            y1 = idecy
            y2 = ideselecty1
            If y1 = y2 Then 'single line selected
                a$ = idegetline(idecy)
                a2$ = ""
                sx1 = ideselectx1: sx2 = idecx
                If sx2 < sx1 Then Swap sx1, sx2
                For x = sx1 To sx2 - 1
                    If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
                Next
                If a2$ <> "" Then
                    menu$(m, i) = "#Increase Indent  TAB": i = i + 1
                    menuDesc$(m, i - 1) = "Increases indentation of the current selection"
                    menu$(m, i) = "#Decrease Indent"
                    menuDesc$(m, i) = "Decreases indentation of the current selection"
                    i = i + 1
                    menu$(m, i) = "-": i = i + 1
                End If
            Else
                menu$(m, i) = "#Increase Indent  TAB": i = i + 1
                menuDesc$(m, i - 1) = "Increases indentation of the current selection"
                menu$(m, i) = "#Decrease Indent"
                menuDesc$(m, i) = "Decreases indentation of the current selection"
                i = i + 1
                menu$(m, i) = "-": i = i + 1
            End If
        Else
            menu$(m, i) = "-": i = i + 1
        End If
        menu$(m, i) = "New #SUB...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new subprocedure at the end of the current program"
        menu$(m, i) = "New #FUNCTION...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new function at the end of the current program"
    End If
    menusize(m) = i - 1
End Sub

Sub IdeMakeEditMenu
    m = ideeditmenuID: i = 0
    menu$(m, i) = "Edit": i = i + 1

    If IdeSystem = 1 Then
        menu$(m, i) = "#Undo  Ctrl+Z": i = i + 1
        menuDesc$(m, i - 1) = "Restores program state before last edit"
        menu$(m, i) = "#Redo  Ctrl+Y": i = i + 1
        menuDesc$(m, i - 1) = "Redoes latest undo action"
    Else
        menu$(m, i) = "~#Undo  Ctrl+Z": i = i + 1
        menuDesc$(m, i - 1) = "Restores program state before last edit"
        menu$(m, i) = "~#Redo  Ctrl+Y": i = i + 1
        menuDesc$(m, i - 1) = "Redoes latest undo action"
    End If
    menu$(m, i) = "-": i = i + 1

    If (IdeSystem = 1 And ideselect = 1) Or IdeSystem = 2 Then
        menu$(m, i) = "Cu#t  Shift+Del or Ctrl+X": i = i + 1
        menuDesc$(m, i - 1) = "Deletes selected text and copies it to clipboard"
        menu$(m, i) = "#Copy  Ctrl+Ins or Ctrl+C": i = i + 1
        menuDesc$(m, i - 1) = "Copies selected text to clipboard"
    Else
        menu$(m, i) = "~Cu#t  Shift+Del or Ctrl+X": i = i + 1
        menuDesc$(m, i - 1) = "Deletes selected text and copies it to clipboard"
        menu$(m, i) = "~#Copy  Ctrl+Ins or Ctrl+C": i = i + 1
        menuDesc$(m, i - 1) = "Copies selected text to clipboard"
    End If

    clip$ = _Clipboard$ 'read clipboard
    If (Len(clip$) > 0 And IdeSystem = 1) Or IdeSystem = 2 Then
        menu$(m, i) = "#Paste  Shift+Ins or Ctrl+V": i = i + 1
        menuDesc$(m, i - 1) = "Inserts clipboard contents at current location"
    Else
        menu$(m, i) = "~#Paste  Shift+Ins or Ctrl+V": i = i + 1
        menuDesc$(m, i - 1) = "Inserts clipboard contents at current location"
    End If

    If (IdeSystem = 1 And ideselect = 1) Or IdeSystem = 2 Then
        menu$(m, i) = "Cl#ear  Del": i = i + 1
        menuDesc$(m, i - 1) = "Deletes selected text"
    Else
        menu$(m, i) = "~Cl#ear  Del": i = i + 1
        menuDesc$(m, i - 1) = "Deletes selected text"
    End If

    menu$(m, i) = "Select #All  Ctrl+A": i = i + 1
    menuDesc$(m, i - 1) = "Selects all contents of current program"

    If IdeSystem = 1 Then
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "To#ggle Comment  Ctrl+T": i = i + 1
        menuDesc$(m, i - 1) = "Toggles comment (') on the current selection"
        menu$(m, i) = "Add Co#mment (')  Ctrl+R": i = i + 1
        menuDesc$(m, i - 1) = "Adds comment marker (') to the current selection"
        menu$(m, i) = "Remove Comme#nt (')  Ctrl+Shift+R": i = i + 1
        menuDesc$(m, i - 1) = "Removes comment marker (') from the current selection"
        If ideselect Then
            y1 = idecy
            y2 = ideselecty1
            If y1 = y2 Then 'single line selected
                a$ = idegetline(idecy)
                a2$ = ""
                sx1 = ideselectx1: sx2 = idecx
                If sx2 < sx1 Then Swap sx1, sx2
                For x = sx1 To sx2 - 1
                    If x <= Len(a$) Then a2$ = a2$ + Mid$(a$, x, 1) Else a2$ = a2$ + " "
                Next
                If a2$ = "" Then
                    menu$(m, i) = "~#Increase Indent  TAB": i = i + 1
                    menuDesc$(m, i - 1) = "Increases indentation of the current selection"
                    menu$(m, i) = "~#Decrease Indent"
                    menuDesc$(m, i) = "Decreases indentation of the current selection"
                    i = i + 1
                Else
                    menu$(m, i) = "#Increase Indent  TAB": i = i + 1
                    menuDesc$(m, i - 1) = "Increases indentation of the current selection"
                    menu$(m, i) = "#Decrease Indent"
                    menuDesc$(m, i) = "Decreases indentation of the current selection"
                    i = i + 1
                End If
            Else
                menu$(m, i) = "#Increase Indent  TAB": i = i + 1
                menuDesc$(m, i - 1) = "Increases indentation of the current selection"
                menu$(m, i) = "#Decrease Indent"
                menuDesc$(m, i) = "Decreases indentation of the current selection"
                i = i + 1
            End If
        Else
            menu$(m, i) = "~#Increase Indent  TAB": i = i + 1
            menuDesc$(m, i - 1) = "Increases indentation of the current selection"
            menu$(m, i) = "~#Decrease Indent"
            menuDesc$(m, i) = "Decreases indentation of the current selection"
            i = i + 1
        End If
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "New #SUB...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new subprocedure at the end of the current program"
        menu$(m, i) = "New #FUNCTION...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new function at the end of the current program"
    Else
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "~To#ggle Comment  Ctrl+T": i = i + 1
        menuDesc$(m, i - 1) = "Toggles comment (') on the current selection"
        menu$(m, i) = "~Add Co#mment (')  Ctrl+R": i = i + 1
        menuDesc$(m, i - 1) = "Adds comment marker (') to the current selection"
        menu$(m, i) = "~Remove Comme#nt (')  Ctrl+Shift+R": i = i + 1
        menuDesc$(m, i - 1) = "Removes comment marker (') from the current selection"
        menu$(m, i) = "~#Increase Indent  TAB": i = i + 1
        menuDesc$(m, i - 1) = "Increases indentation of the current selection"
        menu$(m, i) = "~#Decrease Indent"
        menuDesc$(m, i) = "Decreases indentation of the current selection"
        i = i + 1
        menu$(m, i) = "-": i = i + 1
        menu$(m, i) = "~New #SUB...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new subprocedure at the end of the current program"
        menu$(m, i) = "~New #FUNCTION...": i = i + 1
        menuDesc$(m, i - 1) = "Creates a new function at the end of the current program"
    End If
    menusize(m) = i - 1
End Sub

Sub IdeAddRecent (f2$)
    f$ = f2$
    f$ = removeDoubleSlashes(f$)
    f$ = CRLF + f$ + CRLF
    fh = FreeFile
    Open ".\internal\temp\recent.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    x = InStr(UCase$(a$), UCase$(f$))
    If x Then
        a$ = f$ + Left$(a$, x - 1) + Right$(a$, Len(a$) - (x + Len(f$) - 1))
    Else
        a$ = f$ + a$
    End If
    Put #fh, 1, a$
    Close #fh
    IdeMakeFileMenu
End Sub

Function removeDoubleSlashes$ (f$)
    x = InStr(f$, "//")
    Do While x
        f$ = Left$(f$, x - 1) + Mid$(f$, x + 1)
        x = InStr(f$, "//")
    Loop
    x = InStr(f$, "\\")
    Do While x
        f$ = Left$(f$, x - 1) + Mid$(f$, x + 1)
        x = InStr(f$, "\\")
    Loop
    removeDoubleSlashes$ = f$
End Function

Sub IdeAddSearched (s2$)
    s$ = CRLF + s2$ + CRLF
    fh = FreeFile
    Open ".\internal\temp\searched.bin" For Binary As #fh: a$ = Space$(LOF(fh)): Get #fh, , a$
    x = InStr(UCase$(a$), UCase$(s$))
    If x Then
        a$ = s$ + Left$(a$, x - 1) + Right$(a$, Len(a$) - (x + Len(s$) - 1))
    Else
        a$ = s$ + a$
    End If
    Put #fh, 1, a$
    Close #fh
End Sub

'After Cormen, Leiserson, Rivest & Stein "Introduction To Algoritms" via Wikipedia
Sub sort (arr() As String * 998)
    For i& = LBound(arr) + 1 To UBound(arr)
        x$ = arr(i&)
        j& = i& - 1
        While j& >= LBound(arr)
            If arr(j&) <= x$ Then Exit While
            arr$(j& + 1) = arr$(j&)
            j& = j& - 1
        Wend
        arr$(j& + 1) = x$
    Next i&
End Sub

Function FindProposedTitle$
    'Finds the first occurence of _TITLE to suggest a file name
    'when saving for the first time or saving as.
    Dim c As _Byte, q As _Byte, i
    For i = 1 To iden
        thisline$ = idegetline(i)
        thisline$ = LTrim$(RTrim$(thisline$))
        found_TITLE = InStr(UCase$(thisline$), "_TITLE " + Chr$(34))
        If found_TITLE > 0 Then
            FindQuoteComment thisline$, found_TITLE, c, q
            If Not q Then
                Find_ClosingQuote = InStr(found_TITLE + 8, thisline$, Chr$(34))
                If Find_ClosingQuote > 0 Then
                    TempFound_TITLE$ = Mid$(thisline$, found_TITLE + 8, (Find_ClosingQuote - found_TITLE) - 8)
                End If
                Exit For
            End If
        End If
    Next
    InvalidChars$ = ":/\?*><|" + Chr$(34)
    For i = 1 To Len(TempFound_TITLE$)
        ThisChar$ = Mid$(TempFound_TITLE$, i, 1)
        If InStr(InvalidChars$, ThisChar$) = 0 Then
            Found_TITLE$ = Found_TITLE$ + ThisChar$
        End If
    Next i
    FindProposedTitle$ = LTrim$(RTrim$(Found_TITLE$))
End Function

Function FindCurrentSF$ (whichline)
    'Get the SUB/FUNCTION name 'whichline' is in.
    'The FOR...NEXT loop goes backwards from 'whichline' to the start of the program
    'to see if we're inside a SUB/FUNCTION. EXITs FOR once that is figured.

    sfname$ = ""
    If whichline > 0 Then
        For currSF_CHECK = whichline To 1 Step -1
            thisline$ = idegetline(currSF_CHECK)
            thisline$ = LTrim$(RTrim$(thisline$))
            isSF = 0
            ncthisline$ = UCase$(thisline$)
            If Left$(ncthisline$, 4) = "SUB " Then isSF = 1
            If Left$(ncthisline$, 9) = "FUNCTION " Then isSF = 2
            If Left$(ncthisline$, 7) = "END SUB" And currSF_CHECK < whichline Then Exit For
            If Left$(ncthisline$, 12) = "END FUNCTION" And currSF_CHECK < whichline Then Exit For
            If isSF Then
                If Right$(ncthisline$, 7) = " STATIC" Then
                    thisline$ = RTrim$(Left$(thisline$, Len(thisline$) - 7))
                End If

                If isSF = 1 Then
                    thisline$ = Right$(thisline$, Len(thisline$) - 4)
                Else
                    thisline$ = Right$(thisline$, Len(thisline$) - 9)
                End If
                thisline$ = LTrim$(RTrim$(thisline$))
                checkargs = InStr(thisline$, "(")
                If checkargs Then
                    sfname$ = RTrim$(Left$(thisline$, checkargs - 1))
                Else
                    sfname$ = thisline$
                End If

                'It could be that SUB or FUNCTION is inside a DECLARE LIBRARY.
                'In such case, it must be ignored:
                InsideDECLARE = 0
                For declib_CHECK = currSF_CHECK To 1 Step -1
                    thisline$ = idegetline(declib_CHECK)
                    thisline$ = LTrim$(RTrim$(thisline$))
                    ncthisline$ = UCase$(thisline$)
                    If Left$(ncthisline$, 8) = "DECLARE " And InStr(ncthisline$, " LIBRARY") > 0 Then InsideDECLARE = -1: Exit For
                    If Left$(ncthisline$, 11) = "END DECLARE" Then Exit For
                Next

                If InsideDECLARE = -1 Then
                    sfname$ = ""
                Else
                    'Ok, we're not inside a DECLARE LIBRARY block.
                    'But what if we're past the end of this module's SUBs and FUNCTIONs,
                    'and all that's left is a bunch of comments or $INCLUDES?
                    'We'll also check for that:
                    endedSF = 0
                    For endSF_CHECK = whichline To iden
                        thisline$ = idegetline(endSF_CHECK)
                        thisline$ = LTrim$(RTrim$(thisline$))
                        ncthisline$ = UCase$(thisline$)
                        If Left$(ncthisline$, 7) = "END SUB" Then endedSF = 1: Exit For
                        If Left$(ncthisline$, 12) = "END FUNCTION" Then endedSF = 2: Exit For
                        If Left$(ncthisline$, 4) = "SUB " And endSF_CHECK = whichline Then endedSF = 1: Exit For
                        If Left$(ncthisline$, 9) = "FUNCTION " And endSF_CHECK = whichline Then endedSF = 2: Exit For
                        If Left$(ncthisline$, 4) = "SUB " And InsideDECLARE = 0 Then Exit For
                        If Left$(ncthisline$, 9) = "FUNCTION " And InsideDECLARE = 0 Then Exit For
                        If Left$(ncthisline$, 8) = "DECLARE " And InStr(ncthisline$, " LIBRARY") > 0 Then InsideDECLARE = -1
                        If Left$(ncthisline$, 11) = "END DECLARE" Then InsideDECLARE = 0
                    Next
                    If endedSF = 0 Then sfname$ = "" Else Exit For
                End If
            End If
        Next
    End If

    FindCurrentSF$ = sfname$
End Function

Sub AddQuickNavHistory
    If QuickNavTotal > 0 Then
        If QuickNavHistory(QuickNavTotal).idecy = idecy Then Exit Sub
    End If
    QuickNavTotal = QuickNavTotal + 1
    ReDim _Preserve QuickNavHistory(1 To QuickNavTotal) As QuickNavType
    QuickNavHistory(QuickNavTotal).idecy = idecy
    QuickNavHistory(QuickNavTotal).idecx = idecx
    QuickNavHistory(QuickNavTotal).idesy = idesy
    QuickNavHistory(QuickNavTotal).idesx = idesx
End Sub

Sub UpdateIdeInfo
    'show info message (if any)
    If Len(IdeInfo) Then
        If Asc(IdeInfo, 1) = 0 Then
            'Show progress bar
            IdeInfo = Mid$(IdeInfo, 2)
            Percentage% = Val(Mid$(IdeInfo, 1, 3))
            Color 13, 1
            _PrintString (2, idewy - 1), String$(((idewx - 2) * Percentage%) / 100, "_")
        End If
    End If
    a$ = IdeInfo
    If Len(a$) > (idewx - 20) Then a$ = Left$(a$, (idewx - 23)) + String$(3, 250)
    If Len(a$) < (idewx - 20) Then a$ = a$ + Space$((idewx - 20) - Len(a$))
    Color 0, 3
    _PrintString (2, idewy + idesubwindow), a$
    If Len(versionStringStatus$) = 0 Then
        versionStringStatus$ = " v" + Version$
        If Len(AutoBuildMsg$) Then versionStringStatus$ = versionStringStatus$ + Mid$(AutoBuildMsg$, _InStrRev(AutoBuildMsg$, " "))
        versionStringStatus$ = versionStringStatus$ + " "
    End If
    '_PRINTSTRING (idewx - 22 - LEN(versionStringStatus$), idewy + idesubwindow), CHR$(179)
    Color 2, 3
    _PrintString (idewx - 21 - Len(versionStringStatus$), idewy + idesubwindow), versionStringStatus$
    PCopy 3, 0
End Sub

Function DarkenFGBG (Action As _Byte)
    'Darken the interface while compilation is taking place,
    'to give a sense of temporary unavailability:
    If Action = 1 Then
        TempDarkerBGColor~& = _RGB32(_Red32(IDEBackgroundColor) * .5, _Green32(IDEBackgroundColor) * .5, _Blue32(IDEBackgroundColor) * .5)
        TempDarkerBG2Color~& = _RGB32(_Red32(IDEBackgroundColor2) * .5, _Green32(IDEBackgroundColor2) * .5, _Blue32(IDEBackgroundColor2) * .5)
        TempDarkerFGColor~& = _RGB32(_Red32(IDETextColor) * .5, _Green32(IDETextColor) * .5, _Blue32(IDETextColor) * .5)
        TempDarkerKWColor~& = _RGB32(_Red32(IDEKeywordColor) * .5, _Green32(IDEKeywordColor) * .5, _Blue32(IDEKeywordColor) * .5)
        TempDarkerNumColor~& = _RGB32(_Red32(IDENumbersColor) * .5, _Green32(IDENumbersColor) * .5, _Blue32(IDENumbersColor) * .5)
        TempDarkerCommentColor~& = _RGB32(_Red32(IDECommentColor) * .5, _Green32(IDECommentColor) * .5, _Blue32(IDECommentColor) * .5)
        TempDarkerIDEChromaColor~& = _RGB32(_Red32(IDEChromaColor) * .5, _Green32(IDEChromaColor) * .5, _Blue32(IDEChromaColor) * .5)
        TempDarkerMetaColor~& = _RGB32(_Red32(IDEMetaCommandColor) * .5, _Green32(IDEMetaCommandColor) * .5, _Blue32(IDEMetaCommandColor) * .5)
        TempDarkerQuoteColor~& = _RGB32(_Red32(IDEQuoteColor) * .5, _Green32(IDEQuoteColor) * .5, _Blue32(IDEQuoteColor) * .5)
        _PaletteColor 1, TempDarkerBGColor~&, 0
        _PaletteColor 5, TempDarkerBGColor~&, 0
        _PaletteColor 6, TempDarkerBG2Color~&, 0
        _PaletteColor 7, TempDarkerIDEChromaColor~&, 0
        _PaletteColor 8, TempDarkerNumColor~&, 0
        _PaletteColor 10, TempDarkerMetaColor~&, 0
        _PaletteColor 11, TempDarkerCommentColor~&, 0
        _PaletteColor 12, TempDarkerKWColor~&, 0
        _PaletteColor 13, TempDarkerFGColor~&, 0
        _PaletteColor 14, TempDarkerQuoteColor~&, 0
    Else
        _PaletteColor 1, IDEBackgroundColor, 0
        _PaletteColor 5, IDEBracketHighlightColor, 0
        _PaletteColor 6, IDEBackgroundColor2, 0
        _PaletteColor 7, IDEChromaColor, 0
        _PaletteColor 8, IDENumbersColor, 0
        _PaletteColor 10, IDEMetaCommandColor, 0
        _PaletteColor 11, IDECommentColor, 0
        _PaletteColor 12, IDEKeywordColor, 0
        _PaletteColor 13, IDETextColor, 0
        _PaletteColor 14, IDEQuoteColor, 0
    End If

    DarkenFGBG = 0
End Function

Sub HideBracketHighlight
    'Restore the screen and hide any bracket highlights
    'as we're limited to 16 colors and the highlight
    'color will be used differently in this dialog.
    oldBracketHighlightSetting = brackethighlight
    oldMultiHighlightSetting = multihighlight
    oldShowLineNumbersUseBG = ShowLineNumbersUseBG
    brackethighlight = 0
    multihighlight = 0
    ShowLineNumbersUseBG = 0
    Screen , , 0
    HideCurrentLineHighlight = -1
    ideshowtext
    HideCurrentLineHighlight = 0
    brackethighlight = oldBracketHighlightSetting
    multihighlight = oldMultiHighlightSetting
    ShowLineNumbersUseBG = oldShowLineNumbersUseBG
End Sub

Sub LoadColorSchemes
    Dim i As Long
    'Preset built-in schemes
    PresetColorSchemes = 10
    ReDim ColorSchemes$(1 To PresetColorSchemes): i = 0
    i = i + 1: ColorSchemes$(i) = "Super dark blue|216216216069118147216098078255167000085206085098098098000000039000049078000088108170170170"
    i = i + 1: ColorSchemes$(i) = "Dark blue|226226226069147216245128177255177000085255085049196196000000069000068108000147177170170170"
    i = i + 1: ColorSchemes$(i) = "QB64 Original|226226226147196235245128177255255085085255085085255255000000170000108177000147177170170170"
    i = i + 1: ColorSchemes$(i) = "Classic QB4.5|177177177177177177177177177177177177177177177177177177000000170000000170000147177170170170"
    i = i + 1: ColorSchemes$(i) = "CF Dark|226226226115222227255043138255178034185237049157118137043045037010000020088088088170170170"
    i = i + 1: ColorSchemes$(i) = "Dark side|255255255206206000245010098000177000085255085049186245011022029100100100000147177170170170"
    i = i + 1: ColorSchemes$(i) = "Camouflage|196196196255255255245128177255177000137177147147137020000039029098069020000147177170170170"
    i = i + 1: ColorSchemes$(i) = "Plum|186186186255255255245128177255108000085186078085186255059000059088088128000147177170170170"
    i = i + 1: ColorSchemes$(i) = "Light green|051051051000000216245128177255157255147177093206206206234255234206255206000147177170170170"
    i = i + 1: ColorSchemes$(i) = "All white|051051051000000216245128177206147000059177000206206206255255255245245245000147177170170170"
    TotalColorSchemes = PresetColorSchemes
    LastValidColorScheme = TotalColorSchemes

    'Load user color schemes
    i = 0
    Do
        i = i + 1
        result = ReadConfigSetting(colorSchemesSection$, "Scheme" + str2$(i) + "$", value$)
        If result Then
            TotalColorSchemes = TotalColorSchemes + 1
            If TotalColorSchemes > UBound(ColorSchemes$) Then
                ReDim _Preserve ColorSchemes$(1 To UBound(ColorSchemes$) + 10)
            End If
            ColorSchemes$(TotalColorSchemes) = value$
            FoundPipe = InStr(value$, "|")
            If FoundPipe > 0 Then
                If Len(Mid$(value$, FoundPipe + 1)) = 81 Then
                    'Extended schemes (9 colors):
                    LastValidColorScheme = TotalColorSchemes
                    value$ = value$ + "170170170"
                    WriteConfigSetting colorSchemesSection$, "Scheme" + str2$(i) + "$", value$
                    ColorSchemes$(TotalColorSchemes) = value$
                ElseIf Len(Mid$(value$, FoundPipe + 1)) = 90 Then
                    'Extended schemes (10 colors):
                    LastValidColorScheme = TotalColorSchemes
                ElseIf Len(Mid$(value$, FoundPipe + 1)) = 54 Then
                    'Version 1.1 schemes (only 6 colors)
                    'Convert to extended scheme:
                    temp$ = Left$(value$, FoundPipe)
                    temp$ = temp$ + Mid$(value$, FoundPipe + 1, 9) + "069147216245128177"
                    temp$ = temp$ + Mid$(value$, FoundPipe + 10) + "000147177170170170"
                    ColorSchemes$(TotalColorSchemes) = temp$
                    WriteConfigSetting colorSchemesSection$, "Scheme" + str2$(i) + "$", temp$
                    LastValidColorScheme = TotalColorSchemes
                Else
                    GoTo DiscardInvalid
                End If
            Else
                DiscardInvalid:
                ColorSchemes$(TotalColorSchemes) = "0"
            End If
        Else
            'No more schemes found
            Exit Do
        End If
    Loop
    'End of color schemes
End Sub

Function removesymbol2$ (varname$)
    i = InStr(varname$, "~"): If i Then GoTo foundsymbol
    i = InStr(varname$, "`"): If i Then GoTo foundsymbol
    i = InStr(varname$, "%"): If i Then GoTo foundsymbol
    i = InStr(varname$, "&"): If i Then GoTo foundsymbol
    i = InStr(varname$, "!"): If i Then GoTo foundsymbol
    i = InStr(varname$, "#"): If i Then GoTo foundsymbol
    i = InStr(varname$, "$"): If i Then GoTo foundsymbol
    removesymbol2$ = varname$
    Exit Function
    foundsymbol:
    If i = 1 Then removesymbol2$ = varname$: Exit Function
    removesymbol2$ = Left$(varname$, i - 1)
End Function

Sub cleanSubName (n$)
    x = InStr(n$, "'"): If x Then n$ = Left$(n$, x - 1)
    x = InStr(n$, ":"): If x Then n$ = Left$(n$, x - 1)
    x = InStr(n$, " "): If x Then n$ = Left$(n$, x - 1)
End Sub

Sub clearStatusWindow (whichLine)
    Color 7, 1
    If whichLine = 0 Then
        For whichLine = 1 To 3
            _PrintString (2, (idewy - 4) + whichLine), Space$(idewx - 2)
        Next
    Else
        _PrintString (2, (idewy - 4) + whichLine), Space$(idewx - 2)
    End If
End Sub

Sub setStatusMessage (row, text$, fg)
    Color fg
    _PrintString (2, (idewy - 4) + row), text$
    PCopy 3, 0
End Sub

Function getWordAtCursor$
    a$ = idegetline(idecy)
    x = idecx
    If x <= Len(a$) Then
        If Asc(a$, x) = 32 And x > 1 Then
            If Asc(a$, x - 1) <> 32 Then x = x - 1
        End If
        try:
        If alphanumeric(Asc(a$, x)) Then
            x1 = x
            Do While x1 > 1
                If alphanumeric(Asc(a$, x1 - 1)) Or Asc(a$, x1 - 1) = 36 Then x1 = x1 - 1 Else Exit Do
            Loop
            x2 = x
            Do While x2 < Len(a$)
                If alphanumeric(Asc(a$, x2 + 1)) Or Asc(a$, x2 + 1) = 36 Then x2 = x2 + 1 Else Exit Do
            Loop
            a2$ = Mid$(a$, x1, x2 - x1 + 1)
        Else
            symbol$ = Chr$(Asc(a$, x))
            If symbol$ = Chr$(32) Then Exit Function
            If symbol$ = "~" Then getWordAtCursor$ = "~": Exit Function
            If symbol$ = "`" Then getWordAtCursor$ = "`": Exit Function
            If symbol$ = "%" And Mid$(a$, x + 1) = "&" Then getWordAtCursor$ = "%&": Exit Function
            If symbol$ = "&" And Mid$(a$, x - 1) = "%" Then getWordAtCursor$ = "%&": Exit Function
            x1 = x
            Do While x1 > 1
                If Mid$(a$, x1 - 1, 1) = symbol$ Then x1 = x1 - 1 Else Exit Do
            Loop
            x2 = x
            Do While x2 < Len(a$)
                If Mid$(a$, x2 + 1, 1) = symbol$ Then x2 = x2 + 1 Else Exit Do
            Loop
            a2$ = Mid$(a$, x1, x2 - x1 + 1)
        End If
        getWordAtCursor$ = a2$ 'a2$ now holds the word or character at current cursor position
    ElseIf x = Len(a$) + 1 And x > 1 Then
        If Asc(a$, x - 1) <> 32 Then x = x - 1: GoTo try
    End If
End Function

Function getSelectedText$ (multiline As _Byte)
    If ideselect Then
        sy1 = ideselecty1
        sy2 = idecy
        If sy1 > sy2 Then Swap sy1, sy2
        sx1 = ideselectx1
        sx2 = idecx
        If sx1 > sx2 Then Swap sx1, sx2
        For y = sy1 To sy2
            If y <= iden Then
                a$ = idegetline(y)
                If sy1 = sy2 Then 'single line select
                    For x = sx1 To sx2 - 1
                        If x <= Len(a$) Then clip$ = clip$ + Mid$(a$, x, 1) Else clip$ = clip$ + " "
                    Next
                Else 'multiline select
                    If Not multiline Then Exit Function
                    If idecx = 1 And y = sy2 And idecy > sy1 Then GoTo nofinalcopy
                    clip$ = clip$ + a$ + Chr$(13) + Chr$(10)
                    nofinalcopy:
                    If y = sy2 And idecx > 1 And Len(a$) > 0 Then clip$ = Left$(clip$, Len(clip$) - 2)
                End If
            End If
        Next
        getSelectedText$ = clip$
    End If
End Function

Sub delselect
    sy1 = ideselecty1
    sy2 = idecy
    If sy1 > sy2 Then Swap sy1, sy2
    sx1 = ideselectx1
    sx2 = idecx
    If sx1 > sx2 Then Swap sx1, sx2
    nolastlinedel = 0
    If sy1 <> sy2 And idecx = 1 And idecy > sy1 Then sy2 = sy2 - 1: nolastlinedel = 1 'ignore last line of multi-line select?

    For y = sy2 To sy1 Step -1
        If sy1 = sy2 And nolastlinedel = 0 Then 'single line select
            a$ = idegetline(y)
            a2$ = ""
            If sx1 <= Len(a$) Then a2$ = Left$(a$, sx1 - 1) Else a2$ = a$
            If sx2 <= Len(a$) Then a2$ = a2$ + Right$(a$, Len(a$) - sx2 + 1)
            idesetline y, a2$
        Else 'multiline select
            If iden = 1 And y = 1 Then idesetline y, "" Else idedelline y
        End If
    Next

    idecx = sx1: If sy1 <> sy2 Or nolastlinedel = 1 Then idecx = 1
    idecy = sy1
    ideselect = 0
End Sub

Sub insertAtCursor (tempk$)
    'insert
    If ideselect Then delselect
    a$ = idegetline(idecy)
    If Len(a$) < idecx - 1 Then a$ = a$ + Space$(idecx - 1 - Len(a$))
    a$ = Left$(a$, idecx - 1) + tempk$ + Right$(a$, Len(a$) - idecx + 1)
    idesetline idecy, converttabs$(a$)

    If PasteCursorAtEnd Then
        'Place the cursor at the end of the inserted content:
        idecx = idecx + Len(tempk$)
    End If

    idechangemade = 1
End Sub

Function isnumber (__a$)
    a$ = UCase$(__a$)
    If Len(a$) = 0 Then Exit Function

    If InStr("@&H@&O@&B@", "@" + Left$(a$, 2) + "@") Then isnumber = 1: Exit Function

    i = InStr(a$, "~"): If i Then GoTo foundsymbol
    i = InStr(a$, "`"): If i Then GoTo foundsymbol
    i = InStr(a$, "%"): If i Then GoTo foundsymbol
    i = InStr(a$, "&"): If i Then GoTo foundsymbol
    i = InStr(a$, "!"): If i Then GoTo foundsymbol
    i = InStr(a$, "#"): If i Then GoTo foundsymbol
    i = InStr(a$, "$"): If i Then GoTo foundsymbol
    GoTo proceedWithoutSymbol
    foundsymbol:
    If i = 1 Then Exit Function
    symbol$ = Right$(a$, Len(a$) - i + 1)
    If symboltype(symbol$) = 0 Then Exit Function
    a$ = Left$(a$, i - 1)

    proceedWithoutSymbol:
    ff = 0
    ee = 0
    dd = 0
    neg = 0
    For i = 1 To Len(a$)
        a = Asc(a$, i)
        If a = 45 Then
            If (i = 1 And Len(a$) > 1) Or (i > 1 And ((dd > 0 And dd = i - 1) Or (ee > 0 And ee = i - 1) Or (ff > 0 And ff = i - 1))) Then neg = (i = 1): _Continue
            Exit Function
        End If
        If a = 46 Then
            If dp = 1 Then Exit Function
            dp = 1
            _Continue
        End If
        If a = 68 Then 'dD
            If dd > 0 Or ee > 0 Or ff > 0 Then Exit Function
            dd = i
            If neg <> 0 And dd = 2 Then Exit Function
            _Continue
        End If
        If a = 69 Then 'eE
            If dd > 0 Or ee > 0 Or ff > 0 Then Exit Function
            ee = i
            If neg <> 0 And ee = 2 Then Exit Function
            _Continue
        End If
        If a = 70 Then 'fF
            If dd > 0 Or ee > 0 Or ff > 0 Then Exit Function
            ff = i
            If neg <> 0 And ff = 2 Then Exit Function
            _Continue
        End If
        If a = 43 Then '+
            If (dd > 0 And dd = i - 1) Or (ee > 0 And ee = i - 1) Or (ff > 0 And ff = i - 1) Then _Continue
            Exit Function
        End If

        If a >= 48 And a <= 57 Then _Continue
        Exit Function
    Next
    isnumber = 1
End Function

Sub purgeprecompiledcontent
    ChDir "./internal/c"
    Shell _Hide "./purge_all_precompiled_content_lnx.sh"
    ChDir "../.."
End Sub

Sub printWrapStatus (x As Integer, y As Integer, initialX As Integer, __text$)
    Dim text$, nextWord$
    Dim As Integer i, findSep, findColorMarker, changeColor, changeColorAfter
    text$ = __text$

    Locate y, x
    Do While Len(_Trim$(text$))
        findSep = InStr(text$, " ")
        If findSep Then
            nextWord$ = Left$(text$, findSep)
        Else
            findSep = Len(text$)
            nextWord$ = text$
        End If
        text$ = Mid$(text$, findSep + 1)
        If Pos(0) + Len(nextWord$) > _Width Then
            If CsrLin + 1 <= (idewy - 4) + 3 Then
                Locate CsrLin + 1, initialX
            Else
                'no more room for printing
                Exit Sub
            End If
        End If

        changeColor = 0
        changeColorAfter = 0
        skipSpace = 0
        For i = 0 To 2
            findColorMarker = InStr(nextWord$, Chr$(i))
            If findColorMarker = 1 Then
                nextWord$ = Mid$(nextWord$, 2)
                changeColor = i + 1
                GoSub applyColorChange
            ElseIf findColorMarker > 0 Then
                nextWord$ = Left$(nextWord$, findColorMarker - 1) + Mid$(nextWord$, findColorMarker + 1)
                If Right$(nextWord$, 1) = " " Then
                    nextWord$ = RTrim$(nextWord$)
                    skipSpace = -1
                End If
                changeColorAfter = i + 1
            End If
        Next

        Print nextWord$;

        If changeColorAfter Then
            changeColor = changeColorAfter
            GoSub applyColorChange
            If skipSpace Then Locate , Pos(0) + 1
        End If
    Loop
    Exit Sub

    applyColorChange:
    Select EveryCase changeColor
        Case 1
            If _DefaultColor <> 11 Then Color 11 Else Color 7
        Case 2
            Color 7, 1
        Case 3
            Color 12, 6
    End Select
    Return
End Sub

Function GetBytes$ (__value$, numberOfBytes&)
    Static previousValue$, getBytesPosition&

    value$ = __value$
    If value$ <> previousValue$ Then
        previousValue$ = value$
        getBytesPosition& = 1
    End If

    If numberOfBytes& = 0 Then Exit Function

    GetBytes$ = Mid$(value$, getBytesPosition&, numberOfBytes&)
    getBytesPosition& = getBytesPosition& + numberOfBytes&
End Function
